@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 2003 - 2007	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 2003 - 2008	David A. Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -55,7 +55,7 @@
 #endif
 #define SECTION "setup"
 
-static const char *faceColorString[MAXCOLORS] =
+static const char *faceColorString[MAX_COLORS] =
 {
 	"0 255 0",
 	"255 0 0",
@@ -65,7 +65,7 @@ static const char *faceColorString[MAXCOLORS] =
 	"0 0 0"
 };
 
-static char faceColorChar[MAXCOLORS] =
+static char faceColorChar[MAX_COLORS] =
 {'G', 'R', 'Y', 'O', 'B', 'b'};
 #else
 #include "picture.h"
@@ -275,7 +275,7 @@ static XtResource resourcesPuzzle[] =
 	 XtRString, (caddr_t) PICTURE},
 	{XtNdelay, XtCDelay, XtRInt, sizeof (int),
 	 XtOffset(BarrelWidget, barrel.delay),
-	 XtRString, (caddr_t) "10"}, /* DEFAULTDELAY */
+	 XtRString, (caddr_t) "10"}, /* DEFAULT_DELAY */
 	{XtNsound, XtCSound, XtRBoolean, sizeof (Boolean),
 	 XtOffset(BarrelWidget, barrel.sound),
 	 XtRString, (caddr_t) "FALSE"},
@@ -290,22 +290,22 @@ static XtResource resourcesPuzzle[] =
 	 XtRString, (caddr_t) "9x15bold"},
 	{XtNtiles, XtCTiles, XtRInt, sizeof (int),
 	 XtOffset(BarrelWidget, barrel.tiles),
-	 XtRString, (caddr_t) "6"}, /* DEFAULTTILES */
+	 XtRString, (caddr_t) "6"}, /* DEFAULT_TILES */
 	{XtNfaces, XtCFaces, XtRInt, sizeof (int),
 	 XtOffset(BarrelWidget, barrel.faces),
-	 XtRString, (caddr_t) "5"}, /* DEFAULTFACES */
+	 XtRString, (caddr_t) "5"}, /* DEFAULT_FACES */
 	{XtNorient, XtCOrient, XtRBoolean, sizeof (Boolean),
 	 XtOffset(BarrelWidget, barrel.orient),
-	 XtRString, (caddr_t) "FALSE"}, /* DEFAULTORIENT */
+	 XtRString, (caddr_t) "FALSE"}, /* DEFAULT_ORIENT */
 	{XtNpairs, XtCPairs, XtRBoolean, sizeof (Boolean),
 	 XtOffset(BarrelWidget, barrel.pairs),
-	 XtRString, (caddr_t) "TRUE"}, /* DEFAULTPAIRS */
+	 XtRString, (caddr_t) "TRUE"}, /* DEFAULT_PAIRS */
 	{XtNpractice, XtCPractice, XtRBoolean, sizeof (Boolean),
 	 XtOffset(BarrelWidget, barrel.practice),
-	 XtRString, (caddr_t) "TRUE"}, /* DEFAULTPRACTICE */
+	 XtRString, (caddr_t) "TRUE"}, /* DEFAULT_PRACTICE */
 	{XtNbase, XtCBase, XtRInt, sizeof (int),
 	 XtOffset(BarrelWidget, barrel.base),
-	 XtRString, (caddr_t) "10"}, /* DEFAULTBASE */
+	 XtRString, (caddr_t) "10"}, /* DEFAULT_BASE */
 	{XtNuserName, XtCUserName, XtRString, sizeof (String),
 	 XtOffset(BarrelWidget, barrel.userName),
 	 XtRString, (caddr_t) ""},
@@ -439,47 +439,47 @@ CheckTiles(BarrelWidget w)
 {
 	char *buf1 = NULL, *buf2 = NULL;
 
-	if (w->barrel.tiles < MINTILES) {
+	if (w->barrel.tiles < MIN_TILES) {
 		intCat(&buf1,
 			"Number of tiles in X direction out of bounds, use at least ",
-			MINTILES);
+			MIN_TILES);
 		stringCat(&buf2, buf1, ", defaulting to ");
 		free(buf1);
-		intCat(&buf1, buf2, DEFAULTTILES);
+		intCat(&buf1, buf2, DEFAULT_TILES);
 		free(buf2);
 		DISPLAY_WARNING(buf1);
 		free(buf1);
-		w->barrel.tiles = DEFAULTTILES;
+		w->barrel.tiles = DEFAULT_TILES;
 	}
-	if (w->barrel.faces < MINFACES || w->barrel.faces > MAXFACES) {
+	if (w->barrel.faces < MIN_FACES || w->barrel.faces > MAX_FACES) {
 		intCat(&buf1,
 			"Number of faces out of bounds, use ",
-			MINFACES);
+			MIN_FACES);
 		stringCat(&buf2, buf1, "..");
 		free(buf1);
-		intCat(&buf1, buf2, MAXFACES);
+		intCat(&buf1, buf2, MAX_FACES);
 		free(buf2);
 		stringCat(&buf2, buf1, ", defaulting to ");
 		free(buf1);
-		intCat(&buf1, buf2, DEFAULTFACES);
+		intCat(&buf1, buf2, DEFAULT_FACES);
 		free(buf2);
 		DISPLAY_WARNING(buf1);
 		free(buf1);
-		w->barrel.faces = DEFAULTFACES;
+		w->barrel.faces = DEFAULT_FACES;
 	}
-	if (w->barrel.base < MINBASE || w->barrel.base > MAXBASE) {
-		intCat(&buf1, "Base out of bounds, use ", MINBASE);
+	if (w->barrel.base < MIN_BASE || w->barrel.base > MAX_BASE) {
+		intCat(&buf1, "Base out of bounds, use ", MIN_BASE);
 		stringCat(&buf2, buf1, "..");
 		free(buf1);
-		intCat(&buf1, buf2, MAXBASE);
+		intCat(&buf1, buf2, MAX_BASE);
 		free(buf2);
 		stringCat(&buf2, buf1, ", defaulting to ");
 		free(buf1);
-		intCat(&buf1, buf2, DEFAULTBASE);
+		intCat(&buf1, buf2, DEFAULT_BASE);
 		free(buf2);
 		DISPLAY_WARNING(buf1);
 		free(buf1);
-		w->barrel.base = DEFAULTBASE;
+		w->barrel.base = DEFAULT_BASE;
 	}
 }
 
@@ -599,11 +599,11 @@ TilePicture(BarrelWidget w, int tile)
 		if (tile < inc)
 			return tile + 2 * face + 1;
 	}
-	for (face = 0; face < NUMPLUNGERS; face++) {
+	for (face = 0; face < PLUNGERS_NUMBER; face++) {
 		if (tile == inc++)
 			return (face * 2 + 1) * w->barrel.tiles - 1;
 	}
-	for (face = 0; face < w->barrel.faces - NUMPLUNGERS; face++) {
+	for (face = 0; face < w->barrel.faces - PLUNGERS_NUMBER; face++) {
 		if (tile == inc++)
 			return (2 * face + 1) * w->barrel.tiles;
 		if (tile == inc++)
@@ -630,7 +630,7 @@ PrintPuzzle(BarrelWidget w)
 		}
 	}
 	(void) printf("\n");
-	for (plunger = 0; plunger < NUMPLUNGERS; plunger++) {
+	for (plunger = 0; plunger < PLUNGERS_NUMBER; plunger++) {
 		(void) printf("%d: %d\n", plunger,
 			w->barrel.spacePosition[plunger]);
 	}
@@ -742,7 +742,7 @@ DrawTile(BarrelWidget w, int pos, Boolean blank, Boolean erase,
 	sy = CartesianY(w, tile);
 	if (blank) {
 		FILLRECTANGLE(w, dr,
-			(erase) ? w->barrel.inverseGC : w->barrel.tileGC,
+			(erase) ? w->barrel.inverseGC : w->barrel.tileGC[1],
 			dx, dy,
 			w->barrel.tileSize.x, w->barrel.tileSize.y);
 		return;
@@ -758,11 +758,11 @@ DrawTile(BarrelWidget w, int pos, Boolean blank, Boolean erase,
 		SRCCOPY);
 	(void) SelectObject(w->core.memDC, w->core.hOldBitmap);
 #else
-	XSetGraphicsExposures(XtDisplay(w), w->barrel.tileGC, False);
+	XSetGraphicsExposures(XtDisplay(w), w->barrel.tileGC[1], False);
 	XCopyArea(XtDisplay(w),
 		w->barrel.bufferTiles[pressedOffset],
 		XtWindow(w),
-		w->barrel.tileGC,
+		w->barrel.tileGC[1],
 		sx, sy,
 		w->barrel.tileSize.x, w->barrel.tileSize.y,
 		dx, dy);
@@ -779,12 +779,12 @@ DrawBufferedTile(BarrelWidget w, int pos, int pressedOffset)
 	char buf[66];
 
 	dr = &(w->barrel.bufferTiles[pressedOffset]);
-	tileGC = w->barrel.tileGC;
+	tileGC = w->barrel.tileGC[1];
 	borderGC = w->barrel.borderGC;
 	if ((w->barrel.mono && pressedOffset) || tile <= 0) {
 		ballGC = borderGC;
 	} else {
-		int face = ((tile - 1) / (w->barrel.tiles - 2)) % MAXCOLORS;
+		int face = ((tile - 1) / (w->barrel.tiles - 2)) % MAX_COLORS;
 
 		ballGC = w->barrel.faceGC[face];
 #ifndef WINVER
@@ -799,21 +799,21 @@ DrawBufferedTile(BarrelWidget w, int pos, int pressedOffset)
 	dx = CartesianX(w, pos) + pressedOffset;
 	dy = CartesianY(w, pos) + pressedOffset;
 	if (pressedOffset != 0) {
-		drawShadow(w, *dr, w->barrel.tileDarkerGC,
+		drawShadow(w, *dr, w->barrel.tileGC[1],
 			dx - pressedOffset, dy - pressedOffset,
 			w->barrel.tileSize.x - 1, w->barrel.tileSize.y - 1);
 	}
 	DRAWRECTANGLE(w, *dr, borderGC, dx, dy,
 		w->barrel.tileSize.x + 1, w->barrel.tileSize.y - 1);
 	fill3DRect(w, *dr, tileGC,
-		w->barrel.tileDarkerGC, w->barrel.tileBrighterGC,
+		w->barrel.tileGC[2], w->barrel.tileGC[0],
 		dx, dy, w->barrel.tileSize.x, w->barrel.tileSize.y,
 		pressedOffset == 0);
 	/* FILLRECTANGLE(w, *dr, tileGC,
 		dx + 1, dy + 1,
 		w->barrel.tileSize.x, w->barrel.tileSize.y - 2); */
 	if (tile > 0 && tile <= ((w->barrel.tiles - 2) * w->barrel.faces +
-			NUMPLUNGERS)) {
+			PLUNGERS_NUMBER)) {
 		DrawBall(w, *dr, ballGC, pos, pressedOffset, pressedOffset);
 		buf[0] = '\0';
 		if (w->barrel.orient || w->barrel.mono) {
@@ -827,11 +827,11 @@ DrawBufferedTile(BarrelWidget w, int pos, int pressedOffset)
 #ifdef WINVER
 						w->barrel.faceChar[((tile - 1) /
 							(w->barrel.tiles - 2)) %
-							MAXCOLORS];
+							MAX_COLORS];
 #else
 						w->barrel.faceName[((tile - 1) /
 							(w->barrel.tiles -2)) %
-							MAXCOLORS][0];
+							MAX_COLORS][0];
 #endif
 					buf[last + 1] = '\0';
 					t *= w->barrel.base;
@@ -840,11 +840,11 @@ DrawBufferedTile(BarrelWidget w, int pos, int pressedOffset)
 #ifdef WINVER
 						w->barrel.faceChar[((tile - 1) /
 							(w->barrel.tiles - 2)) %
-							MAXCOLORS];
+							MAX_COLORS];
 #else
 						w->barrel.faceName[((tile - 1) /
 							(w->barrel.tiles - 2)) %
-							MAXCOLORS][0];
+							MAX_COLORS][0];
 #endif
 					buf[1] = '\0';
 					t = 1;
@@ -894,13 +894,13 @@ static void
 AnimateSlide(BarrelWidget w, int numTiles, int dir, int fast)
 {
 	int inc, aTile, plunger;
-	int fillBeginPos[NUMPLUNGERS];
+	int fillBeginPos[PLUNGERS_NUMBER];
 	int fillBeginI = 0, gapI = 0, moveI = 0;
 	int dx, dy, pos, posNext;
 	int ix = 0, iy = 0;
 	Pixmap dr = 0;
 
-	for (plunger = 0; plunger < NUMPLUNGERS; plunger++) {
+	for (plunger = 0; plunger < PLUNGERS_NUMBER; plunger++) {
 		fillBeginPos[plunger] =
 			TileNFromSpace(w, plunger, numTiles, dir);
 	}
@@ -917,7 +917,7 @@ AnimateSlide(BarrelWidget w, int numTiles, int dir, int fast)
 	for (inc = 0; inc < moveI + gapI; inc += gapI) {
 	  if (inc > moveI)
 	    inc = moveI;
-	  for (plunger = 0; plunger < NUMPLUNGERS; plunger++) {
+	  for (plunger = 0; plunger < PLUNGERS_NUMBER; plunger++) {
 	    for (aTile = 0; aTile < numTiles; aTile++) {
 	      posNext = TileNFromSpace(w, plunger, aTile + 1, dir);
 	      /* Calculate deltas */
@@ -964,7 +964,7 @@ AnimateSlide(BarrelWidget w, int numTiles, int dir, int fast)
 	    useTimer(&(w->barrel.oldTime), w->barrel.delay / fast);
 	  }
 	}
-	for (plunger = 0; plunger < NUMPLUNGERS; plunger++) {
+	for (plunger = 0; plunger < PLUNGERS_NUMBER; plunger++) {
 	  pos = w->barrel.spacePosition[plunger];
 	  for (aTile = 0; aTile < numTiles; aTile++) {
 	    posNext = TileNFromSpace(w, plunger, aTile + 1, dir);
@@ -973,7 +973,7 @@ AnimateSlide(BarrelWidget w, int numTiles, int dir, int fast)
 	    pos = posNext;
 	  }
 	  w->barrel.spacePosition[plunger] = fillBeginPos[plunger];
-	  w->barrel.tileOfPosition[fillBeginPos[plunger]] = -NUMPLUNGERS +
+	  w->barrel.tileOfPosition[fillBeginPos[plunger]] = -PLUNGERS_NUMBER +
 		plunger;
 	}
 }
@@ -1166,7 +1166,7 @@ MoveTiles(BarrelWidget w, int from, int fast)
 
 		dir = (w->barrel.spacePosition[0] % w->barrel.tiles == 0) ?
 			LEFT : RIGHT;
-		for (plunger = 0; plunger < NUMPLUNGERS; plunger++) {
+		for (plunger = 0; plunger < PLUNGERS_NUMBER; plunger++) {
 			pos = w->barrel.spacePosition[plunger];
 			for (aTile = 0; aTile < w->barrel.tiles - 1; aTile++) {
 				posNext = TileNFromSpace(w, plunger, 1, dir);
@@ -1176,7 +1176,7 @@ MoveTiles(BarrelWidget w, int from, int fast)
 				pos = posNext;
 				w->barrel.spacePosition[plunger] = pos;
 			}
-			w->barrel.tileOfPosition[pos] = -NUMPLUNGERS + plunger;
+			w->barrel.tileOfPosition[pos] = -PLUNGERS_NUMBER + plunger;
 			DrawTile(w, pos, True, True, FALSE, 0, 0);
 		}
 	}
@@ -1208,7 +1208,7 @@ RotateTiles(BarrelWidget w, int start, int finish, int direction, int fast)
 			tempTile = w->barrel.tileOfPosition[newPos];
 			w->barrel.tileOfPosition[newPos] = currTile;
 			currTile = tempTile;
-			for (plunger = 0; plunger < NUMPLUNGERS; plunger++) {
+			for (plunger = 0; plunger < PLUNGERS_NUMBER; plunger++) {
 				if (w->barrel.spacePosition[plunger] == pos) {
 					if (!animate)
 						DrawTile(w, newPos, True, True,
@@ -1216,14 +1216,14 @@ RotateTiles(BarrelWidget w, int start, int finish, int direction, int fast)
 					break;
 				}
 			}
-			if (!animate && plunger == NUMPLUNGERS)
+			if (!animate && plunger == PLUNGERS_NUMBER)
 				DrawTile(w, newPos, False, False,
 					FALSE, 0, 0);
 			r = newR;
 		}
 	}
 	if (start == 0) {
-		for (plunger = 0; plunger < NUMPLUNGERS; plunger++) {
+		for (plunger = 0; plunger < PLUNGERS_NUMBER; plunger++) {
 			i = (direction == TOP) ? w->barrel.faces - 1 : 1;
 			w->barrel.spacePosition[plunger] =
 				(w->barrel.spacePosition[plunger] + i *
@@ -1308,7 +1308,7 @@ ControlPuzzle(BarrelWidget w, int direction)
 
 	switch (direction) {
 	case TOP:
-		if (w->barrel.faces <= MINFACES)
+		if (w->barrel.faces <= MIN_FACES)
 			return;
 		reason = ACTION_DECY;
 		break;
@@ -1316,12 +1316,12 @@ ControlPuzzle(BarrelWidget w, int direction)
 		reason = ACTION_INCX;
 		break;
 	case BOTTOM:
-		if (w->barrel.faces >= MAXFACES)
+		if (w->barrel.faces >= MAX_FACES)
 			return;
 		reason = ACTION_INCY;
 		break;
 	case LEFT:
-		if (w->barrel.tiles <= MINTILES)
+		if (w->barrel.tiles <= MIN_TILES)
 			return;
 		reason = ACTION_DECX;
 		break;
@@ -1574,16 +1574,16 @@ ResetTiles(BarrelWidget w)
 			w->barrel.tileOfPosition[i] = 0;
 		}
 	}
-	for (i = 0; i < NUMPLUNGERS; i++) {
+	for (i = 0; i < PLUNGERS_NUMBER; i++) {
 		w->barrel.spacePosition[i] = 2 * i * w->barrel.tiles;
 		w->barrel.tileOfPosition[2 * i * w->barrel.tiles] =
-			-NUMPLUNGERS + i;
+			-PLUNGERS_NUMBER + i;
 		inc++;
 		w->barrel.tileOfPosition[(2 * i + 1) * w->barrel.tiles - 1] =
 			inc;
 	}
 	inc++;
-	for (i = 0; i < w->barrel.faces - NUMPLUNGERS; i++) {
+	for (i = 0; i < w->barrel.faces - PLUNGERS_NUMBER; i++) {
 		w->barrel.tileOfPosition[(2 * i + 1) * w->barrel.tiles] =
 			inc++;
 		w->barrel.tileOfPosition[(2 * i + 2) * w->barrel.tiles - 1] =
@@ -1642,7 +1642,7 @@ GetTiles(BarrelWidget w)
 	flushMoves(w, &redo, FALSE);
 	while ((c = getc(fp)) != EOF && c != SYMBOL);
 	(void) fscanf(fp, "%d", &tiles);
-	if (tiles >= MINTILES) {
+	if (tiles >= MIN_TILES) {
 		for (i = w->barrel.tiles; i < tiles; i++) {
 			setPuzzle(w, ACTION_INCX);
 		}
@@ -1655,7 +1655,7 @@ GetTiles(BarrelWidget w)
 		free(buf1);
 		stringCat(&buf1, buf2, " should be between ");
 		free(buf2);
-		intCat(&buf2, buf1, MINTILES);
+		intCat(&buf2, buf1, MIN_TILES);
 		free(buf1);
 		stringCat(&buf1, buf2, " and MAXINT");
 		free(buf2);
@@ -1664,7 +1664,7 @@ GetTiles(BarrelWidget w)
 	}
 	while ((c = getc(fp)) != EOF && c != SYMBOL);
 	(void) fscanf(fp, "%d", &faces);
-	if (faces >= MINFACES && faces <= MAXFACES) {
+	if (faces >= MIN_FACES && faces <= MAX_FACES) {
 		for (i = w->barrel.faces; i < faces; i++) {
 			setPuzzle(w, ACTION_INCY);
 		}
@@ -1677,11 +1677,11 @@ GetTiles(BarrelWidget w)
 		free(buf1);
 		stringCat(&buf1, buf2, " should be between ");
 		free(buf2);
-		intCat(&buf2, buf1, MINFACES);
+		intCat(&buf2, buf1, MIN_FACES);
 		free(buf1);
 		stringCat(&buf1, buf2, " and ");
 		free(buf2);
-		intCat(&buf2, buf1, MAXFACES);
+		intCat(&buf2, buf1, MAX_FACES);
 		free(buf1);
 		DISPLAY_WARNING(buf2);
 		free(buf2);
@@ -1963,24 +1963,26 @@ SoundTiles(BarrelWidget w)
 	w->barrel.sound = !w->barrel.sound;
 }
 
-#define FACTOR 0.7
+#define BRIGHT_FACTOR 0.8
+#define DARK_FACTOR 0.75
+
 #ifdef WINVER
-#define MAXINTENSITY 0xFF
+#define MAX_INTENSITY 0xFF
 static int
 brighter(const int light)
 {
-	int i = (int) ((1 - FACTOR) * MAXINTENSITY);
+	int i = (int) ((1 - BRIGHT_FACTOR) * MAX_INTENSITY);
 	int temp = light;
 
 	if (temp < i)
 		temp = i;
-	return MIN(temp / FACTOR, MAXINTENSITY);
+	return MIN(temp / BRIGHT_FACTOR, MAX_INTENSITY);
 }
 
 static int
 darker(const int light)
 {
-	return (int) (light * FACTOR);
+	return (int) (light * DARK_FACTOR);
 }
 
 static void
@@ -1993,21 +1995,21 @@ SetValuesPuzzle(BarrelWidget w)
 	int face;
 
 	w->barrel.tiles = GetPrivateProfileInt(SECTION, "tiles",
-		DEFAULTTILES, INIFILE);
+		DEFAULT_TILES, INIFILE);
 	w->barrel.faces = GetPrivateProfileInt(SECTION, "faces",
-		DEFAULTFACES, INIFILE);
+		DEFAULT_FACES, INIFILE);
 	w->barrel.orient = (BOOL) GetPrivateProfileInt(SECTION, "orient",
-		DEFAULTORIENT, INIFILE);
+		DEFAULT_ORIENT, INIFILE);
 	w->barrel.pairs = (BOOL) GetPrivateProfileInt(SECTION, "pairs",
-		DEFAULTPAIRS, INIFILE);
+		DEFAULT_PAIRS, INIFILE);
 	w->barrel.practice = (BOOL) GetPrivateProfileInt(SECTION, "practice",
-		DEFAULTPRACTICE, INIFILE);
+		DEFAULT_PRACTICE, INIFILE);
 	w->barrel.base = GetPrivateProfileInt(SECTION, "base",
-		DEFAULTBASE, INIFILE);
+		DEFAULT_BASE, INIFILE);
 	w->barrel.mono = (BOOL) GetPrivateProfileInt(SECTION, "mono",
-		DEFAULTMONO, INIFILE);
+		DEFAULT_MONO, INIFILE);
 	w->barrel.reverse = (BOOL) GetPrivateProfileInt(SECTION,
-		"reverseVideo", DEFAULTREVERSE, INIFILE);
+		"reverseVideo", DEFAULT_REVERSE, INIFILE);
 	/* cyan */
 	(void) GetPrivateProfileString(SECTION, "frameColor", "0 255 255",
 		szBuf, sizeof (szBuf), INIFILE);
@@ -2019,15 +2021,15 @@ SetValuesPuzzle(BarrelWidget w)
 		szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
-	w->barrel.tileGC = RGB(color.red, color.green, color.blue);
+	w->barrel.tileGC[1] = RGB(color.red, color.green, color.blue);
 	/* gray50 */
 	(void) GetPrivateProfileString(SECTION, "tileBorder", "127 127 127",
 		szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
-	w->barrel.tileBrighterGC = RGB(brighter(color.red),
+	w->barrel.tileGC[0] = RGB(brighter(color.red),
 		brighter(color.green), brighter(color.blue));
-	w->barrel.tileDarkerGC = RGB(darker(color.red),
+	w->barrel.tileGC[2] = RGB(darker(color.red),
 		darker(color.green), darker(color.blue));
 	w->barrel.borderGC = RGB(color.red, color.green, color.blue);
 	/* #AEB2C3 */
@@ -2036,7 +2038,7 @@ SetValuesPuzzle(BarrelWidget w)
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
 	w->barrel.inverseGC = RGB(color.red, color.green, color.blue);
-	for (face = 0; face < MAXCOLORS; face++) {
+	for (face = 0; face < MAX_COLORS; face++) {
 		(void) sprintf(buf, "faceColor%d", face);
 		(void) GetPrivateProfileString(SECTION,
 			buf, faceColorString[face],
@@ -2057,7 +2059,7 @@ SetValuesPuzzle(BarrelWidget w)
 	(void) strcpy(w->barrel.picture, szBuf);
 	w->barrel.picture[80] = 0;
 	w->barrel.delay = GetPrivateProfileInt(SECTION, "delay",
-		DEFAULTDELAY, INIFILE);
+		DEFAULT_DELAY, INIFILE);
 	w->barrel.sound = (BOOL)
 		GetPrivateProfileInt(SECTION, "sound", 0, INIFILE);
 	(void) GetPrivateProfileString(SECTION, "bumpSound", BUMPSOUND,
@@ -2095,7 +2097,7 @@ DestroyPuzzle(BarrelWidget w, HBRUSH brush)
 }
 
 #else
-#define MAXINTENSITY 0xFFFF
+#define MAX_INTENSITY 0xFFFF
 
 static Pixel
 brighter(BarrelWidget w, Pixel pixel)
@@ -2103,19 +2105,19 @@ brighter(BarrelWidget w, Pixel pixel)
 	XColor color;
 	Colormap colormap = (w->barrel.colormap == None) ?
 		w->barrel.oldColormap : w->barrel.colormap;
-	int i = (int) ((1 - FACTOR) * MAXINTENSITY);
+	int i = (int) ((1 - BRIGHT_FACTOR) * MAX_INTENSITY);
 
 	color.pixel = pixel;
-	XQueryColor(XtDisplay(w), colormap, &color);
+	VOID XQueryColor(XtDisplay(w), colormap, &color);
 	if (color.red < i)
 		color.red = i;
 	if (color.green < i)
 		color.green = i;
 	if (color.blue < i)
 		color.blue = i;
-	color.red = (unsigned short) MIN(color.red / FACTOR, MAXINTENSITY);
-	color.green = (unsigned short) MIN(color.green / FACTOR, MAXINTENSITY);
-	color.blue = (unsigned short) MIN(color.blue / FACTOR, MAXINTENSITY);
+	color.red = (unsigned short) MIN(color.red / BRIGHT_FACTOR, MAX_INTENSITY);
+	color.green = (unsigned short) MIN(color.green / BRIGHT_FACTOR, MAX_INTENSITY);
+	color.blue = (unsigned short) MIN(color.blue / BRIGHT_FACTOR, MAX_INTENSITY);
 	if (XAllocColor(XtDisplay(w), colormap, &color))
 		return color.pixel;
 	return pixel;
@@ -2129,10 +2131,10 @@ darker(BarrelWidget w, Pixel pixel)
 		w->barrel.oldColormap : w->barrel.colormap;
 
 	color.pixel = pixel;
-	XQueryColor(XtDisplay(w), colormap, &color);
-	color.red = (unsigned short) (color.red * FACTOR);
-	color.green = (unsigned short) (color.green * FACTOR);
-	color.blue = (unsigned short) (color.blue * FACTOR);
+	VOID XQueryColor(XtDisplay(w), colormap, &color);
+	color.red = (unsigned short) (color.red * DARK_FACTOR);
+	color.green = (unsigned short) (color.green * DARK_FACTOR);
+	color.blue = (unsigned short) (color.blue * DARK_FACTOR);
 	if (XAllocColor(XtDisplay(w), colormap, &color))
 		return color.pixel;
 	return pixel;
@@ -2232,21 +2234,21 @@ SetAllColors(BarrelWidget w)
 		values.foreground = w->barrel.tileColor;
 		values.background = w->barrel.borderColor;
 	}
-	if (w->barrel.tileGC)
-		XtReleaseGC((Widget) w, w->barrel.tileGC);
-	w->barrel.tileGC = XtGetGC((Widget) w, valueMask, &values);
+	if (w->barrel.tileGC[1])
+		XtReleaseGC((Widget) w, w->barrel.tileGC[1]);
+	w->barrel.tileGC[1] = XtGetGC((Widget) w, valueMask, &values);
 	if (!w->barrel.mono) {
 		values.foreground = darker(w, w->barrel.tileColor);
 	}
-	if (w->barrel.tileBrighterGC)
-		XtReleaseGC((Widget) w, w->barrel.tileBrighterGC);
-	w->barrel.tileBrighterGC = XtGetGC((Widget) w, valueMask, &values);
+	if (w->barrel.tileGC[0])
+		XtReleaseGC((Widget) w, w->barrel.tileGC[0]);
+	w->barrel.tileGC[0] = XtGetGC((Widget) w, valueMask, &values);
 	if (!w->barrel.mono) {
 		values.foreground = brighter(w, w->barrel.tileColor);
 	}
-	if (w->barrel.tileDarkerGC)
-		XtReleaseGC((Widget) w, w->barrel.tileDarkerGC);
-	w->barrel.tileDarkerGC = XtGetGC((Widget) w, valueMask, &values);
+	if (w->barrel.tileGC[2])
+		XtReleaseGC((Widget) w, w->barrel.tileGC[2]);
+	w->barrel.tileGC[2] = XtGetGC((Widget) w, valueMask, &values);
 	if (w->barrel.mono) {
 		if (w->barrel.reverse) {
 			values.foreground = w->barrel.foreground;
@@ -2262,10 +2264,10 @@ SetAllColors(BarrelWidget w)
 	if (w->barrel.borderGC)
 		XtReleaseGC((Widget) w, w->barrel.borderGC);
 	w->barrel.borderGC = XtGetGC((Widget) w, valueMask, &values);
-	for (face = 0; face < MAXCOLORS; face++)
+	for (face = 0; face < MAX_COLORS; face++)
 		GetColor(w, face);
 	if (w->barrel.fontInfo) {
-		XSetFont(XtDisplay(w), w->barrel.tileGC,
+		XSetFont(XtDisplay(w), w->barrel.tileGC[1],
 			w->barrel.fontInfo->fid);
 	}
 }
@@ -2279,7 +2281,7 @@ SetValuesPuzzle(Widget current, Widget request, Widget renew)
 	int face;
 
 	CheckTiles(w);
-	for (face = 0; face < MAXFACES; face++) {
+	for (face = 0; face < MAX_FACES; face++) {
 		if (strcmp(w->barrel.faceName[face],
 				c->barrel.faceName[face])) {
 			setColors = True;
@@ -2315,8 +2317,8 @@ SetValuesPuzzle(Widget current, Widget request, Widget renew)
 		redraw = True;
 	}
 	if (w->barrel.delay != c->barrel.delay) {
-		w->barrel.numSlices = ((w->barrel.delay < MAXSLICES) ?
-			w->barrel.delay + 1 : MAXSLICES);
+		w->barrel.numSlices = ((w->barrel.delay < MAX_SLICES) ?
+			w->barrel.delay + 1 : MAX_SLICES);
 	}
 	if (w->barrel.menu != ACTION_IGNORE) {
 		int menu = w->barrel.menu;
@@ -2380,14 +2382,13 @@ DestroyPuzzle(Widget old)
 {
 	BarrelWidget w = (BarrelWidget) old;
 	Display *display = XtDisplay(w);
-	int face, sel;
+	int i;
 
-	for (face = 0; face < MAXCOLORS; face++)
-		XtReleaseGC(old, w->barrel.faceGC[face]);
-	XtReleaseGC(old, w->barrel.tileGC);
+	for (i = 0; i < MAX_COLORS; i++)
+		XtReleaseGC(old, w->barrel.faceGC[i]);
+	for (i = 0; i < FG_SHADES; i++)
+		w->barrel.tileGC[i] = NULL;
 	XtReleaseGC(old, w->barrel.borderGC);
-	XtReleaseGC(old, w->barrel.tileBrighterGC);
-	XtReleaseGC(old, w->barrel.tileDarkerGC);
 	XtReleaseGC(old, w->barrel.frameGC);
 	XtReleaseGC(old, w->barrel.inverseGC);
 	XtRemoveCallbacks(old, XtNselectCallback, w->barrel.select);
@@ -2395,9 +2396,9 @@ DestroyPuzzle(Widget old)
 		XInstallColormap(display, w->barrel.oldColormap);
 		XFreeColormap(display, w->barrel.colormap);
 	}
-	for (sel = 0; sel < 2; sel++)
-		if (w->barrel.bufferTiles[sel] != None)
-			XFreePixmap(display, w->barrel.bufferTiles[sel]);
+	for (i = 0; i < 2; i++)
+		if (w->barrel.bufferTiles[i] != None)
+			XFreePixmap(display, w->barrel.bufferTiles[i]);
 	if (w->barrel.fontInfo) {
 		XUnloadFont(display, w->barrel.fontInfo->fid);
 		XFreeFont(display, w->barrel.fontInfo);
@@ -2580,6 +2581,7 @@ Widget request, Widget renew
 	w->barrel.bufferTiles[1] = NULL;
 #else
 	BarrelWidget w = (BarrelWidget) renew;
+	int i;
 
 	(void) SRAND(getpid());
 	w->barrel.bufferTiles[0] = None;
@@ -2587,25 +2589,24 @@ Widget request, Widget renew
 	w->barrel.colormap = None;
 	w->barrel.oldColormap = None;
 	w->barrel.fontInfo = NULL;
-	w->barrel.tileGC = NULL;
+	for (i = 0; i < FG_SHADES; i++)
+		w->barrel.tileGC[i] = NULL;
 	w->barrel.borderGC = NULL;
-	w->barrel.tileBrighterGC = NULL;
-	w->barrel.tileDarkerGC = NULL;
 	w->barrel.frameGC = NULL;
 	w->barrel.inverseGC = NULL;
 	w->barrel.image = NULL;
 #endif
 	w->barrel.focus = False;
 	loadFont(w);
-	w->barrel.tiles = MAXTILES;
-	w->barrel.faces = MAXFACES;
+	w->barrel.tiles = MAX_TILES;
+	w->barrel.faces = MAX_FACES;
 	w->barrel.tileOfPosition = NULL;
 	CheckTiles(w);
 	newMoves(&undo);
 	newMoves(&redo);
 	ResetTiles(w);
-	w->barrel.numSlices = ((w->barrel.delay < MAXSLICES) ?
-		w->barrel.delay + 1 : MAXSLICES);
+	w->barrel.numSlices = ((w->barrel.delay < MAX_SLICES) ?
+		w->barrel.delay + 1 : MAX_SLICES);
 	w->barrel.cheat = False;
 	SizePuzzle(w);
 }
