@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 2007	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1994 - 2007	David A. Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -126,35 +126,35 @@ typedef struct {
 #define ACTION_LEFT 303
 #define ACTION_UP 310
 #define ACTION_DOWN 312
-#define ACTION_INCX 400
-#define ACTION_DECX 401
+#define ACTION_INCX 401
+#define ACTION_DECX 403
 #define ACTION_INCY 402
-#define ACTION_DECY 403
+#define ACTION_DECY 400
 #define ACTION_DESCRIPTION 900
 #define ACTION_FEATURES 901
 #define ACTION_REFERENCES 902
 #define ACTION_ABOUT 903
 #define ACTION_IGNORE 999
 
-#define MINFACES 5
-#define MAXFACES 5
-#define MINTILES 6
-#define MAXTILES 6
-#define DEFAULTFACES 5
-#define DEFAULTTILES 6
-#define DEFAULTORIENT FALSE
-#define DEFAULTPAIRS TRUE
-#define DEFAULTPRACTICE TRUE
-#define DEFAULTDELAY 10
+#define MIN_FACES 5
+#define MAX_FACES 5
+#define MIN_TILES 6
+#define MAX_TILES 6
+#define DEFAULT_FACES 5
+#define DEFAULT_TILES 6
+#define DEFAULT_ORIENT FALSE
+#define DEFAULT_PAIRS TRUE
+#define DEFAULT_PRACTICE TRUE
+#define DEFAULT_DELAY 10
 #ifdef MONOTEST
-#define DEFAULTMONO TRUE
+#define DEFAULT_MONO TRUE
 #else
-#define DEFAULTMONO FALSE
+#define DEFAULT_MONO FALSE
 #endif
-#define DEFAULTREVERSE FALSE
-#define MINBASE 2 /* Base 1 is rediculous :) */
-#define MAXBASE 36 /* 10 numbers + 26 letters (ASCII) */
-#define DEFAULTBASE 10
+#define DEFAULT_REVERSE FALSE
+#define MIN_BASE 2 /* Base 1 is rediculous :) */
+#define MAX_BASE 36 /* 10 numbers + 26 letters (ASCII) */
+#define DEFAULT_BASE 10
 
 #define BOOL_STRING(a) ((a==0)?"false":"true")
 
