@@ -8,7 +8,7 @@
 #  Taken from James G. Nourse's The Simple Solutions to Cubic Puzzles.
 #  Break ability taken from the X puzzle by Don Bennett, HP Labs
 #
-#  Copyright (c) 2003 - 2007    David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 2003 - 2007    David A. Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -209,7 +209,7 @@ CheckLevelSolved(const BarrelWidget w, int i)
 			} else if (i == w->barrel.faces &&
 					j % 2 == 1 &&
 					color != w->barrel.faces &&
-				   	LEVELTILE(w->barrel.tiles - 1, j) <
+					LEVELTILE(w->barrel.tiles - 1, j) <
 					w->barrel.faces) {
 				return j;
 			}
@@ -679,18 +679,18 @@ FindL1Color(BarrelWidget w, int colors[])
 	(void) printf("1: search level %d, piece %d\n", searchLevel, piece);
 #endif
 	switch (piece) {
-	case 0:	
+	case 0:
 		RightTowards2(w);
 		return CENTER();
-	case 1:	
+	case 1:
 		RightTowards(w);
 		return CENTER();
 	case 2:
 		return CENTER();
-	case 3:	
+	case 3:
 		RightAway(w);
 		return CENTER();
-	case 4:	
+	case 4:
 		RightAway2(w);
 		return CENTER();
 	}
@@ -700,22 +700,22 @@ FindL1Color(BarrelWidget w, int colors[])
 	(void) printf("1: search level %d, piece %d\n", searchLevel, piece);
 #endif
 	switch (piece) {
-	case 0:	
+	case 0:
 		RightTowards2(w);
 		L2_4232(w);
 		return CENTER();
-	case 1:	
+	case 1:
 		RightTowards(w);
 		L2_4232(w);
 		return CENTER();
 	case 2:
 		L2_4232(w);
 		return CENTER();
-	case 3:	
+	case 3:
 		RightAway(w);
 		L2_4232(w);
 		return CENTER();
-	case 4:	
+	case 4:
 		RightAway2(w);
 		L2_4232(w);
 		return CENTER();
@@ -726,13 +726,13 @@ FindL1Color(BarrelWidget w, int colors[])
 	(void) printf("1: search level %d, piece %d\n", searchLevel, piece);
 #endif
 	switch (piece) {
-	case 0:	
+	case 0:
 		L2_5032(w);
 		return CENTER();
 	case 2:
 		L2_5232(w);
 		return CENTER();
-	case 4:	
+	case 4:
 		L2_5432(w);
 		return CENTER();
 	}
@@ -742,7 +742,7 @@ FindL1Color(BarrelWidget w, int colors[])
 	(void) printf("1: search level %d, piece %d\n", searchLevel, piece);
 #endif
 	switch (piece) {
-	case 0:	
+	case 0:
 		LeftTowards(w);
 		L2_2131(w);
 		LeftAway(w);
@@ -751,7 +751,7 @@ FindL1Color(BarrelWidget w, int colors[])
 	case 2:
 		L2_2232(w);
 		return CENTER();
-	case 4:	
+	case 4:
 		LeftAway(w);
 		L2_2333(w);
 		LeftTowards(w);
@@ -772,18 +772,18 @@ findL2(BarrelWidget w, int color)
 	(void) printf("2: search level %d, %d\n", searchLevel, piece);
 #endif
 	switch (piece) {
-	case 0:	
+	case 0:
 		RightTowards2(w);
 		return CENTER();
-	case 1:	
+	case 1:
 		RightTowards(w);
 		return CENTER();
 	case 2:
 		return CENTER();
-	case 3:	
+	case 3:
 		RightAway(w);
 		return CENTER();
-	case 4:	
+	case 4:
 		RightAway2(w);
 		return CENTER();
 	}
@@ -793,22 +793,22 @@ findL2(BarrelWidget w, int color)
 	(void) printf("2: search level %d, %d\n", searchLevel, piece);
 #endif
 	switch (piece) {
-	case 0:	
+	case 0:
 		RightTowards2(w);
 		L2_4232(w);
 		return CENTER();
-	case 1:	
+	case 1:
 		RightTowards(w);
 		L2_4232(w);
 		return CENTER();
 	case 2:
 		L2_4232(w);
 		return CENTER();
-	case 3:	
+	case 3:
 		RightAway(w);
 		L2_4232(w);
 		return CENTER();
-	case 4:	
+	case 4:
 		RightAway2(w);
 		L2_4232(w);
 		return CENTER();
@@ -819,13 +819,13 @@ findL2(BarrelWidget w, int color)
 	(void) printf("2: search level %d, %d\n", searchLevel, piece);
 #endif
 	switch (piece) {
-	case 0:	
+	case 0:
 		L2_5032(w);
 		return CENTER();
 	case 2:
 		L2_5232(w);
 		return CENTER();
-	case 4:	
+	case 4:
 		L2_5432(w);
 		return CENTER();
 	}
@@ -835,7 +835,7 @@ findL2(BarrelWidget w, int color)
 	(void) printf("2: search level %d, %d\n", searchLevel, piece);
 #endif
 	switch (piece) {
-	case 0:	
+	case 0:
 		LeftTowards(w);
 		L2_2131(w);
 		LeftAway(w);
@@ -844,7 +844,7 @@ findL2(BarrelWidget w, int color)
 	case 2:
 		L2_2232(w);
 		return CENTER();
-	case 4:	
+	case 4:
 		LeftAway(w);
 		L2_2333(w);
 		LeftTowards(w);
@@ -867,18 +867,18 @@ FindL3Color(BarrelWidget w, int face, int color)
 #endif
 	if (face == 2) {
 		switch (piece) {
-		case 0:	
+		case 0:
 			RightTowards2(w);
 			return searchLevel;
-		case 1:	
+		case 1:
 			RightTowards(w);
 			return searchLevel;
 		case 2:
 			return searchLevel;
-		case 3:	
+		case 3:
 			RightAway(w);
 			return searchLevel;
-		case 4:	
+		case 4:
 			RightAway2(w);
 			return searchLevel;
 		}
@@ -903,7 +903,7 @@ FindL3Color(BarrelWidget w, int face, int color)
 				(void) printf("Should not get here\n");
 				return searchLevel;
 			}
-		case 1:	
+		case 1:
 			switch (face) {
 			case 0: /* 7->3 */
 				L3_3130(w);
@@ -943,7 +943,7 @@ FindL3Color(BarrelWidget w, int face, int color)
 				(void) printf("Should not get here\n");
 				return searchLevel;
 			}
-		case 4:	
+		case 4:
 			switch (face) {
 			case 0: /* 19->3 */
 				RightTowards(w);
@@ -1000,7 +1000,7 @@ FindL3Color(BarrelWidget w, int face, int color)
 			return searchLevel;
 		}
 		break;
-	case 1:	
+	case 1:
 		switch (face) {
 		case 0: /* 8->3 */
 			RightTowards(w);
@@ -1056,7 +1056,7 @@ FindL3Color(BarrelWidget w, int face, int color)
 			return searchLevel;
 		}
 		break;
-	case 3:	
+	case 3:
 		switch (face) {
 		case 0: /* 16->3 */
 			RightAway2(w);
@@ -1087,7 +1087,7 @@ FindL3Color(BarrelWidget w, int face, int color)
 /* 12->7  L3_4231(w) */
 /* 8->15  L3_4133(w) */
 /* 16->7  L3_4331(w) */
-	case 4:	
+	case 4:
 		switch (face) {
 		case 0: /* 20->3 */
 			RightAway2(w);
@@ -1124,7 +1124,7 @@ FindL3Color(BarrelWidget w, int face, int color)
 #endif
 	piece = FindMatch(w, searchLevel, color);
 	switch (piece) {
-	case 0:	
+	case 0:
 		switch (face) {
 		case 0: /* 21->3 */
 			RightAway(w);
@@ -1186,7 +1186,7 @@ FindL3Color(BarrelWidget w, int face, int color)
 /* 22->15 L3_5233(w) */
 /* 21->19 L3_5034(w) */
 /* 23->3  L3_5430(w) */
-	case 4:	
+	case 4:
 		switch (face) {
 		case 0: /* 23->3 */
 			L3_5430(w);
@@ -1246,7 +1246,7 @@ FindL5Color(BarrelWidget w, int face, int color)
 			return True;
 		}
 		break;
-	case 1:	
+	case 1:
 		switch (face) {
 		case 0: /* 8->21 */
 			RightAway2(w);
@@ -1309,7 +1309,7 @@ FindL5Color(BarrelWidget w, int face, int color)
 			return True;
 		}
 		break;
-	case 4:	
+	case 4:
 		switch (face) {
 		case 0: /* 20->21 */
 			L5_4450(w);
@@ -1364,7 +1364,7 @@ FindL4Color(BarrelWidget w, int face, int color)
 			return True;
 		}
 		break;
-	case 1:	
+	case 1:
 		switch (face) {
 		case 0: /* 8->4 */
 			RightTowards(w);
@@ -1428,7 +1428,7 @@ FindL4Color(BarrelWidget w, int face, int color)
 			return True;
 		}
 		break;
-	case 4:	
+	case 4:
 		switch (face) {
 		case 0: /* 20->4 */
 			RightAway2(w);
@@ -1642,7 +1642,7 @@ MoveToCenter(BarrelWidget w, int level, int face)
 static Boolean
 solveL1Orient(BarrelWidget w)
 {
-	int orient[MAXFACES] = {-1, -1, -1, -1, -1};
+	int orient[MAX_FACES] = {-1, -1, -1, -1, -1};
 	int piece = CheckLevelSolved(w, 1);
 	int currentLevel, currentFace;
 	int ok = -2;
@@ -1829,7 +1829,7 @@ solveL1Orient(BarrelWidget w)
 static Boolean
 solveL1Color(BarrelWidget w)
 {
-	int colors[MAXFACES+1] = {-1, -1, -1, -1, -1, -1};
+	int colors[MAX_FACES+1] = {-1, -1, -1, -1, -1, -1};
 	int piece = CheckLevelSolved(w, 1);
 
 	if (piece == w->barrel.faces) {
@@ -1948,7 +1948,7 @@ solveL1Color(BarrelWidget w)
 static Boolean
 solveL2(BarrelWidget w)
 {
-	/*int faces[MAXFACES] = {1, 3, 2, 0, 5};*/
+	/*int faces[MAX_FACES] = {1, 3, 2, 0, 5};*/
 	int piece = CheckLevelSolved(w, 2);
 
 	if (piece == w->barrel.faces) {
