@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 2003 - 2007	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 2003 - 2007	David A. Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -205,26 +205,26 @@ static const char solveHelp[] = {
 #endif
 
 #define NEVER (-1)
-#define FILENAMELEN 1024
-#define USERNAMELEN 120
-#define MESSAGELEN (USERNAMELEN+64)
-#define TITLELEN 2048
+#define FILE_NAME_LENGTH 1024
+#define USER_NAME_LENGTH 120
+#define MESSAGE_LENGTH (USER_NAME_LENGTH+64)
+#define TITLE_LENGTH 2048
 #define NOACCESS "noaccess"
 #define NOBODY "nobody"
 
 typedef struct {
 	int score;
-	char name[USERNAMELEN];
+	char name[USER_NAME_LENGTH];
 } PuzzleRecord;
 
 static PuzzleRecord puzzleRecord[2][2];
 static int movesDsp = 0;
-static char messageDsp[MESSAGELEN] = "Welcome";
-static char recordDsp[MESSAGELEN] = "NOT RECORDED";
+static char messageDsp[MESSAGE_LENGTH] = "Welcome";
+static char recordDsp[MESSAGE_LENGTH] = "NOT RECORDED";
 
 #ifdef HAVE_MOTIF
-#define MINSPEED 1
-#define MAXSPEED 50
+#define MIN_SPEED 1
+#define MAX_SPEED 50
 static Widget moves, record, message;
 static Widget orientizeSwitch, pairsSwitch, practiceSwitch;
 #if 0
@@ -237,19 +237,19 @@ static Widget optionsDialog, referencesDialog, aboutDialog;
 static Widget solveDialog, practiceDialog, randomizeDialog;
 static Arg arg[3];
 #else
-static char titleDsp[TITLELEN] = "";
+static char titleDsp[TITLE_LENGTH] = "";
 #endif
-static char scoreFileName[FILENAMELEN] = SCOREFILE;
-static char fileName[FILENAMELEN];
+static char scoreFileName[FILE_NAME_LENGTH] = SCOREFILE;
+static char fileName[FILE_NAME_LENGTH];
 #ifdef WINVER
-#define MAXPROGNAME 80
-static char progDsp[MAXPROGNAME] = TITLE;
-static char userNameDsp[USERNAMELEN] = "Guest";
+#define PROGRAM_NAME_LENGTH 80
+static char progDsp[PROGRAM_NAME_LENGTH] = TITLE;
+static char userNameDsp[USER_NAME_LENGTH] = "Guest";
 #else
 static Pixmap pixmap = None;
 static Widget topLevel, puzzle;
 static char *progDsp;
-static char userNameDsp[USERNAMELEN] = "";
+static char userNameDsp[USER_NAME_LENGTH] = "";
 
 #ifdef HAVE_MOTIF
 static void
@@ -291,7 +291,7 @@ InitRecords(void)
 		for (k = 0; k < 2; k++) {
 			puzzleRecord[l][k].score = NEVER;
 			(void) strncpy(puzzleRecord[l][k].name,
-				NOACCESS, USERNAMELEN);
+				NOACCESS, USER_NAME_LENGTH);
 		}
 }
 
@@ -300,7 +300,7 @@ ReadRecords(void)
 {
 	FILE *fp;
 	int k, l, n;
-	char userName[USERNAMELEN];
+	char userName[USER_NAME_LENGTH];
 	char *buf1 = NULL, *buf2 = NULL;
 	char *fname, *lname;
 
@@ -310,9 +310,9 @@ ReadRecords(void)
 	stringCat(&buf2, buf1, SCOREFILE);
 	free(buf1);
 	fname = buf2;
-	(void) strncpy(fileName, lname, USERNAMELEN);
+	(void) strncpy(fileName, lname, USER_NAME_LENGTH);
 	if ((fp = fopen(fileName, "r")) == NULL) {
-		(void) strncpy(fileName, fname, USERNAMELEN);
+		(void) strncpy(fileName, fname, USER_NAME_LENGTH);
 		/* Try installed directory. */
 		if ((fp = fopen(fileName, "r")) == NULL) {
 			stringCat(&buf1, "Can not read ", fname);
@@ -348,7 +348,7 @@ ReadRecords(void)
 					puzzleRecord[l][k].score <= NEVER) {
 				puzzleRecord[l][k].score = n;
 				(void) strncpy(puzzleRecord[l][k].name,
-					userName, USERNAMELEN);
+					userName, USER_NAME_LENGTH);
 			}
 		}
 	(void) fclose(fp);
@@ -370,9 +370,9 @@ WriteRecords(void)
 	{
 #if HAVE_FCNTL_H
 		int lfd;
-		char lockFile[FILENAMELEN];
+		char lockFile[FILE_NAME_LENGTH];
 
-		(void) strncpy(lockFile, fileName, FILENAMELEN - 6);
+		(void) strncpy(lockFile, fileName, FILE_NAME_LENGTH - 6);
 		(void) strcat(lockFile, ".lock");
 		while (((lfd = open(lockFile, O_CREAT | O_EXCL, 0644)) < 0) &&
 				errno == EEXIST)
@@ -410,10 +410,10 @@ PrintRecord(Boolean orient, Boolean pairs, Boolean practice)
 	int k = (orient) ? 1 : 0, l = (pairs) ? 1 : 0;
 
 	if (practice) {
-		(void) strncpy(recordDsp, "practice", MESSAGELEN);
+		(void) strncpy(recordDsp, "practice", MESSAGE_LENGTH);
 #if 0
-	} else if (tiles > MAXTILES) {
-		(void) strncpy(recordDsp, "NOT RECORDED", MESSAGELEN);
+	} else if (tiles > MAX_TILES) {
+		(void) strncpy(recordDsp, "NOT RECORDED", MESSAGE_LENGTH);
 #endif
 	} else if (puzzleRecord[l][k].score <= NEVER) {
 		(void) sprintf(recordDsp, "NEVER %s", NOACCESS);
@@ -463,7 +463,7 @@ HandleSolved(int counter, Boolean orient, Boolean pairs)
 		ReadRecords();	/* Maybe its been updated by another */
 		puzzleRecord[l][k].score = counter;
 		(void) strncpy(puzzleRecord[l][k].name, userNameDsp,
-			USERNAMELEN);
+			USER_NAME_LENGTH);
 		WriteRecords();
 		PrintRecord(orient, pairs, False);
 		return True;
@@ -493,7 +493,7 @@ Widget w
 	userName = w->barrel.userName;
 	scoreFile = w->barrel.scoreFile;
 	if (strcmp(scoreFile, ""))
-		(void) strncpy(scoreFileName, scoreFile, FILENAMELEN);
+		(void) strncpy(scoreFileName, scoreFile, FILE_NAME_LENGTH);
 #else
 	Boolean scoreOnly, versionOnly;
 
@@ -510,7 +510,7 @@ Widget w
 		exit(0);
 	}
 	if (strcmp(scoreFile, ""))
-		(void) strncpy(scoreFileName, scoreFile, FILENAMELEN);
+		(void) strncpy(scoreFileName, scoreFile, FILE_NAME_LENGTH);
 	if (scoreOnly) {
 		InitRecords();
 		ReadRecords();
@@ -519,7 +519,7 @@ Widget w
 	}
 #ifdef HAVE_MOTIF
 #if 0
-	if (tiles > MAXTILES)
+	if (tiles > MAX_TILES)
 		XtVaSetValues(tile, XmNmaximum, tiles, NULL);
 	XmScaleSetValue(tile, tiles);
 	XmScaleSetValue(face, faces);
@@ -531,7 +531,7 @@ Widget w
 		int delay;
 
 		XtVaGetValues(w, XtNdelay, &delay, NULL);
-		XmScaleSetValue(speed, MAXSPEED + MINSPEED - delay - 1);
+		XmScaleSetValue(speed, MAX_SPEED + MIN_SPEED - delay - 1);
 	}
 #endif
 #endif
@@ -539,13 +539,13 @@ Widget w
 	InitRecords();
 	ReadRecords();
 #ifndef WINVER
-	(void) strncpy(userNameDsp, userName, USERNAMELEN);
+	(void) strncpy(userNameDsp, userName, USER_NAME_LENGTH);
 #endif
 	if (!strcmp(userName, "") || !strcmp(userName, "(null)") ||
 			!strcmp(userName, NOACCESS) ||
 			!strcmp(userName, NOBODY)) {
 #ifdef WINVER
-		(void) strncpy(userNameDsp, userName, USERNAMELEN);
+		(void) strncpy(userNameDsp, userName, USER_NAME_LENGTH);
 #else
 		char *login = getlogin();
 
@@ -630,13 +630,13 @@ CallbackPuzzle(Widget w, caddr_t clientData, barrelCallbackStruct *callData)
 #ifdef HAVE_MOTIF
 		XtManageChild(solveDialog);
 #else
-		(void) strncpy(messageDsp, solveHelp, MESSAGELEN);
+		(void) strncpy(messageDsp, solveHelp, MESSAGE_LENGTH);
 #endif
 #endif
 		break;
 	case ACTION_RESTORE:
 		if (practice) {
-			(void) strncpy(recordDsp, "practice", MESSAGELEN);
+			(void) strncpy(recordDsp, "practice", MESSAGE_LENGTH);
 #ifdef HAVE_MOTIF
 			PrintState(record, recordDsp);
 #endif
@@ -647,18 +647,18 @@ CallbackPuzzle(Widget w, caddr_t clientData, barrelCallbackStruct *callData)
 		movesDsp = 0;
 		break;
 	case ACTION_BLOCKED:
-		(void) strncpy(messageDsp, "Blocked", MESSAGELEN);
+		(void) strncpy(messageDsp, "Blocked", MESSAGE_LENGTH);
 		break;
 	case ACTION_SPACE:
 #if 0
 		/* Too annoying */
 		(void) strncpy(messageDsp, "A space can not slide",
-			MESSAGELEN);
+			MESSAGE_LENGTH);
 #endif
 		break;
 	case ACTION_IGNORE:
 		(void) strncpy(messageDsp, "Randomize to start",
-			MESSAGELEN);
+			MESSAGE_LENGTH);
 		break;
 	case ACTION_MOVED:
 		movesDsp++;
@@ -677,7 +677,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, barrelCallbackStruct *callData)
 				"Congratulations %s!!", userNameDsp);
 		else
 			(void) strncpy(messageDsp, "Solved!",
-				MESSAGELEN);
+				MESSAGE_LENGTH);
 		SET_STARTED(w, False);
 		break;
 	case ACTION_COMPUTED:
@@ -688,7 +688,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, barrelCallbackStruct *callData)
 		practice = !practice;
 		if (!practice)
 			(void) strncpy(messageDsp, "Randomize to start",
-				MESSAGELEN);
+				MESSAGE_LENGTH);
 		PrintRecord(orient, pairs, practice);
 #ifdef WINVER
 		w->barrel.practice = practice;
@@ -749,7 +749,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, barrelCallbackStruct *callData)
 #else
 		XtVaSetValues(w, XtNtiles, tiles, NULL);
 #ifdef HAVE_MOTIF
-		if (tiles > MAXTILES)
+		if (tiles > MAX_TILES)
 			XtVaSetValues(tile, XmNmaximum, tiles, NULL);
 		XmScaleSetValue(tile, tiles);
 #endif
@@ -765,7 +765,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, barrelCallbackStruct *callData)
 		XtVaSetValues(w, XtNtiles, tiles, NULL);
 #ifdef HAVE_MOTIF
 		XmScaleSetValue(tile, tiles);
-		if (tiles > MAXTILES)
+		if (tiles > MAX_TILES)
 			XtVaSetValues(tile, XmNmaximum, tiles, NULL);
 #endif
 #endif
@@ -813,8 +813,8 @@ CallbackPuzzle(Widget w, caddr_t clientData, barrelCallbackStruct *callData)
 			XtVaGetValues(puzzle,
 				XtNdelay, &delay, NULL);
 			oldDelay = delay;
-			if (delay > MAXSPEED - MINSPEED)
-				delay = MAXSPEED - MINSPEED;
+			if (delay > MAX_SPEED - MIN_SPEED)
+				delay = MAX_SPEED - MIN_SPEED;
 			if (delay < 0)
 				delay = 0;
 			if (delay != oldDelay) {
@@ -822,7 +822,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, barrelCallbackStruct *callData)
 					XtNdelay, delay, NULL);
 			}
 			XmScaleSetValue(speed,
-				MAXSPEED + MINSPEED - delay - 1);
+				MAX_SPEED + MIN_SPEED - delay - 1);
 		}
 		return;
 #endif
@@ -1353,14 +1353,14 @@ PracticeToggle(Widget w, XtPointer clientData,
 	if (practice)
 		(void) strcpy(messageDsp, "");
 	else
-		(void) strncpy(messageDsp, "Randomize to start", MESSAGELEN);
+		(void) strncpy(messageDsp, "Randomize to start", MESSAGE_LENGTH);
 	PrintState(message, messageDsp);
 }
 
 static void
 SpeedSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 {
-	int delay = MAXSPEED + MINSPEED - cbs->value - 1, oldDelay;
+	int delay = MAX_SPEED + MIN_SPEED - cbs->value - 1, oldDelay;
 
 	XtVaGetValues(puzzle,
 		XtNdelay, &oldDelay, NULL);
@@ -1391,7 +1391,7 @@ static Widget
 createQuery(Widget w, char *text, char *title, XtCallbackProc callback)
 {
 	Widget button, messageBox;
-	char titleDsp[FILENAMELEN + 8];
+	char titleDsp[FILE_NAME_LENGTH + 8];
 	XmString titleString = NULL, messageString = NULL;
 	static XmStringCharSet charSet =
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
@@ -1417,7 +1417,7 @@ static Widget
 createHelp(Widget w, char *text, char *title)
 {
 	Widget button, messageBox;
-	char titleDsp[FILENAMELEN + 8];
+	char titleDsp[FILE_NAME_LENGTH + 8];
 	XmString titleString = NULL, messageString = NULL, buttonString = NULL;
 	static XmStringCharSet charSet =
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
@@ -1679,9 +1679,9 @@ main(int argc, char **argv)
 	tile = XtVaCreateManagedWidget("tile",
 		xmScaleWidgetClass, tilesRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Tiles", 6,
-		XmNminimum, MINTILES,
-		XmNmaximum, MAXTILES,
-		XmNvalue, DEFAULTTILES,
+		XmNminimum, MIN_TILES,
+		XmNmaximum, MAX_TILES,
+		XmNvalue, DEFAULT_TILES,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
 	XtAddCallback(tile, XmNvalueChangedCallback,
@@ -1689,9 +1689,9 @@ main(int argc, char **argv)
 	face = XtVaCreateManagedWidget("face",
 		xmScaleWidgetClass, tilesRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Faces", 6,
-		XmNminimum, MINFACES,
-		XmNmaximum, MAXFACES,
-		XmNvalue, DEFAULTFACES,
+		XmNminimum, MIN_FACES,
+		XmNmaximum, MAX_FACES,
+		XmNvalue, DEFAULT_FACES,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
 	XtAddCallback(face, XmNvalueChangedCallback,
@@ -1705,9 +1705,9 @@ main(int argc, char **argv)
 	speed = XtVaCreateManagedWidget("Animation Speed",
 		xmScaleWidgetClass, speedRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Animation Speed", 16,
-		XmNminimum, MINSPEED,
-		XmNmaximum, MAXSPEED,
-		XmNvalue, MAXSPEED - DEFAULTDELAY,
+		XmNminimum, MIN_SPEED,
+		XmNmaximum, MAX_SPEED,
+		XmNvalue, MAX_SPEED - DEFAULT_DELAY,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
 	XtAddCallback(speed, XmNvalueChangedCallback,
@@ -1719,17 +1719,17 @@ main(int argc, char **argv)
 		XmNpacking, XmPACK_COLUMN, NULL);
 	orientizeSwitch = XtVaCreateManagedWidget("Oriented",
 		xmToggleButtonWidgetClass, switchRowCol,
-		XmNset, DEFAULTORIENT, NULL);
+		XmNset, DEFAULT_ORIENT, NULL);
 	XtAddCallback(orientizeSwitch, XmNvalueChangedCallback,
 		(XtCallbackProc) OrientToggle, (XtPointer) NULL);
 	pairsSwitch = XtVaCreateManagedWidget("Pairs rigid",
 		xmToggleButtonWidgetClass, switchRowCol,
-		XmNset, DEFAULTPAIRS, NULL);
+		XmNset, DEFAULT_PAIRS, NULL);
 	XtAddCallback(pairsSwitch, XmNvalueChangedCallback,
 		(XtCallbackProc) PairsToggle, (XtPointer) NULL);
 	practiceSwitch = XtVaCreateManagedWidget("Practice",
 		xmToggleButtonWidgetClass, switchRowCol,
-		XmNset, DEFAULTPRACTICE, NULL);
+		XmNset, DEFAULT_PRACTICE, NULL);
 	XtAddCallback(practiceSwitch, XmNvalueChangedCallback,
 		(XtCallbackProc) PracticeToggle, (XtPointer) NULL);
 	messageRowCol = XtVaCreateManagedWidget("messageRowCol",
