@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 2007	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1994 - 2007	David A. Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -196,10 +196,10 @@ static XtResource resourcesPuzzle[] =
 {
 	{XtNwidth, XtCWidth, XtRDimension, sizeof (Dimension),
 	 XtOffset(CubesWidget, core.width),
-	 XtRString, (caddr_t) "512"},
+	 XtRString, (caddr_t) "516"},
 	{XtNheight, XtCHeight, XtRDimension, sizeof (Dimension),
 	 XtOffset(CubesWidget, core.height),
-	 XtRString, (caddr_t) "512"},
+	 XtRString, (caddr_t) "516"},
 	{XtNmono, XtCMono, XtRBoolean, sizeof (Boolean),
 	 XtOffset(CubesWidget, cubes.mono),
 	 XtRString, (caddr_t) "FALSE"},
@@ -214,12 +214,12 @@ static XtResource resourcesPuzzle[] =
 	 XtRString, (caddr_t) XtDefaultBackground},
 	{XtNframeColor, XtCColor, XtRPixel, sizeof (Pixel),
 	 XtOffset(CubesWidget, cubes.frameColor),
-	 XtRString, (caddr_t) "cyan" /* XtDefaultForeground*/},
+	 XtRString, (caddr_t) "cyan" /*XtDefaultForeground*/},
 	{XtNblockColor, XtCColor, XtRPixel, sizeof (Pixel),
 	 XtOffset(CubesWidget, cubes.blockColor),
 	 XtRString, (caddr_t) "gray75" /*XtDefaultForeground*/},
-	{XtNblockBorder, XtCColor, XtRPixel, sizeof (Pixel),
-	 XtOffset(CubesWidget, cubes.borderColor),
+	{XtNtextColor, XtCColor, XtRPixel, sizeof (Pixel),
+	 XtOffset(CubesWidget, cubes.textColor),
 	 XtRString, (caddr_t) "gray25" /*XtDefaultBackground*/},
 	{XtNinstall, XtCInstall, XtRBoolean, sizeof (Boolean),
 	 XtOffset(CubesWidget, cubes.install),
@@ -229,7 +229,7 @@ static XtResource resourcesPuzzle[] =
 	 XtRString, (caddr_t) PICTURE},
 	{XtNdelay, XtCDelay, XtRInt, sizeof (int),
 	 XtOffset(CubesWidget, cubes.delay),
-	 XtRString, (caddr_t) "10"}, /* DEFAULTDELAY */
+	 XtRString, (caddr_t) "10"}, /* DEFAULT_DELAY */
 	{XtNsound, XtCSound, XtRBoolean, sizeof (Boolean),
 	 XtOffset(CubesWidget, cubes.sound),
 	 XtRString, (caddr_t) "FALSE"},
@@ -244,16 +244,16 @@ static XtResource resourcesPuzzle[] =
 	 XtRString, (caddr_t) "9x15bold"},
 	{XtNsizeX, XtCSizeX, XtRInt, sizeof (int),
 	 XtOffset(CubesWidget, cubes.sizeX),
-	 XtRString, (caddr_t) "4"}, /* DEFAULTCUBESX */
+	 XtRString, (caddr_t) "4"}, /* DEFAULT_CUBESX */
 	{XtNsizeY, XtCSizeY, XtRInt, sizeof (int),
 	 XtOffset(CubesWidget, cubes.sizeY),
-	 XtRString, (caddr_t) "4"}, /* DEFAULTCUBESY */
+	 XtRString, (caddr_t) "4"}, /* DEFAULT_CUBESY */
 	{XtNsizeZ, XtCSizeZ, XtRInt, sizeof (int),
 	 XtOffset(CubesWidget, cubes.sizeZ),
-	 XtRString, (caddr_t) "1"}, /* DEFAULTCUBESZ */
+	 XtRString, (caddr_t) "1"}, /* DEFAULT_CUBESZ */
 	{XtNbase, XtCBase, XtRInt, sizeof (int),
 	 XtOffset(CubesWidget, cubes.base),
-	 XtRString, (caddr_t) "10"}, /* DEFAULTBASE */
+	 XtRString, (caddr_t) "10"}, /* DEFAULT_BASE */
 	{XtNuserName, XtCUserName, XtRString, sizeof (String),
 	 XtOffset(CubesWidget, cubes.userName),
 	 XtRString, (caddr_t) ""},
@@ -387,41 +387,41 @@ CheckBlocks(CubesWidget w)
 {
 	char *buf1 = NULL, *buf2 = NULL;
 
-	if (w->cubes.sizeX < MINCUBES) {
+	if (w->cubes.sizeX < MIN_CUBES) {
 		intCat(&buf1,
 			"Number of cubes in X direction out of bounds, use at least ",
-			MINCUBES);
+			MIN_CUBES);
 		stringCat(&buf2, buf1, ", defaulting to ");
 		free(buf1);
-		intCat(&buf1, buf2, DEFAULTCUBESX);
+		intCat(&buf1, buf2, DEFAULT_CUBESX);
 		free(buf2);
 		DISPLAY_WARNING(buf1);
 		free(buf1);
-		w->cubes.sizeX = DEFAULTCUBESX;
+		w->cubes.sizeX = DEFAULT_CUBESX;
 	}
-	if (w->cubes.sizeY < MINCUBES) {
+	if (w->cubes.sizeY < MIN_CUBES) {
 		intCat(&buf1,
 			"Number of cubes in Y direction out of bounds, use at least ",
-			MINCUBES);
+			MIN_CUBES);
 		stringCat(&buf2, buf1, ", defaulting to ");
 		free(buf1);
-		intCat(&buf1, buf2, DEFAULTCUBESY);
+		intCat(&buf1, buf2, DEFAULT_CUBESY);
 		free(buf2);
 		DISPLAY_WARNING(buf1);
 		free(buf1);
-		w->cubes.sizeY = DEFAULTCUBESY;
+		w->cubes.sizeY = DEFAULT_CUBESY;
 	}
-	if (w->cubes.sizeZ < MINCUBES) {
+	if (w->cubes.sizeZ < MIN_CUBES) {
 		intCat(&buf1,
 			"Number of cubes in Z direction out of bounds, use at least ",
-			MINCUBES);
+			MIN_CUBES);
 		stringCat(&buf2, buf1, ", defaulting to ");
 		free(buf1);
-		intCat(&buf1, buf2, DEFAULTCUBESZ);
+		intCat(&buf1, buf2, DEFAULT_CUBESZ);
 		free(buf2);
 		DISPLAY_WARNING(buf1);
 		free(buf1);
-		w->cubes.sizeZ = DEFAULTCUBESZ;
+		w->cubes.sizeZ = DEFAULT_CUBESZ;
 	}
 	if (w->cubes.delay < 0) {
 		intCat(&buf1, "Delay can not be negative (",
@@ -432,19 +432,19 @@ CheckBlocks(CubesWidget w)
 		free(buf2);
 		w->cubes.delay = -w->cubes.delay;
 	}
-	if (w->cubes.base < MINBASE || w->cubes.base > MAXBASE) {
-		intCat(&buf1, "Base out of bounds, use ", MINBASE);
+	if (w->cubes.base < MIN_BASE || w->cubes.base > MAX_BASE) {
+		intCat(&buf1, "Base out of bounds, use ", MIN_BASE);
 		stringCat(&buf2, buf1, "..");
 		free(buf1);
-		intCat(&buf1, buf2, MAXBASE);
+		intCat(&buf1, buf2, MAX_BASE);
 		free(buf2);
 		stringCat(&buf2, buf1, ", defaulting to ");
 		free(buf1);
-		intCat(&buf1, buf2, DEFAULTBASE);
+		intCat(&buf1, buf2, DEFAULT_BASE);
 		free(buf2);
 		DISPLAY_WARNING(buf1);
 		free(buf1);
-		w->cubes.base = DEFAULTBASE;
+		w->cubes.base = DEFAULT_BASE;
 	}
 }
 
@@ -483,9 +483,9 @@ CartesianX(CubesWidget w, int pos)
 	int x;
 
 	x = Column(w, pos) * w->cubes.offset.x + w->cubes.delta.x +
-		w->cubes.puzzleOffset.x;
+		w->cubes.puzzleOffset.x + 1;
 	if (!w->cubes.vertical) {
-		x += Stack(w, pos) * (w->cubes.sizeX * w->cubes.offset.x + 1);
+		x += Stack(w, pos) * (w->cubes.sizeX * w->cubes.offset.x + 5);
 	}
 	return x;
 }
@@ -496,9 +496,9 @@ CartesianY(CubesWidget w, int pos)
 	int y;
 
 	y = Row(w, pos) * w->cubes.offset.y + w->cubes.delta.y +
-		w->cubes.puzzleOffset.y;
+		w->cubes.puzzleOffset.y + 1;
 	if (w->cubes.vertical) {
-		y += Stack(w, pos) * (w->cubes.sizeY * w->cubes.offset.y + 1);
+		y += Stack(w, pos) * (w->cubes.sizeY * w->cubes.offset.y + 5);
 	}
 	return y;
 }
@@ -643,8 +643,8 @@ DrawBlock(CubesWidget w, int pos, Boolean blank, Boolean erase,
 	sx = CartesianX(w, block);
 	sy = CartesianY(w, block);
 	if (blank) {
-		FILLRECTANGLE(w, dr,
-			(erase) ? w->cubes.inverseGC : w->cubes.blockGC,
+		FILLRECTANGLE(w, dr, (erase) ?
+			w->cubes.inverseGC[2] : w->cubes.blockGC[1],
 			dx, dy,
 			w->cubes.blockSize.x, w->cubes.blockSize.y);
 		return;
@@ -660,11 +660,11 @@ DrawBlock(CubesWidget w, int pos, Boolean blank, Boolean erase,
 		SRCCOPY);
 	(void) SelectObject(w->core.memDC, w->core.hOldBitmap);
 #else
-	XSetGraphicsExposures(XtDisplay(w), w->cubes.blockGC, False);
+	XSetGraphicsExposures(XtDisplay(w), w->cubes.blockGC[1], False);
 	XCopyArea(XtDisplay(w),
 		w->cubes.bufferBlocks[pressedOffset],
 		XtWindow(w),
-		w->cubes.blockGC,
+		w->cubes.blockGC[1],
 		sx, sy,
 		w->cubes.blockSize.x, w->cubes.blockSize.y,
 		dx, dy);
@@ -686,8 +686,8 @@ DrawBlockPiece(CubesWidget w, int pos, Boolean blank, Boolean erase,
 	sx = CartesianX(w, block);
 	sy = CartesianY(w, block);
 	if (blank) {
-		FILLRECTANGLE(w, dr,
-			(erase) ? w->cubes.inverseGC : w->cubes.blockGC,
+		FILLRECTANGLE(w, dr, (erase) ?
+			w->cubes.inverseGC[2] : w->cubes.blockGC[1],
 			dx + lox, dy + loy,
 			lsx, lsy);
 		return;
@@ -703,11 +703,11 @@ DrawBlockPiece(CubesWidget w, int pos, Boolean blank, Boolean erase,
 		SRCCOPY);
 	(void) SelectObject(w->core.memDC, w->core.hOldBitmap);
 #else
-	XSetGraphicsExposures(XtDisplay(w), w->cubes.blockGC, False);
+	XSetGraphicsExposures(XtDisplay(w), w->cubes.blockGC[1], False);
 	XCopyArea(XtDisplay(w),
 		w->cubes.bufferBlocks[pressedOffset],
 		XtWindow(w),
-		w->cubes.blockGC,
+		w->cubes.blockGC[1],
 		sx + lox, sy + loy,
 		lsx, lsy,
 		dx + lox, dy + loy);
@@ -718,23 +718,23 @@ static void
 DrawBufferedBlock(CubesWidget w, int pos, int pressedOffset)
 {
 	Pixmap *dr;
-	GC blockGC, borderGC;
+	GC blockGC, textGC;
 	int dx, dy, block = SolvedPosition(w, pos);
 	int i = 0, digitOffsetX = 0;
 	char buf[65];
 
 	dr = &(w->cubes.bufferBlocks[pressedOffset]);
-	blockGC = w->cubes.blockGC;
-	borderGC = w->cubes.borderGC;
+	blockGC = w->cubes.blockGC[1];
+	textGC = w->cubes.textGC;
 	dx = CartesianX(w, pos) + pressedOffset;
 	dy = CartesianY(w, pos) + pressedOffset;
 	if (pressedOffset != 0) {
-		drawShadow(w, *dr, w->cubes.blockDarkerGC,
+		drawShadow(w, *dr, w->cubes.blockGC[2],
 			dx - pressedOffset, dy - pressedOffset,
 			w->cubes.blockSize.x - 1, w->cubes.blockSize.y - 1);
 	}
 	fill3DRect(w, *dr, blockGC,
-		w->cubes.blockDarkerGC, w->cubes.blockBrighterGC,
+		w->cubes.blockGC[2], w->cubes.blockGC[0],
 		dx, dy, w->cubes.blockSize.x, w->cubes.blockSize.y,
 		pressedOffset == 0);
 	(void) int2String(w, buf, block, w->cubes.base, True);
@@ -743,7 +743,7 @@ DrawBufferedBlock(CubesWidget w, int pos, int pressedOffset)
 		digitOffsetX += w->cubes.digitOffset.x;
 		i++;
 	}
-	DRAWTEXT(w, *dr, borderGC,
+	DRAWTEXT(w, *dr, textGC,
 		dx + w->cubes.blockSize.x / 2 - digitOffsetX,
 		dy + w->cubes.blockSize.y / 2 + w->cubes.digitOffset.y,
 		buf, i);
@@ -778,16 +778,16 @@ DrawBlockFrame(CubesWidget w, int xR, int yR, int wR, int hR, int incAt)
 		/* Perfectionism here...
 		 * have the erasing square be 3D also */
 		FILLRECTANGLE(w, dr,
-			w->cubes.blockBrighterGC,
+			w->cubes.blockGC[0],
 			xR + incAt, yR + incAt, 2, hR - 2 * incAt);
 		FILLRECTANGLE(w, dr,
-			w->cubes.blockBrighterGC,
+			w->cubes.blockGC[0],
 			xR + incAt, yR + incAt, wR - 2 * incAt, 2);
 		FILLRECTANGLE(w, dr,
-			w->cubes.blockDarkerGC,
+			w->cubes.blockGC[2],
 			xR + wR - incAt - 2, yR + incAt, 2, hR - 2 * incAt);
 		FILLRECTANGLE(w, dr,
-			w->cubes.blockDarkerGC,
+			w->cubes.blockGC[2],
 			xR + incAt, yR + hR - incAt - 2, wR - 2 * incAt, 2);
 	}
 }
@@ -845,25 +845,25 @@ AnimateSlide(CubesWidget w, int numBlocks, int dir, int fast, Boolean logMoves)
 	      switch (dir) {
 	      case TOP:
 		FILLRECTANGLE(w, dr,
-		  w->cubes.inverseGC,
+		  w->cubes.inverseGC[2],
 		  ix, iy + w->cubes.blockSize.y,
 		  w->cubes.blockSize.x, gapI);
 		break;
 	      case RIGHT:
 		FILLRECTANGLE(w, dr,
-		  w->cubes.inverseGC,
+		  w->cubes.inverseGC[2],
 		  ix - gapI,
 		  iy, gapI, w->cubes.blockSize.y);
 		break;
 	      case BOTTOM:
 		FILLRECTANGLE(w, dr,
-		  w->cubes.inverseGC,
+		  w->cubes.inverseGC[2],
 		  ix, iy - gapI,
 		  w->cubes.blockSize.x, gapI);
 		break;
 	      case LEFT:
 		FILLRECTANGLE(w, dr,
-		  w->cubes.inverseGC,
+		  w->cubes.inverseGC[2],
 		  ix + w->cubes.blockSize.x, iy,
 		  gapI, w->cubes.blockSize.y);
 		break;
@@ -872,25 +872,25 @@ AnimateSlide(CubesWidget w, int numBlocks, int dir, int fast, Boolean logMoves)
 	      switch (dir) {
 	      case TOP:
 		FILLRECTANGLE(w, dr,
-		  w->cubes.inverseGC,
+		  w->cubes.inverseGC[2],
 		  ix, iy + w->cubes.blockSize.y,
 		  w->cubes.blockSize.x, fillBeginI - iy);
 		break;
 	      case RIGHT:
 		FILLRECTANGLE(w, dr,
-		  w->cubes.inverseGC,
+		  w->cubes.inverseGC[2],
 		  fillBeginI, iy,
 		  ix - fillBeginI, w->cubes.blockSize.y);
 		break;
 	      case BOTTOM:
 		FILLRECTANGLE(w, dr,
-		  w->cubes.inverseGC,
+		  w->cubes.inverseGC[2],
 		  ix, fillBeginI,
 		  w->cubes.blockSize.x, iy - fillBeginI);
 		break;
 	      case LEFT:
 		FILLRECTANGLE(w, dr,
-		  w->cubes.inverseGC,
+		  w->cubes.inverseGC[2],
 		  ix + w->cubes.blockSize.x, iy,
 		  fillBeginI - ix, w->cubes.blockSize.y);
 		break;
@@ -930,17 +930,17 @@ AnimateMove(CubesWidget w, int fromPos, int fast)
 	incAt = MAX(incTo * fast / (2 * w->cubes.numSlices), 1);
 
 	FILLRECTANGLE(w, dr,
-		w->cubes.inverseGC,
+		w->cubes.inverseGC[2],
 		fx, fy, incAt, w->cubes.blockSize.y);
 	FILLRECTANGLE(w, dr,
-		w->cubes.inverseGC,
+		w->cubes.inverseGC[2],
 		fx, fy, w->cubes.blockSize.x, incAt);
 	FILLRECTANGLE(w, dr,
-		w->cubes.inverseGC,
+		w->cubes.inverseGC[2],
 		fx + w->cubes.blockSize.x - incAt, fy,
 		incAt, w->cubes.blockSize.y);
 	FILLRECTANGLE(w, dr,
-		w->cubes.inverseGC,
+		w->cubes.inverseGC[2],
 		fx, fy + w->cubes.blockSize.y - incAt,
 		w->cubes.blockSize.x, incAt);
 	FLUSH(w);
@@ -953,16 +953,16 @@ AnimateMove(CubesWidget w, int fromPos, int fast)
 		/* start disappear block */
 		if (wR > 0 && hR > 0) {
 			FILLRECTANGLE(w, dr,
-				w->cubes.inverseGC,
+				w->cubes.inverseGC[2],
 				xR, yR, incAt, hR);
 			FILLRECTANGLE(w, dr,
-				w->cubes.inverseGC,
+				w->cubes.inverseGC[2],
 				xR, yR, wR, incAt);
 			FILLRECTANGLE(w, dr,
-				w->cubes.inverseGC,
+				w->cubes.inverseGC[2],
 				xR + wR - incAt, yR, incAt, hR);
 			FILLRECTANGLE(w, dr,
-				w->cubes.inverseGC,
+				w->cubes.inverseGC[2],
 				xR, yR + hR - incAt, wR, incAt);
 		}
 		if (!(w->cubes.picture && *(w->cubes.picture))) {
@@ -986,9 +986,9 @@ AnimateMove(CubesWidget w, int fromPos, int fast)
 				incAt);
 		}
 #if 0
-			fill3DRect(w, dr, w->cubes.blockGC,
-				w->cubes.blockDarkerGC,
-				w->cubes.blockBrighterGC,
+			fill3DRect(w, dr, w->cubes.blockGC[1],
+				w->cubes.blockGC[2],
+				w->cubes.blockGC[0],
 				xToCenter - inc - (w->cubes.blockSize.x / 2 - w->cubes.blockSize.y / 2) + dx,
 				yToCenter - inc + dy,
 				2 * (inc + w->cubes.blockSize.x / 2 - w->cubes.blockSize.y / 2),
@@ -1011,9 +1011,9 @@ AnimateMove(CubesWidget w, int fromPos, int fast)
 				incAt);
 		}
 #if 0
-			fill3DRect(w, dr, w->cubes.blockGC,
-				w->cubes.blockDarkerGC,
-				w->cubes.blockBrighterGC,
+			fill3DRect(w, dr, w->cubes.blockGC[1],
+				w->cubes.blockGC[2],
+				w->cubes.blockGC[0],
 				xToCenter - inc + dx,
 				yToCenter - inc - (w->cubes.blockSize.y / 2 - w->cubes.blockSize.x / 2) + dy,
 				2 * inc,
@@ -1030,10 +1030,42 @@ AnimateMove(CubesWidget w, int fromPos, int fast)
 	w->cubes.spacePosition = fromPos;
 }
 
+static void
+Draw3DFrame(const CubesWidget w, Pixmap dr, Boolean inside,
+	int x, int y, int width, int height)
+{
+	GC gc;
+
+	if (inside)
+		gc = w->cubes.inverseGC[3];
+	else
+		gc = w->cubes.inverseGC[2];
+	FILLRECTANGLE(w, dr, gc,
+		x, y, width, 1);
+	FILLRECTANGLE(w, dr, gc,
+		x, y + 1, 1, height - 1);
+	FILLRECTANGLE(w, dr, gc,
+		x + 1, y + 1, width - 2, 1);
+	FILLRECTANGLE(w, dr, gc,
+		x + 1, y + 2, 1, height - 3);
+	if (inside)
+		gc = w->cubes.inverseGC[0];
+	else
+		gc = w->cubes.inverseGC[2];
+	FILLRECTANGLE(w, dr, gc,
+		x + 1, y + height - 1, width - 1, 1);
+	FILLRECTANGLE(w, dr, gc,
+		x + width - 1, y + 1, 1, height - 2);
+	FILLRECTANGLE(w, dr, gc,
+		x + 2, y + height - 2, width - 3, 1);
+	FILLRECTANGLE(w, dr, gc,
+		x + width - 2, y + 2, 1, height - 4);
+}
+
 static void
 EraseFrame(const CubesWidget w, Pixmap dr)
 {
-	FILLRECTANGLE(w, dr, w->cubes.inverseGC,
+	FILLRECTANGLE(w, dr, w->cubes.inverseGC[2],
 		0, 0, w->core.width, w->core.height);
 }
 
@@ -1041,23 +1073,22 @@ static void
 DrawFrame(CubesWidget w, Pixmap dr, Boolean focus)
 {
 	int sumX, sumY, sumZ, offsetX, offsetY, dz, k;
-	GC gc = (focus) ? w->cubes.frameGC : w->cubes.borderGC;
 
 	offsetX = w->cubes.puzzleOffset.x;
 	offsetY = w->cubes.puzzleOffset.y;
-	FILLRECTANGLE(w, dr, w->cubes.borderGC,
+	FILLRECTANGLE(w, dr, w->cubes.inverseGC[4],
 		0, 0, w->core.width, offsetY);
-	FILLRECTANGLE(w, dr, w->cubes.borderGC,
+	FILLRECTANGLE(w, dr, w->cubes.inverseGC[4],
 		0, w->core.height - offsetY,
 		w->core.width, offsetY);
-	FILLRECTANGLE(w, dr, w->cubes.borderGC,
-		0, 0, offsetX, w->core.height);
-	FILLRECTANGLE(w, dr, w->cubes.borderGC,
-		w->core.width - offsetX, 0,
-		offsetX, w->core.height);
+	FILLRECTANGLE(w, dr, w->cubes.inverseGC[4],
+		0, offsetY, offsetX, w->core.height - offsetY);
+	FILLRECTANGLE(w, dr, w->cubes.inverseGC[4],
+		w->core.width - offsetX, offsetY,
+		offsetX, w->core.height - offsetY);
 
-	sumX = w->cubes.sizeX * w->cubes.offset.x + 1;
-	sumY = w->cubes.sizeY * w->cubes.offset.y + 1;
+	sumX = w->cubes.sizeX * w->cubes.offset.x + 4;
+	sumY = w->cubes.sizeY * w->cubes.offset.y + 4;
 	if (w->cubes.vertical) {
 		sumZ = offsetY;
 		dz = sumY;
@@ -1067,23 +1098,21 @@ DrawFrame(CubesWidget w, Pixmap dr, Boolean focus)
 	}
 	for (k = 0; k < w->cubes.sizeZ; k++) {
 		if (w->cubes.vertical) {
-			FILLRECTANGLE(w, dr, gc,
-				offsetX, sumZ, 1, sumY);
-			FILLRECTANGLE(w, dr, gc,
-				offsetX, sumZ, sumX, 1);
-			FILLRECTANGLE(w, dr, gc,
-				sumX + offsetX, sumZ, 1, sumY + 1);
-			FILLRECTANGLE(w, dr, gc,
-				offsetX, sumY + sumZ, sumX + 1, 1);
+			Draw3DFrame(w, dr, focus,
+				offsetX, sumZ + k, sumX, sumY);
+			if (k > 0)
+				FILLRECTANGLE(w, dr, (focus) ?
+					w->cubes.frameGC : w->cubes.inverseGC[2],
+					offsetX, sumZ + k - 1,
+					sumX, 1);
 		} else {
-			FILLRECTANGLE(w, dr, gc,
-				sumZ, offsetY, 1, sumY);
-			FILLRECTANGLE(w, dr, gc,
-				sumZ, offsetY, sumX, 1);
-			FILLRECTANGLE(w, dr, gc,
-				sumX + sumZ, offsetY, 1, sumY + 1);
-			FILLRECTANGLE(w, dr, gc,
-				sumZ, sumY + offsetY, sumX + 1, 1);
+			Draw3DFrame(w, dr, focus,
+				sumZ + k, offsetY, sumX, sumY);
+			if (k > 0)
+				FILLRECTANGLE(w, dr, (focus) ?
+					w->cubes.frameGC : w->cubes.inverseGC[2],
+					sumZ + k - 1, offsetY,
+					1, sumY);
 		}
 		sumZ += dz;
 	}
@@ -1111,8 +1140,10 @@ MoveBlocks(CubesWidget w, int from, int fast)
 		int j = w->cubes.currentRow[1] = Row(w, from);
 		int k = w->cubes.currentRow[2] = Stack(w, from);
 
-		int l = i + w->cubes.sizeX * j - w->cubes.spacePosition % w->cubes.sizeRect;
-		/* int m = i + w->cubes.sizeX * j + w->cubes.sizeRect * k - w->cubes.spacePosition; */
+		int l = i + w->cubes.sizeX *
+			j - w->cubes.spacePosition % w->cubes.sizeRect;
+		/* int m = i + w->cubes.sizeX * j +
+			w->cubes.sizeRect * k - w->cubes.spacePosition; */
 		/* Order important if w->cubes.sizeX = 1 */
 
 		w->cubes.currentPosition = from;
@@ -1237,7 +1268,7 @@ MovePuzzle(CubesWidget w, const int direction, const int control)
 		reason = ACTION_IGNORE;
 		switch (direction) {
 		case TOP:
-			if (w->cubes.sizeY <= MINCUBES)
+			if (w->cubes.sizeY <= MIN_CUBES)
 				return FALSE;
 			reason = ACTION_DECY;
 			break;
@@ -1248,12 +1279,12 @@ MovePuzzle(CubesWidget w, const int direction, const int control)
 			reason = ACTION_INCY;
 			break;
 		case LEFT:
-			if (w->cubes.sizeX <= MINCUBES)
+			if (w->cubes.sizeX <= MIN_CUBES)
 				return FALSE;
 			reason = ACTION_DECX;
 			break;
 		case INWARDS:
-			if (w->cubes.sizeZ <= MINCUBES)
+			if (w->cubes.sizeZ <= MIN_CUBES)
 				return FALSE;
 			reason = ACTION_DECZ;
 			break;
@@ -1320,20 +1351,22 @@ PositionToBlock(CubesWidget w, int x, int y, int *i, int *j, int *k)
 		*i = (x - w->cubes.delta.x / 2 -
 			w->cubes.puzzleOffset.x) / w->cubes.offset.x;
 		*j = ((y - w->cubes.delta.y / 2 -
-			w->cubes.puzzleOffset.y) % (w->cubes.sizeY * w->cubes.offset.y +
-			w->cubes.delta.y - 1)) / w->cubes.offset.y;
+			w->cubes.puzzleOffset.y) % (w->cubes.sizeY *
+			w->cubes.offset.y + w->cubes.delta.y + 4)) /
+			w->cubes.offset.y;
 		*k = (y - w->cubes.delta.y / 2 -
-			w->cubes.puzzleOffset.y) / (w->cubes.sizeY * w->cubes.offset.y +
-			w->cubes.delta.y - 1);
+			w->cubes.puzzleOffset.y) / (w->cubes.sizeY *
+			w->cubes.offset.y + w->cubes.delta.y + 4);
 	} else {
 		*i = ((x - w->cubes.delta.x / 2 -
-			w->cubes.puzzleOffset.x) % (w->cubes.sizeX * w->cubes.offset.x +
-			w->cubes.delta.x - 1)) / w->cubes.offset.x;
+			w->cubes.puzzleOffset.x) % (w->cubes.sizeX *
+			w->cubes.offset.x + w->cubes.delta.x + 4)) /
+			w->cubes.offset.x;
 		*j = (y - w->cubes.delta.y / 2 -
 			w->cubes.puzzleOffset.y) / w->cubes.offset.y;
 		*k = (x - w->cubes.delta.x / 2 -
-			w->cubes.puzzleOffset.x) / (w->cubes.sizeX * w->cubes.offset.x +
-			w->cubes.delta.y - 1);
+			w->cubes.puzzleOffset.x) / (w->cubes.sizeX *
+			w->cubes.offset.x + w->cubes.delta.y + 4);
 	}
 	if (*i >= 0 && *j >= 0 && *k >= 0 && *i < w->cubes.sizeX &&
 			*j < w->cubes.sizeY && *k < w->cubes.sizeZ)
@@ -1602,7 +1635,7 @@ GetBlocks(CubesWidget w)
 	flushMoves(w, &redo, FALSE);
 	while ((c = getc(fp)) != EOF && c != SYMBOL);
 	(void) fscanf(fp, "%d", &sizeX);
-	if (sizeX >= MINCUBES) {
+	if (sizeX >= MIN_CUBES) {
 		for (i = w->cubes.sizeX; i < sizeX; i++) {
 			setPuzzle(w, ACTION_INCX);
 		}
@@ -1615,7 +1648,7 @@ GetBlocks(CubesWidget w)
 		free(buf1);
 		stringCat(&buf1, buf2, " should be between ");
 		free(buf2);
-		intCat(&buf2, buf1, MINCUBES);
+		intCat(&buf2, buf1, MIN_CUBES);
 		free(buf1);
 		stringCat(&buf1, buf2, " and MAXINT");
 		free(buf2);
@@ -1624,7 +1657,7 @@ GetBlocks(CubesWidget w)
 	}
 	while ((c = getc(fp)) != EOF && c != SYMBOL);
 	(void) fscanf(fp, "%d", &sizeY);
-	if (sizeY >= MINCUBES) {
+	if (sizeY >= MIN_CUBES) {
 		for (i = w->cubes.sizeY; i < sizeY; i++) {
 			setPuzzle(w, ACTION_INCY);
 		}
@@ -1637,7 +1670,7 @@ GetBlocks(CubesWidget w)
 		free(buf1);
 		stringCat(&buf1, buf2, " should be between ");
 		free(buf2);
-		intCat(&buf2, buf1, MINCUBES);
+		intCat(&buf2, buf1, MIN_CUBES);
 		free(buf1);
 		stringCat(&buf1, buf2, " and MAXINT");
 		free(buf2);
@@ -1646,7 +1679,7 @@ GetBlocks(CubesWidget w)
 	}
 	while ((c = getc(fp)) != EOF && c != SYMBOL);
 	(void) fscanf(fp, "%d", &sizeZ);
-	if (sizeZ >= MINCUBES) {
+	if (sizeZ >= MIN_CUBES) {
 		for (i = w->cubes.sizeZ; i < sizeZ; i++) {
 			setPuzzle(w, ACTION_INCZ);
 		}
@@ -1659,7 +1692,7 @@ GetBlocks(CubesWidget w)
 		free(buf1);
 		stringCat(&buf1, buf2, " should be between ");
 		free(buf2);
-		intCat(&buf2, buf1, MINCUBES);
+		intCat(&buf2, buf1, MIN_CUBES);
 		free(buf1);
 		stringCat(&buf1, buf2, " and MAXINT");
 		free(buf2);
@@ -1931,25 +1964,26 @@ SoundBlocks(CubesWidget w)
 	w->cubes.sound = !w->cubes.sound;
 }
 
-#define FACTOR 0.7
+#define BRIGHT_FACTOR 0.8
+#define DARK_FACTOR 0.75
 
 #ifdef WINVER
-#define MAXINTENSITY 0xFF
+#define MAX_INTENSITY 0xFF
 static int
 brighter(const int light)
 {
-	int i = (int) ((1 - FACTOR) * MAXINTENSITY);
+	int i = (int) ((1 - BRIGHT_FACTOR) * MAX_INTENSITY);
 	int temp = light;
 
 	if (temp < i)
 		temp = i;
-	return MIN(temp / FACTOR, MAXINTENSITY);
+	return MIN(temp / BRIGHT_FACTOR, MAX_INTENSITY);
 }
 
 static int
 darker(const int light)
 {
-	return (int) (light * FACTOR);
+	return (int) (light * DARK_FACTOR);
 }
 
 static void
@@ -1961,17 +1995,17 @@ SetValuesPuzzle(CubesWidget w)
 	char szBuf[80];
 
 	w->cubes.sizeX = GetPrivateProfileInt(SECTION, "sizeX",
-		DEFAULTCUBESX, INIFILE);
+		DEFAULT_CUBESX, INIFILE);
 	w->cubes.sizeY = GetPrivateProfileInt(SECTION, "sizeY",
-		DEFAULTCUBESY, INIFILE);
+		DEFAULT_CUBESY, INIFILE);
 	w->cubes.sizeZ = GetPrivateProfileInt(SECTION, "sizeZ",
-		DEFAULTCUBESZ, INIFILE);
+		DEFAULT_CUBESZ, INIFILE);
 	w->cubes.base = GetPrivateProfileInt(SECTION, "base",
-		DEFAULTBASE, INIFILE);
+		DEFAULT_BASE, INIFILE);
 	w->cubes.mono = (BOOL) GetPrivateProfileInt(SECTION, "mono",
-		DEFAULTMONO, INIFILE);
+		DEFAULT_MONO, INIFILE);
 	w->cubes.reverse = (BOOL) GetPrivateProfileInt(SECTION, "reverseVideo",
-		DEFAULTREVERSE, INIFILE);
+		DEFAULT_REVERSE, INIFILE);
 	/* cyan */
 	(void) GetPrivateProfileString(SECTION, "frameColor", "0 255 255",
 		szBuf, sizeof (szBuf), INIFILE);
@@ -1983,29 +2017,38 @@ SetValuesPuzzle(CubesWidget w)
 		szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
-	w->cubes.blockGC = RGB(color.red, color.green, color.blue);
-	w->cubes.blockBrighterGC = RGB(brighter(color.red),
+	w->cubes.blockGC[1] = RGB(color.red, color.green, color.blue);
+	w->cubes.blockGC[0] = RGB(brighter(color.red),
 		brighter(color.green), brighter(color.blue));
-	w->cubes.blockDarkerGC = RGB(darker(color.red),
+	w->cubes.blockGC[2] = RGB(darker(color.red),
 		darker(color.green), darker(color.blue));
 	/* gray25 */
-	(void) GetPrivateProfileString(SECTION, "blockBorder", "64 64 64",
+	(void) GetPrivateProfileString(SECTION, "textColor", "64 64 64",
 		szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
-	w->cubes.borderGC = RGB(color.red, color.green, color.blue);
+	w->cubes.textGC = RGB(color.red, color.green, color.blue);
 	/* #AEB2C3 */
 	(void) GetPrivateProfileString(SECTION, "background", "174 178 195",
 		szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
-	w->cubes.inverseGC = RGB(color.red, color.green, color.blue);
+	w->cubes.inverseGC[1] = RGB(color.red, color.green, color.blue);
+	w->cubes.inverseGC[0] = RGB(brighter(color.red),
+		brighter(color.green), brighter(color.blue));
+	w->cubes.inverseGC[2] = RGB(darker(color.red),
+		darker(color.green), darker(color.blue));
+	w->cubes.inverseGC[3] = RGB(darker(darker(color.red)),
+		darker(darker(color.green)), darker(darker(color.blue)));
+	w->cubes.inverseGC[4] = RGB(darker(darker(darker(color.red))),
+		darker(darker(darker(color.green))),
+		darker(darker(darker(color.blue))));
 	(void) GetPrivateProfileString(SECTION, "picture", PICTURE,
 		szBuf, sizeof (szBuf), INIFILE);
 	(void) strcpy(w->cubes.picture, szBuf);
 	w->cubes.picture[80] = 0;
 	w->cubes.delay = GetPrivateProfileInt(SECTION, "delay",
-		DEFAULTDELAY, INIFILE);
+		DEFAULT_DELAY, INIFILE);
 	w->cubes.sound = (BOOL)
 		GetPrivateProfileInt(SECTION, "sound", 0, INIFILE);
 	(void) GetPrivateProfileString(SECTION, "bumpSound", BUMPSOUND,
@@ -2043,7 +2086,7 @@ DestroyPuzzle(CubesWidget w, HBRUSH brush)
 }
 
 #else
-#define MAXINTENSITY 0xFFFF
+#define MAX_INTENSITY 0xFFFF
 
 static Pixel
 brighter(CubesWidget w, Pixel pixel)
@@ -2051,19 +2094,19 @@ brighter(CubesWidget w, Pixel pixel)
 	XColor color;
 	Colormap colormap = (w->cubes.colormap == None) ?
 		w->cubes.oldColormap : w->cubes.colormap;
-	int i = (int) ((1 - FACTOR) * MAXINTENSITY);
+	int i = (int) ((1 - BRIGHT_FACTOR) * MAX_INTENSITY);
 
 	color.pixel = pixel;
-	XQueryColor(XtDisplay(w), colormap, &color);
+	VOID XQueryColor(XtDisplay(w), colormap, &color);
 	if (color.red < i)
 		color.red = i;
 	if (color.green < i)
 		color.green = i;
 	if (color.blue < i)
 		color.blue = i;
-	color.red = (unsigned short) MIN(color.red / FACTOR, MAXINTENSITY);
-	color.green = (unsigned short) MIN(color.green / FACTOR, MAXINTENSITY);
-	color.blue = (unsigned short) MIN(color.blue / FACTOR, MAXINTENSITY);
+	color.red = (unsigned short) MIN(color.red / BRIGHT_FACTOR, MAX_INTENSITY);
+	color.green = (unsigned short) MIN(color.green / BRIGHT_FACTOR, MAX_INTENSITY);
+	color.blue = (unsigned short) MIN(color.blue / BRIGHT_FACTOR, MAX_INTENSITY);
 	if (XAllocColor(XtDisplay(w), colormap, &color))
 		return color.pixel;
 	return pixel;
@@ -2077,10 +2120,10 @@ darker(CubesWidget w, Pixel pixel)
 		w->cubes.oldColormap : w->cubes.colormap;
 
 	color.pixel = pixel;
-	XQueryColor(XtDisplay(w), colormap, &color);
-	color.red = (unsigned short) (color.red * FACTOR);
-	color.green = (unsigned short) (color.green * FACTOR);
-	color.blue = (unsigned short) (color.blue * FACTOR);
+	VOID XQueryColor(XtDisplay(w), colormap, &color);
+	color.red = (unsigned short) (color.red * DARK_FACTOR);
+	color.green = (unsigned short) (color.green * DARK_FACTOR);
+	color.blue = (unsigned short) (color.blue * DARK_FACTOR);
 	if (XAllocColor(XtDisplay(w), colormap, &color))
 		return color.pixel;
 	return pixel;
@@ -2101,9 +2144,38 @@ SetAllColors(CubesWidget w)
 		values.foreground = w->cubes.background;
 		values.background = w->cubes.foreground;
 	}
-	if (w->cubes.inverseGC)
-		XtReleaseGC((Widget) w, w->cubes.inverseGC);
-	w->cubes.inverseGC = XtGetGC((Widget) w, valueMask, &values);
+	if (w->cubes.inverseGC[1])
+		XtReleaseGC((Widget) w, w->cubes.inverseGC[1]);
+	w->cubes.inverseGC[1] = XtGetGC((Widget) w, valueMask, &values);
+	if (!w->cubes.mono) {
+		values.foreground = brighter(w, (w->cubes.reverse) ?
+			w->cubes.foreground : w->cubes.background);
+	}
+	if (w->cubes.inverseGC[0])
+		XtReleaseGC((Widget) w, w->cubes.inverseGC[0]);
+	w->cubes.inverseGC[0] = XtGetGC((Widget) w, valueMask, &values);
+	if (!w->cubes.mono) {
+		values.foreground = darker(w, (w->cubes.reverse) ?
+			w->cubes.foreground : w->cubes.background);
+	}
+	if (w->cubes.inverseGC[2])
+		XtReleaseGC((Widget) w, w->cubes.inverseGC[2]);
+	w->cubes.inverseGC[2] = XtGetGC((Widget) w, valueMask, &values);
+	if (!w->cubes.mono) {
+		values.foreground = darker(w, darker(w, (w->cubes.reverse) ?
+			w->cubes.foreground : w->cubes.background));
+	}
+	if (w->cubes.inverseGC[3])
+		XtReleaseGC((Widget) w, w->cubes.inverseGC[3]);
+	w->cubes.inverseGC[3] = XtGetGC((Widget) w, valueMask, &values);
+	if (!w->cubes.mono) {
+		values.foreground = darker(w, darker(w, darker(w,
+			(w->cubes.reverse) ?  w->cubes.foreground :
+			w->cubes.background)));
+	}
+	if (w->cubes.inverseGC[4])
+		XtReleaseGC((Widget) w, w->cubes.inverseGC[4]);
+	w->cubes.inverseGC[4] = XtGetGC((Widget) w, valueMask, &values);
 	if (w->cubes.mono) {
 		if (w->cubes.reverse) {
 			values.foreground = w->cubes.background;
@@ -2114,7 +2186,7 @@ SetAllColors(CubesWidget w)
 		}
 	} else {
 		values.foreground = w->cubes.frameColor;
-		values.background = w->cubes.borderColor;
+		values.background = w->cubes.background;
 	}
 	if (w->cubes.frameGC)
 		XtReleaseGC((Widget) w, w->cubes.frameGC);
@@ -2129,24 +2201,24 @@ SetAllColors(CubesWidget w)
 		}
 	} else {
 		values.foreground = w->cubes.blockColor;
-		values.background = w->cubes.borderColor;
+		values.background = w->cubes.textColor;
 	}
 
-	if (w->cubes.blockGC)
-		XtReleaseGC((Widget) w, w->cubes.blockGC);
-	w->cubes.blockGC = XtGetGC((Widget) w, valueMask, &values);
+	if (w->cubes.blockGC[1])
+		XtReleaseGC((Widget) w, w->cubes.blockGC[1]);
+	w->cubes.blockGC[1] = XtGetGC((Widget) w, valueMask, &values);
 	if (!w->cubes.mono) {
 		values.foreground = brighter(w, w->cubes.blockColor);
 	}
-	if (w->cubes.blockBrighterGC)
-		XtReleaseGC((Widget) w, w->cubes.blockBrighterGC);
-	w->cubes.blockBrighterGC = XtGetGC((Widget) w, valueMask, &values);
+	if (w->cubes.blockGC[0])
+		XtReleaseGC((Widget) w, w->cubes.blockGC[0]);
+	w->cubes.blockGC[0] = XtGetGC((Widget) w, valueMask, &values);
 	if (!w->cubes.mono) {
 		values.foreground = darker(w, w->cubes.blockColor);
 	}
-	if (w->cubes.blockDarkerGC)
-		XtReleaseGC((Widget) w, w->cubes.blockDarkerGC);
-	w->cubes.blockDarkerGC = XtGetGC((Widget) w, valueMask, &values);
+	if (w->cubes.blockGC[2])
+		XtReleaseGC((Widget) w, w->cubes.blockGC[2]);
+	w->cubes.blockGC[2] = XtGetGC((Widget) w, valueMask, &values);
 	if (w->cubes.mono) {
 		if (w->cubes.reverse) {
 			values.foreground = w->cubes.foreground;
@@ -2156,14 +2228,14 @@ SetAllColors(CubesWidget w)
 			values.background = w->cubes.foreground;
 		}
 	} else {
-		values.foreground = w->cubes.borderColor;
+		values.foreground = w->cubes.textColor;
 		values.background = w->cubes.blockColor;
 	}
-	if (w->cubes.borderGC)
-		XtReleaseGC((Widget) w, w->cubes.borderGC);
-	w->cubes.borderGC = XtGetGC((Widget) w, valueMask, &values);
+	if (w->cubes.textGC)
+		XtReleaseGC((Widget) w, w->cubes.textGC);
+	w->cubes.textGC = XtGetGC((Widget) w, valueMask, &values);
 	if (w->cubes.fontInfo)
-		XSetFont(XtDisplay(w), w->cubes.borderGC,
+		XSetFont(XtDisplay(w), w->cubes.textGC,
 			w->cubes.fontInfo->fid);
 }
 
@@ -2176,7 +2248,7 @@ SetValuesPuzzle(Widget current, Widget request, Widget renew)
 
 	CheckBlocks(w);
 	if (w->cubes.font != c->cubes.font ||
-			w->cubes.borderColor != c->cubes.borderColor ||
+			w->cubes.textColor != c->cubes.textColor ||
 			w->cubes.reverse != c->cubes.reverse ||
 			w->cubes.mono != c->cubes.mono) {
 		loadFont(w);
@@ -2200,8 +2272,8 @@ SetValuesPuzzle(Widget current, Widget request, Widget renew)
 		redraw = True;
 	}
 	if (w->cubes.delay != c->cubes.delay) {
-		w->cubes.numSlices = ((w->cubes.delay < MAXSLICES) ?
-			w->cubes.delay + 1 : MAXSLICES);
+		w->cubes.numSlices = ((w->cubes.delay < MAX_SLICES) ?
+			w->cubes.delay + 1 : MAX_SLICES);
 	}
 	if (w->cubes.menu != ACTION_IGNORE) {
 		int menu = w->cubes.menu;
@@ -2257,22 +2329,21 @@ DestroyPuzzle(Widget old)
 {
 	CubesWidget w = (CubesWidget) old;
 	Display *display = XtDisplay(w);
-	int sel;
+	int i;
 
-	XtReleaseGC(old, w->cubes.blockGC);
-	XtReleaseGC(old, w->cubes.borderGC);
-	XtReleaseGC(old, w->cubes.blockBrighterGC);
-	XtReleaseGC(old, w->cubes.blockDarkerGC);
-	XtReleaseGC(old, w->cubes.frameGC);
-	XtReleaseGC(old, w->cubes.inverseGC);
+	XtReleaseGC(old, w->cubes.textGC);
+	for (i = 0; i < FG_SHADES; i++)
+		XtReleaseGC(old, w->cubes.blockGC[i]);
+	for (i = 0; i < BG_SHADES; i++)
+		XtReleaseGC(old, w->cubes.inverseGC[i]);
 	XtRemoveCallbacks(old, XtNselectCallback, w->cubes.select);
 	if (w->cubes.colormap != None) {
 		XInstallColormap(display, w->cubes.oldColormap);
 		XFreeColormap(display, w->cubes.colormap);
 	}
-	for (sel = 0; sel < 2; sel++)
-		if (w->cubes.bufferBlocks[sel] != None)
-			XFreePixmap(display, w->cubes.bufferBlocks[sel]);
+	for (i = 0; i < 2; i++)
+		if (w->cubes.bufferBlocks[i] != None)
+			XFreePixmap(display, w->cubes.bufferBlocks[i]);
 	if (w->cubes.fontInfo) {
 		XUnloadFont(XtDisplay(w), w->cubes.fontInfo->fid);
 		XFreeFont(display, w->cubes.fontInfo);
@@ -2370,12 +2441,12 @@ ResizeBlocks(CubesWidget w)
 	SetAllColors(w);
 	for (sel = 0; sel < 2; sel++) {
 		FILLRECTANGLE(w, w->cubes.bufferBlocks[sel],
-			w->cubes.inverseGC,
+			w->cubes.inverseGC[2],
 			0, 0, w->core.width, w->core.height);
 		if ((w->cubes.picture && *(w->cubes.picture))) {
 
 			(void) XPutImage(display, w->cubes.bufferBlocks[sel],
-				w->cubes.inverseGC, w->cubes.image, 0, 0,
+				w->cubes.inverseGC[2], w->cubes.image, 0, 0,
 				0, 0,
 				MIN(w->cubes.image->width, w->core.width),
 				MIN(w->cubes.image->height, w->core.height));
@@ -2401,36 +2472,36 @@ ResizePuzzle(CubesWidget w)
 
 	w->cubes.delta.x = 1;
 	w->cubes.delta.y = 1;
-	w->cubes.offset.x = MAX(((int) w->core.width - 2) /
+	w->cubes.offset.x = MAX(((int) w->core.width - 4) /
 		w->cubes.sizeX, 0);
-	w->cubes.offset.y = MAX(((int) w->core.height - 2) /
+	w->cubes.offset.y = MAX(((int) w->core.height - 4) /
 		w->cubes.sizeY, 0);
 	if (w->cubes.offset.y >= w->cubes.offset.x) {
 		w->cubes.vertical = TRUE;
-		w->cubes.offset.y = MAX(((int) w->core.height /
-			w->cubes.sizeZ - 2) / w->cubes.sizeY, 0);
+		w->cubes.offset.y = MAX((((int) w->core.height -
+			5 * w->cubes.sizeZ + 1) / w->cubes.sizeZ) /
+			w->cubes.sizeY, 0);
 	} else {
 		w->cubes.vertical = FALSE;
-		w->cubes.offset.x = MAX(((int) w->core.width /
-			w->cubes.sizeZ - 2) / w->cubes.sizeX, 0);
+		w->cubes.offset.x = MAX((((int) w->core.width -
+			5 * w->cubes.sizeZ + 1) / w->cubes.sizeZ) /
+			w->cubes.sizeX, 0);
 	}
-	w->cubes.faceSize.x = w->cubes.offset.x * w->cubes.sizeX +
-		w->cubes.delta.x + 2;
-	w->cubes.faceSize.y = w->cubes.offset.y * w->cubes.sizeY +
-		w->cubes.delta.y + 2;
+	w->cubes.faceSize.x = w->cubes.offset.x * w->cubes.sizeX + 4;
+	w->cubes.faceSize.y = w->cubes.offset.y * w->cubes.sizeY + 4;
 	if (w->cubes.vertical) {
 		w->cubes.puzzleSize.x = w->cubes.faceSize.x;
-		w->cubes.puzzleSize.y = (w->cubes.faceSize.y - 2) *
-			w->cubes.sizeZ + 2;
+		w->cubes.puzzleSize.y = w->cubes.faceSize.y *
+			w->cubes.sizeZ + w->cubes.sizeZ - 1;
 	} else {
-		w->cubes.puzzleSize.x = (w->cubes.faceSize.x - 2) *
-			w->cubes.sizeZ + 2;
+		w->cubes.puzzleSize.x = w->cubes.faceSize.x *
+			w->cubes.sizeZ + w->cubes.sizeZ - 1;
 		w->cubes.puzzleSize.y = w->cubes.faceSize.y;
 	}
 	w->cubes.puzzleOffset.x = ((int) w->core.width -
-		w->cubes.puzzleSize.x + 2) / 2;
+		w->cubes.puzzleSize.x) / 2;
 	w->cubes.puzzleOffset.y = ((int) w->core.height -
-		w->cubes.puzzleSize.y + 2) / 2;
+		w->cubes.puzzleSize.y) / 2;
 	w->cubes.blockSize.x = MAX(w->cubes.offset.x - w->cubes.delta.x, 0);
 	w->cubes.blockSize.y = MAX(w->cubes.offset.y - w->cubes.delta.y, 0);
 }
@@ -2459,13 +2530,14 @@ Widget request, Widget renew
 {
 #ifdef WINVER
 	SetValuesPuzzle(w);
-	brush = CreateSolidBrush(w->cubes.inverseGC);
+	brush = CreateSolidBrush(w->cubes.inverseGC[2]);
 	SETBACK(w->core.hWnd, brush);
 	(void) SRAND(time(NULL));
 	w->cubes.bufferBlocks[0] = NULL;
 	w->cubes.bufferBlocks[1] = NULL;
 #else
 	CubesWidget w = (CubesWidget) renew;
+	int i;
 
 	(void) SRAND(getpid());
 	w->cubes.bufferBlocks[0] = None;
@@ -2473,12 +2545,11 @@ Widget request, Widget renew
 	w->cubes.colormap = None;
 	w->cubes.oldColormap = None;
 	w->cubes.fontInfo = NULL;
-	w->cubes.blockGC = NULL;
-	w->cubes.borderGC = NULL;
-	w->cubes.blockBrighterGC = NULL;
-	w->cubes.blockDarkerGC = NULL;
-	w->cubes.frameGC = NULL;
-	w->cubes.inverseGC = NULL;
+	w->cubes.textGC = NULL;
+	for (i = 0; i < FG_SHADES; i++)
+		w->cubes.blockGC[i] = NULL;
+	for (i = 0; i < BG_SHADES; i++)
+		w->cubes.inverseGC[i] = NULL;
 	w->cubes.image = NULL;
 #endif
 	w->cubes.focus = False;
@@ -2487,8 +2558,8 @@ Widget request, Widget renew
 	CheckBlocks(w);
 	newMoves(&undo);
 	newMoves(&redo);
-	w->cubes.numSlices = ((w->cubes.delay < MAXSLICES) ?
-		w->cubes.delay + 1 : MAXSLICES);
+	w->cubes.numSlices = ((w->cubes.delay < MAX_SLICES) ?
+		w->cubes.delay + 1 : MAX_SLICES);
 	w->cubes.cheat = False;
 	SizePuzzle(w);
 }
@@ -2793,43 +2864,37 @@ LeavePuzzle(CubesWidget w
 
 #ifndef WINVER
 static void
-MovePuzzleOut(CubesWidget w, XEvent *event, char **args, int nArgs
-)
+MovePuzzleOut(CubesWidget w, XEvent *event, char **args, int nArgs)
 {
 	(void) MovePuzzle(w, OUTWARDS, (int) (event->xkey.state & ControlMask));
 }
 
 static void
-MovePuzzleTop(CubesWidget w, XEvent *event, char **args, int nArgs
-)
+MovePuzzleTop(CubesWidget w, XEvent *event, char **args, int nArgs)
 {
 	(void) MovePuzzle(w, TOP, (int) (event->xkey.state & ControlMask));
 }
 
 static void
-MovePuzzleLeft(CubesWidget w, XEvent *event, char **args, int nArgs
-)
+MovePuzzleLeft(CubesWidget w, XEvent *event, char **args, int nArgs)
 {
 	(void) MovePuzzle(w, LEFT, (int) (event->xkey.state & ControlMask));
 }
 
 static void
-MovePuzzleIn(CubesWidget w, XEvent *event, char **args, int nArgs
-)
+MovePuzzleIn(CubesWidget w, XEvent *event, char **args, int nArgs)
 {
 	(void) MovePuzzle(w, INWARDS, (int) (event->xkey.state & ControlMask));
 }
 
 static void
-MovePuzzleRight(CubesWidget w, XEvent *event, char **args, int nArgs
-)
+MovePuzzleRight(CubesWidget w, XEvent *event, char **args, int nArgs)
 {
 	(void) MovePuzzle(w, RIGHT, (int) (event->xkey.state & ControlMask));
 }
 
 static void
-MovePuzzleBottom(CubesWidget w, XEvent *event, char **args, int nArgs
-)
+MovePuzzleBottom(CubesWidget w, XEvent *event, char **args, int nArgs)
 {
 	(void) MovePuzzle(w, BOTTOM, (int) (event->xkey.state & ControlMask));
 }
