@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1993 - 2007	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1993 - 2008	David A. Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -88,7 +88,7 @@ static CubesRec widget;
 
 #ifndef WINVER
 static const char aboutHelp[] = {
-"Cubes Version 7.3.2\n"
+"Cubes Version 7.3.3\n"
 "Send bugs (reports or fixes) to the author: "
 "David Bagley <bagleyd@tux.org>\n"
 "The latest version is at: "
@@ -99,7 +99,7 @@ static const char optionsHelp[] = {
 "[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
 "[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
 "[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
-"[-block {color}] [-{border|bd} {color}] [-[no]install]\n"
+"[-block {color}] [-text {color}] [-[no]install]\n"
 "[-picture {filename}] [-delay msecs] [-[no]sound]\n"
 "[-bumpSound {filename}] [-dripSound {filename}]\n"
 "[-{font|fn} {fontname}] [-size{x|y|z} {int}] [-base {int}]\n"
@@ -197,29 +197,29 @@ static const char solveHelp[] = {
 #define SCOREFILE "cubes.scores"
 #endif
 
-#define MAXCUBES 8
+#define MAX_CUBES 8
 #define NEVER (-1)
-#define FILENAMELEN 1024
-#define USERNAMELEN 120
-#define MESSAGELEN (USERNAMELEN+64)
-#define TITLELEN 2048
+#define FILE_NAME_LENGTH 1024
+#define USER_NAME_LENGTH 120
+#define MESSAGE_LENGTH (USER_NAME_LENGTH+64)
+#define TITLE_LENGTH 2048
 #define NOACCESS "noaccess"
 #define NOBODY "nobody"
 
 typedef struct {
 	int score;
-	char name[USERNAMELEN];
+	char name[USER_NAME_LENGTH];
 } PuzzleRecord;
 
-static PuzzleRecord puzzleRecord[MAXCUBES - MINCUBES + 1]
-[MAXCUBES - MINCUBES + 1][MAXCUBES - MINCUBES + 1];
+static PuzzleRecord puzzleRecord[MAX_CUBES - MIN_CUBES + 1]
+[MAX_CUBES - MIN_CUBES + 1][MAX_CUBES - MIN_CUBES + 1];
 static int movesDsp = 0;
-static char messageDsp[MESSAGELEN] = "Welcome";
-static char recordDsp[MESSAGELEN] = "NOT RECORDED";
+static char messageDsp[MESSAGE_LENGTH] = "Welcome";
+static char recordDsp[MESSAGE_LENGTH] = "NOT RECORDED";
 
 #ifdef HAVE_MOTIF
-#define MINSPEED 1
-#define MAXSPEED 50
+#define MIN_SPEED 1
+#define MAX_SPEED 50
 static Widget moves, record, message, blockX, blockY, blockZ, speed;
 static char buff[21];
 static Widget descriptionDialog, featuresDialog;
@@ -227,20 +227,20 @@ static Widget optionsDialog, referencesDialog, aboutDialog;
 static Widget solveDialog, clearDialog;
 static Arg arg[3];
 #else
-static char titleDsp[TITLELEN] = "";
+static char titleDsp[TITLE_LENGTH] = "";
 #endif
-static char scoreFileName[FILENAMELEN] = SCOREFILE;
-static char fileName[FILENAMELEN];
+static char scoreFileName[FILE_NAME_LENGTH] = SCOREFILE;
+static char fileName[FILE_NAME_LENGTH];
 static Boolean randomized = False;
 #ifdef WINVER
-#define MAXPROGNAME 80
-static char progDsp[MAXPROGNAME] = TITLE;
-static char userNameDsp[USERNAMELEN] = "Guest";
+#define PROGRAM_NAME_LENGTH 80
+static char progDsp[PROGRAM_NAME_LENGTH] = TITLE;
+static char userNameDsp[USER_NAME_LENGTH] = "Guest";
 #else
 static Pixmap pixmap = None;
 static Widget topLevel, puzzle;
 static char *progDsp;
-static char userNameDsp[USERNAMELEN] = "";
+static char userNameDsp[USER_NAME_LENGTH] = "";
 
 #ifdef HAVE_MOTIF
 static void
@@ -262,9 +262,9 @@ PrintRecords(void)
 
 	(void) printf("          CUBES  HALL OF FAME\n\n");
 	(void) printf("   Z   Y   X USER             MOVES\n");
-	for (i = 0; i < MAXCUBES - MINCUBES + 1; i++)
-		for (j = i; j < MAXCUBES - MINCUBES + 1; j++)
-			for (k = j; k < MAXCUBES - MINCUBES + 1; k++) {
+	for (i = 0; i < MAX_CUBES - MIN_CUBES + 1; i++)
+		for (j = i; j < MAX_CUBES - MIN_CUBES + 1; j++)
+			for (k = j; k < MAX_CUBES - MIN_CUBES + 1; k++) {
 				if (puzzleRecord[k][j][i].score > 0)
 					(void) printf("%4d%4d%4d %-12s%9d\n",
 						i + 1, j + 1, k + 1,
@@ -279,24 +279,24 @@ InitRecords(void)
 {
 	int i, j, k;
 
-	for (i = 0; i < MAXCUBES - MINCUBES + 1; i++)
-		for (j = i; j < MAXCUBES - MINCUBES + 1; j++)
-			for (k = j; k < MAXCUBES - MINCUBES + 1; k++) {
+	for (i = 0; i < MAX_CUBES - MIN_CUBES + 1; i++)
+		for (j = i; j < MAX_CUBES - MIN_CUBES + 1; j++)
+			for (k = j; k < MAX_CUBES - MIN_CUBES + 1; k++) {
 				puzzleRecord[k][j][i].score = puzzleRecord[k][i][j].score =
 					puzzleRecord[j][k][i].score = puzzleRecord[j][i][k].score =
 					puzzleRecord[i][k][j].score = puzzleRecord[i][j][k].score = NEVER;
 				(void) strncpy(puzzleRecord[k][j][i].name,
-					NOACCESS, USERNAMELEN);
+					NOACCESS, USER_NAME_LENGTH);
 				(void) strncpy(puzzleRecord[k][i][j].name,
-					NOACCESS, USERNAMELEN);
+					NOACCESS, USER_NAME_LENGTH);
 				(void) strncpy(puzzleRecord[j][k][i].name,
-					NOACCESS, USERNAMELEN);
+					NOACCESS, USER_NAME_LENGTH);
 				(void) strncpy(puzzleRecord[j][i][k].name,
-					NOACCESS, USERNAMELEN);
+					NOACCESS, USER_NAME_LENGTH);
 				(void) strncpy(puzzleRecord[i][k][j].name,
-					NOACCESS, USERNAMELEN);
+					NOACCESS, USER_NAME_LENGTH);
 				(void) strncpy(puzzleRecord[i][j][k].name,
-					NOACCESS, USERNAMELEN);
+					NOACCESS, USER_NAME_LENGTH);
 			}
 }
 
@@ -305,7 +305,7 @@ ReadRecords(void)
 {
 	FILE *fp;
 	int i, j, k, n;
-	char userName[USERNAMELEN];
+	char userName[USER_NAME_LENGTH];
 	char *buf1 = NULL, *buf2 = NULL;
 	char *fname, *lname;
 
@@ -315,9 +315,9 @@ ReadRecords(void)
 	stringCat(&buf2, buf1, SCOREFILE);
 	free(buf1);
 	fname = buf2;
-	(void) strncpy(fileName, lname, USERNAMELEN);
+	(void) strncpy(fileName, lname, USER_NAME_LENGTH);
 	if ((fp = fopen(fileName, "r")) == NULL) {
-		(void) strncpy(fileName, fname, USERNAMELEN);
+		(void) strncpy(fileName, fname, USER_NAME_LENGTH);
 		/* Try installed directory. */
 		if ((fp = fopen(fileName, "r")) == NULL) {
 			stringCat(&buf1, "Can not read ", fname);
@@ -346,9 +346,9 @@ ReadRecords(void)
 	}
 	free(lname);
 	free(fname);
-	for (i = 0; i < MAXCUBES - MINCUBES + 1; i++)
-		for (j = i; j < MAXCUBES - MINCUBES + 1; j++)
-			for (k = j; k < MAXCUBES - MINCUBES + 1; k++) {
+	for (i = 0; i < MAX_CUBES - MIN_CUBES + 1; i++)
+		for (j = i; j < MAX_CUBES - MIN_CUBES + 1; j++)
+			for (k = j; k < MAX_CUBES - MIN_CUBES + 1; k++) {
 				(void) fscanf(fp, "%d %s", &n, userName);
 				if (n <= puzzleRecord[i][j][k].score ||
 						puzzleRecord[i][j][k].score <= NEVER) {
@@ -356,17 +356,17 @@ ReadRecords(void)
 						puzzleRecord[j][k][i].score = puzzleRecord[j][i][k].score =
 						puzzleRecord[i][k][j].score = puzzleRecord[i][j][k].score = n;
 					(void) strncpy(puzzleRecord[k][j][i].name,
-						userName, USERNAMELEN);
+						userName, USER_NAME_LENGTH);
 					(void) strncpy(puzzleRecord[k][i][j].name,
-						userName, USERNAMELEN);
+						userName, USER_NAME_LENGTH);
 					(void) strncpy(puzzleRecord[j][k][i].name,
-						userName, USERNAMELEN);
+						userName, USER_NAME_LENGTH);
 					(void) strncpy(puzzleRecord[j][i][k].name,
-						userName, USERNAMELEN);
+						userName, USER_NAME_LENGTH);
 					(void) strncpy(puzzleRecord[i][k][j].name,
-						userName, USERNAMELEN);
+						userName, USER_NAME_LENGTH);
 					(void) strncpy(puzzleRecord[i][j][k].name,
-						userName, USERNAMELEN);
+						userName, USER_NAME_LENGTH);
 				}
 			}
 	(void) fclose(fp);
@@ -388,9 +388,9 @@ WriteRecords(void)
 	{
 #if HAVE_FCNTL_H
 		int lfd;
-		char lockFile[FILENAMELEN];
+		char lockFile[FILE_NAME_LENGTH];
 
-		(void) strncpy(lockFile, fileName, FILENAMELEN - 6);
+		(void) strncpy(lockFile, fileName, FILE_NAME_LENGTH - 6);
 		(void) strcat(lockFile, ".lock");
 		while (((lfd = open(lockFile, O_CREAT | O_EXCL, 0644)) < 0) &&
 				errno == EEXIST)
@@ -406,9 +406,9 @@ WriteRecords(void)
 #endif
 		}
 #endif
-		for (i = 0; i < MAXCUBES - MINCUBES + 1; i++) {
-			for (j = i; j < MAXCUBES - MINCUBES + 1; j++) {
-				for (k = j; k < MAXCUBES - MINCUBES + 1; k++)
+		for (i = 0; i < MAX_CUBES - MIN_CUBES + 1; i++) {
+			for (j = i; j < MAX_CUBES - MIN_CUBES + 1; j++) {
+				for (k = j; k < MAX_CUBES - MIN_CUBES + 1; k++)
 					(void) fprintf(fp, "%d %s\n",
 						puzzleRecord[i][j][k].score,
 						puzzleRecord[i][j][k].name);
@@ -427,10 +427,10 @@ WriteRecords(void)
 static void
 PrintRecord(int sizeX, int sizeY, int sizeZ)
 {
-	int i = sizeX - MINCUBES, j = sizeY - MINCUBES, k = sizeZ - MINCUBES;
+	int i = sizeX - MIN_CUBES, j = sizeY - MIN_CUBES, k = sizeZ - MIN_CUBES;
 
-	if (sizeX > MAXCUBES || sizeY > MAXCUBES || sizeZ > MAXCUBES) {
-		(void) strncpy(recordDsp, "NOT RECORDED", MESSAGELEN);
+	if (sizeX > MAX_CUBES || sizeY > MAX_CUBES || sizeZ > MAX_CUBES) {
+		(void) strncpy(recordDsp, "NOT RECORDED", MESSAGE_LENGTH);
 	} else if (puzzleRecord[i][j][k].score <= NEVER) {
 		(void) sprintf(recordDsp, "NEVER %s", NOACCESS);
 	} else {
@@ -467,9 +467,9 @@ PrintStatus(char *msg, int nMoves
 static Boolean
 HandleSolved(int counter, int sizeX, int sizeY, int sizeZ)
 {
-	int i = sizeX - MINCUBES, j = sizeY - MINCUBES, k = sizeZ - MINCUBES;
+	int i = sizeX - MIN_CUBES, j = sizeY - MIN_CUBES, k = sizeZ - MIN_CUBES;
 
-	if (sizeX <= MAXCUBES && sizeY <= MAXCUBES && sizeZ <= MAXCUBES &&
+	if (sizeX <= MAX_CUBES && sizeY <= MAX_CUBES && sizeZ <= MAX_CUBES &&
 			(counter < puzzleRecord[i][j][k].score ||
 			puzzleRecord[i][j][k].score <= NEVER)) {
 		ReadRecords();	/* Maybe its been updated by another */
@@ -481,17 +481,17 @@ HandleSolved(int counter, int sizeX, int sizeY, int sizeZ)
 			puzzleRecord[k][j][i].score =
 			counter;
 		(void) strncpy(puzzleRecord[i][j][k].name, userNameDsp,
-			USERNAMELEN);
+			USER_NAME_LENGTH);
 		(void) strncpy(puzzleRecord[i][k][j].name, userNameDsp,
-			USERNAMELEN);
+			USER_NAME_LENGTH);
 		(void) strncpy(puzzleRecord[j][i][k].name, userNameDsp,
-			USERNAMELEN);
+			USER_NAME_LENGTH);
 		(void) strncpy(puzzleRecord[j][k][i].name, userNameDsp,
-			USERNAMELEN);
+			USER_NAME_LENGTH);
 		(void) strncpy(puzzleRecord[k][i][j].name, userNameDsp,
-			USERNAMELEN);
+			USER_NAME_LENGTH);
 		(void) strncpy(puzzleRecord[k][j][i].name, userNameDsp,
-			USERNAMELEN);
+			USER_NAME_LENGTH);
 		WriteRecords();
 		PrintRecord(sizeX, sizeY, sizeZ);
 		return True;
@@ -520,7 +520,7 @@ Widget w
 	userName = w->cubes.userName;
 	scoreFile = w->cubes.scoreFile;
 	if (strcmp(scoreFile, ""))
-		(void) strncpy(scoreFileName, scoreFile, FILENAMELEN);
+		(void) strncpy(scoreFileName, scoreFile, FILE_NAME_LENGTH);
 #else
 	Boolean scoreOnly, versionOnly;
 
@@ -537,7 +537,7 @@ Widget w
 		exit(0);
 	}
 	if (strcmp(scoreFile, ""))
-		(void) strncpy(scoreFileName, scoreFile, FILENAMELEN);
+		(void) strncpy(scoreFileName, scoreFile, FILE_NAME_LENGTH);
 	if (scoreOnly) {
 		InitRecords();
 		ReadRecords();
@@ -545,20 +545,20 @@ Widget w
 		exit(0);
 	}
 #ifdef HAVE_MOTIF
-	if (sizeX > MAXCUBES)
+	if (sizeX > MAX_CUBES)
 		XtVaSetValues(blockX, XmNmaximum, sizeX, NULL);
 	XmScaleSetValue(blockX, sizeX);
-	if (sizeY > MAXCUBES)
+	if (sizeY > MAX_CUBES)
 		XtVaSetValues(blockY, XmNmaximum, sizeY, NULL);
 	XmScaleSetValue(blockY, sizeY);
-	if (sizeZ > MAXCUBES)
+	if (sizeZ > MAX_CUBES)
 		XtVaSetValues(blockZ, XmNmaximum, sizeZ, NULL);
 	XmScaleSetValue(blockZ, sizeZ);
 	{
 		int delay;
 
 		XtVaGetValues(w, XtNdelay, &delay, NULL);
-		XmScaleSetValue(speed, MAXSPEED + MINSPEED - delay - 1);
+		XmScaleSetValue(speed, MAX_SPEED + MIN_SPEED - delay - 1);
 	}
 #endif
 #endif
@@ -566,13 +566,13 @@ Widget w
 	InitRecords();
 	ReadRecords();
 #ifndef WINVER
-	(void) strncpy(userNameDsp, userName, USERNAMELEN);
+	(void) strncpy(userNameDsp, userName, USER_NAME_LENGTH);
 #endif
 	if (!strcmp(userName, "") || !strcmp(userName, "(null)") ||
 			!strcmp(userName, NOACCESS) ||
 			!strcmp(userName, NOBODY)) {
 #ifdef WINVER
-		(void) strncpy(userNameDsp, userName, USERNAMELEN);
+		(void) strncpy(userNameDsp, userName, USER_NAME_LENGTH);
 #else
 		char *login = getlogin();
 
@@ -651,7 +651,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, cubesCallbackStruct *callData)
 #ifdef HAVE_MOTIF
 		XtManageChild(solveDialog);
 #else
-		(void) strncpy(messageDsp, solveHelp, MESSAGELEN);
+		(void) strncpy(messageDsp, solveHelp, MESSAGE_LENGTH);
 #endif
 #endif
 			break;
@@ -661,18 +661,18 @@ CallbackPuzzle(Widget w, caddr_t clientData, cubesCallbackStruct *callData)
 		randomized = False;
 		break;
 	case ACTION_BLOCKED:
-		(void) strncpy(messageDsp, "Blocked", MESSAGELEN);
+		(void) strncpy(messageDsp, "Blocked", MESSAGE_LENGTH);
 		break;
 	case ACTION_SPACE:
 #if 0
 		/* Too annoying */
 		(void) strncpy(messageDsp, "A space can not slide",
-			MESSAGELEN);
+			MESSAGE_LENGTH);
 #endif
 		break;
 	case ACTION_IGNORE:
 		(void) strncpy(messageDsp, "Clear to start",
-			MESSAGELEN);
+			MESSAGE_LENGTH);
 		break;
 	case ACTION_MOVED:
 		movesDsp++;
@@ -688,7 +688,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, cubesCallbackStruct *callData)
 				"Congratulations %s!!", userNameDsp);
 		else
 			(void) strncpy(messageDsp, "Solved!",
-				MESSAGELEN);
+				MESSAGE_LENGTH);
 		SET_STARTED(w, False);
 		break;
 	case ACTION_COMPUTED:
@@ -708,7 +708,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, cubesCallbackStruct *callData)
 #else
 		XtVaSetValues(w, XtNsizeX, sizeX, NULL);
 #ifdef HAVE_MOTIF
-		if (sizeX > MAXCUBES)
+		if (sizeX > MAX_CUBES)
 			XtVaSetValues(blockX, XmNmaximum, sizeX, NULL);
 		XmScaleSetValue(blockX, sizeX);
 #endif
@@ -724,7 +724,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, cubesCallbackStruct *callData)
 		XtVaSetValues(w, XtNsizeX, sizeX, NULL);
 #ifdef HAVE_MOTIF
 		XmScaleSetValue(blockX, sizeX);
-		if (sizeX >= MAXCUBES)
+		if (sizeX >= MAX_CUBES)
 			XtVaSetValues(blockX, XmNmaximum, sizeX, NULL);
 #endif
 #endif
@@ -738,7 +738,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, cubesCallbackStruct *callData)
 #else
 		XtVaSetValues(w, XtNsizeY, sizeY, NULL);
 #ifdef HAVE_MOTIF
-		if (sizeY > MAXCUBES)
+		if (sizeY > MAX_CUBES)
 			XtVaSetValues(blockY, XmNmaximum, sizeY, NULL);
 		XmScaleSetValue(blockY, sizeY);
 #endif
@@ -754,7 +754,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, cubesCallbackStruct *callData)
 		XtVaSetValues(w, XtNsizeY, sizeY, NULL);
 #ifdef HAVE_MOTIF
 		XmScaleSetValue(blockY, sizeY);
-		if (sizeY >= MAXCUBES)
+		if (sizeY >= MAX_CUBES)
 			XtVaSetValues(blockY, XmNmaximum, sizeY, NULL);
 #endif
 #endif
@@ -768,7 +768,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, cubesCallbackStruct *callData)
 #else
 		XtVaSetValues(w, XtNsizeZ, sizeZ, NULL);
 #ifdef HAVE_MOTIF
-		if (sizeZ > MAXCUBES)
+		if (sizeZ > MAX_CUBES)
 			XtVaSetValues(blockZ, XmNmaximum, sizeZ, NULL);
 		XmScaleSetValue(blockZ, sizeZ);
 #endif
@@ -784,7 +784,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, cubesCallbackStruct *callData)
 		XtVaSetValues(w, XtNsizeZ, sizeZ, NULL);
 #ifdef HAVE_MOTIF
 		XmScaleSetValue(blockZ, sizeZ);
-		if (sizeZ >= MAXCUBES)
+		if (sizeZ >= MAX_CUBES)
 			XtVaSetValues(blockZ, XmNmaximum, sizeZ, NULL);
 #endif
 #endif
@@ -805,8 +805,8 @@ CallbackPuzzle(Widget w, caddr_t clientData, cubesCallbackStruct *callData)
 			XtVaGetValues(puzzle,
 				XtNdelay, &delay, NULL);
 			oldDelay = delay;
-			if (delay > MAXSPEED - MINSPEED)
-				delay = MAXSPEED - MINSPEED;
+			if (delay > MAX_SPEED - MIN_SPEED)
+				delay = MAX_SPEED - MIN_SPEED;
 			if (delay < 0)
 				delay = 0;
 			if (delay != oldDelay) {
@@ -814,7 +814,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, cubesCallbackStruct *callData)
 					XtNdelay, delay, NULL);
 			}
 			XmScaleSetValue(speed,
-				MAXSPEED + MINSPEED - delay - 1);
+				MAX_SPEED + MIN_SPEED - delay - 1);
 		}
 		return;
 #endif
@@ -1078,7 +1078,7 @@ WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine,
 		(signed) CW_USEDEFAULT,
 		(signed) CW_USEDEFAULT,
 #else
-		512 + 10, 512 + 10 + 34,
+		512 + 10 + 4, 512 + 10 + 4 + 34,
 #endif
 		HWND_DESKTOP,
 		(HMENU) NULL,
@@ -1125,10 +1125,8 @@ static XrmOptionDescRec options[] =
 	{(char *) "-foreground", (char *) "*cubes.foreground", XrmoptionSepArg, NULL},
 	{(char *) "-bg", (char *) "*Background", XrmoptionSepArg, NULL},
 	{(char *) "-background", (char *) "*Background", XrmoptionSepArg, NULL},
-	{(char *) "-bd", (char *) "*cubes.blockBorder", XrmoptionSepArg, NULL},
-	{(char *) "-border", (char *) "*cubes.blockBorder", XrmoptionSepArg, NULL},
-	{(char *) "-frame", (char *) "*cubes.frameColor", XrmoptionSepArg, NULL},
 	{(char *) "-block", (char *) "*cubes.blockColor", XrmoptionSepArg, NULL},
+	{(char *) "-text", (char *) "*cubes.textColor", XrmoptionSepArg, NULL},
 	{(char *) "-install", (char *) "*cubes.install", XrmoptionNoArg, (char *) "TRUE"},
 	{(char *) "-noinstall", (char *) "*cubes.install", XrmoptionNoArg, (char *) "FALSE"},
 	{(char *) "-picture", (char *) "*cubes.picture", XrmoptionSepArg, NULL},
@@ -1224,7 +1222,7 @@ BlockZSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 static void
 SpeedSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 {
-	int delay = MAXSPEED + MINSPEED - cbs->value - 1, oldDelay;
+	int delay = MAX_SPEED + MIN_SPEED - cbs->value - 1, oldDelay;
 
 	XtVaGetValues(puzzle,
 		XtNdelay, &oldDelay, NULL);
@@ -1255,7 +1253,7 @@ static Widget
 createQuery(Widget w, char *text, char *title, XtCallbackProc callback)
 {
 	Widget button, messageBox;
-	char titleDsp[FILENAMELEN + 8];
+	char titleDsp[FILE_NAME_LENGTH + 8];
 	XmString titleString = NULL, messageString = NULL;
 	static XmStringCharSet charSet =
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
@@ -1281,7 +1279,7 @@ static Widget
 createHelp(Widget w, char *text, char *title)
 {
 	Widget button, messageBox;
-	char titleDsp[FILENAMELEN + 8];
+	char titleDsp[FILE_NAME_LENGTH + 8];
 	XmString titleString = NULL, messageString = NULL, buttonString = NULL;
 	static XmStringCharSet charSet =
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
@@ -1527,9 +1525,9 @@ main(int argc, char **argv)
 	blockX = XtVaCreateManagedWidget("blockX",
 		xmScaleWidgetClass, blocksRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Blocks X", 9,
-		XmNminimum, MINCUBES,
-		XmNmaximum, MAXCUBES,
-		XmNvalue, DEFAULTCUBESX,
+		XmNminimum, MIN_CUBES,
+		XmNmaximum, MAX_CUBES,
+		XmNvalue, DEFAULT_CUBESX,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
 	XtAddCallback(blockX, XmNvalueChangedCallback,
@@ -1537,9 +1535,9 @@ main(int argc, char **argv)
 	blockY = XtVaCreateManagedWidget("blockY",
 		xmScaleWidgetClass, blocksRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Blocks Y", 9,
-		XmNminimum, MINCUBES,
-		XmNmaximum, MAXCUBES,
-		XmNvalue, DEFAULTCUBESY,
+		XmNminimum, MIN_CUBES,
+		XmNmaximum, MAX_CUBES,
+		XmNvalue, DEFAULT_CUBESY,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
 	XtAddCallback(blockY, XmNvalueChangedCallback,
@@ -1547,9 +1545,9 @@ main(int argc, char **argv)
 	blockZ = XtVaCreateManagedWidget("blockZ",
 		xmScaleWidgetClass, blocksRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Blocks Z", 9,
-		XmNminimum, MINCUBES,
-		XmNmaximum, MAXCUBES,
-		XmNvalue, DEFAULTCUBESZ,
+		XmNminimum, MIN_CUBES,
+		XmNmaximum, MAX_CUBES,
+		XmNvalue, DEFAULT_CUBESZ,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
 	XtAddCallback(blockZ, XmNvalueChangedCallback,
@@ -1562,9 +1560,9 @@ main(int argc, char **argv)
 	speed = XtVaCreateManagedWidget("Animation Speed",
 		xmScaleWidgetClass, speedRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Animation Speed", 16,
-		XmNminimum, MINSPEED,
-		XmNmaximum, MAXSPEED,
-		XmNvalue, MAXSPEED - DEFAULTDELAY,
+		XmNminimum, MIN_SPEED,
+		XmNmaximum, MAX_SPEED,
+		XmNvalue, MAX_SPEED - DEFAULT_DELAY,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
 	XtAddCallback(speed, XmNvalueChangedCallback,
