@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1995 - 2007	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1995 - 2007	David A. Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -45,7 +45,7 @@
 
 #define SECTION "setup"
 
-static const char *faceColorString[MAXFACES] =
+static const char *faceColorString[MAX_FACES] =
 {
 	"255 0 0",
 	"0 0 255",
@@ -55,7 +55,7 @@ static const char *faceColorString[MAXFACES] =
 	"255 165 0",
 };
 
-static const char faceColorChar[MAXFACES] =
+static const char faceColorChar[MAX_FACES] =
 {'R', 'B', 'Y', 'G', 'W', 'O'};
 #else
 
@@ -181,7 +181,7 @@ loadFont(DinoWidget w)
 #define LOGFILE "dino.log"
 #endif
 
-static int facesToDirection[MAXFACES][MAXFACES][MAXORIENT] =
+static int facesToDirection[MAX_FACES][MAX_FACES][MAX_ORIENT] =
 {
 	{
 		{-3, -3, -3, -3},
@@ -232,7 +232,7 @@ static int facesToDirection[MAXFACES][MAXFACES][MAXORIENT] =
 		{-3, -3, -3, -3}
 	}
 };
-static DinoLoc slideCorner[MAXFACES][MAXORIENT][MAXORIENT / 2] =
+static DinoLoc slideCorner[MAX_FACES][MAX_ORIENT][MAX_ORIENT / 2] =
 {
 	{
 		{
@@ -344,10 +344,10 @@ static DinoLoc slideCorner[MAXFACES][MAXORIENT][MAXORIENT / 2] =
 	}
 };
 
-static int oppFace[MAXFACES] =
+static int oppFace[MAX_FACES] =
 {4, 3, 5, 1, 0, 2};
 
-static DinoCornerLoc oppCorner[MAXFACES][MAXORIENT] =
+static DinoCornerLoc oppCorner[MAX_FACES][MAX_ORIENT] =
 {
 	{
 		{4, 3},
@@ -387,9 +387,9 @@ static DinoCornerLoc oppCorner[MAXFACES][MAXORIENT] =
 	}
 };
 
-/* static int slideNextFace2[MAXFACES] = {4, 3, 5, 1, 0, 2}; */
+/* static int slideNextFace2[MAX_FACES] = {4, 3, 5, 1, 0, 2}; */
 
-static DinoCornerLoc slideNextFace[MAXFACES][MAXORIENT] =
+static DinoCornerLoc slideNextFace[MAX_FACES][MAX_ORIENT] =
 {
 	{
 		{5, STRT},
@@ -429,7 +429,7 @@ static DinoCornerLoc slideNextFace[MAXFACES][MAXORIENT] =
 	}
 };
 
-static int faceToRotate2[MAXFACES][MAXORIENT][2] =
+static int faceToRotate2[MAX_FACES][MAX_ORIENT][2] =
 {
 	{
 		{3, 5},
@@ -469,7 +469,7 @@ static int faceToRotate2[MAXFACES][MAXORIENT][2] =
 	}
 };
 
-static int faceToRotate[MAXFACES][MAXORIENT] =
+static int faceToRotate[MAX_FACES][MAX_ORIENT] =
 {
 	{3, 2, 1, 5},
 	{2, 4, 5, 0},
@@ -489,10 +489,10 @@ CheckPieces(DinoWidget w)
 
 	if (w->dino.mode < PERIOD2 || w->dino.mode > BOTH) {
 		intCat(&buf1, "Mode is in error, use 2 for Period2, 3 for Period3, 4 for Both, defaulting to ",
-		DEFAULTMODE);
+		DEFAULT_MODE);
 		DISPLAY_WARNING(buf1);
 		free(buf1);
-		w->dino.mode = DEFAULTMODE;
+		w->dino.mode = DEFAULT_MODE;
 	}
 }
 
@@ -531,14 +531,14 @@ CheckSolved(DinoWidget w)
 	int face, position;
 	DinoCornerLoc test = {0, FALSE};
 
-	for (face = 0; face < MAXFACES; face++)
-		for (position = 0; position < MAXORIENT; position++) {
+	for (face = 0; face < MAX_FACES; face++)
+		for (position = 0; position < MAX_ORIENT; position++) {
 			if (!position) {
 				test.face = w->dino.cubeLoc[face][position].face;
 				test.rotation = w->dino.cubeLoc[face][position].rotation;
 			} else if (test.face !=		/*face */
 				  w->dino.cubeLoc[face][position].face ||
-				  (w->dino.orient && test.rotation !=	/*STRT - MAXORIENT */
+				  (w->dino.orient && test.rotation !=	/*STRT - MAX_ORIENT */
 				  w->dino.cubeLoc[face][position].rotation))
 				return False;
 		}
@@ -551,8 +551,8 @@ PrintCube(DinoWidget w)
 {
 	int face, position;
 
-	for (face = 0; face < MAXFACES; face++) {
-		for (position = 0; position < MAXORIENT; position++)
+	for (face = 0; face < MAX_FACES; face++) {
+		for (position = 0; position < MAX_ORIENT; position++)
 			(void) printf("%d %d  ",
 				w->dino.cubeLoc[face][position].face,
 				w->dino.cubeLoc[face][position].rotation);
@@ -581,8 +581,8 @@ DrawAllPieces(DinoWidget w)
 		DrawAllPiecesGL((DinoGLWidget) w);
 	}
 #endif
-	for (face = 0; face < MAXFACES; face++)
-		for (position = 0; position < MAXORIENT; position++)
+	for (face = 0; face < MAX_FACES; face++)
+		for (position = 0; position < MAX_ORIENT; position++)
 			DrawTriangle(w, face, position, FALSE);
 }
 
@@ -611,15 +611,15 @@ RotateFace(DinoWidget w, int face, int direction)
 	int side;
 
 	/* Read Face */
-	for (side = 0; side < MAXORIENT; side++)
+	for (side = 0; side < MAX_ORIENT; side++)
 		w->dino.faceLoc[side] = w->dino.cubeLoc[face][side];
 	/* Write Face */
-	for (side = 0; side < MAXORIENT; side++) {
+	for (side = 0; side < MAX_ORIENT; side++) {
 		w->dino.cubeLoc[face][side] = (direction == CW) ?
-			w->dino.faceLoc[(side + MAXORIENT - 1) % MAXORIENT] :
-			w->dino.faceLoc[(side + 1) % MAXORIENT];
+			w->dino.faceLoc[(side + MAX_ORIENT - 1) % MAX_ORIENT] :
+			w->dino.faceLoc[(side + 1) % MAX_ORIENT];
 		w->dino.cubeLoc[face][side].rotation =
-			(w->dino.cubeLoc[face][side].rotation + direction) % MAXORIENT;
+			(w->dino.cubeLoc[face][side].rotation + direction) % MAX_ORIENT;
 		DrawTriangle(w, face, side, FALSE);
 	}
 #ifdef HAVE_OPENGL
@@ -633,20 +633,20 @@ static void
 ReadDiagonal(DinoWidget w, int face, int corner, int h)
 {
 	w->dino.spindleLoc[h][0] = w->dino.cubeLoc[face][corner];
-	w->dino.spindleLoc[h][1] = w->dino.cubeLoc[face][(corner + 1) % MAXORIENT];
+	w->dino.spindleLoc[h][1] = w->dino.cubeLoc[face][(corner + 1) % MAX_ORIENT];
 }
 
 static void
 WriteDiagonal(DinoWidget w, int face, int corner, int rotate, int h)
 {
 	w->dino.spindleLoc[h][0].rotation =
-		(w->dino.spindleLoc[h][0].rotation + rotate) % MAXORIENT;
+		(w->dino.spindleLoc[h][0].rotation + rotate) % MAX_ORIENT;
 	w->dino.spindleLoc[h][1].rotation =
-		(w->dino.spindleLoc[h][1].rotation + rotate) % MAXORIENT;
+		(w->dino.spindleLoc[h][1].rotation + rotate) % MAX_ORIENT;
 	w->dino.cubeLoc[face][corner] = w->dino.spindleLoc[h][0];
 	DrawTriangle(w, face, corner, FALSE);
-	w->dino.cubeLoc[face][(corner + 1) % MAXORIENT] = w->dino.spindleLoc[h][1];
-	DrawTriangle(w, face, (corner + 1) % MAXORIENT, FALSE);
+	w->dino.cubeLoc[face][(corner + 1) % MAX_ORIENT] = w->dino.spindleLoc[h][1];
+	DrawTriangle(w, face, (corner + 1) % MAX_ORIENT, FALSE);
 #ifdef HAVE_OPENGL
 	if (w->dino.dim == 4) {
 		DrawAllPiecesGL((DinoGLWidget) w);
@@ -659,7 +659,7 @@ ReadFace(DinoWidget w, int face, int h)
 {
 	int side;
 
-	for (side = 0; side < MAXORIENT; side++)
+	for (side = 0; side < MAX_ORIENT; side++)
 		w->dino.rowLoc[h][side] = w->dino.cubeLoc[face][side];
 }
 
@@ -668,12 +668,12 @@ WriteFace(DinoWidget w, int face, int rotate, int h)
 {
 	int side, newSide;
 
-	for (side = 0; side < MAXORIENT; side++) {
-		newSide = (side + rotate) % MAXORIENT;
+	for (side = 0; side < MAX_ORIENT; side++) {
+		newSide = (side + rotate) % MAX_ORIENT;
 		w->dino.cubeLoc[face][newSide] = w->dino.rowLoc[h][side];
 		w->dino.cubeLoc[face][newSide].rotation =
-			(w->dino.cubeLoc[face][newSide].rotation + rotate) % MAXORIENT;
-		DrawTriangle(w, face, (side + rotate) % MAXORIENT, FALSE);
+			(w->dino.cubeLoc[face][newSide].rotation + rotate) % MAX_ORIENT;
+		DrawTriangle(w, face, (side + rotate) % MAX_ORIENT, FALSE);
 	}
 #ifdef HAVE_OPENGL
 	if (w->dino.dim == 4) {
@@ -691,11 +691,11 @@ MoveEdges(DinoWidget w, int face, int corner, int direction)
 	for (k = 1; k <= 2; k++) {
 		newFace = oppFace[face];
 		/*rotate = (((face == 1 || face == 3) ? 1 : 3) + 3 * direction) %
-		  MAXORIENT; */
+		  MAX_ORIENT; */
 		newCorner = ((((face == 1 || face == 3) + corner) % 2) ?
-			(corner + 3) : (corner + 1)) % MAXORIENT;
-		rotate = (newCorner - corner + MAXORIENT) % MAXORIENT;
-		newDirection = (rotate + direction) % MAXORIENT;
+			(corner + 3) : (corner + 1)) % MAX_ORIENT;
+		rotate = (newCorner - corner + MAX_ORIENT) % MAX_ORIENT;
+		newDirection = (rotate + direction) % MAX_ORIENT;
 		if (k != 2)
 			ReadDiagonal((DinoWidget) w, newFace, newCorner, k);
 		WriteDiagonal(w, newFace, newCorner, rotate, k - 1);
@@ -714,7 +714,7 @@ MoveFaces(DinoWidget w, int f, int d, int rotate)
 	ReadFace((DinoWidget) w, face, 0);
 	for (k = 1; k <= 2; k++) {
 		newFace = faceToRotate2[f][d][k % 2];
-		rotate = MAXORIENT - rotate;
+		rotate = MAX_ORIENT - rotate;
 		if (k != 2)
 			ReadFace((DinoWidget) w, newFace, k);
 		WriteFace(w, newFace, rotate, k - 1);
@@ -728,16 +728,16 @@ MoveInsideCorners(DinoWidget w, int face, int corner, int direction)
 	int newFace, newCorner, newDirection, dir, k;
 
 	ReadDiagonal((DinoWidget) w, face, corner, 0);
-	for (k = 1; k <= MAXROTATE; k++) {
+	for (k = 1; k <= MAX_ROTATE; k++) {
 		dir = direction / 2;
 		newFace = slideCorner[face][corner][dir].face;
 		newCorner = slideCorner[face][corner][dir].side;
 		newDirection = 2 * slideCorner[face][corner][dir].dir +
 			!(newCorner % 2);
-		if (k != MAXROTATE)
+		if (k != MAX_ROTATE)
 			ReadDiagonal((DinoWidget) w, newFace, newCorner, k);
 		WriteDiagonal(w, newFace, newCorner,
-		  (newDirection - direction + MAXORIENT) % MAXORIENT, k - 1);
+		  (newDirection - direction + MAX_ORIENT) % MAX_ORIENT, k - 1);
 		face = newFace;
 		corner = newCorner;
 		direction = newDirection;
@@ -750,18 +750,18 @@ MoveOutsideCorners(DinoWidget w, int face, int corner, int direction)
 	int newFace, newCorner, newDirection, dir, k;
 
 	ReadDiagonal((DinoWidget) w, face, corner, 0);
-	for (k = 1; k <= MAXROTATE; k++) {
-		corner = (corner + 2) % MAXORIENT;
+	for (k = 1; k <= MAX_ROTATE; k++) {
+		corner = (corner + 2) % MAX_ORIENT;
 		dir = direction / 2;
 		newFace = slideCorner[face][corner][dir].face;
 		newCorner = (slideCorner[face][corner][dir].side + 2) %
-			MAXORIENT;
+			MAX_ORIENT;
 		newDirection = 2 * slideCorner[face][corner][dir].dir +
 			!(newCorner % 2);
-		if (k != MAXROTATE)
+		if (k != MAX_ROTATE)
 			ReadDiagonal((DinoWidget) w, newFace, newCorner, k);
 		WriteDiagonal(w, newFace, newCorner,
-		  (newDirection - direction + MAXORIENT) % MAXORIENT, k - 1);
+		  (newDirection - direction + MAX_ORIENT) % MAX_ORIENT, k - 1);
 		face = newFace;
 		corner = newCorner;
 		direction = newDirection;
@@ -773,8 +773,8 @@ MovePieces(DinoWidget w, int face, int position, int direction, int style)
 {
 	int corner, newCorner;
 
-	corner = (position - !((position + direction) % 2) + MAXORIENT) %
-		MAXORIENT;
+	corner = (position - !((position + direction) % 2) + MAX_ORIENT) %
+		MAX_ORIENT;
 	if (style == CORNER) {
 		MoveInsideCorners(w, face, corner, direction);
 	} else if (style == MIDDLE) {
@@ -782,27 +782,27 @@ MovePieces(DinoWidget w, int face, int position, int direction, int style)
 		newCorner = oppCorner[face][corner].rotation;
 		face = oppCorner[face][corner].face;
 		if (((face != 1 && face != 3) + corner) % 2)
-			direction = (direction + 1) % MAXORIENT;
+			direction = (direction + 1) % MAX_ORIENT;
 		else
-			direction = (direction + 3) % MAXORIENT;
+			direction = (direction + 3) % MAX_ORIENT;
 		corner = newCorner;
 		MoveOutsideCorners(w, face, corner, direction);
 	} else if (style == EDGE) {
 		MoveEdges(w, face, corner, direction);
 		MoveFaces(w, face, corner,
-			((face == 2 || face == 5) ? CCW : HALF) % MAXORIENT);
+			((face == 2 || face == 5) ? CCW : HALF) % MAX_ORIENT);
 	} else {
 		int k, newFace, rotate, newDirection;
 
-		RotateFace(w, faceToRotate[face][direction % MAXORIENT], CW);
-		RotateFace(w, faceToRotate[face][(direction + 2) % MAXORIENT],
+		RotateFace(w, faceToRotate[face][direction % MAX_ORIENT], CW);
+		RotateFace(w, faceToRotate[face][(direction + 2) % MAX_ORIENT],
 			CCW);
 		ReadFace((DinoWidget) w, face, 0);
-		for (k = 1; k <= MAXORIENT; k++) {
-			newFace = slideNextFace[face][direction % MAXORIENT].face;
-			rotate = slideNextFace[face][direction % MAXORIENT].rotation;
-			newDirection = (rotate + direction) % MAXORIENT;
-			if (k != MAXORIENT)
+		for (k = 1; k <= MAX_ORIENT; k++) {
+			newFace = slideNextFace[face][direction % MAX_ORIENT].face;
+			rotate = slideNextFace[face][direction % MAX_ORIENT].rotation;
+			newDirection = (rotate + direction) % MAX_ORIENT;
+			if (k != MAX_ORIENT)
 				ReadFace((DinoWidget) w, newFace, k);
 			WriteFace(w, newFace, rotate, k - 1);
 			face = newFace;
@@ -819,12 +819,12 @@ MoveControlCb(DinoWidget w, int face, int position, int direction, int style)
 	MovePieces(w, face, position, direction, style);
 	setPuzzleMove(w, ACTION_CONTROL, face, position, direction, style);
 	if (style == CORNER) {
-		newSide = (position + 2) % MAXORIENT;
+		newSide = (position + 2) % MAX_ORIENT;
 		MovePieces(w, face, newSide, direction, MIDDLE);
 		setPuzzleMove(w, ACTION_CONTROL, face, newSide, direction,
 			MIDDLE);
 		corner = (position - !((position + direction) % 2) +
-			MAXORIENT) % MAXORIENT;
+			MAX_ORIENT) % MAX_ORIENT;
 		newFace = oppCorner[face][corner].face;
 		newCorner = oppCorner[face][corner].rotation;
 		newDirection = 2 * ((direction / 2 +
@@ -834,25 +834,25 @@ MoveControlCb(DinoWidget w, int face, int position, int direction, int style)
 		setPuzzleMove(w, ACTION_CONTROL, newFace, newSide,
 			newDirection, CORNER);
 	} else if (style == MIDDLE) {
-		newSide = (position + 2) % MAXORIENT;
+		newSide = (position + 2) % MAX_ORIENT;
 		MovePieces(w, face, newSide, direction, CORNER);
 		setPuzzleMove(w, ACTION_CONTROL, face, newSide, direction,
 			CORNER);
 		corner = (position - !((position + direction) % 2) +
-			MAXORIENT) % MAXORIENT;
+			MAX_ORIENT) % MAX_ORIENT;
 		newCorner = oppCorner[face][corner].rotation;
 		newFace = oppCorner[face][corner].face;
 		if (newFace != 1 && newFace != 3)
-			newDirection = (direction + 2) % MAXORIENT;
+			newDirection = (direction + 2) % MAX_ORIENT;
 		else
 			newDirection = direction;
 		newDirection = 2 * (newDirection / 2) + !(newDirection % 2);
-		newSide = (newCorner + 2) % MAXORIENT;
+		newSide = (newCorner + 2) % MAX_ORIENT;
 		MovePieces(w, newFace, newSide, newDirection, CORNER);
 		setPuzzleMove(w, ACTION_CONTROL, newFace, newSide,
 			newDirection, CORNER);
 	} else if (style == EDGE) {
-		newSide = (position + 2) % MAXORIENT;
+		newSide = (position + 2) % MAX_ORIENT;
 		MovePieces(w, face, newSide, direction, EDGE);
 		setPuzzleMove(w, ACTION_CONTROL, face, newSide, direction,
 			EDGE);
@@ -896,7 +896,7 @@ CheckMoveDir(int position1, int position2, int *direction)
 {
 	if (position1 == position2)
 		return 2;
-	if (!((position1 - position2 + MAXORIENT) % 2))
+	if (!((position1 - position2 + MAX_ORIENT) % 2))
 		return 0;
 	switch (position1) {
 	case 0:
@@ -947,7 +947,7 @@ MovePuzzleInput(DinoWidget w, int x, int y, int direction, int shift,
 	}
 	if (!PositionPieces(w, x, y, &face, &position, &direction))
 		return;
-	if (direction >= 2 * MAXORIENT) {
+	if (direction >= 2 * MAX_ORIENT) {
 		if (control)
 			style = FACE;
 		else
@@ -966,11 +966,11 @@ ResetPieces(DinoWidget w)
 {
 	int face, position;
 
-	for (face = 0; face < MAXFACES; face++)
-		for (position = 0; position < MAXORIENT; position++) {
+	for (face = 0; face < MAX_FACES; face++)
+		for (position = 0; position < MAX_ORIENT; position++) {
 			w->dino.cubeLoc[face][position].face = face;
 			w->dino.cubeLoc[face][position].rotation = STRT -
-				MAXORIENT;
+				MAX_ORIENT;
 		}
 	flushMoves(w, &undo, TRUE);
 	flushMoves(w, &redo, FALSE);
@@ -1146,9 +1146,9 @@ UndoPieces(DinoWidget w)
 			&face, &position, &direction, &style, &control);
 		setMove(&redo,
 			face, position, direction, style, control);
-		direction = (direction < MAXORIENT) ?
-			(direction + MAXORIENT / 2) % MAXORIENT :
-			5 * MAXORIENT - direction;
+		direction = (direction < MAX_ORIENT) ?
+			(direction + MAX_ORIENT / 2) % MAX_ORIENT :
+			5 * MAX_ORIENT - direction;
 		if (control)
 			MoveControlCb(w, face, position, direction, style);
 		else {
@@ -1201,7 +1201,7 @@ static void
 RandomizePieces(DinoWidget w)
 {
 	int face, position, direction, style;
-	int big = MAXORIENT * 3 + NRAND(2);
+	int big = MAX_ORIENT * 3 + NRAND(2);
 
 	w->dino.cheat = False;
 	if (w->dino.practice)
@@ -1213,10 +1213,10 @@ RandomizePieces(DinoWidget w)
 #endif
 
 	while (big--) {
-		face = NRAND(MAXFACES);
-		position = NRAND(MAXORIENT);
+		face = NRAND(MAX_FACES);
+		position = NRAND(MAX_ORIENT);
 		direction = ((NRAND(2)) ? position + 1 : position + 3) %
-			MAXORIENT;
+			MAX_ORIENT;
 		if (w->dino.mode == PERIOD2)
 			style = EDGE;
 		else if (w->dino.mode == BOTH)
@@ -1292,16 +1292,16 @@ SetValuesPuzzle(DinoWidget w)
 	int face;
 
 	w->dino.mode = GetPrivateProfileInt(SECTION, "mode",
-		DEFAULTMODE, INIFILE);
+		DEFAULT_MODE, INIFILE);
 	w->dino.orient = (BOOL) GetPrivateProfileInt(SECTION, "orient",
-		DEFAULTORIENT, INIFILE);
+		DEFAULT_ORIENT, INIFILE);
 	w->dino.practice = (BOOL) GetPrivateProfileInt(SECTION, "practice",
-		DEFAULTPRACTICE, INIFILE);
+		DEFAULT_PRACTICE, INIFILE);
 	w->dino.dim = GetPrivateProfileInt(SECTION, "dim", 4, INIFILE);
 	w->dino.mono = (BOOL) GetPrivateProfileInt(SECTION, "mono",
-		DEFAULTMONO, INIFILE);
+		DEFAULT_MONO, INIFILE);
 	w->dino.reverse = (BOOL) GetPrivateProfileInt(SECTION, "reverseVideo",
-		DEFAULTREVERSE, INIFILE);
+		DEFAULT_REVERSE, INIFILE);
 	/* cyan */
 	(void) GetPrivateProfileString(SECTION, "frameColor", "0 255 255",
 		szBuf, sizeof (szBuf), INIFILE);
@@ -1320,7 +1320,7 @@ SetValuesPuzzle(DinoWidget w)
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
 	w->dino.inverseGC = RGB(color.red, color.green, color.blue);
-	for (face = 0; face < MAXFACES; face++) {
+	for (face = 0; face < MAX_FACES; face++) {
 		(void) sprintf(buf, "faceColor%d", face);
 		(void) GetPrivateProfileString(SECTION, buf,
 			faceColorString[face],
@@ -1493,7 +1493,7 @@ SetAllColors(DinoWidget w)
 	if (w->dino.borderGC)
 		XtReleaseGC((Widget) w, w->dino.borderGC);
 	w->dino.borderGC = XtGetGC((Widget) w, valueMask, &values);
-	for (face = 0; face < MAXFACES; face++)
+	for (face = 0; face < MAX_FACES; face++)
 		GetColor(w, face);
 	if (w->dino.fontInfo)
 		XSetFont(XtDisplay(w), w->dino.borderGC,
@@ -1507,7 +1507,7 @@ SetValuesPuzzle(Widget current, Widget request, Widget renew)
 	Boolean redraw = False, setColors = False;
 	int face;
 
-	for (face = 0; face < MAXFACES; face++) {
+	for (face = 0; face < MAX_FACES; face++) {
 		if (strcmp(w->dino.faceName[face], c->dino.faceName[face])) {
 			setColors = True;
 			break;
@@ -1608,7 +1608,7 @@ DestroyPuzzle(Widget old)
 	Display *display = XtDisplay(w);
 	int face;
 
-	for (face = 0; face < MAXFACES; face++)
+	for (face = 0; face < MAX_FACES; face++)
 		XtReleaseGC(old, w->dino.faceGC[face]);
 	XtReleaseGC(old, w->dino.borderGC);
 	XtReleaseGC(old, w->dino.frameGC);
@@ -1651,7 +1651,7 @@ Widget request, Widget renew
 	w->dino.mono = (DefaultDepthOfScreen(XtScreen(w)) < 2 ||
 		w->dino.mono);
 	w->dino.fontInfo = NULL;
-	for (face = 0; face < MAXFACES; face++)
+	for (face = 0; face < MAX_FACES; face++)
 		w->dino.faceGC[face] = NULL;
 	w->dino.borderGC = NULL;
 	w->dino.frameGC = NULL;
@@ -1750,7 +1750,7 @@ ReleasePuzzle(DinoWidget w
 				w->dino.currentPosition = position;
 				direction = facesToDirection[w->dino.currentFace][face][w->dino.currentPosition];
 				if (direction >= 0)
-					direction = (direction + MAXORIENT / 2) % MAXORIENT;
+					direction = (direction + MAX_ORIENT / 2) % MAX_ORIENT;
 			}
 			count = (direction == AMBIGUOUS_DIR) ? 2 : 1;
 			if (direction == IGNORE_DIR)
