@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1995 - 2007	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1995 - 2007	David A. Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -216,13 +216,13 @@ static XtResource resourcesPuzzle2D[] =
 	 XtRString, (caddr_t) "9x15bold"},
 	{XtNmode, XtCMode, XtRInt, sizeof (int),
 	 XtOffset(DinoWidget, dino.mode),
-	 XtRString, (caddr_t) "3"}, /* DEFAULTMODE */
+	 XtRString, (caddr_t) "3"}, /* DEFAULT_MODE */
 	{XtNorient, XtCOrient, XtRBoolean, sizeof (Boolean),
 	 XtOffset(DinoWidget, dino.orient),
-	 XtRString, (caddr_t) "FALSE"},	/* DEFAULTORIENT */
+	 XtRString, (caddr_t) "FALSE"},	/* DEFAULT_ORIENT */
 	{XtNpractice, XtCPractice, XtRBoolean, sizeof (Boolean),
 	 XtOffset(DinoWidget, dino.practice),
-	 XtRString, (caddr_t) "TRUE"}, /* DEFAULTPRACTICE */
+	 XtRString, (caddr_t) "TRUE"}, /* DEFAULT_PRACTICE */
 	{XtNuserName, XtCUserName, XtRString, sizeof (String),
 	 XtOffset(DinoWidget, dino.userName),
 	 XtRString, (caddr_t) ""},
@@ -311,11 +311,11 @@ Dino2DClassRec dino2dClassRec =
 WidgetClass dino2dWidgetClass = (WidgetClass) & dino2dClassRec;
 #endif
 
-static int planeToCube[MAXRECT] =
+static int planeToCube[MAX_RECT] =
 {6, 0, 6, 1, 2, 3, 6, 4, 6, 6, 5, 6};
-static int cubeToPlane[MAXFACES] =
+static int cubeToPlane[MAX_FACES] =
 {1, 3, 4, 5, 7, 10};
-static Point triangleUnit[MAXORIENT][4] =
+static Point triangleUnit[MAX_ORIENT][4] =
 {
 	{
 		{2, 0},
@@ -341,15 +341,15 @@ static Point triangleUnit[MAXORIENT][4] =
 		{-1, 1},
 		{0, -2}
 	}
-}, letterUnit[MAXORIENT] =
+}, letterUnit[MAX_ORIENT] =
 {
 	{1, 0},
 	{2, 1},
 	{1, 2},
 	{0, 1}
 };
-static Point triangleList[MAXORIENT][4], letterList[MAXORIENT];
-static Point offsetList[MAXORIENT];
+static Point triangleList[MAX_ORIENT][4], letterList[MAX_ORIENT];
+static Point offsetList[MAX_ORIENT];
 
 static Pixmap dr = 0; /* dummy for future double buffering */
 
@@ -404,7 +404,7 @@ DrawTriangle2D(Dino2DWidget w, int face, int position, int offset)
 	int dx, dy, letterX, letterY, newSide, orient;
 
 	orient = w->dino.cubeLoc[face][position].rotation;
-	if (w->dino.vertical || face != MAXFACES - 1) {
+	if (w->dino.vertical || face != MAX_FACES - 1) {
 		dx = (cubeToPlane[face] % MAXX) * w->dino2d.viewLength;
 		dy = (cubeToPlane[face] / MAXX) * w->dino2d.viewLength;
 		newSide = position;
@@ -453,7 +453,7 @@ DrawTriangle2D(Dino2DWidget w, int face, int position, int offset)
 		DRAWTEXT(w, dr, borderGC, letterX, letterY, buf, 1);
 	}
 	if (w->dino.orient)
-		DrawOrientLine(w, orient + 2 * MAXORIENT,
+		DrawOrientLine(w, orient + 2 * MAX_ORIENT,
 			letterX - w->dino.letterOffset.x + 1,
 			letterY - w->dino.letterOffset.y,
 			borderGC);
@@ -507,7 +507,7 @@ ResizePieces(Dino2DWidget w)
 	w->dino.orientLineLength = w->dino2d.diamondLength / 4 - 1;
 	w->dino.letterOffset.x = -2;
 	w->dino.letterOffset.y = 4;
-	for (i = 0; i < MAXORIENT; i++) {
+	for (i = 0; i < MAX_ORIENT; i++) {
 		for (j = 0; j <= 3; j++) {
 			triangleList[i][j].x = triangleUnit[i][j].x *
 				(w->dino2d.diamondLength / 2 - 2 * w->dino.delta);
@@ -574,28 +574,28 @@ SelectPieces2D(Dino2DWidget w, int x, int y, int *face, int *position)
 	else if (j - i > 0 && i + j < w->dino2d.viewLength)
 		*position = LEFT;
 	else
-		*position = MAXORIENT;
+		*position = MAX_ORIENT;
 	if ((faceX != 1 && faceY != 1) ||
 			(faceX >= 3 && w->dino.vertical) ||
 			(faceY >= 3 && !w->dino.vertical))
 		return FALSE;
 	*face = planeToCube[faceX + faceY * MAXX];
-	if (*position != MAXORIENT && faceX == 3) {
-		*face = MAXFACES - 1;
-		*position = (*position + HALF) % MAXORIENT;
+	if (*position != MAX_ORIENT && faceX == 3) {
+		*face = MAX_FACES - 1;
+		*position = (*position + HALF) % MAX_ORIENT;
 	} else
-		*position %= MAXORIENT;
+		*position %= MAX_ORIENT;
 	return True;
 }
 
 Boolean
 NarrowSelection2D(Dino2DWidget w, int *face, int *direction)
 {
-	if (*face == MAXFACES - 1 && *direction < MAXORIENT && !w->dino.vertical) {
-		if (*direction < MAXORIENT)
-			*direction = (*direction + HALF) % MAXORIENT;
-		else if (*direction >= 2 * MAXORIENT)
-			*direction = 2 * MAXORIENT + (*direction + HALF) % MAXORIENT;
+	if (*face == MAX_FACES - 1 && *direction < MAX_ORIENT && !w->dino.vertical) {
+		if (*direction < MAX_ORIENT)
+			*direction = (*direction + HALF) % MAX_ORIENT;
+		else if (*direction >= 2 * MAX_ORIENT)
+			*direction = 2 * MAX_ORIENT + (*direction + HALF) % MAX_ORIENT;
 	}
 	return TRUE;
 }
