@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1995 - 2007	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1995 - 2007	David A. Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -226,13 +226,13 @@ static XtResource resourcesPuzzle3D[] =
 	 XtRString, (caddr_t) "9x15bold"},
 	{XtNmode, XtCMode, XtRInt, sizeof (int),
 	 XtOffset(DinoWidget, dino.mode),
-	 XtRString, (caddr_t) "3"}, /*DEFAULTMODE */
+	 XtRString, (caddr_t) "3"}, /*DEFAULT_MODE */
 	{XtNorient, XtCOrient, XtRBoolean, sizeof (Boolean),
 	 XtOffset(DinoWidget, dino.orient),
-	 XtRString, (caddr_t) "FALSE"},	/* DEFAULTORIENT */
+	 XtRString, (caddr_t) "FALSE"},	/* DEFAULT_ORIENT */
 	{XtNpractice, XtCPractice, XtRBoolean, sizeof (Boolean),
 	 XtOffset(DinoWidget, dino.practice),
-	 XtRString, (caddr_t) "TRUE"}, /* DEFAULTPRACTICE */
+	 XtRString, (caddr_t) "TRUE"}, /* DEFAULT_PRACTICE */
 	{XtNuserName, XtCUserName, XtRString, sizeof (String),
 	 XtOffset(DinoWidget, dino.userName),
 	 XtRString, (caddr_t) ""},
@@ -321,13 +321,13 @@ Dino3DClassRec dino3dClassRec =
 WidgetClass dino3dWidgetClass = (WidgetClass) & dino3dClassRec;
 #endif
 
-static Point faceLoc3D[MAXFACES][MAXORIENT];
-static Point cubeLoc3D[MAXFACES][MAXORIENT];
-static Point diamondLoc3D[MAXFACES][MAXORIENT];
-static Point tinyDiamondLoc3D[MAXFACES][MAXORIENT];
-static Point triangleLoc3D[MAXFACES][MAXORIENT][4];
-static Point letter3DList[MAXFACES][MAXORIENT];
-static Point orientTriangle[MAXFACES][MAXORIENT][2];
+static Point faceLoc3D[MAX_FACES][MAX_ORIENT];
+static Point cubeLoc3D[MAX_FACES][MAX_ORIENT];
+static Point diamondLoc3D[MAX_FACES][MAX_ORIENT];
+static Point tinyDiamondLoc3D[MAX_FACES][MAX_ORIENT];
+static Point triangleLoc3D[MAX_FACES][MAX_ORIENT][4];
+static Point letter3DList[MAX_FACES][MAX_ORIENT];
+static Point orientTriangle[MAX_FACES][MAX_ORIENT][2];
 
 static Pixmap dr = 0; /* dummy for future double buffering */
 
@@ -453,18 +453,18 @@ MapTo3D(Dino3DWidget w, int face, int corner, int *side)
 {
 	switch (face) {
 	case 0:
-		*side = (corner + 2) % MAXORIENT;
+		*side = (corner + 2) % MAX_ORIENT;
 		break;
 	case 1:
 	case 5:
 		*side = corner;
 		break;
 	case 2:
-		*side = (corner + 1) % MAXORIENT;
+		*side = (corner + 1) % MAX_ORIENT;
 		break;
 	case 3:
 	case 4:
-		*side = (corner + 3) % MAXORIENT;
+		*side = (corner + 3) % MAX_ORIENT;
 		break;
 	default:
 		{
@@ -482,18 +482,18 @@ MapFrom3D(Dino3DWidget w, int face, int side, int *corner)
 {
 	switch (face) {
 	case 0:
-		*corner = (side + 2) % MAXORIENT;
+		*corner = (side + 2) % MAX_ORIENT;
 		break;
 	case 1:
 	case 5:
 		*corner = side;
 		break;
 	case 2:
-		*corner = (side + 3) % MAXORIENT;
+		*corner = (side + 3) % MAX_ORIENT;
 		break;
 	case 3:
 	case 4:
-		*corner = (side + 1) % MAXORIENT;
+		*corner = (side + 1) % MAX_ORIENT;
 		break;
 	default:
 		{
@@ -597,9 +597,9 @@ DrawFrame3D(Dino3DWidget w, Boolean focus)
 			(int) (-w->dino.delta - 2 * w->dino.letterOffset.y + w->core.height),
 			"Back", 4);
 	}
-	for (face = 0; face < MAXFACES; face++) {
+	for (face = 0; face < MAX_FACES; face++) {
 		POLYLINE((DinoWidget) w, dr, gc,
-			faceLoc3D[face], MAXORIENT, False);
+			faceLoc3D[face], MAX_ORIENT, False);
 	}
 }
 
@@ -607,10 +607,10 @@ static void
 ResizePieces(Dino3DWidget w)
 {
 	int face, orient, side, corner;
-	Point subcubeLoc3D[MAXFACES][MAXORIENT];
-	Point orientCubeLoc3D[2][MAXFACES][MAXORIENT];
-	Point subdiamondLoc3D[MAXFACES][MAXORIENT];
-	Point orientDiamondLoc3D[2][MAXFACES][MAXORIENT];
+	Point subcubeLoc3D[MAX_FACES][MAX_ORIENT];
+	Point orientCubeLoc3D[2][MAX_FACES][MAX_ORIENT];
+	Point subdiamondLoc3D[MAX_FACES][MAX_ORIENT];
+	Point orientDiamondLoc3D[2][MAX_FACES][MAX_ORIENT];
 
 	w->dino.letterOffset.x = -2;
 	w->dino.letterOffset.y = 3;
@@ -618,10 +618,10 @@ ResizePieces(Dino3DWidget w)
 		w->dino.puzzleOffset.x;
 	w->dino3d.viewMiddle.y = w->dino3d.faceSize.y +
 		w->dino.puzzleOffset.y;
-	for (face = 0; face < MAXFACES; face++) {
+	for (face = 0; face < MAX_FACES; face++) {
 		faceLoc3D[face][0].x = w->dino3d.viewMiddle.x;
 		faceLoc3D[face][0].y = w->dino3d.viewMiddle.y;
-		for (orient = 1; orient < MAXORIENT; orient++) {
+		for (orient = 1; orient < MAX_ORIENT; orient++) {
 			faceLoc3D[face][orient].x = w->dino3d.faceSize.x;
 			faceLoc3D[face][orient].y = w->dino3d.faceSize.y;
 		}
@@ -643,7 +643,7 @@ ResizePieces(Dino3DWidget w)
 		faceLoc3D[2][3].x /= -1;
 		faceLoc3D[2][3].y = 0;
 
-		for (face = MAXFACES / 2; face < MAXFACES; face++)
+		for (face = MAX_FACES / 2; face < MAX_FACES; face++)
 			faceLoc3D[face][0].y += w->dino3d.viewSize.y + 3;
 
 		faceLoc3D[3][1].x /= 2;
@@ -679,7 +679,7 @@ ResizePieces(Dino3DWidget w)
 		faceLoc3D[2][3].y /= 2;
 		faceLoc3D[2][3].x /= -1;
 
-		for (face = MAXFACES / 2; face < MAXFACES; face++)
+		for (face = MAX_FACES / 2; face < MAX_FACES; face++)
 			faceLoc3D[face][0].x += w->dino3d.viewSize.x + 3;
 
 		faceLoc3D[3][1].x /= -1;
@@ -700,14 +700,14 @@ ResizePieces(Dino3DWidget w)
 		faceLoc3D[5][3].x = 0;
 	}
 
-	for (face = 0; face < MAXFACES; face++) {
+	for (face = 0; face < MAX_FACES; face++) {
 		cubeLoc3D[face][0].x = faceLoc3D[face][0].x;
 		cubeLoc3D[face][0].y = faceLoc3D[face][0].y;
 		subcubeLoc3D[face][0].x = faceLoc3D[face][0].x;
 		subcubeLoc3D[face][0].y = faceLoc3D[face][0].y;
 		orientCubeLoc3D[0][face][0].x = orientCubeLoc3D[1][face][0].x = 0;
 		orientCubeLoc3D[0][face][0].y = orientCubeLoc3D[1][face][0].y = 0;
-		for (orient = 1; orient < MAXORIENT; orient++) {
+		for (orient = 1; orient < MAX_ORIENT; orient++) {
 			cubeLoc3D[face][orient].x = faceLoc3D[face][orient].x - 3 *
 				w->dino.delta * faceLoc3D[face][orient].x /
 				w->dino3d.faceSize.x;
@@ -739,7 +739,7 @@ ResizePieces(Dino3DWidget w)
 		orientTriangle[face][corner][0].y = -orientCubeLoc3D[0][face][2].y / 2;
 		orientTriangle[face][corner][1].x = -orientCubeLoc3D[1][face][2].x / 2;
 		orientTriangle[face][corner][1].y = -orientCubeLoc3D[1][face][2].y / 2;
-		for (orient = 0; orient < MAXORIENT - 1; orient++) {
+		for (orient = 0; orient < MAX_ORIENT - 1; orient++) {
 			diamondLoc3D[face][orient].x = (cubeLoc3D[face][orient].x +
 				cubeLoc3D[face][orient + 1].x) / 2;
 			diamondLoc3D[face][orient].y = (cubeLoc3D[face][orient].y +
@@ -766,30 +766,30 @@ ResizePieces(Dino3DWidget w)
 				orientCubeLoc3D[1][face][orient + 1].y) / 2;
 		}
 		/* Its a parallelagram so take advantage of that */
-		diamondLoc3D[face][orient].x = (cubeLoc3D[face][MAXORIENT - 1].x -
-			cubeLoc3D[face][MAXORIENT / 2].x) / 2;
-		diamondLoc3D[face][orient].y = (cubeLoc3D[face][MAXORIENT - 1].y -
-			cubeLoc3D[face][MAXORIENT / 2].y) / 2;
-		subdiamondLoc3D[face][orient].x = (subcubeLoc3D[face][MAXORIENT - 1].x -
-			subcubeLoc3D[face][MAXORIENT / 2].x) / 2;
-		subdiamondLoc3D[face][orient].y = (subcubeLoc3D[face][MAXORIENT - 1].y -
-			subcubeLoc3D[face][MAXORIENT / 2].y) / 2;
+		diamondLoc3D[face][orient].x = (cubeLoc3D[face][MAX_ORIENT - 1].x -
+			cubeLoc3D[face][MAX_ORIENT / 2].x) / 2;
+		diamondLoc3D[face][orient].y = (cubeLoc3D[face][MAX_ORIENT - 1].y -
+			cubeLoc3D[face][MAX_ORIENT / 2].y) / 2;
+		subdiamondLoc3D[face][orient].x = (subcubeLoc3D[face][MAX_ORIENT - 1].x -
+			subcubeLoc3D[face][MAX_ORIENT / 2].x) / 2;
+		subdiamondLoc3D[face][orient].y = (subcubeLoc3D[face][MAX_ORIENT - 1].y -
+			subcubeLoc3D[face][MAX_ORIENT / 2].y) / 2;
 		tinyDiamondLoc3D[face][0].x = diamondLoc3D[face][orient].x -
 			subdiamondLoc3D[face][orient].x;
 		tinyDiamondLoc3D[face][0].y = diamondLoc3D[face][orient].y -
 			subdiamondLoc3D[face][orient].y;
 		orientDiamondLoc3D[0][face][orient].x =
-			(orientCubeLoc3D[0][face][MAXORIENT - 1].x -
-			orientCubeLoc3D[0][face][MAXORIENT / 2].x) / 2;
+			(orientCubeLoc3D[0][face][MAX_ORIENT - 1].x -
+			orientCubeLoc3D[0][face][MAX_ORIENT / 2].x) / 2;
 		orientDiamondLoc3D[0][face][orient].y =
-			(orientCubeLoc3D[0][face][MAXORIENT - 1].y -
-			orientCubeLoc3D[0][face][MAXORIENT / 2].y) / 2;
+			(orientCubeLoc3D[0][face][MAX_ORIENT - 1].y -
+			orientCubeLoc3D[0][face][MAX_ORIENT / 2].y) / 2;
 		orientDiamondLoc3D[1][face][orient].x =
-			(orientCubeLoc3D[1][face][MAXORIENT - 1].x -
-			orientCubeLoc3D[1][face][MAXORIENT / 2].x) / 2;
+			(orientCubeLoc3D[1][face][MAX_ORIENT - 1].x -
+			orientCubeLoc3D[1][face][MAX_ORIENT / 2].x) / 2;
 		orientDiamondLoc3D[1][face][orient].y =
-			(orientCubeLoc3D[1][face][MAXORIENT - 1].y -
-			orientCubeLoc3D[1][face][MAXORIENT / 2].y) / 2;
+			(orientCubeLoc3D[1][face][MAX_ORIENT - 1].y -
+			orientCubeLoc3D[1][face][MAX_ORIENT / 2].y) / 2;
 
 		MapFrom3D(w, face, 1, &corner);
 		orientTriangle[face][corner][0].x = -orientCubeLoc3D[0][face][2].x / 2;
@@ -821,7 +821,7 @@ ResizePieces(Dino3DWidget w)
 		triangleLoc3D[face][3][1].y = subdiamondLoc3D[face][1].y;
 		triangleLoc3D[face][3][2].y = subdiamondLoc3D[face][2].y -
 			subdiamondLoc3D[face][1].y;
-		for (orient = 0; orient < MAXORIENT; orient++) {
+		for (orient = 0; orient < MAX_ORIENT; orient++) {
 			letter3DList[face][orient].x =
 				(2 * triangleLoc3D[face][orient][1].x +
 				triangleLoc3D[face][orient][2].x) / 3;
@@ -833,9 +833,9 @@ ResizePieces(Dino3DWidget w)
 			triangleLoc3D[face][orient][3].y =
 				-triangleLoc3D[face][orient][1].y - triangleLoc3D[face][orient][2].y;
 		}
-		for (orient = 1; orient < MAXORIENT; orient++) {
+		for (orient = 1; orient < MAX_ORIENT; orient++) {
 			side = corner;
-			MapFrom3D(w, face, (orient + 1) % MAXORIENT, &corner);
+			MapFrom3D(w, face, (orient + 1) % MAX_ORIENT, &corner);
 			orientTriangle[face][corner][0].x =
 				orientTriangle[face][side][0].x +
 				orientDiamondLoc3D[0][face][orient].x;
@@ -913,7 +913,7 @@ SelectPieces3D(Dino3DWidget w, int x, int y, int *face, int *position)
 	y = y_1;
 	found = 0;
 	DiamondOffset3D(w, *face, &dx, &dy);
-	for (corner = 0; corner < MAXORIENT; corner++) {
+	for (corner = 0; corner < MAX_ORIENT; corner++) {
 		int ok = 0;
 
 		x_1 = dx + triangleLoc3D[*face][corner][1].x;
@@ -950,31 +950,31 @@ NarrowSelection3D(Dino3DWidget w, int *face, int *direction)
 	case TL:
 		if (w->dino.vertical) {
 			if (*face == 1)
-				*direction = *direction + 2 * MAXORIENT;
+				*direction = *direction + 2 * MAX_ORIENT;
 			else if (*face == 3)
-				*direction = (*direction + 3) % MAXORIENT +
-					2 * MAXORIENT;
+				*direction = (*direction + 3) % MAX_ORIENT +
+					2 * MAX_ORIENT;
 		} else {
 			if (*face == 0)
-				*direction = (*direction + 3) % MAXORIENT +
-					2 * MAXORIENT;
+				*direction = (*direction + 3) % MAX_ORIENT +
+					2 * MAX_ORIENT;
 			else if (*face == 4)
-				*direction = (*direction + 2) % MAXORIENT +
-					2 * MAXORIENT;
+				*direction = (*direction + 2) % MAX_ORIENT +
+					2 * MAX_ORIENT;
 			if (*face == 5)
-				*direction = (*direction + 2) % MAXORIENT;
+				*direction = (*direction + 2) % MAX_ORIENT;
 		}
 		break;
 	case CCW:
 	case CW:
 		if (*face == 3 || *face == 4)
-			*direction = (TR + *direction - CW) % MAXORIENT;
+			*direction = (TR + *direction - CW) % MAX_ORIENT;
 		else if (*face == 0)
-			*direction = (BR + *direction - CW) % MAXORIENT;
+			*direction = (BR + *direction - CW) % MAX_ORIENT;
 		else if (*face == 2)
-			*direction = (BL + *direction - CW) % MAXORIENT;
+			*direction = (BL + *direction - CW) % MAX_ORIENT;
 		else if (*face == 1 || *face == 5)
-			*direction = (TL + *direction - CW) % MAXORIENT;
+			*direction = (TL + *direction - CW) % MAX_ORIENT;
 		break;
 	case TOP:
 	case RIGHT:
@@ -982,17 +982,17 @@ NarrowSelection3D(Dino3DWidget w, int *face, int *direction)
 	case LEFT:
 		if (w->dino.vertical) {
 			if (*face == 1)
-				*direction = (TL + *direction) % MAXORIENT;
+				*direction = (TL + *direction) % MAX_ORIENT;
 			else if (*face == 3)
-				*direction = (BL + *direction) % MAXORIENT;
+				*direction = (BL + *direction) % MAX_ORIENT;
 		} else {
 			if (*face == 0)
-				*direction = (TR + *direction) % MAXORIENT;
+				*direction = (TR + *direction) % MAX_ORIENT;
 			else if (*face == 4)
-				*direction = (BR + *direction) % MAXORIENT;
+				*direction = (BR + *direction) % MAX_ORIENT;
 			else if (*face == 5)
-				*direction = (BL + *direction) % MAXORIENT +
-					2 * MAXORIENT;
+				*direction = (BL + *direction) % MAX_ORIENT +
+					2 * MAX_ORIENT;
 		}
 		break;
 	default:
@@ -1034,7 +1034,7 @@ ResizePuzzle3D(Dino3DWidget w)
 	w->dino.delta = 4;
 	w->dino.vertical = (w->core.height >= w->core.width);
 	if (w->dino.vertical) {
-		tempSize.y = w->core.height / MAXVIEWS;
+		tempSize.y = w->core.height / MAX_VIEWS;
 		tempSize.x = w->core.width;
 		if (tempSize.x >= DIVIDE(tempSize.y)) {
 			w->dino3d.cubeSize.y = MAX((tempSize.y -
@@ -1052,9 +1052,9 @@ ResizePuzzle3D(Dino3DWidget w)
 		w->dino3d.viewSize.x = 2 * w->dino3d.faceSize.x + 3;
 		w->dino3d.viewSize.y = 2 * w->dino3d.faceSize.y + 3;
 		w->dino.puzzleSize.x = w->dino3d.viewSize.x + 1;
-		w->dino.puzzleSize.y = MAXVIEWS * w->dino3d.viewSize.y + 1;
+		w->dino.puzzleSize.y = MAX_VIEWS * w->dino3d.viewSize.y + 1;
 	} else {
-		tempSize.x = w->core.width / MAXVIEWS;
+		tempSize.x = w->core.width / MAX_VIEWS;
 		tempSize.y = w->core.height;
 		if (tempSize.y >= DIVIDE(tempSize.x)) {
 			w->dino3d.cubeSize.x = MAX((tempSize.x -
@@ -1072,7 +1072,7 @@ ResizePuzzle3D(Dino3DWidget w)
 		w->dino3d.viewSize.y = 2 * w->dino3d.faceSize.y + 3;
 		w->dino3d.viewSize.x = 2 * w->dino3d.faceSize.x + 3;
 		w->dino.puzzleSize.y = w->dino3d.viewSize.y + 1;
-		w->dino.puzzleSize.x = MAXVIEWS * w->dino3d.viewSize.x + 1;
+		w->dino.puzzleSize.x = MAX_VIEWS * w->dino3d.viewSize.x + 1;
 	}
 	w->dino.puzzleOffset.x = ((int) w->core.width - w->dino.puzzleSize.x) / 2;
 	w->dino.puzzleOffset.y = ((int) w->core.height - w->dino.puzzleSize.y) /
