@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1995 - 2007	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1995 - 2007	David A. Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -50,7 +50,7 @@ extern Dino3DClassRec dino3dClassRec;
 #define DOWN 0
 #define UP 1
 #define COORD3D 12
-#define MAXORIENT 4
+#define MAX_ORIENT 4
 
 #define SQRT_3 1.732050808
 #define MULTIPLY(a) ((int)(a*SQRT_3/2.0))
