@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 2007	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 2007	David A. Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -309,13 +309,13 @@ static XtResource resourcesPuzzleGL[] =
 	 XtRString, (caddr_t) "1"},
 	{XtNmode, XtCMode, XtRInt, sizeof (int),
 	 XtOffset(DinoWidget, dino.mode),
-	 XtRString, (caddr_t) "3"}, /*DEFAULTMODE */
+	 XtRString, (caddr_t) "3"}, /*DEFAULT_MODE */
 	{XtNorient, XtCOrient, XtRBoolean, sizeof (Boolean),
 	 XtOffset(DinoWidget, dino.orient),
-	 XtRString, (caddr_t) "FALSE"},	/* DEFAULTORIENT */
+	 XtRString, (caddr_t) "FALSE"},	/* DEFAULT_ORIENT */
 	{XtNpractice, XtCPractice, XtRBoolean, sizeof (Boolean),
 	 XtOffset(DinoWidget, dino.practice),
-	 XtRString, (caddr_t) "TRUE"}, /* DEFAULTPRACTICE */
+	 XtRString, (caddr_t) "TRUE"}, /* DEFAULT_PRACTICE */
 	{XtNuserName, XtCUserName, XtRString, sizeof (String),
 	 XtOffset(DinoWidget, dino.userName),
 	 XtRString, (caddr_t) ""},
@@ -410,8 +410,8 @@ printCube(DinoGLWidget w)
 {
 	int face, position;
 
-	for (face = 0; face < MAXFACES; face++) {
-		for (position = 0; position < MAXORIENT; position++) {
+	for (face = 0; face < MAX_FACES; face++) {
+		for (position = 0; position < MAX_ORIENT; position++) {
 			(void) printf("%d %d  ",
 				w->dino.cubeLoc[face][position].face,
 				w->dino.cubeLoc[face][position].rotation);
@@ -453,14 +453,14 @@ pickColor(DinoGLWidget w, int C, int mono)
 	color.red = GetRValue(w->dino.faceGC[C]);
 	color.green = GetGValue(w->dino.faceGC[C]);
 	color.blue = GetBValue(w->dino.faceGC[C]);
-#define MAXCOLOR 0xFF
+#define MAX_INTENSITY 0xFF
 #else
 	XColor color;
 
 	color.pixel = w->dino.faceColor[C];
 	XQueryColor(XtDisplay(w), DefaultColormapOfScreen(XtScreen(w)),
 		&color);
-#define MAXCOLOR 0xFFFF
+#define MAX_INTENSITY 0xFFFF
 #endif
 #ifdef DEBUG
 	(void) printf("i%d %d %d\n", color.red, color.green, color.blue);
@@ -473,13 +473,13 @@ pickColor(DinoGLWidget w, int C, int mono)
 #ifdef DEBUG
 		(void) printf("m%g\n", intensity);
 #endif
-		Material[0] *= (float) intensity / MAXCOLOR;
-		Material[1] *= (float) intensity / MAXCOLOR;
-		Material[2] *= (float) intensity / MAXCOLOR;
+		Material[0] *= (float) intensity / MAX_INTENSITY;
+		Material[1] *= (float) intensity / MAX_INTENSITY;
+		Material[2] *= (float) intensity / MAX_INTENSITY;
 	} else {
-		Material[0] *= (float) color.red / MAXCOLOR;
-		Material[1] *= (float) color.green / MAXCOLOR;
-		Material[2] *= (float) color.blue / MAXCOLOR;
+		Material[0] *= (float) color.red / MAX_INTENSITY;
+		Material[1] *= (float) color.green / MAX_INTENSITY;
+		Material[2] *= (float) color.blue / MAX_INTENSITY;
 	}
 	}
 #ifdef DEBUG
@@ -496,63 +496,63 @@ draw_stickerless_cubit(Boolean sep)
 		glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialGray);
 		/* Internal to cubit */
 		glNormal3f(0.0, 1.0, 1.0);
-		glVertex3f(-CUBEROUND, CUBELEN, -CUBELEN);
-		glVertex3f(CUBEROUND, CUBELEN, -CUBEFULLROUND - CUBELEN);
-		glVertex3f(0, CUBELEN - CUBEROUND, -CUBELEN);
+		glVertex3f(-CUBE_ROUND, CUBE_LENGTH, -CUBE_LENGTH);
+		glVertex3f(CUBE_ROUND, CUBE_LENGTH, -CUBEFULLROUND - CUBE_LENGTH);
+		glVertex3f(0, CUBE_LENGTH - CUBE_ROUND, -CUBE_LENGTH);
 		glNormal3f(0.0, 1.0, 1.0);
-		glVertex3f(CUBELEN, CUBEROUND, -CUBEFULLROUND - CUBELEN);
-		glVertex3f(CUBELEN, -CUBEROUND, -CUBELEN);
-		glVertex3f(CUBELEN - CUBEROUND, 0, -CUBELEN);
+		glVertex3f(CUBE_LENGTH, CUBE_ROUND, -CUBEFULLROUND - CUBE_LENGTH);
+		glVertex3f(CUBE_LENGTH, -CUBE_ROUND, -CUBE_LENGTH);
+		glVertex3f(CUBE_LENGTH - CUBE_ROUND, 0, -CUBE_LENGTH);
 		glNormal3f(0.0, 1.0, 1.0);
-		glVertex3f(CUBELEN, -CUBEROUND, -CUBELEN);
-		glVertex3f(CUBEROUND, CUBELEN, CUBEFULLROUND - CUBELEN);
-		glVertex3f(0, CUBELEN - CUBEROUND, -CUBELEN);
+		glVertex3f(CUBE_LENGTH, -CUBE_ROUND, -CUBE_LENGTH);
+		glVertex3f(CUBE_ROUND, CUBE_LENGTH, CUBEFULLROUND - CUBE_LENGTH);
+		glVertex3f(0, CUBE_LENGTH - CUBE_ROUND, -CUBE_LENGTH);
 		glNormal3f(0.0, 1.0, 1.0);
-		glVertex3f(CUBELEN, CUBEROUND, CUBEFULLROUND - CUBELEN);
-		glVertex3f(-CUBEROUND, CUBELEN, -CUBELEN);
-		glVertex3f(CUBELEN - CUBEROUND, 0, -CUBELEN);
+		glVertex3f(CUBE_LENGTH, CUBE_ROUND, CUBEFULLROUND - CUBE_LENGTH);
+		glVertex3f(-CUBE_ROUND, CUBE_LENGTH, -CUBE_LENGTH);
+		glVertex3f(CUBE_LENGTH - CUBE_ROUND, 0, -CUBE_LENGTH);
 		glNormal3f(1.0, 1.0, 0.0);
-		glVertex3f(CUBEROUND, CUBELEN, -CUBEFULLROUND - CUBELEN);
-		glVertex3f(CUBEROUND, CUBELEN, CUBEFULLROUND - CUBELEN);
-		glVertex3f(0, CUBELEN - CUBEROUND, -CUBELEN);
+		glVertex3f(CUBE_ROUND, CUBE_LENGTH, -CUBEFULLROUND - CUBE_LENGTH);
+		glVertex3f(CUBE_ROUND, CUBE_LENGTH, CUBEFULLROUND - CUBE_LENGTH);
+		glVertex3f(0, CUBE_LENGTH - CUBE_ROUND, -CUBE_LENGTH);
 		glNormal3f(1.0, 1.0, 0.0);
-		glVertex3f(CUBELEN, CUBEROUND, CUBEFULLROUND - CUBELEN);
-		glVertex3f(CUBELEN, CUBEROUND, -CUBEFULLROUND - CUBELEN);
-		glVertex3f(CUBELEN - CUBEROUND, 0, -CUBELEN);
+		glVertex3f(CUBE_LENGTH, CUBE_ROUND, CUBEFULLROUND - CUBE_LENGTH);
+		glVertex3f(CUBE_LENGTH, CUBE_ROUND, -CUBEFULLROUND - CUBE_LENGTH);
+		glVertex3f(CUBE_LENGTH - CUBE_ROUND, 0, -CUBE_LENGTH);
 		glEnd();
 	} else {
 		glBegin(GL_QUADS);
 		glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialGray);
 		/* Edge of cubit */
 		glNormal3f(1.0, 1.0, 0.0);
-		glVertex3f(CUBEROUND, CUBELEN, -CUBEFULLROUND - CUBELEN);
-		glVertex3f(CUBEROUND, CUBELEN, CUBEFULLROUND - CUBELEN);
-		glVertex3f(CUBELEN, CUBEROUND, CUBEFULLROUND - CUBELEN);
-		glVertex3f(CUBELEN, CUBEROUND, -CUBEFULLROUND - CUBELEN);
+		glVertex3f(CUBE_ROUND, CUBE_LENGTH, -CUBEFULLROUND - CUBE_LENGTH);
+		glVertex3f(CUBE_ROUND, CUBE_LENGTH, CUBEFULLROUND - CUBE_LENGTH);
+		glVertex3f(CUBE_LENGTH, CUBE_ROUND, CUBEFULLROUND - CUBE_LENGTH);
+		glVertex3f(CUBE_LENGTH, CUBE_ROUND, -CUBEFULLROUND - CUBE_LENGTH);
 		/* Internal to cubit */
 		glNormal3f(0.0, 1.0, 1.0);
-		glVertex3f(CUBEROUND, CUBELEN, -CUBEFULLROUND - CUBELEN);
-		glVertex3f(CUBELEN, CUBEROUND, -CUBEFULLROUND - CUBELEN);
-		glVertex3f(CUBELEN, -CUBEROUND, -CUBELEN);
-		glVertex3f(-CUBEROUND, CUBELEN, -CUBELEN);
+		glVertex3f(CUBE_ROUND, CUBE_LENGTH, -CUBEFULLROUND - CUBE_LENGTH);
+		glVertex3f(CUBE_LENGTH, CUBE_ROUND, -CUBEFULLROUND - CUBE_LENGTH);
+		glVertex3f(CUBE_LENGTH, -CUBE_ROUND, -CUBE_LENGTH);
+		glVertex3f(-CUBE_ROUND, CUBE_LENGTH, -CUBE_LENGTH);
 		glNormal3f(0.0, 1.0, 1.0);
-		glVertex3f(CUBEROUND, CUBELEN, CUBEFULLROUND - CUBELEN);
-		glVertex3f(CUBELEN, CUBEROUND, CUBEFULLROUND - CUBELEN);
-		glVertex3f(-CUBEROUND, CUBELEN, -CUBELEN);
-		glVertex3f(CUBELEN, -CUBEROUND, -CUBELEN);
+		glVertex3f(CUBE_ROUND, CUBE_LENGTH, CUBEFULLROUND - CUBE_LENGTH);
+		glVertex3f(CUBE_LENGTH, CUBE_ROUND, CUBEFULLROUND - CUBE_LENGTH);
+		glVertex3f(-CUBE_ROUND, CUBE_LENGTH, -CUBE_LENGTH);
+		glVertex3f(CUBE_LENGTH, -CUBE_ROUND, -CUBE_LENGTH);
 		glEnd();
 	}
 	glBegin(GL_TRIANGLES);
 	glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialGray);
 	/* Put sticker here */
 	glNormal3f(1.0, 0.0, 0.0);
-	glVertex3f(CUBELEN, CUBEROUND, -CUBEFULLROUND - CUBELEN);
-	glVertex3f(CUBELEN, CUBEROUND, CUBEFULLROUND - CUBELEN);
-	glVertex3f(CUBELEN, -CUBEROUND, -CUBELEN);
+	glVertex3f(CUBE_LENGTH, CUBE_ROUND, -CUBEFULLROUND - CUBE_LENGTH);
+	glVertex3f(CUBE_LENGTH, CUBE_ROUND, CUBEFULLROUND - CUBE_LENGTH);
+	glVertex3f(CUBE_LENGTH, -CUBE_ROUND, -CUBE_LENGTH);
 	glNormal3f(0.0, 1.0, 0.0);
-	glVertex3f(-CUBEROUND, CUBELEN, -CUBELEN);
-	glVertex3f(CUBEROUND, CUBELEN, CUBEFULLROUND - CUBELEN);
-	glVertex3f(CUBEROUND, CUBELEN, -CUBEFULLROUND - CUBELEN);
+	glVertex3f(-CUBE_ROUND, CUBE_LENGTH, -CUBE_LENGTH);
+	glVertex3f(CUBE_ROUND, CUBE_LENGTH, CUBEFULLROUND - CUBE_LENGTH);
+	glVertex3f(CUBE_ROUND, CUBE_LENGTH, -CUBEFULLROUND - CUBE_LENGTH);
 	glEnd();
 	return True;
 }
@@ -573,26 +573,26 @@ DrawOrientLine(DinoGLWidget w, int face, int rotation,
 		case 0:
 			glVertex3f(-CUT, 0.0, -CUT);
 			glVertex3f(CUT, 0.0, -CUT);
-			glVertex3f(CUT, 0.0, -STICKERSHORT);
-			glVertex3f(-CUT, 0.0, -STICKERSHORT);
+			glVertex3f(CUT, 0.0, -STICKER_SHORT);
+			glVertex3f(-CUT, 0.0, -STICKER_SHORT);
 			break;
 		case 1:
 			glVertex3f(CUT, 0.0, -CUT);
 			glVertex3f(CUT, 0.0, CUT);
-			glVertex3f(STICKERSHORT, 0.0, CUT);
-			glVertex3f(STICKERSHORT, 0.0, -CUT);
+			glVertex3f(STICKER_SHORT, 0.0, CUT);
+			glVertex3f(STICKER_SHORT, 0.0, -CUT);
 			break;
 		case 2:
 			glVertex3f(CUT, 0.0, CUT);
 			glVertex3f(-CUT, 0.0, CUT);
-			glVertex3f(-CUT, 0.0, STICKERSHORT);
-			glVertex3f(CUT, 0.0, STICKERSHORT);
+			glVertex3f(-CUT, 0.0, STICKER_SHORT);
+			glVertex3f(CUT, 0.0, STICKER_SHORT);
 			break;
 		case 3:
 			glVertex3f(-CUT, 0.0, CUT);
 			glVertex3f(-CUT, 0.0, -CUT);
-			glVertex3f(-STICKERSHORT, 0.0, -CUT);
-			glVertex3f(-STICKERSHORT, 0.0, CUT);
+			glVertex3f(-STICKER_SHORT, 0.0, -CUT);
+			glVertex3f(-STICKER_SHORT, 0.0, CUT);
 			break;
 		default:
 			err = 1;
@@ -603,26 +603,26 @@ DrawOrientLine(DinoGLWidget w, int face, int rotation,
 		case 0:
 			glVertex3f(0.0, CUT, -CUT);
 			glVertex3f(0.0, CUT, CUT);
-			glVertex3f(0.0, STICKERSHORT, CUT);
-			glVertex3f(0.0, STICKERSHORT, -CUT);
+			glVertex3f(0.0, STICKER_SHORT, CUT);
+			glVertex3f(0.0, STICKER_SHORT, -CUT);
 			break;
 		case 1:
 			glVertex3f(0.0, CUT, CUT);
 			glVertex3f(0.0, -CUT, CUT);
-			glVertex3f(0.0, -CUT, STICKERSHORT);
-			glVertex3f(0.0, CUT, STICKERSHORT);
+			glVertex3f(0.0, -CUT, STICKER_SHORT);
+			glVertex3f(0.0, CUT, STICKER_SHORT);
 			break;
 		case 2:
 			glVertex3f(0.0, -CUT, CUT);
 			glVertex3f(0.0, -CUT, -CUT);
-			glVertex3f(0.0, -STICKERSHORT, -CUT);
-			glVertex3f(0.0, -STICKERSHORT, CUT);
+			glVertex3f(0.0, -STICKER_SHORT, -CUT);
+			glVertex3f(0.0, -STICKER_SHORT, CUT);
 			break;
 		case 3:
 			glVertex3f(0.0, -CUT, -CUT);
 			glVertex3f(0.0, CUT, -CUT);
-			glVertex3f(0.0, CUT, -STICKERSHORT);
-			glVertex3f(0.0, -CUT, -STICKERSHORT);
+			glVertex3f(0.0, CUT, -STICKER_SHORT);
+			glVertex3f(0.0, -CUT, -STICKER_SHORT);
 			break;
 		default:
 			err = 1;
@@ -633,26 +633,26 @@ DrawOrientLine(DinoGLWidget w, int face, int rotation,
 		case 0:
 			glVertex3f(-CUT, CUT, 0.0);
 			glVertex3f(CUT, CUT, 0.0);
-			glVertex3f(CUT, STICKERSHORT, 0.0);
-			glVertex3f(-CUT, STICKERSHORT, 0.0);
+			glVertex3f(CUT, STICKER_SHORT, 0.0);
+			glVertex3f(-CUT, STICKER_SHORT, 0.0);
 			break;
 		case 1:
 			glVertex3f(CUT, CUT, 0.0);
 			glVertex3f(CUT, -CUT, 0.0);
-			glVertex3f(STICKERSHORT, -CUT, 0.0);
-			glVertex3f(STICKERSHORT, CUT, 0.0);
+			glVertex3f(STICKER_SHORT, -CUT, 0.0);
+			glVertex3f(STICKER_SHORT, CUT, 0.0);
 			break;
 		case 2:
 			glVertex3f(CUT, -CUT, 0.0);
 			glVertex3f(-CUT, -CUT, 0.0);
-			glVertex3f(-CUT, -STICKERSHORT, 0.0);
-			glVertex3f(CUT, -STICKERSHORT, 0.0);
+			glVertex3f(-CUT, -STICKER_SHORT, 0.0);
+			glVertex3f(CUT, -STICKER_SHORT, 0.0);
 			break;
 		case 3:
 			glVertex3f(-CUT, -CUT, 0.0);
 			glVertex3f(-CUT, CUT, 0.0);
-			glVertex3f(-STICKERSHORT, CUT, 0.0);
-			glVertex3f(-STICKERSHORT, -CUT, 0.0);
+			glVertex3f(-STICKER_SHORT, CUT, 0.0);
+			glVertex3f(-STICKER_SHORT, -CUT, 0.0);
 			break;
 		default:
 			err = 1;
@@ -662,26 +662,26 @@ DrawOrientLine(DinoGLWidget w, int face, int rotation,
 		switch (rotation) {
 		case 0:
 			glVertex3f(0.0, CUT, -CUT);
-			glVertex3f(0.0, STICKERSHORT, -CUT);
-			glVertex3f(0.0, STICKERSHORT, CUT);
+			glVertex3f(0.0, STICKER_SHORT, -CUT);
+			glVertex3f(0.0, STICKER_SHORT, CUT);
 			glVertex3f(0.0, CUT, CUT);
 			break;
 		case 1:
 			glVertex3f(0.0, -CUT, -CUT);
-			glVertex3f(0.0, -CUT, -STICKERSHORT);
-			glVertex3f(0.0, CUT, -STICKERSHORT);
+			glVertex3f(0.0, -CUT, -STICKER_SHORT);
+			glVertex3f(0.0, CUT, -STICKER_SHORT);
 			glVertex3f(0.0, CUT, -CUT);
 			break;
 		case 2:
 			glVertex3f(0.0, -CUT, CUT);
-			glVertex3f(0.0, -STICKERSHORT, CUT);
-			glVertex3f(0.0, -STICKERSHORT, -CUT);
+			glVertex3f(0.0, -STICKER_SHORT, CUT);
+			glVertex3f(0.0, -STICKER_SHORT, -CUT);
 			glVertex3f(0.0, -CUT, -CUT);
 			break;
 		case 3:
 			glVertex3f(0.0, CUT, CUT);
-			glVertex3f(0.0, CUT, STICKERSHORT);
-			glVertex3f(0.0, -CUT, STICKERSHORT);
+			glVertex3f(0.0, CUT, STICKER_SHORT);
+			glVertex3f(0.0, -CUT, STICKER_SHORT);
 			glVertex3f(0.0, -CUT, CUT);
 			break;
 		default:
@@ -692,26 +692,26 @@ DrawOrientLine(DinoGLWidget w, int face, int rotation,
 		switch (rotation) {
 		case 0:
 			glVertex3f(CUT, 0.0, CUT);
-			glVertex3f(CUT, 0.0, STICKERSHORT);
-			glVertex3f(-CUT, 0.0, STICKERSHORT);
+			glVertex3f(CUT, 0.0, STICKER_SHORT);
+			glVertex3f(-CUT, 0.0, STICKER_SHORT);
 			glVertex3f(-CUT, 0.0, CUT);
 			break;
 		case 1:
 			glVertex3f(CUT, 0.0, -CUT);
-			glVertex3f(STICKERSHORT, 0.0, -CUT);
-			glVertex3f(STICKERSHORT, 0.0, CUT);
+			glVertex3f(STICKER_SHORT, 0.0, -CUT);
+			glVertex3f(STICKER_SHORT, 0.0, CUT);
 			glVertex3f(CUT, 0.0, CUT);
 			break;
 		case 2:
 			glVertex3f(-CUT, 0.0, -CUT);
-			glVertex3f(-CUT, 0.0, -STICKERSHORT);
-			glVertex3f(CUT, 0.0, -STICKERSHORT);
+			glVertex3f(-CUT, 0.0, -STICKER_SHORT);
+			glVertex3f(CUT, 0.0, -STICKER_SHORT);
 			glVertex3f(CUT, 0.0, -CUT);
 			break;
 		case 3:
 			glVertex3f(-CUT, 0.0, CUT);
-			glVertex3f(-STICKERSHORT, 0.0, CUT);
-			glVertex3f(-STICKERSHORT, 0.0, -CUT);
+			glVertex3f(-STICKER_SHORT, 0.0, CUT);
+			glVertex3f(-STICKER_SHORT, 0.0, -CUT);
 			glVertex3f(-CUT, 0.0, -CUT);
 			break;
 		default:
@@ -722,26 +722,26 @@ DrawOrientLine(DinoGLWidget w, int face, int rotation,
 		switch (rotation) {
 		case 0:
 			glVertex3f(CUT, -CUT, 0.0);
-			glVertex3f(CUT, -STICKERSHORT, 0.0);
-			glVertex3f(-CUT, -STICKERSHORT, 0.0);
+			glVertex3f(CUT, -STICKER_SHORT, 0.0);
+			glVertex3f(-CUT, -STICKER_SHORT, 0.0);
 			glVertex3f(-CUT, -CUT, 0.0);
 			break;
 		case 1:
 			glVertex3f(CUT, CUT, 0.0);
-			glVertex3f(STICKERSHORT, CUT, 0.0);
-			glVertex3f(STICKERSHORT, -CUT, 0.0);
+			glVertex3f(STICKER_SHORT, CUT, 0.0);
+			glVertex3f(STICKER_SHORT, -CUT, 0.0);
 			glVertex3f(CUT, -CUT, 0.0);
 			break;
 		case 2:
 			glVertex3f(-CUT, CUT, 0.0);
-			glVertex3f(-CUT, STICKERSHORT, 0.0);
-			glVertex3f(CUT, STICKERSHORT, 0.0);
+			glVertex3f(-CUT, STICKER_SHORT, 0.0);
+			glVertex3f(CUT, STICKER_SHORT, 0.0);
 			glVertex3f(CUT, CUT, 0.0);
 			break;
 		case 3:
 			glVertex3f(-CUT, -CUT, 0.0);
-			glVertex3f(-STICKERSHORT, -CUT, 0.0);
-			glVertex3f(-STICKERSHORT, CUT, 0.0);
+			glVertex3f(-STICKER_SHORT, -CUT, 0.0);
+			glVertex3f(-STICKER_SHORT, CUT, 0.0);
 			glVertex3f(-CUT, CUT, 0.0);
 			break;
 		default:
@@ -772,7 +772,7 @@ DrawCubit(DinoGLWidget w,
 		pickColor(w, back, mono);
 		glNormal3f(0.0, 0.0, -1.0);
 		if (top != NO_FACE) {
-			glTranslatef(-CUBELEN, -CUBEROUND, -STICKERDEPTH);
+			glTranslatef(-CUBE_LENGTH, -CUBE_ROUND, -STICKER_DEPTH);
 			glBegin(GL_TRIANGLES);
 			glVertex3f(0.0, OFFSET, 0.0);
 			glVertex3f(-STICKERFULLSHORT, STICKERFULLLONG, 0.0);
@@ -781,12 +781,12 @@ DrawCubit(DinoGLWidget w,
 			if (w->dino.orient) {
 				DrawOrientLine(w, BACK_FACE,
 					w->dino.cubeLoc[BACK_FACE][0].rotation,
-					0.0, CUBEROUND - 2.0 * CUBELEN,
-					-CUTDEPTH + STICKERDEPTH);
+					0.0, CUBE_ROUND - 2.0 * CUBE_LENGTH,
+					-CUT_DEPTH + STICKER_DEPTH);
 			}
 		}
 		if (left != NO_FACE) {
-			glTranslatef(CUBEROUND, CUBELEN, -STICKERDEPTH);
+			glTranslatef(CUBE_ROUND, CUBE_LENGTH, -STICKER_DEPTH);
 			glBegin(GL_TRIANGLES);
 			glVertex3f(-OFFSET, 0.0, 0.0);
 			glVertex3f(-STICKERFULLLONG, -STICKERFULLSHORT, 0.0);
@@ -795,12 +795,12 @@ DrawCubit(DinoGLWidget w,
 			if (w->dino.orient) {
 				DrawOrientLine(w, BACK_FACE,
 					w->dino.cubeLoc[BACK_FACE][1].rotation,
-					-CUBEROUND + 2.0 * CUBELEN, 0.0,
-					-CUTDEPTH + STICKERDEPTH);
+					-CUBE_ROUND + 2.0 * CUBE_LENGTH, 0.0,
+					-CUT_DEPTH + STICKER_DEPTH);
 			}
 		}
 		if (bottom != NO_FACE) {
-			glTranslatef(CUBELEN, CUBEROUND, -STICKERDEPTH);
+			glTranslatef(CUBE_LENGTH, CUBE_ROUND, -STICKER_DEPTH);
 			glBegin(GL_TRIANGLES);
 			glVertex3f(0.0, -OFFSET, 0.0);
 			glVertex3f(STICKERFULLSHORT, -STICKERFULLLONG, 0.0);
@@ -809,12 +809,12 @@ DrawCubit(DinoGLWidget w,
 			if (w->dino.orient) {
 				DrawOrientLine(w, BACK_FACE,
 					w->dino.cubeLoc[BACK_FACE][2].rotation,
-					0.0, -CUBEROUND + 2.0 * CUBELEN,
-					-CUTDEPTH + STICKERDEPTH);
+					0.0, -CUBE_ROUND + 2.0 * CUBE_LENGTH,
+					-CUT_DEPTH + STICKER_DEPTH);
 			}
 		}
 		if (right != NO_FACE) {
-			glTranslatef(-CUBEROUND, -CUBELEN, -STICKERDEPTH);
+			glTranslatef(-CUBE_ROUND, -CUBE_LENGTH, -STICKER_DEPTH);
 			glBegin(GL_TRIANGLES);
 			glVertex3f(OFFSET, 0.0, 0.0);
 			glVertex3f(STICKERFULLLONG, STICKERFULLSHORT, 0.0);
@@ -823,8 +823,8 @@ DrawCubit(DinoGLWidget w,
 			if (w->dino.orient) {
 				DrawOrientLine(w, BACK_FACE,
 					w->dino.cubeLoc[BACK_FACE][3].rotation,
-					CUBEROUND - 2.0 * CUBELEN, 0.0,
-					-CUTDEPTH + STICKERDEPTH);
+					CUBE_ROUND - 2.0 * CUBE_LENGTH, 0.0,
+					-CUT_DEPTH + STICKER_DEPTH);
 			}
 		}
 		glPopMatrix();
@@ -834,7 +834,7 @@ DrawCubit(DinoGLWidget w,
 		pickColor(w, front, mono);
 		glNormal3f(0.0, 0.0, 1.0);
 		if (top != NO_FACE) {
-			glTranslatef(CUBELEN, -CUBEROUND, STICKERDEPTH);
+			glTranslatef(CUBE_LENGTH, -CUBE_ROUND, STICKER_DEPTH);
 			glBegin(GL_TRIANGLES);
 			glVertex3f(0.0, OFFSET, 0.0);
 			glVertex3f(STICKERFULLSHORT, STICKERFULLLONG, 0.0);
@@ -843,12 +843,12 @@ DrawCubit(DinoGLWidget w,
 			if (w->dino.orient) {
 				DrawOrientLine(w, FRONT_FACE,
 					w->dino.cubeLoc[FRONT_FACE][2].rotation,
-					0.0, CUBEROUND - 2.0 * CUBELEN,
-					CUTDEPTH - STICKERDEPTH);
+					0.0, CUBE_ROUND - 2.0 * CUBE_LENGTH,
+					CUT_DEPTH - STICKER_DEPTH);
 			}
 		}
 		if (left != NO_FACE) {
-			glTranslatef(CUBEROUND, -CUBELEN, STICKERDEPTH);
+			glTranslatef(CUBE_ROUND, -CUBE_LENGTH, STICKER_DEPTH);
 			glBegin(GL_TRIANGLES);
 			glVertex3f(-OFFSET, 0.0, 0.0);
 			glVertex3f(-STICKERFULLLONG, STICKERFULLSHORT, 0.0);
@@ -857,12 +857,12 @@ DrawCubit(DinoGLWidget w,
 			if (w->dino.orient) {
 				DrawOrientLine(w, FRONT_FACE,
 					w->dino.cubeLoc[FRONT_FACE][1].rotation,
-					-CUBEROUND + 2.0 * CUBELEN, 0.0,
-					CUTDEPTH - STICKERDEPTH);
+					-CUBE_ROUND + 2.0 * CUBE_LENGTH, 0.0,
+					CUT_DEPTH - STICKER_DEPTH);
 			}
 		}
 		if (bottom != NO_FACE) {
-			glTranslatef(-CUBELEN, CUBEROUND, STICKERDEPTH);
+			glTranslatef(-CUBE_LENGTH, CUBE_ROUND, STICKER_DEPTH);
 			glBegin(GL_TRIANGLES);
 			glVertex3f(0.0, -OFFSET, 0.0);
 			glVertex3f(-STICKERFULLSHORT, -STICKERFULLLONG, 0.0);
@@ -871,12 +871,12 @@ DrawCubit(DinoGLWidget w,
 			if (w->dino.orient) {
 				DrawOrientLine(w, FRONT_FACE,
 					w->dino.cubeLoc[FRONT_FACE][0].rotation,
-					0.0, -CUBEROUND + 2.0 * CUBELEN,
-					CUTDEPTH - STICKERDEPTH);
+					0.0, -CUBE_ROUND + 2.0 * CUBE_LENGTH,
+					CUT_DEPTH - STICKER_DEPTH);
 			}
 		}
 		if (right != NO_FACE) {
-			glTranslatef(-CUBEROUND, CUBELEN, STICKERDEPTH);
+			glTranslatef(-CUBE_ROUND, CUBE_LENGTH, STICKER_DEPTH);
 			glBegin(GL_TRIANGLES);
 			glVertex3f(OFFSET, 0.0, 0.0);
 			glVertex3f(STICKERFULLLONG, -STICKERFULLSHORT, 0.0);
@@ -885,8 +885,8 @@ DrawCubit(DinoGLWidget w,
 			if (w->dino.orient) {
 				DrawOrientLine(w, FRONT_FACE,
 					w->dino.cubeLoc[FRONT_FACE][3].rotation,
-					CUBEROUND - 2.0 * CUBELEN, 0.0,
-					CUTDEPTH - STICKERDEPTH);
+					CUBE_ROUND - 2.0 * CUBE_LENGTH, 0.0,
+					CUT_DEPTH - STICKER_DEPTH);
 			}
 		}
 		glPopMatrix();
@@ -896,7 +896,7 @@ DrawCubit(DinoGLWidget w,
 		pickColor(w, left, mono);
 		glNormal3f(-1.0, 0.0, 0.0);
 		if (front != NO_FACE) {
-			glTranslatef(-STICKERDEPTH, -CUBELEN, -CUBEROUND);
+			glTranslatef(-STICKER_DEPTH, -CUBE_LENGTH, -CUBE_ROUND);
 			glBegin(GL_TRIANGLES);
 			glVertex3f(0.0, 0.0, OFFSET);
 			glVertex3f(0.0, -STICKERFULLSHORT, STICKERFULLLONG);
@@ -905,13 +905,13 @@ DrawCubit(DinoGLWidget w,
 			if (w->dino.orient) {
 				DrawOrientLine(w, LEFT_FACE,
 					w->dino.cubeLoc[LEFT_FACE][3].rotation,
-					-CUTDEPTH + STICKERDEPTH,
+					-CUT_DEPTH + STICKER_DEPTH,
 					0.0,
-					CUBEROUND - 2.0 * CUBELEN);
+					CUBE_ROUND - 2.0 * CUBE_LENGTH);
 			}
 		}
 		if (top != NO_FACE) {
-			glTranslatef(-STICKERDEPTH, -CUBEROUND, CUBELEN);
+			glTranslatef(-STICKER_DEPTH, -CUBE_ROUND, CUBE_LENGTH);
 			glBegin(GL_TRIANGLES);
 			glVertex3f(0.0, OFFSET, 0.0);
 			glVertex3f(0.0, STICKERFULLLONG, STICKERFULLSHORT);
@@ -920,13 +920,13 @@ DrawCubit(DinoGLWidget w,
 			if (w->dino.orient) {
 				DrawOrientLine(w, LEFT_FACE,
 					w->dino.cubeLoc[LEFT_FACE][0].rotation,
-					-CUTDEPTH + STICKERDEPTH,
-					CUBEROUND,
+					-CUT_DEPTH + STICKER_DEPTH,
+					CUBE_ROUND,
 					0.0);
 			}
 		}
 		if (back != NO_FACE) {
-			glTranslatef(-STICKERDEPTH, CUBELEN, CUBEROUND);
+			glTranslatef(-STICKER_DEPTH, CUBE_LENGTH, CUBE_ROUND);
 			glBegin(GL_TRIANGLES);
 			glVertex3f(0.0, 0.0, -OFFSET);
 			glVertex3f(0.0, STICKERFULLSHORT, -STICKERFULLLONG);
@@ -935,13 +935,13 @@ DrawCubit(DinoGLWidget w,
 			if (w->dino.orient) {
 				DrawOrientLine(w, LEFT_FACE,
 					w->dino.cubeLoc[LEFT_FACE][1].rotation,
-					-CUTDEPTH + STICKERDEPTH,
+					-CUT_DEPTH + STICKER_DEPTH,
 					0.0,
-					-CUBEROUND + 2.0 * CUBELEN);
+					-CUBE_ROUND + 2.0 * CUBE_LENGTH);
 			}
 		}
 		if (bottom != NO_FACE) {
-			glTranslatef(-STICKERDEPTH, CUBEROUND, -CUBELEN);
+			glTranslatef(-STICKER_DEPTH, CUBE_ROUND, -CUBE_LENGTH);
 			glBegin(GL_TRIANGLES);
 			glVertex3f(0.0, -OFFSET, 0.0);
 			glVertex3f(0.0, -STICKERFULLLONG, -STICKERFULLSHORT);
@@ -950,8 +950,8 @@ DrawCubit(DinoGLWidget w,
 			if (w->dino.orient) {
 				DrawOrientLine(w, LEFT_FACE,
 					w->dino.cubeLoc[LEFT_FACE][2].rotation,
-					-CUTDEPTH + STICKERDEPTH,
-					-CUBEROUND,
+					-CUT_DEPTH + STICKER_DEPTH,
+					-CUBE_ROUND,
 					0.0);
 			}
 		}
@@ -962,7 +962,7 @@ DrawCubit(DinoGLWidget w,
 		pickColor(w, right, mono);
 		glNormal3f(1.0, 0.0, 0.0);
 		if (front != NO_FACE) {
-			glTranslatef(STICKERDEPTH, CUBELEN, -CUBEROUND);
+			glTranslatef(STICKER_DEPTH, CUBE_LENGTH, -CUBE_ROUND);
 			glBegin(GL_TRIANGLES);
 			glVertex3f(0.0, 0.0, OFFSET);
 			glVertex3f(0.0, STICKERFULLSHORT, STICKERFULLLONG);
@@ -971,13 +971,13 @@ DrawCubit(DinoGLWidget w,
 			if (w->dino.orient) {
 				DrawOrientLine(w, RIGHT_FACE,
 					w->dino.cubeLoc[RIGHT_FACE][1].rotation,
-					CUTDEPTH - STICKERDEPTH,
-					CUBEROUND - CUBELEN,
-					CUBEROUND - 2.0 * CUBELEN);
+					CUT_DEPTH - STICKER_DEPTH,
+					CUBE_ROUND - CUBE_LENGTH,
+					CUBE_ROUND - 2.0 * CUBE_LENGTH);
 			}
 		}
 		if (top != NO_FACE) {
-			glTranslatef(STICKERDEPTH, -CUBEROUND, -CUBELEN);
+			glTranslatef(STICKER_DEPTH, -CUBE_ROUND, -CUBE_LENGTH);
 			glBegin(GL_TRIANGLES);
 			glVertex3f(0.0, OFFSET, 0.0);
 			glVertex3f(0.0, STICKERFULLLONG, -STICKERFULLSHORT);
@@ -986,13 +986,13 @@ DrawCubit(DinoGLWidget w,
 			if (w->dino.orient) {
 				DrawOrientLine(w, RIGHT_FACE,
 					w->dino.cubeLoc[RIGHT_FACE][0].rotation,
-					CUTDEPTH - STICKERDEPTH,
-					CUBELEN,
-					-CUBELEN + CUBEROUND);
+					CUT_DEPTH - STICKER_DEPTH,
+					CUBE_LENGTH,
+					-CUBE_LENGTH + CUBE_ROUND);
 			}
 		}
 		if (back != NO_FACE) {
-			glTranslatef(STICKERDEPTH, -CUBELEN, CUBEROUND);
+			glTranslatef(STICKER_DEPTH, -CUBE_LENGTH, CUBE_ROUND);
 			glBegin(GL_TRIANGLES);
 			glVertex3f(0.0, 0.0, -OFFSET);
 			glVertex3f(0.0, -STICKERFULLSHORT, -STICKERFULLLONG);
@@ -1001,12 +1001,12 @@ DrawCubit(DinoGLWidget w,
 			if (w->dino.orient) {
 				DrawOrientLine(w, RIGHT_FACE,
 					w->dino.cubeLoc[RIGHT_FACE][3].rotation,
-					CUTDEPTH - STICKERDEPTH,
-					0.0, -CUBEROUND + 2.0 * CUBELEN);
+					CUT_DEPTH - STICKER_DEPTH,
+					0.0, -CUBE_ROUND + 2.0 * CUBE_LENGTH);
 			}
 		}
 		if (bottom != NO_FACE) {
-			glTranslatef(STICKERDEPTH, CUBEROUND, CUBELEN);
+			glTranslatef(STICKER_DEPTH, CUBE_ROUND, CUBE_LENGTH);
 			glBegin(GL_TRIANGLES);
 			glVertex3f(0.0, -OFFSET, 0.0);
 			glVertex3f(0.0, -STICKERFULLLONG, STICKERFULLSHORT);
@@ -1015,8 +1015,8 @@ DrawCubit(DinoGLWidget w,
 			if (w->dino.orient) {
 				DrawOrientLine(w, RIGHT_FACE,
 					w->dino.cubeLoc[RIGHT_FACE][2].rotation,
-					CUTDEPTH - STICKERDEPTH,
-					-CUBELEN, 0.0);
+					CUT_DEPTH - STICKER_DEPTH,
+					-CUBE_LENGTH, 0.0);
 			}
 		}
 		glPopMatrix();
@@ -1026,7 +1026,7 @@ DrawCubit(DinoGLWidget w,
 		pickColor(w, bottom, mono);
 		glNormal3f(0.0, -1.0, 0.0);
 		if (left != NO_FACE) {
-			glTranslatef(CUBEROUND, -STICKERDEPTH, -CUBELEN);
+			glTranslatef(CUBE_ROUND, -STICKER_DEPTH, -CUBE_LENGTH);
 			glBegin(GL_TRIANGLES);
 			glVertex3f(-OFFSET, 0.0, 0.0);
 			glVertex3f(-STICKERFULLLONG, 0.0, STICKERFULLSHORT);
@@ -1035,12 +1035,12 @@ DrawCubit(DinoGLWidget w,
 			if (w->dino.orient) {
 				DrawOrientLine(w, BOTTOM_FACE,
 					w->dino.cubeLoc[BOTTOM_FACE][3].rotation,
-					-CUBEROUND,
-					-CUTDEPTH + STICKERDEPTH, 0.0);
+					-CUBE_ROUND,
+					-CUT_DEPTH + STICKER_DEPTH, 0.0);
 			}
 		}
 		if (front != NO_FACE) {
-			glTranslatef(-CUBELEN, -STICKERDEPTH, -CUBEROUND);
+			glTranslatef(-CUBE_LENGTH, -STICKER_DEPTH, -CUBE_ROUND);
 			glBegin(GL_TRIANGLES);
 			glVertex3f(0.0, 0.0, OFFSET);
 			glVertex3f(STICKERFULLSHORT, 0.0, STICKERFULLLONG);
@@ -1049,12 +1049,12 @@ DrawCubit(DinoGLWidget w,
 			if (w->dino.orient) {
 				DrawOrientLine(w, BOTTOM_FACE,
 					w->dino.cubeLoc[BOTTOM_FACE][0].rotation,
-					0.0, -CUTDEPTH + STICKERDEPTH,
-					CUBEROUND);
+					0.0, -CUT_DEPTH + STICKER_DEPTH,
+					CUBE_ROUND);
 			}
 		}
 		if (right != NO_FACE) {
-			glTranslatef(-CUBEROUND, -STICKERDEPTH, CUBELEN);
+			glTranslatef(-CUBE_ROUND, -STICKER_DEPTH, CUBE_LENGTH);
 			glBegin(GL_TRIANGLES);
 			glVertex3f(OFFSET, 0.0, 0.0);
 			glVertex3f(STICKERFULLLONG, 0.0, -STICKERFULLSHORT);
@@ -1063,12 +1063,12 @@ DrawCubit(DinoGLWidget w,
 			if (w->dino.orient) {
 				DrawOrientLine(w, BOTTOM_FACE,
 					w->dino.cubeLoc[BOTTOM_FACE][1].rotation,
-					CUBEROUND,
-					-CUTDEPTH + STICKERDEPTH, 0.0);
+					CUBE_ROUND,
+					-CUT_DEPTH + STICKER_DEPTH, 0.0);
 			}
 		}
 		if (back != NO_FACE) {
-			glTranslatef(CUBELEN, -STICKERDEPTH, CUBEROUND);
+			glTranslatef(CUBE_LENGTH, -STICKER_DEPTH, CUBE_ROUND);
 			glBegin(GL_TRIANGLES);
 			glVertex3f(0.0, 0.0, -OFFSET);
 			glVertex3f(-STICKERFULLSHORT, 0.0, -STICKERFULLLONG);
@@ -1077,8 +1077,8 @@ DrawCubit(DinoGLWidget w,
 			if (w->dino.orient) {
 				DrawOrientLine(w, BOTTOM_FACE,
 					w->dino.cubeLoc[BOTTOM_FACE][2].rotation,
-					0.0, -CUTDEPTH + STICKERDEPTH,
-					-CUBEROUND);
+					0.0, -CUT_DEPTH + STICKER_DEPTH,
+					-CUBE_ROUND);
 			}
 		}
 		glPopMatrix();
@@ -1088,7 +1088,7 @@ DrawCubit(DinoGLWidget w,
 		pickColor(w, top, mono);
 		glNormal3f(0.0, 1.0, 0.0);
 		if (left != NO_FACE) {
-			glTranslatef(CUBEROUND, STICKERDEPTH, CUBELEN);
+			glTranslatef(CUBE_ROUND, STICKER_DEPTH, CUBE_LENGTH);
 			glBegin(GL_TRIANGLES);
 			glVertex3f(-OFFSET, 0.0, 0.0);
 			glVertex3f(-STICKERFULLLONG, 0.0, -STICKERFULLSHORT);
@@ -1097,12 +1097,12 @@ DrawCubit(DinoGLWidget w,
 			if (w->dino.orient) {
 				DrawOrientLine(w, TOP_FACE,
 					w->dino.cubeLoc[TOP_FACE][3].rotation,
-					-CUBELEN,
-					CUTDEPTH - STICKERDEPTH, 0.0);
+					-CUBE_LENGTH,
+					CUT_DEPTH - STICKER_DEPTH, 0.0);
 			}
 		}
 		if (front != NO_FACE) {
-			glTranslatef(CUBELEN, STICKERDEPTH, -CUBEROUND);
+			glTranslatef(CUBE_LENGTH, STICKER_DEPTH, -CUBE_ROUND);
 			glBegin(GL_TRIANGLES);
 			glVertex3f(0.0, 0.0, OFFSET);
 			glVertex3f(-STICKERFULLSHORT, 0.0, STICKERFULLLONG);
@@ -1111,12 +1111,12 @@ DrawCubit(DinoGLWidget w,
 			if (w->dino.orient) {
 				DrawOrientLine(w, TOP_FACE,
 					w->dino.cubeLoc[TOP_FACE][2].rotation,
-					0.0, CUTDEPTH - STICKERDEPTH,
-					CUBELEN);
+					0.0, CUT_DEPTH - STICKER_DEPTH,
+					CUBE_LENGTH);
 			}
 		}
 		if (right != NO_FACE) {
-			glTranslatef(-CUBEROUND, STICKERDEPTH, -CUBELEN);
+			glTranslatef(-CUBE_ROUND, STICKER_DEPTH, -CUBE_LENGTH);
 			glBegin(GL_TRIANGLES);
 			glVertex3f(OFFSET, 0.0, 0.0);
 			glVertex3f(STICKERFULLLONG, 0.0, STICKERFULLSHORT);
@@ -1125,12 +1125,12 @@ DrawCubit(DinoGLWidget w,
 			if (w->dino.orient) {
 				DrawOrientLine(w, TOP_FACE,
 					w->dino.cubeLoc[TOP_FACE][1].rotation,
-					CUBELEN,
-					CUTDEPTH - STICKERDEPTH, 0.0);
+					CUBE_LENGTH,
+					CUT_DEPTH - STICKER_DEPTH, 0.0);
 			}
 		}
 		if (back != NO_FACE) {
-			glTranslatef(-CUBELEN, STICKERDEPTH, CUBEROUND);
+			glTranslatef(-CUBE_LENGTH, STICKER_DEPTH, CUBE_ROUND);
 			glBegin(GL_TRIANGLES);
 			glVertex3f(0.0, 0.0, -OFFSET);
 			glVertex3f(STICKERFULLSHORT, 0.0, -STICKERFULLLONG);
@@ -1139,8 +1139,8 @@ DrawCubit(DinoGLWidget w,
 			if (w->dino.orient) {
 				DrawOrientLine(w, TOP_FACE,
 					w->dino.cubeLoc[TOP_FACE][0].rotation,
-					0.0, CUTDEPTH - STICKERDEPTH,
-					-CUBELEN);
+					0.0, CUT_DEPTH - STICKER_DEPTH,
+					-CUBE_LENGTH);
 			}
 		}
 		glPopMatrix();
@@ -1570,14 +1570,14 @@ static
 #endif
 void
 ExposePuzzleGL(
-#ifdef WINVER 
+#ifdef WINVER
 DinoGLWidget w
 #else
 Widget renew, XEvent *event, Region region
 #endif
 )
 {
-#ifdef WINVER 
+#ifdef WINVER
 	if (hRC == NULL) {
 #if 1
 		BYTE type = PFD_TYPE_RGBA;
