@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1995 - 2007	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1995 - 2007	David A. Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -225,35 +225,35 @@ static const char solveHelp[] = {
 #endif
 
 #define NEVER (-1)
-#define FILENAMELEN 1024
-#define USERNAMELEN 120
-#define MESSAGELEN (USERNAMELEN+64)
-#define TITLELEN 2048
+#define FILE_NAME_LENGTH 1024
+#define USER_NAME_LENGTH 120
+#define MESSAGE_LENGTH (USER_NAME_LENGTH+64)
+#define TITLE_LENGTH 2048
 #define NOACCESS "noaccess"
 #define NOBODY "nobody"
 
 typedef struct {
 	int score;
-	char name[USERNAMELEN];
+	char name[USER_NAME_LENGTH];
 } PuzzleRecord;
 
-static PuzzleRecord puzzleRecord[MAXMODES][2];
+static PuzzleRecord puzzleRecord[MAX_MODES][2];
 static int movesDsp = 0;
-static char messageDsp[MESSAGELEN] = "Welcome";
-static char recordDsp[MESSAGELEN] = "NOT RECORDED";
+static char messageDsp[MESSAGE_LENGTH] = "Welcome";
+static char recordDsp[MESSAGE_LENGTH] = "NOT RECORDED";
 #ifndef HAVE_MOTIF
-static char titleDsp[TITLELEN] = "";
+static char titleDsp[TITLE_LENGTH] = "";
 #endif
-static char scoreFileName[FILENAMELEN] = SCOREFILE;
-static char fileName[FILENAMELEN];
+static char scoreFileName[FILE_NAME_LENGTH] = SCOREFILE;
+static char fileName[FILE_NAME_LENGTH];
 static Boolean randomized = False;
 #ifdef WINVER
-#define MAXPROGNAME 80
-static char progDsp[MAXPROGNAME] = TITLE;
-static char userNameDsp[USERNAMELEN] = "Guest";
+#define PROGRAM_NAME_LENGTH 80
+static char progDsp[PROGRAM_NAME_LENGTH] = TITLE;
+static char userNameDsp[USER_NAME_LENGTH] = "Guest";
 #else
 #ifdef HAVE_MOTIF
-static Widget moves, record, message, modes[MAXMODES];
+static Widget moves, record, message, modes[MAX_MODES];
 static Widget orientizeSwitch, practiceSwitch;
 static char buff[21];
 static const char *modeString[] =
@@ -276,7 +276,7 @@ static Widget topLevel, puzzle2d, puzzle3d;
 static Widget puzzleGL;
 #endif
 static char *progDsp;
-static char userNameDsp[USERNAMELEN] = "";
+static char userNameDsp[USER_NAME_LENGTH] = "";
 
 #ifdef HAVE_MOTIF
 static void
@@ -298,7 +298,7 @@ PrintRecords(void)
 
 	(void) printf("          DINO  HALL OF FAME\n\n");
 	(void) printf("MODE ORIENT USER            MOVES\n");
-	for (mode = 0; mode < MAXMODES; mode++)
+	for (mode = 0; mode < MAX_MODES; mode++)
 		for (orient = 0; orient < 2; orient++) {
 			if (puzzleRecord[mode][orient].score > 0)
 				(void) printf("%4d%7d %-12s%9d\n",
@@ -314,11 +314,11 @@ InitRecords(void)
 {
 	int mode, orient;
 
-	for (mode = 0; mode < MAXMODES; mode++)
+	for (mode = 0; mode < MAX_MODES; mode++)
 		for (orient = 0; orient < 2; orient++) {
 			puzzleRecord[mode][orient].score = NEVER;
 			(void) strncpy(puzzleRecord[mode][orient].name, NOACCESS,
-				USERNAMELEN);
+				USER_NAME_LENGTH);
 		}
 }
 
@@ -327,7 +327,7 @@ ReadRecords(void)
 {
 	FILE *fp;
 	int n, mode, orient;
-	char userName[USERNAMELEN];
+	char userName[USER_NAME_LENGTH];
 	char *buf1 = NULL, *buf2 = NULL;
 	char *fname, *lname;
 
@@ -337,9 +337,9 @@ ReadRecords(void)
 	stringCat(&buf2, buf1, SCOREFILE);
 	free(buf1);
 	fname = buf2;
-	(void) strncpy(fileName, lname, USERNAMELEN);
+	(void) strncpy(fileName, lname, USER_NAME_LENGTH);
 	if ((fp = fopen(fileName, "r")) == NULL) {
-		(void) strncpy(fileName, fname, USERNAMELEN);
+		(void) strncpy(fileName, fname, USER_NAME_LENGTH);
 		/* Try installed directory. */
 		if ((fp = fopen(fileName, "r")) == NULL) {
 			stringCat(&buf1, "Can not read ", fname);
@@ -368,14 +368,14 @@ ReadRecords(void)
 	}
 	free(lname);
 	free(fname);
-	for (mode = 0; mode < MAXMODES; mode++)
+	for (mode = 0; mode < MAX_MODES; mode++)
 		for (orient = 0; orient < 2; orient++) {
 			(void) fscanf(fp, "%d %s\n", &n, userName);
 			if (n <= puzzleRecord[mode][orient].score ||
 					puzzleRecord[mode][orient].score <= NEVER) {
 				puzzleRecord[mode][orient].score = n;
 				(void) strncpy(puzzleRecord[mode][orient].name,
-					userName, USERNAMELEN);
+					userName, USER_NAME_LENGTH);
 			}
 		}
 	(void) fclose(fp);
@@ -397,9 +397,9 @@ WriteRecords(void)
 	{
 #if HAVE_FCNTL_H
 		int lfd;
-		char lockFile[FILENAMELEN];
+		char lockFile[FILE_NAME_LENGTH];
 
-		(void) strncpy(lockFile, fileName, FILENAMELEN - 6);
+		(void) strncpy(lockFile, fileName, FILE_NAME_LENGTH - 6);
 		(void) strcat(lockFile, ".lock");
 		while (((lfd = open(lockFile, O_CREAT | O_EXCL, 0644)) < 0) &&
 				errno == EEXIST)
@@ -415,7 +415,7 @@ WriteRecords(void)
 #endif
 		}
 #endif
-		for (mode = 0; mode < MAXMODES; mode++) {
+		for (mode = 0; mode < MAX_MODES; mode++) {
 			for (orient = 0; orient < 2; orient++)
 				(void) fprintf(fp, "%d %s\n",
 					puzzleRecord[mode][orient].score,
@@ -437,7 +437,7 @@ PrintRecord(int mode, Boolean orient, Boolean practice)
 	int j = (orient) ? 1 : 0;
 
 	if (practice) {
-		(void) strncpy(recordDsp, "practice", MESSAGELEN);
+		(void) strncpy(recordDsp, "practice", MESSAGE_LENGTH);
 	} else if (puzzleRecord[i][j].score <= NEVER) {
 		(void) sprintf(recordDsp, "NEVER %s", NOACCESS);
 	} else {
@@ -459,7 +459,7 @@ MakeEquivalent(String *userName, String *scoreFile, int *mode,
 	Boolean mono, reverse;
 	Boolean scoreOnly, versionOnly;
 	Pixel foreground, background, pieceBorder;
-	String faceColor[MAXFACES];
+	String faceColor[MAX_FACES];
 
 	XtVaGetValues(puzzle2d,
 		XtNuserName, userName,
@@ -485,7 +485,7 @@ MakeEquivalent(String *userName, String *scoreFile, int *mode,
 		exit(0);
 	}
 	if (strcmp(*scoreFile, ""))
-		(void) strncpy(scoreFileName, *scoreFile, FILENAMELEN);
+		(void) strncpy(scoreFileName, *scoreFile, FILE_NAME_LENGTH);
 	if (scoreOnly) {
 		InitRecords();
 		ReadRecords();
@@ -586,12 +586,12 @@ HandleSolved(int counter, int mode, Boolean orient)
 		ReadRecords();	/* Maybe its been updated by another */
 		puzzleRecord[i][j].score = counter;
 		(void) strncpy(puzzleRecord[i][j].name, userNameDsp,
-			USERNAMELEN);
+			USER_NAME_LENGTH);
 		if (orient && (counter < puzzleRecord[!i][j].score ||
 				puzzleRecord[!i][j].score <= NEVER)) {
 			puzzleRecord[!i][j].score = counter;
 			(void) strncpy(puzzleRecord[!i][j].name, userNameDsp,
-				USERNAMELEN);
+				USER_NAME_LENGTH);
 		}
 		WriteRecords();
 		PrintRecord(mode, orient, False);
@@ -625,7 +625,7 @@ void
 	dim = w->dino.dim;
 	SET_STARTED(w, False);
 	if (strcmp(scoreFile, ""))
-		(void) strncpy(scoreFileName, scoreFile, FILENAMELEN);
+		(void) strncpy(scoreFileName, scoreFile, FILE_NAME_LENGTH);
 #else
 	MakeEquivalent(&userName, &scoreFile, &mode, &orient, &practice);
 #ifdef HAVE_MOTIF
@@ -637,13 +637,13 @@ void
 	InitRecords();
 	ReadRecords();
 #ifndef WINVER
-	(void) strncpy(userNameDsp, userName, USERNAMELEN);
+	(void) strncpy(userNameDsp, userName, USER_NAME_LENGTH);
 #endif
 	if (!strcmp(userName, "") || !strcmp(userName, "(null)") ||
 			!strcmp(userName, NOACCESS) ||
 			!strcmp(userName, NOBODY)) {
 #ifdef WINVER
-		(void) strncpy(userNameDsp, userName, USERNAMELEN);
+		(void) strncpy(userNameDsp, userName, USER_NAME_LENGTH);
 #else
 		char *login = getlogin();
 
@@ -798,14 +798,14 @@ CallbackPuzzle(Widget w, caddr_t clientData, dinoCallbackStruct *callData)
 #ifdef HAVE_MOTIF
 		XtManageChild(solveDialog);
 #else
-		(void) strncpy(messageDsp, solveHelp, MESSAGELEN);
+		(void) strncpy(messageDsp, solveHelp, MESSAGE_LENGTH);
 #endif
 #endif
 		break;
 	case ACTION_RESTORE:
 		if (practice) {
 			(void) strncpy(recordDsp, "practice",
-				MESSAGELEN);
+				MESSAGE_LENGTH);
 #ifdef HAVE_MOTIF
 			PrintState(record, recordDsp);
 #endif
@@ -843,15 +843,15 @@ CallbackPuzzle(Widget w, caddr_t clientData, dinoCallbackStruct *callData)
 		break;
 	case ACTION_AMBIGUOUS:
 		(void) strncpy(messageDsp, "Ambiguous move",
-			MESSAGELEN);
+			MESSAGE_LENGTH);
 		break;
 	case ACTION_ILLEGAL:
 		if (practice || randomized)
 			(void) strncpy(messageDsp, "Illegal move",
-				MESSAGELEN);
+				MESSAGE_LENGTH);
 		else
 			(void) strncpy(messageDsp,
-				"Randomize to start", MESSAGELEN);
+				"Randomize to start", MESSAGE_LENGTH);
 		break;
 #ifndef WINVER
 	case ACTION_MOVED:
@@ -898,7 +898,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, dinoCallbackStruct *callData)
 				"Congratulations %s!!", userNameDsp);
 		else
 			(void) strncpy(messageDsp, "Solved!",
-				MESSAGELEN);
+				MESSAGE_LENGTH);
 		SET_STARTED(w, False);
 #ifndef WINVER
 #ifdef HAVE_OPENGL
@@ -923,7 +923,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, dinoCallbackStruct *callData)
 		practice = !practice;
 		if (!practice)
 			(void) strncpy(messageDsp, "Randomize to start",
-				MESSAGELEN);
+				MESSAGE_LENGTH);
 		PrintRecord(mode, orient, practice);
 #ifdef WINVER
 		w->dino.practice = practice;
@@ -976,7 +976,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, dinoCallbackStruct *callData)
 			XtVaGetValues(puzzleGL,
 				XtNview, &view, NULL);
 #endif
-			view = (view + 1) % (2 * MAXVIEWS);
+			view = (view + 1) % (2 * MAX_VIEWS);
 #ifdef WINVER
 			w->dino.view = view;
 #else
@@ -1359,16 +1359,16 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 				(void) ReleaseDC(hWnd, widget.core.hDC);
 			}
 			break;
-		case ACTION_SHIFTCONTROL_TR:
-		case ACTION_SHIFTCONTROL_BR:
-		case ACTION_SHIFTCONTROL_BL:
-		case ACTION_SHIFTCONTROL_TL:
-		case ACTION_SHIFTCONTROL_CW:
-		case ACTION_SHIFTCONTROL_CCW:
-		case ACTION_SHIFTCONTROL_TOP:
-		case ACTION_SHIFTCONTROL_RIGHT:
-		case ACTION_SHIFTCONTROL_BOTTOM:
-		case ACTION_SHIFTCONTROL_LEFT:
+		case ACTION_SHIFT_CONTROL_TR:
+		case ACTION_SHIFT_CONTROL_BR:
+		case ACTION_SHIFT_CONTROL_BL:
+		case ACTION_SHIFT_CONTROL_TL:
+		case ACTION_SHIFT_CONTROL_CW:
+		case ACTION_SHIFT_CONTROL_CCW:
+		case ACTION_SHIFT_CONTROL_TOP:
+		case ACTION_SHIFT_CONTROL_RIGHT:
+		case ACTION_SHIFT_CONTROL_BOTTOM:
+		case ACTION_SHIFT_CONTROL_LEFT:
 			shift = 1;
 		case ACTION_CONTROL_TR:
 		case ACTION_CONTROL_BR:
@@ -1393,22 +1393,22 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 					cursor.x - origin.x,
 					cursor.y - origin.y,
 					(int) LOWORD(wParam) -
-					((shift) ? ACTION_SHIFTCONTROL_TR :
+					((shift) ? ACTION_SHIFT_CONTROL_TR :
 					ACTION_CONTROL_TR),
 					shift, TRUE, FALSE);
 				(void) ReleaseDC(hWnd, widget.core.hDC);
 			}
 			break;
-		case ACTION_CONTROLALT_TR:
-		case ACTION_CONTROLALT_BR:
-		case ACTION_CONTROLALT_BL:
-		case ACTION_CONTROLALT_TL:
-		case ACTION_CONTROLALT_CW:
-		case ACTION_CONTROLALT_CCW:
-		case ACTION_CONTROLALT_TOP:
-		case ACTION_CONTROLALT_RIGHT:
-		case ACTION_CONTROLALT_BOTTOM:
-		case ACTION_CONTROLALT_LEFT:
+		case ACTION_CONTROL_ALT_TR:
+		case ACTION_CONTROL_ALT_BR:
+		case ACTION_CONTROL_ALT_BL:
+		case ACTION_CONTROL_ALT_TL:
+		case ACTION_CONTROL_ALT_CW:
+		case ACTION_CONTROL_ALT_CCW:
+		case ACTION_CONTROL_ALT_TOP:
+		case ACTION_CONTROL_ALT_RIGHT:
+		case ACTION_CONTROL_ALT_BOTTOM:
+		case ACTION_CONTROL_ALT_LEFT:
 			shift = 1;
 		case ACTION_ALT_TR:
 		case ACTION_ALT_BR:
@@ -1433,7 +1433,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 					cursor.x - origin.x,
 					cursor.y - origin.y,
 					(int) LOWORD(wParam) -
-					((shift) ? ACTION_CONTROLALT_TR :
+					((shift) ? ACTION_CONTROL_ALT_TR :
 					ACTION_ALT_TR),
 					FALSE, shift, TRUE);
 				(void) ReleaseDC(hWnd, widget.core.hDC);
@@ -1676,7 +1676,7 @@ PracticeToggle(Widget w, XtPointer clientData,
 	if (practice)
 		(void) strcpy(messageDsp, "");
 	else
-		(void) strncpy(messageDsp, "Randomize to start", MESSAGELEN);
+		(void) strncpy(messageDsp, "Randomize to start", MESSAGE_LENGTH);
 	PrintState(message, messageDsp);
 }
 
@@ -1702,7 +1702,7 @@ static Widget
 createQuery(Widget w, char *text, char *title, XtCallbackProc callback)
 {
 	Widget button, messageBox;
-	char titleDsp[FILENAMELEN + 8];
+	char titleDsp[FILE_NAME_LENGTH + 8];
 	XmString titleString = NULL, messageString = NULL;
 	static XmStringCharSet charSet =
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
@@ -1728,7 +1728,7 @@ static Widget
 createHelp(Widget w, char *text, char *title)
 {
 	Widget button, messageBox;
-	char titleDsp[FILENAMELEN + 8];
+	char titleDsp[FILE_NAME_LENGTH + 8];
 	XmString titleString = NULL, messageString = NULL, buttonString = NULL;
 	static XmStringCharSet charSet =
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
@@ -2008,12 +2008,12 @@ main(int argc, char **argv)
 		XmNpacking, XmPACK_COLUMN, NULL);
 	orientizeSwitch = XtVaCreateManagedWidget("Oriented",
 		xmToggleButtonWidgetClass, switchRowCol,
-		XmNset, DEFAULTORIENT, NULL);
+		XmNset, DEFAULT_ORIENT, NULL);
 	XtAddCallback(orientizeSwitch, XmNvalueChangedCallback,
 		(XtCallbackProc) OrientToggle, (XtPointer) NULL);
 	practiceSwitch = XtVaCreateManagedWidget("Practice",
 		xmToggleButtonWidgetClass, switchRowCol,
-		XmNset, DEFAULTPRACTICE, NULL);
+		XmNset, DEFAULT_PRACTICE, NULL);
 	XtAddCallback(practiceSwitch, XmNvalueChangedCallback,
 		(XtCallbackProc) PracticeToggle, (XtPointer) NULL);
 	messageRowCol = XtVaCreateManagedWidget("messageRowCol",
