@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 2007	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1994 - 2008	David A. Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -241,14 +241,11 @@ static XtResource resourcesPuzzle[] =
 	{XtNbackground, XtCBackground, XtRPixel, sizeof (Pixel),
 	 XtOffset(HexagonsWidget, hexagons.background),
 	 XtRString, (caddr_t) XtDefaultBackground},
-	{XtNframeColor, XtCColor, XtRPixel, sizeof (Pixel),
-	 XtOffset(HexagonsWidget, hexagons.frameColor),
-	 XtRString, (caddr_t) "cyan" /*XtDefaultForeground*/},
 	{XtNtileColor, XtCColor, XtRPixel, sizeof (Pixel),
 	 XtOffset(HexagonsWidget, hexagons.tileColor),
 	 XtRString, (caddr_t) "gray75" /*XtDefaultForeground*/},
-	{XtNtileBorder, XtCColor, XtRPixel, sizeof (Pixel),
-	 XtOffset(HexagonsWidget, hexagons.borderColor),
+	{XtNtextColor, XtCColor, XtRPixel, sizeof (Pixel),
+	 XtOffset(HexagonsWidget, hexagons.textColor),
 	 XtRString, (caddr_t) "gray25" /*XtDefaultBackground*/},
 	{XtNinstall, XtCInstall, XtRBoolean, sizeof (Boolean),
 	 XtOffset(HexagonsWidget, hexagons.install),
@@ -258,7 +255,7 @@ static XtResource resourcesPuzzle[] =
 	 XtRString, (caddr_t) PICTURE},
 	{XtNdelay, XtCDelay, XtRInt, sizeof (int),
 	 XtOffset(HexagonsWidget, hexagons.delay),
-	 XtRString, (caddr_t) "10"}, /* DEFAULTDELAY */
+	 XtRString, (caddr_t) "10"}, /* DEFAULT_DELAY */
 	{XtNsound, XtCSound, XtRBoolean, sizeof (Boolean),
 	 XtOffset(HexagonsWidget, hexagons.sound),
 	 XtRString, (caddr_t) "FALSE"},
@@ -270,16 +267,16 @@ static XtResource resourcesPuzzle[] =
 	 XtRString, (caddr_t) "9x15bold"},
 	{XtNsizeX, XtCSizeX, XtRInt, sizeof (int),
 	 XtOffset(HexagonsWidget, hexagons.sizeX),
-	 XtRString, (caddr_t) "3"}, /* DEFAULTTILESX */
+	 XtRString, (caddr_t) "3"}, /* DEFAULT_TILESX */
 	{XtNsizeY, XtCSizeY, XtRInt, sizeof (int),
 	 XtOffset(HexagonsWidget, hexagons.sizeY),
-	 XtRString, (caddr_t) "3"}, /* DEFAULTTILESY */
+	 XtRString, (caddr_t) "3"}, /* DEFAULT_TILESY */
 	{XtNcorners, XtCCorners, XtRBoolean, sizeof (Boolean),
 	 XtOffset(HexagonsWidget, hexagons.corners),
-	 XtRString, (caddr_t) "TRUE"}, /* DEFAULTCORNERS */
+	 XtRString, (caddr_t) "TRUE"}, /* DEFAULT_CORNERS */
 	{XtNbase, XtCBase, XtRInt, sizeof (int),
 	 XtOffset(HexagonsWidget, hexagons.base),
-	 XtRString, (caddr_t) "10"}, /* DEFAULTBASE */
+	 XtRString, (caddr_t) "10"}, /* DEFAULT_BASE */
 	{XtNuserName, XtCUserName, XtRString, sizeof (String),
 	 XtOffset(HexagonsWidget, hexagons.userName),
 	 XtRString, (caddr_t) ""},
@@ -405,7 +402,7 @@ loadFont(HexagonsWidget w)
 #define LOGFILE "hexagons.log"
 #endif
 
-static Point hexagonUnit[MAXORIENT][7] =
+static Point hexagonUnit[MAX_ORIENT][7] =
 {
 	{
 		{0, 0},
@@ -426,7 +423,7 @@ static Point hexagonUnit[MAXORIENT][7] =
 		{1, -1}
 	}
 };
-static Point hexagonList[MAXORIENT][7];
+static Point hexagonList[MAX_ORIENT][7];
 
 static HexagonsStack undo = {NULL, NULL, NULL, 0};
 static HexagonsStack redo = {NULL, NULL, NULL, 0};
@@ -436,29 +433,29 @@ CheckTiles(HexagonsWidget w)
 {
 	char *buf1 = NULL, *buf2 = NULL;
 
-	if (w->hexagons.sizeX < MINTILES) {
+	if (w->hexagons.sizeX < MIN_TILES) {
 		intCat(&buf1,
 			"Smallest number of hexagons in X direction out of bounds, use at least ",
-			MINTILES);
+			MIN_TILES);
 		stringCat(&buf2, buf1, ", defaulting to ");
 		free(buf1);
-		intCat(&buf1, buf2, DEFAULTTILESX);
+		intCat(&buf1, buf2, DEFAULT_TILESX);
 		free(buf2);
 		DISPLAY_WARNING(buf1);
 		free(buf1);
-		w->hexagons.sizeX = DEFAULTTILESX;
+		w->hexagons.sizeX = DEFAULT_TILESX;
 	}
-	if (w->hexagons.sizeY < MINTILES) {
+	if (w->hexagons.sizeY < MIN_TILES) {
 		intCat(&buf1,
 			"Largest number of hexagons in Y direction out of bounds, use at least ",
-			MINTILES);
+			MIN_TILES);
 		stringCat(&buf2, buf1, ", defaulting to ");
 		free(buf1);
-		intCat(&buf1, buf2, DEFAULTTILESY);
+		intCat(&buf1, buf2, DEFAULT_TILESY);
 		free(buf2);
 		DISPLAY_WARNING(buf1);
 		free(buf1);
-		w->hexagons.sizeY = DEFAULTTILESY;
+		w->hexagons.sizeY = DEFAULT_TILESY;
 	}
 #if 0
 	if (w->hexagons.delay < 0) {
@@ -471,19 +468,19 @@ CheckTiles(HexagonsWidget w)
 		w->hexagons.delay = -w->hexagons.delay;
 	}
 #endif
-	if (w->hexagons.base < MINBASE || w->hexagons.base > MAXBASE) {
-		intCat(&buf1, "Base out of bounds, use ", MINBASE);
+	if (w->hexagons.base < MIN_BASE || w->hexagons.base > MAX_BASE) {
+		intCat(&buf1, "Base out of bounds, use ", MIN_BASE);
 		stringCat(&buf2, buf1, "..");
 		free(buf1);
-		intCat(&buf1, buf2, MAXBASE);
+		intCat(&buf1, buf2, MAX_BASE);
 		free(buf2);
 		stringCat(&buf2, buf1, ", defaulting to ");
 		free(buf1);
-		intCat(&buf1, buf2, DEFAULTBASE);
+		intCat(&buf1, buf2, DEFAULT_BASE);
 		free(buf2);
 		DISPLAY_WARNING(buf1);
 		free(buf1);
-		w->hexagons.base = DEFAULTBASE;
+		w->hexagons.base = DEFAULT_BASE;
 	}
 }
 
@@ -883,16 +880,16 @@ DrawTile(HexagonsWidget w, int pos, Boolean blank, Boolean erase,
 	Pixmap adr = 0;
 	int dx, dy, row;
 	int corners = (w->hexagons.corners) ? 1 : 0;
-	GC tileGC, borderGC;
+	GC tileGC, textGC;
 
 	/*dr = &(w->hexagons.bufferTiles[pressedOffset]);*/
 	dr = &adr;
 	if (erase) {
-		tileGC = w->hexagons.inverseGC;
-		borderGC = w->hexagons.inverseGC;
+		tileGC = w->hexagons.inverseGC[2];
+		textGC = w->hexagons.inverseGC[2];
 	} else {
-		tileGC = w->hexagons.tileGC;
-		borderGC = w->hexagons.borderGC;
+		tileGC = w->hexagons.tileGC[1];
+		textGC = w->hexagons.textGC;
 	}
 
 	row = Row(w, pos);
@@ -907,16 +904,16 @@ DrawTile(HexagonsWidget w, int pos, Boolean blank, Boolean erase,
 			(w->hexagons.tileSize.y + w->hexagons.delta.y) / 4;
 	}
 	if (blank) {
-		POLYGON(w, *dr, tileGC, borderGC,
+		POLYGON(w, *dr, tileGC, textGC,
 			hexagonList[corners], 6, True, False);
 	} else {
 		if (pressedOffset != 0) {
-			drawShadow(w, *dr, w->hexagons.tileDarkerGC,
+			drawShadow(w, *dr, w->hexagons.tileGC[2],
 				-pressedOffset, -pressedOffset,
 				hexagonList[corners], w->hexagons.corners);
 		}
-		fill3DHexagon(w, *dr, tileGC, w->hexagons.tileDarkerGC,
-			w->hexagons.tileBrighterGC,
+		fill3DHexagon(w, *dr, tileGC, w->hexagons.tileGC[2],
+			w->hexagons.tileGC[0],
 			hexagonList[corners],
 			pressedOffset == 0, w->hexagons.corners);
 	}
@@ -931,7 +928,7 @@ DrawTile(HexagonsWidget w, int pos, Boolean blank, Boolean erase,
 			digitOffsetX += w->hexagons.digitOffset.x;
 			i++;
 		}
-		DRAWTEXT(w, *dr, borderGC,
+		DRAWTEXT(w, *dr, textGC,
 			dx - digitOffsetX,
 			dy + w->hexagons.tileSize.y + w->hexagons.digitOffset.y,
 			buf, i);
@@ -1172,7 +1169,7 @@ MovableNoCornTile(HexagonsWidget w)
 
 	/* Are the spaces in a "row" with the mouse click?
 	 * (If two, then one clicked on a space). */
-	for (l = 0; l < ROWTYPES; l++) {
+	for (l = 0; l < ROW_TYPES; l++) {
 		if (w->hexagons.currentRow[l] == w->hexagons.spaceRow[l]) {
 			if (rowType == BLOCKED) {
 				rowType = l;
@@ -1418,7 +1415,7 @@ ResetTiles(HexagonsWidget w)
 static void
 EraseFrame(HexagonsWidget w, Pixmap dr)
 {
-	FILLRECTANGLE(w, dr, w->hexagons.inverseGC,
+	FILLRECTANGLE(w, dr, w->hexagons.inverseGC[2],
 		0, 0, w->core.width, w->core.height);
 }
 
@@ -1426,8 +1423,9 @@ static void
 DrawFrame(HexagonsWidget w, Pixmap dr, Boolean all, Boolean focus)
 {
 	int sumX, sumY, sumX4, sum3X4, sumY2, offsetX, offsetY;
-	Point tempList[8];
-	GC gc = (focus) ? w->hexagons.frameGC : w->hexagons.borderGC;
+	Point tempList[7];
+	GC gc = (focus) ? w->hexagons.inverseGC[1] :
+		w->hexagons.inverseGC[3];
 
 	sumX = (w->hexagons.sizeX + w->hexagons.sizeY) * w->hexagons.offset.x -
 		w->hexagons.tileSize.x / 2 - 2 * w->hexagons.delta.x - 1;
@@ -1444,19 +1442,19 @@ DrawFrame(HexagonsWidget w, Pixmap dr, Boolean all, Boolean focus)
 	offsetX += -1 - w->hexagons.sizeX / 2;
 	if (all) {
 		if (offsetY > 0) {
-			FILLRECTANGLE(w, dr, w->hexagons.borderGC,
+			FILLRECTANGLE(w, dr, w->hexagons.textGC,
 				0, 0, w->core.width, offsetY);
 		}
 		if (sumY < w->core.height) {
-			FILLRECTANGLE(w, dr, w->hexagons.borderGC,
+			FILLRECTANGLE(w, dr, w->hexagons.textGC,
 				0, sumY + 1, w->core.width, w->core.height - sumY);
 		}
 		if (offsetX > 0) {
-			FILLRECTANGLE(w, dr, w->hexagons.borderGC,
+			FILLRECTANGLE(w, dr, w->hexagons.textGC,
 				0, 0, offsetX, w->core.height);
 		}
 		if (sumX < w->core.width) {
-			FILLRECTANGLE(w, dr, w->hexagons.borderGC,
+			FILLRECTANGLE(w, dr, w->hexagons.textGC,
 				sumX + 1, 0, w->core.width - sumX - 1, w->core.height);
 		}
 		tempList[0].x = offsetX;
@@ -1467,7 +1465,7 @@ DrawFrame(HexagonsWidget w, Pixmap dr, Boolean all, Boolean focus)
 		tempList[2].y = sumY2;
 		tempList[3].x = tempList[0].x;
 		tempList[3].y = tempList[0].y;
-		POLYGON(w, dr, w->hexagons.borderGC, w->hexagons.borderGC,
+		POLYGON(w, dr, w->hexagons.textGC, w->hexagons.textGC,
 			tempList, 3, True, True);
 		tempList[0].x = sumX + 1;
 		tempList[0].y = offsetY;
@@ -1479,7 +1477,7 @@ DrawFrame(HexagonsWidget w, Pixmap dr, Boolean all, Boolean focus)
 		tempList[3].y = offsetY;
 		tempList[4].x = tempList[0].x;
 		tempList[4].y = tempList[0].y;
-		POLYGON(w, dr, w->hexagons.borderGC, w->hexagons.borderGC,
+		POLYGON(w, dr, w->hexagons.textGC, w->hexagons.textGC,
 			tempList, 4, True, True);
 		tempList[0].x = offsetX;
 		tempList[0].y = sumY + 1;
@@ -1491,7 +1489,7 @@ DrawFrame(HexagonsWidget w, Pixmap dr, Boolean all, Boolean focus)
 		tempList[3].y = sumY + 1;
 		tempList[4].x = tempList[0].x;
 		tempList[4].y = tempList[0].y;
-		POLYGON(w, dr, w->hexagons.borderGC, w->hexagons.borderGC,
+		POLYGON(w, dr, w->hexagons.textGC, w->hexagons.textGC,
 			tempList, 4, True, True);
 		tempList[0].x = sumX + 1;
 		tempList[0].y = sumY + 1;
@@ -1505,30 +1503,86 @@ DrawFrame(HexagonsWidget w, Pixmap dr, Boolean all, Boolean focus)
 		tempList[4].y = sumY2;
 		tempList[5].x = tempList[0].x;
 		tempList[5].y = tempList[0].y;
-		POLYGON(w, dr, w->hexagons.borderGC, w->hexagons.borderGC,
+		POLYGON(w, dr, w->hexagons.textGC, w->hexagons.textGC,
 			tempList, 5, True, True);
 	}
-	tempList[0].x = sumX4;
-	tempList[0].y = offsetY;
-	tempList[1].x = sum3X4;
-	tempList[1].y = offsetY;
-	tempList[2].x = sumX;
-	tempList[2].y = sumY2;
-	tempList[3].x = sum3X4;
-	tempList[3].y = sumY;
-	tempList[4].x = sumX4;
-	tempList[4].y = sumY;
-	tempList[5].x = offsetX;
-	tempList[5].y = sumY2;
-	tempList[6].x = sumX4;
-	tempList[6].y = offsetY;
-	tempList[7].x = tempList[0].x;
-	tempList[7].y = tempList[0].y;
 	if (all) {
-		POLYGON(w, dr, w->hexagons.inverseGC, gc,
+		tempList[0].x = sumX4;
+		tempList[0].y = offsetY;
+		tempList[1].x = sum3X4;
+		tempList[1].y = offsetY;
+		tempList[2].x = sumX;
+		tempList[2].y = sumY2;
+		tempList[3].x = sum3X4;
+		tempList[3].y = sumY;
+		tempList[4].x = sumX4;
+		tempList[4].y = sumY;
+		tempList[5].x = offsetX;
+		tempList[5].y = sumY2;
+		tempList[6].x = sumX4;
+		tempList[6].y = offsetY;
+		POLYGON(w, dr, w->hexagons.inverseGC[2], gc,
 			tempList, 6, True, True);
 	} else {
-		POLYLINE(w, dr, gc, tempList, 7, True);
+		GC brighterGC = (focus) ? w->hexagons.inverseGC[1] :
+			w->hexagons.inverseGC[2];
+		GC darkerGC = (focus) ? w->hexagons.inverseGC[3] :
+			w->hexagons.inverseGC[2];
+
+		tempList[0].x = sum3X4;
+		tempList[0].y = offsetY;
+		tempList[1].x = sumX;
+		tempList[1].y = sumY2;
+		tempList[2].x = sum3X4;
+		tempList[2].y = sumY;
+		tempList[3].x = sumX4;
+		tempList[3].y = sumY;
+		POLYLINE(w, dr, brighterGC, tempList, 4, True);
+		tempList[0].x = sumX4;
+		tempList[0].y = sumY;
+		tempList[1].x = offsetX;
+		tempList[1].y = sumY2;
+		tempList[2].x = sumX4;
+		tempList[2].y = offsetY;
+		tempList[3].x = sum3X4;
+		tempList[3].y = offsetY;
+		POLYLINE(w, dr, darkerGC, tempList, 4, True);
+		tempList[0].x = sum3X4 - 1;
+		tempList[0].y = offsetY;
+		tempList[1].x = sumX - 1;
+		tempList[1].y = sumY2;
+		tempList[2].x = sum3X4 - 1;
+		tempList[2].y = sumY;
+		tempList[3].x = sumX4 + 1;
+		tempList[3].y = sumY;
+		POLYLINE(w, dr, brighterGC, tempList, 4, True);
+		tempList[0].x = sumX4 + 1;
+		tempList[0].y = sumY;
+		tempList[1].x = offsetX + 1;
+		tempList[1].y = sumY2;
+		tempList[2].x = sumX4 + 1;
+		tempList[2].y = offsetY;
+		tempList[3].x = sum3X4 - 1;
+		tempList[3].y = offsetY;
+		POLYLINE(w, dr, darkerGC, tempList, 4, True);
+		tempList[0].x = sum3X4;
+		tempList[0].y = offsetY - 1;
+		tempList[1].x = sumX + 1;
+		tempList[1].y = sumY2;
+		tempList[2].x = sum3X4;
+		tempList[2].y = sumY + 1;
+		tempList[3].x = sumX4;
+		tempList[3].y = sumY + 1;
+		POLYLINE(w, dr, brighterGC, tempList, 4, True);
+		tempList[0].x = sumX4;
+		tempList[0].y = sumY + 1;
+		tempList[1].x = offsetX - 1;
+		tempList[1].y = sumY2;
+		tempList[2].x = sumX4;
+		tempList[2].y = offsetY - 1;
+		tempList[3].x = sum3X4;
+		tempList[3].y = offsetY - 1;
+		POLYLINE(w, dr, darkerGC, tempList, 4, True);
 	}
 }
 
@@ -1877,7 +1931,7 @@ MovePuzzle(HexagonsWidget w, const int direction, const int control)
 		case TL:
 		case TOP:
 		case TR:
-			if (w->hexagons.sizeY <= MINTILES +
+			if (w->hexagons.sizeY <= MIN_TILES +
 					w->hexagons.corners)
 				return FALSE;
 			reason = ACTION_DECY;
@@ -1891,7 +1945,7 @@ MovePuzzle(HexagonsWidget w, const int direction, const int control)
 			reason = ACTION_INCY;
 			break;
 		case LEFT:
-			if (w->hexagons.sizeX <= MINTILES)
+			if (w->hexagons.sizeX <= MIN_TILES)
 				return FALSE;
 			reason = ACTION_DECX;
 			break;
@@ -2270,7 +2324,7 @@ GetTiles(HexagonsWidget w)
 	}
 	while ((c = getc(fp)) != EOF && c != SYMBOL);
 	(void) fscanf(fp, "%d", &sizeX);
-	if (sizeX >= MINTILES) {
+	if (sizeX >= MIN_TILES) {
 		for (i = w->hexagons.sizeX; i < sizeX; i++) {
 			setPuzzle(w, ACTION_INCX);
 		}
@@ -2283,7 +2337,7 @@ GetTiles(HexagonsWidget w)
 		free(buf1);
 		stringCat(&buf1, buf2, " should be between ");
 		free(buf2);
-		intCat(&buf2, buf1, MINTILES);
+		intCat(&buf2, buf1, MIN_TILES);
 		free(buf1);
 		stringCat(&buf1, buf2, " and MAXINT");
 		free(buf2);
@@ -2293,7 +2347,7 @@ GetTiles(HexagonsWidget w)
 
 	while ((c = getc(fp)) != EOF && c != SYMBOL);
 	(void) fscanf(fp, "%d", &sizeY);
-	if (sizeY >= MINTILES) {
+	if (sizeY >= MIN_TILES) {
 		for (i = w->hexagons.sizeY; i < sizeY; i++) {
 			setPuzzle(w, ACTION_INCY);
 		}
@@ -2306,7 +2360,7 @@ GetTiles(HexagonsWidget w)
 		free(buf1);
 		stringCat(&buf1, buf2, " should be between ");
 		free(buf2);
-		intCat(&buf2, buf1, MINTILES);
+		intCat(&buf2, buf1, MIN_TILES);
 		free(buf1);
 		stringCat(&buf1, buf2, " and MAXINT");
 		free(buf2);
@@ -2487,25 +2541,26 @@ SoundTiles(HexagonsWidget w)
 	w->hexagons.sound = !w->hexagons.sound;
 }
 
-#define FACTOR 0.7
+#define BRIGHT_FACTOR 0.8
+#define DARK_FACTOR 0.75
 
 #ifdef WINVER
-#define MAXINTENSITY 0xFF
+#define MAX_INTENSITY 0xFF
 static int
 brighter(const int light)
 {
-	int i = (int) ((1 - FACTOR) * MAXINTENSITY);
+	int i = (int) ((1 - BRIGHT_FACTOR) * MAX_INTENSITY);
 	int temp = light;
 
 	if (temp < i)
 		temp = i;
-	return MIN(temp / FACTOR, MAXINTENSITY);
+	return MIN(temp / BRIGHT_FACTOR, MAX_INTENSITY);
 }
 
 static int
 darker(const int light)
 {
- return (int) (light * FACTOR);
+ return (int) (light * DARK_FACTOR);
 }
 
 static void
@@ -2517,45 +2572,48 @@ SetValuesPuzzle(HexagonsWidget w)
 	char szBuf[80];
 
 	w->hexagons.sizeX = GetPrivateProfileInt(SECTION, "sizeX",
-		DEFAULTTILESX, INIFILE);
+		DEFAULT_TILESX, INIFILE);
 	w->hexagons.sizeY = GetPrivateProfileInt(SECTION, "sizeY",
-		DEFAULTTILESY, INIFILE);
+		DEFAULT_TILESY, INIFILE);
 	w->hexagons.base = GetPrivateProfileInt(SECTION, "base",
-		DEFAULTBASE, INIFILE);
+		DEFAULT_BASE, INIFILE);
 	w->hexagons.corners = (BOOL) GetPrivateProfileInt(SECTION, "corners",
-		DEFAULTCORNERS, INIFILE);
+		DEFAULT_CORNERS, INIFILE);
 	w->hexagons.mono = (BOOL) GetPrivateProfileInt(SECTION, "mono",
-		DEFAULTMONO, INIFILE);
+		DEFAULT_MONO, INIFILE);
 	w->hexagons.reverse = (BOOL) GetPrivateProfileInt(SECTION,
-		"reverseVideo", DEFAULTREVERSE, INIFILE);
-	/* cyan */
-	(void) GetPrivateProfileString(SECTION, "frameColor", "0 255 255",
-		szBuf, sizeof (szBuf), INIFILE);
-	(void) sscanf(szBuf, "%d %d %d",
-		&(color.red), &(color.green), &(color.blue));
-	w->hexagons.frameGC = RGB(color.red, color.green, color.blue);
+		"reverseVideo", DEFAULT_REVERSE, INIFILE);
 	/* gray75 */
 	(void) GetPrivateProfileString(SECTION, "tileColor", "191 191 191",
 		szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
-	w->hexagons.tileGC = RGB(color.red, color.green, color.blue);
-	w->hexagons.tileBrighterGC = RGB(brighter(color.red),
-		brighter(color.green), brighter(color.blue));
-	w->hexagons.tileDarkerGC = RGB(darker(color.red),
-		darker(color.green), darker(color.blue));
+	w->hexagons.tileGC[1] = RGB(color.red, color.green, color.blue);
+        w->hexagons.tileGC[0] = RGB(brighter(color.red),
+	       brighter(color.green), brighter(color.blue));
+        w->hexagons.tileGC[2] = RGB(darker(color.red),
+	       darker(color.green), darker(color.blue));
 	/* gray25 */
-	(void) GetPrivateProfileString(SECTION, "tileBorder", "64 64 64",
+	(void) GetPrivateProfileString(SECTION, "textColor", "64 64 64",
 		szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
-	w->hexagons.borderGC = RGB(color.red, color.green, color.blue);
+	w->hexagons.textGC = RGB(color.red, color.green, color.blue);
 	/* #AEB2C3 */
 	(void) GetPrivateProfileString(SECTION, "background", "174 178 195",
 		szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
-	w->hexagons.inverseGC = RGB(color.red, color.green, color.blue);
+	w->hexagons.inverseGC[1] = RGB(color.red, color.green, color.blue);
+        w->hexagons.inverseGC[0] = RGB(brighter(color.red),
+	       brighter(color.green), brighter(color.blue));
+        w->hexagons.inverseGC[2] = RGB(darker(color.red),
+	       darker(color.green), darker(color.blue));
+        w->hexagons.inverseGC[3] = RGB(darker(darker(color.red)),
+	       darker(darker(color.green)), darker(darker(color.blue)));
+        w->hexagons.inverseGC[4] = RGB(darker(darker(darker(color.red))),
+	       darker(darker(darker(color.green))),
+	       darker(darker(darker(color.blue))));
 	(void) GetPrivateProfileString(SECTION, "userName", "Guest",
 		szBuf, sizeof (szBuf), INIFILE);
 	(void) strcpy(w->hexagons.userName, szBuf);
@@ -2583,28 +2641,27 @@ DestroyPuzzle(HexagonsWidget w, HBRUSH brush)
 }
 
 #else
-#define MAXINTENSITY 0xFFFF
+#define MAX_INTENSITY 0xFFFF
 
 static Pixel
 brighter(HexagonsWidget w, Pixel pixel)
 {
 	XColor color;
-	int i = (int) ((1 - FACTOR) * MAXINTENSITY);
+	Colormap colormap = DefaultColormapOfScreen(XtScreen(w));
+	int i = (int) ((1 - BRIGHT_FACTOR) * MAX_INTENSITY);
 
 	color.pixel = pixel;
-	XQueryColor(XtDisplay(w), DefaultColormapOfScreen(XtScreen(w)),
-		&color);
+	VOID XQueryColor(XtDisplay(w), colormap, &color);
 	if (color.red < i)
 		color.red = i;
 	if (color.green < i)
 		color.green = i;
 	if (color.blue < i)
 		color.blue = i;
-	color.red = (unsigned short) MIN(color.red / FACTOR, MAXINTENSITY);
-	color.green = (unsigned short) MIN(color.green / FACTOR, MAXINTENSITY);
-	color.blue = (unsigned short) MIN(color.blue / FACTOR, MAXINTENSITY);
-	if (XAllocColor(XtDisplay(w), DefaultColormapOfScreen(XtScreen(w)),
-			&color))
+	color.red = (unsigned short) MIN(color.red / BRIGHT_FACTOR, MAX_INTENSITY);
+	color.green = (unsigned short) MIN(color.green / BRIGHT_FACTOR, MAX_INTENSITY);
+	color.blue = (unsigned short) MIN(color.blue / BRIGHT_FACTOR, MAX_INTENSITY);
+	if (XAllocColor(XtDisplay(w), colormap, &color))
 		return color.pixel;
 	return pixel;
 }
@@ -2613,15 +2670,14 @@ static Pixel
 darker(HexagonsWidget w, Pixel pixel)
 {
 	XColor color;
+	Colormap colormap = DefaultColormapOfScreen(XtScreen(w));
 
 	color.pixel = pixel;
-	XQueryColor(XtDisplay(w), DefaultColormapOfScreen(XtScreen(w)),
-		&color);
-	color.red = (unsigned short) (color.red * FACTOR);
-	color.green = (unsigned short) (color.green * FACTOR);
-	color.blue = (unsigned short) (color.blue * FACTOR);
-	if (XAllocColor(XtDisplay(w), DefaultColormapOfScreen(XtScreen(w)),
-			&color))
+	VOID XQueryColor(XtDisplay(w), colormap, &color);
+	color.red = (unsigned short) (color.red * DARK_FACTOR);
+	color.green = (unsigned short) (color.green * DARK_FACTOR);
+	color.blue = (unsigned short) (color.blue * DARK_FACTOR);
+	if (XAllocColor(XtDisplay(w), colormap, &color))
 		return color.pixel;
 	return pixel;
 }
@@ -2640,24 +2696,38 @@ SetAllColors(HexagonsWidget w)
 		values.foreground = w->hexagons.background;
 		values.background = w->hexagons.foreground;
 	}
-	if (w->hexagons.inverseGC)
-		XtReleaseGC((Widget) w, w->hexagons.inverseGC);
-	w->hexagons.inverseGC = XtGetGC((Widget) w, valueMask, &values);
-	if (w->hexagons.mono) {
-		if (w->hexagons.reverse) {
-			values.foreground = w->hexagons.background;
-			values.background = w->hexagons.foreground;
-		} else {
-			values.foreground = w->hexagons.foreground;
-			values.background = w->hexagons.background;
-		}
-	} else {
-		values.foreground = w->hexagons.frameColor;
-		values.background = w->hexagons.borderColor;
-	}
-	if (w->hexagons.frameGC)
-		XtReleaseGC((Widget) w, w->hexagons.frameGC);
-	w->hexagons.frameGC = XtGetGC((Widget) w, valueMask, &values);
+	if (w->hexagons.inverseGC[1])
+	       XtReleaseGC((Widget) w, w->hexagons.inverseGC[1]);
+        w->hexagons.inverseGC[1] = XtGetGC((Widget) w, valueMask, &values);
+        if (!w->hexagons.mono) {
+	       values.foreground = brighter(w, (w->hexagons.reverse) ?
+		      w->hexagons.foreground : w->hexagons.background);
+        }
+        if (w->hexagons.inverseGC[0])
+	       XtReleaseGC((Widget) w, w->hexagons.inverseGC[0]);
+        w->hexagons.inverseGC[0] = XtGetGC((Widget) w, valueMask, &values);
+        if (!w->hexagons.mono) {
+	       values.foreground = darker(w, (w->hexagons.reverse) ?
+		      w->hexagons.foreground : w->hexagons.background);
+        }
+        if (w->hexagons.inverseGC[2])
+	       XtReleaseGC((Widget) w, w->hexagons.inverseGC[2]);
+        w->hexagons.inverseGC[2] = XtGetGC((Widget) w, valueMask, &values);
+        if (!w->hexagons.mono) {
+	       values.foreground = darker(w, darker(w, (w->hexagons.reverse) ?
+		      w->hexagons.foreground : w->hexagons.background));
+        }
+        if (w->hexagons.inverseGC[3])
+	       XtReleaseGC((Widget) w, w->hexagons.inverseGC[3]);
+        w->hexagons.inverseGC[3] = XtGetGC((Widget) w, valueMask, &values);
+        if (!w->hexagons.mono) {
+	       values.foreground = darker(w, darker(w, darker(w,
+		      (w->hexagons.reverse) ?  w->hexagons.foreground :
+		      w->hexagons.background)));
+        }
+        if (w->hexagons.inverseGC[4])
+	       XtReleaseGC((Widget) w, w->hexagons.inverseGC[4]);
+        w->hexagons.inverseGC[4] = XtGetGC((Widget) w, valueMask, &values);
 	if (w->hexagons.mono) {
 		if (w->hexagons.reverse) {
 			values.foreground = w->hexagons.background;
@@ -2668,23 +2738,23 @@ SetAllColors(HexagonsWidget w)
 		}
 	} else {
 		values.foreground = w->hexagons.tileColor;
-		values.background = w->hexagons.borderColor;
+		values.background = w->hexagons.textColor;
 	}
-	if (w->hexagons.tileGC)
-		XtReleaseGC((Widget) w, w->hexagons.tileGC);
-	w->hexagons.tileGC = XtGetGC((Widget) w, valueMask, &values);
-	if (!w->hexagons.mono) {
-		values.foreground = brighter(w, w->hexagons.tileColor);
-	}
-	if (w->hexagons.tileBrighterGC)
-		XtReleaseGC((Widget) w, w->hexagons.tileBrighterGC);
-		w->hexagons.tileBrighterGC = XtGetGC((Widget) w, valueMask, &values);
-		if (!w->hexagons.mono) {
-			values.foreground = darker(w, w->hexagons.tileColor);
-		}
-	if (w->hexagons.tileDarkerGC)
-		XtReleaseGC((Widget) w, w->hexagons.tileDarkerGC);
-	w->hexagons.tileDarkerGC = XtGetGC((Widget) w, valueMask, &values);
+	if (w->hexagons.tileGC[1])
+	       XtReleaseGC((Widget) w, w->hexagons.tileGC[1]);
+        w->hexagons.tileGC[1] = XtGetGC((Widget) w, valueMask, &values);
+        if (!w->hexagons.mono) {
+	       values.foreground = brighter(w, w->hexagons.tileColor);
+        }
+        if (w->hexagons.tileGC[0])
+	       XtReleaseGC((Widget) w, w->hexagons.tileGC[0]);
+        w->hexagons.tileGC[0] = XtGetGC((Widget) w, valueMask, &values);
+        if (!w->hexagons.mono) {
+	       values.foreground = darker(w, w->hexagons.tileColor);
+        }
+        if (w->hexagons.tileGC[2])
+	       XtReleaseGC((Widget) w, w->hexagons.tileGC[2]);
+        w->hexagons.tileGC[2] = XtGetGC((Widget) w, valueMask, &values);
 	if (w->hexagons.mono) {
 		if (w->hexagons.reverse) {
 			values.foreground = w->hexagons.foreground;
@@ -2694,14 +2764,14 @@ SetAllColors(HexagonsWidget w)
 			values.background = w->hexagons.foreground;
 		}
 	} else {
-		values.foreground = w->hexagons.borderColor;
+		values.foreground = w->hexagons.textColor;
 		values.background = w->hexagons.tileColor;
 	}
-	if (w->hexagons.borderGC)
-		XtReleaseGC((Widget) w, w->hexagons.borderGC);
-	w->hexagons.borderGC = XtGetGC((Widget) w, valueMask, &values);
+	if (w->hexagons.textGC)
+		XtReleaseGC((Widget) w, w->hexagons.textGC);
+	w->hexagons.textGC = XtGetGC((Widget) w, valueMask, &values);
 	if (w->hexagons.fontInfo)
-		XSetFont(XtDisplay(w), w->hexagons.borderGC,
+		XSetFont(XtDisplay(w), w->hexagons.textGC,
 			w->hexagons.fontInfo->fid);
 }
 
@@ -2714,7 +2784,7 @@ SetValuesPuzzle(Widget current, Widget request, Widget renew)
 
 	CheckTiles(w);
 	if (w->hexagons.font != c->hexagons.font ||
-			w->hexagons.borderColor != c->hexagons.borderColor ||
+			w->hexagons.textColor != c->hexagons.textColor ||
 			w->hexagons.reverse != c->hexagons.reverse ||
 			w->hexagons.mono != c->hexagons.mono) {
 		loadFont(w);
@@ -2792,22 +2862,21 @@ DestroyPuzzle(Widget old)
 {
 	HexagonsWidget w = (HexagonsWidget) old;
 	Display *display = XtDisplay(w);
-	int sel;
+	int i;
 
-	XtReleaseGC(old, w->hexagons.tileGC);
-	XtReleaseGC(old, w->hexagons.borderGC);
-	XtReleaseGC(old, w->hexagons.tileBrighterGC);
-	XtReleaseGC(old, w->hexagons.tileDarkerGC);
-	XtReleaseGC(old, w->hexagons.frameGC);
-	XtReleaseGC(old, w->hexagons.inverseGC);
+	XtReleaseGC(old, w->hexagons.textGC);
+	for (i = 0; i < FG_SHADES; i++)
+	       XtReleaseGC(old, w->hexagons.tileGC[i]);
+        for (i = 0; i < BG_SHADES; i++)
+	       XtReleaseGC(old, w->hexagons.inverseGC[i]);
 	XtRemoveCallbacks(old, XtNselectCallback, w->hexagons.select);
 	if (w->hexagons.colormap != None) {
 		XInstallColormap(display, w->hexagons.oldColormap);
 		XFreeColormap(display, w->hexagons.colormap);
 	}
-	for (sel = 0; sel < 2; sel++)
-		if (w->hexagons.bufferTiles[sel] != None)
-			XFreePixmap(display, w->hexagons.bufferTiles[sel]);
+	for (i = 0; i < 2; i++)
+		if (w->hexagons.bufferTiles[i] != None)
+			XFreePixmap(display, w->hexagons.bufferTiles[i]);
 	if (w->hexagons.fontInfo) {
 		XUnloadFont(display, w->hexagons.fontInfo->fid);
 		XFreeFont(display, w->hexagons.fontInfo);
@@ -2828,7 +2897,6 @@ static void
 ResizeTiles(HexagonsWidget w)
 {
 	int i;
-	int sel;
 
 #ifdef WINVER
 	if (w->core.memDC == NULL) {
@@ -2837,13 +2905,13 @@ ResizeTiles(HexagonsWidget w)
 			DISPLAY_ERROR("Not enough memory, exiting.");
 		}
 	}
-	for (sel = 0; sel < 2; sel++) {
-		if (w->hexagons.bufferTiles[sel] != NULL) {
-			DeleteObject(w->hexagons.bufferTiles[sel]);
-				w->hexagons.bufferTiles[sel] = NULL;
+	for (i = 0; i < 2; i++) {
+		if (w->hexagons.bufferTiles[i] != NULL) {
+			DeleteObject(w->hexagons.bufferTiles[i]);
+				w->hexagons.bufferTiles[i] = NULL;
 		}
 		if (!(w->hexagons.picture && *(w->hexagons.picture))) {
-			if ((w->hexagons.bufferTiles[sel] =
+			if ((w->hexagons.bufferTiles[i] =
 					CreateCompatibleBitmap(w->core.hDC,
 					w->core.width,
 					w->core.height)) == NULL) {
@@ -2861,12 +2929,12 @@ ResizeTiles(HexagonsWidget w)
 		w->hexagons.mono = (xgwa.depth < 2 || w->hexagons.mono);
 		w->hexagons.oldColormap = xgwa.colormap;
 	}
-	for (sel = 0; sel < 2; sel++) {
-		if (w->hexagons.bufferTiles[sel] != None) {
-			XFreePixmap(display, w->hexagons.bufferTiles[sel]);
-			w->hexagons.bufferTiles[sel] = None;
+	for (i = 0; i < 2; i++) {
+		if (w->hexagons.bufferTiles[i] != None) {
+			XFreePixmap(display, w->hexagons.bufferTiles[i]);
+			w->hexagons.bufferTiles[i] = None;
 		}
-		if ((w->hexagons.bufferTiles[sel] = XCreatePixmap(display,
+		if ((w->hexagons.bufferTiles[i] = XCreatePixmap(display,
 			window, w->core.width, w->core.height,
 			xgwa.depth)) == None) {
 			DISPLAY_ERROR("Not enough memory, exiting.");
@@ -2875,8 +2943,8 @@ ResizeTiles(HexagonsWidget w)
 #endif
 	if (w->hexagons.picture && *(w->hexagons.picture)) {
 #ifdef WINVER
-		for (sel = 0; sel < 2; sel++) {
-			w->hexagons.bufferTiles[sel] =
+		for (i = 0; i < 2; i++) {
+			w->hexagons.bufferTiles[i] =
 				LoadBitmap(w->core.hInstance,
 				w->hexagons.picture);
 		}
@@ -2904,14 +2972,14 @@ ResizeTiles(HexagonsWidget w)
 			xgwa.visual, AllocNone);
 	}
 	SetAllColors(w);
-	for (sel = 0; sel < 2; sel++) {
-		FILLRECTANGLE(w, w->hexagons.bufferTiles[sel],
-			w->hexagons.inverseGC,
+	for (i = 0; i < 2; i++) {
+		FILLRECTANGLE(w, w->hexagons.bufferTiles[i],
+			w->hexagons.inverseGC[2],
 			0, 0, w->core.width, w->core.height);
 		if ((w->hexagons.picture && *(w->hexagons.picture))) {
 
-			(void) XPutImage(display, w->hexagons.bufferTiles[sel],
-				w->hexagons.inverseGC, w->hexagons.image, 0, 0,
+			(void) XPutImage(display, w->hexagons.bufferTiles[i],
+				w->hexagons.inverseGC[2], w->hexagons.image, 0, 0,
 				0, 0,
 				MIN(w->hexagons.image->width, w->core.width),
 				MIN(w->hexagons.image->height, w->core.height));
@@ -3009,29 +3077,26 @@ Widget request, Widget renew
 {
 #ifdef WINVER
 	SetValuesPuzzle(w);
-	brush = CreateSolidBrush(w->hexagons.inverseGC);
+	brush = CreateSolidBrush(w->hexagons.inverseGC[2]);
 	SETBACK(w->core.hWnd, brush);
 	(void) SRAND(time(NULL));
 	w->hexagons.bufferTiles[0] = NULL;
 	w->hexagons.bufferTiles[1] = NULL;
 #else
 	HexagonsWidget w = (HexagonsWidget) renew;
+	int i;
 
-#ifdef DEBUG
-XSynchronize(XtDisplay(w), True);
-#endif
 	(void) SRAND(getpid());
 	w->hexagons.bufferTiles[0] = None;
 	w->hexagons.bufferTiles[1] = None;
 	w->hexagons.colormap = None;
 	w->hexagons.oldColormap = None;
 	w->hexagons.fontInfo = NULL;
-	w->hexagons.tileGC = NULL;
-	w->hexagons.borderGC = NULL;
-	w->hexagons.tileBrighterGC = NULL;
-	w->hexagons.tileDarkerGC = NULL;
-	w->hexagons.frameGC = NULL;
-	w->hexagons.inverseGC = NULL;
+	w->hexagons.textGC = NULL;
+	for (i = 0; i < FG_SHADES; i++)
+	       w->hexagons.tileGC[i] = NULL;
+        for (i = 0; i < BG_SHADES; i++)
+	       w->hexagons.inverseGC[i] = NULL;
 	w->hexagons.image = NULL;
 #endif
 	w->hexagons.focus = False;
@@ -3040,8 +3105,8 @@ XSynchronize(XtDisplay(w), True);
 	CheckTiles(w);
 	newMoves(&undo);
 	newMoves(&redo);;
-	w->hexagons.numSlices = ((w->hexagons.delay < MAXSLICES) ?
-		w->hexagons.delay + 1 : MAXSLICES);
+	w->hexagons.numSlices = ((w->hexagons.delay < MAX_SLICES) ?
+		w->hexagons.delay + 1 : MAX_SLICES);
 	w->hexagons.cheat = False;
 	SizePuzzle(w);
 }
