@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1993 - 2007	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1993 - 2008	David A. Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -89,7 +89,7 @@ static HexagonsRec widget;
 
 #ifndef WINVER
 static const char aboutHelp[] = {
-"Hexagons Version 7.3.2\n"
+"Hexagons Version 7.3.3\n"
 "Send bugs (reports or fixes) to the author: "
 "David Bagley <bagleyd@tux.org>\n"
 "The latest version is at: "
@@ -100,7 +100,7 @@ static const char optionsHelp[] = {
 "[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
 "[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
 "[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
-"[-tile {color}] [-{border|bd} {color}] [-delay msecs]\n"
+"[-tile {color}] [-text {color}] [-delay msecs]\n"
 "[-[no]sound] [-bumpSound {filename}]\n"
 "[-{font|fn} {fontname}] [-size{x|y} {int}] [-[no]corners]\n"
 "[-base {int}] [-userName {string}] [-scoreFile {filename}]\n"
@@ -196,29 +196,29 @@ static const char solveHelp[] = {
 #define SCOREFILE "hexagons.scores"
 #endif
 
-#define MAXTILES 10
+#define MAX_TILES 10
 #define NEVER (-1)
-#define FILENAMELEN 1024
-#define USERNAMELEN 120
-#define MESSAGELEN (USERNAMELEN+64)
-#define TITLELEN 2048
+#define FILE_NAME_LENGTH 1024
+#define USER_NAME_LENGTH 120
+#define MESSAGE_LENGTH (USER_NAME_LENGTH+64)
+#define TITLE_LENGTH 2048
 #define NOACCESS "noaccess"
 #define NOBODY "nobody"
 
 typedef struct {
 	int score;
-	char name[USERNAMELEN];
+	char name[USER_NAME_LENGTH];
 } PuzzleRecord;
 
-static PuzzleRecord puzzleRecord[MAXORIENT]
-[MAXTILES - MINTILES + 1][MAXTILES - MINTILES + 1];
+static PuzzleRecord puzzleRecord[MAX_ORIENT]
+[MAX_TILES - MIN_TILES + 1][MAX_TILES - MIN_TILES + 1];
 static int movesDsp = 0;
-static char messageDsp[MESSAGELEN] = "Welcome";
-static char recordDsp[MESSAGELEN] = "NOT RECORDED";
+static char messageDsp[MESSAGE_LENGTH] = "Welcome";
+static char recordDsp[MESSAGE_LENGTH] = "NOT RECORDED";
 
 #ifdef HAVE_MOTIF
-#define MINSPEED 1
-#define MAXSPEED 50
+#define MIN_SPEED 1
+#define MAX_SPEED 50
 #ifdef ANIMATE
 static Widget speed;
 #endif
@@ -229,20 +229,20 @@ static Widget optionsDialog, referencesDialog, aboutDialog;
 static Widget solveDialog, clearDialog;
 static Arg arg[3];
 #else
-static char titleDsp[TITLELEN] = "";
+static char titleDsp[TITLE_LENGTH] = "";
 #endif
-static char scoreFileName[FILENAMELEN] = SCOREFILE;
-static char fileName[FILENAMELEN];
+static char scoreFileName[FILE_NAME_LENGTH] = SCOREFILE;
+static char fileName[FILE_NAME_LENGTH];
 static Boolean randomized = False;
 #ifdef WINVER
-#define MAXPROGNAME 80
-static char progDsp[MAXPROGNAME] = TITLE;
-static char userNameDsp[USERNAMELEN] = "Guest";
+#define PROGRAM_NAME_LENGTH 80
+static char progDsp[PROGRAM_NAME_LENGTH] = TITLE;
+static char userNameDsp[USER_NAME_LENGTH] = "Guest";
 #else
 static Pixmap pixmap = None;
 static Widget topLevel, puzzle;
 static char *progDsp;
-static char userNameDsp[USERNAMELEN] = "";
+static char userNameDsp[USER_NAME_LENGTH] = "";
 
 #ifdef HAVE_MOTIF
 static void
@@ -264,9 +264,9 @@ PrintRecords(void)
 
 	(void) printf("         HEXAGONS  HALL OF FAME\n\n");
 	(void) printf("CORNER   X   Y USER            MOVES\n");
-	for (i = 0; i < MAXORIENT; i++)
-		for (j = 0; j < MAXTILES - MINTILES + 1; j++)
-			for (k = 0; k < MAXTILES - MINTILES + 1; k++) {
+	for (i = 0; i < MAX_ORIENT; i++)
+		for (j = 0; j < MAX_TILES - MIN_TILES + 1; j++)
+			for (k = 0; k < MAX_TILES - MIN_TILES + 1; k++) {
 				if (puzzleRecord[i][j][k].score > 0)
 					(void) printf("%6d%4d%4d %-12s%9d\n",
 						i, j + 1, k + 1,
@@ -281,12 +281,12 @@ InitRecords(void)
 {
 	int i, j, k;
 
-	for (i = 0; i < MAXORIENT; i++)
-		for (j = 0; j < MAXTILES - MINTILES + 1; j++)
-			for (k = 0; k < MAXTILES - MINTILES + 1; k++) {
+	for (i = 0; i < MAX_ORIENT; i++)
+		for (j = 0; j < MAX_TILES - MIN_TILES + 1; j++)
+			for (k = 0; k < MAX_TILES - MIN_TILES + 1; k++) {
 				puzzleRecord[i][j][k].score = NEVER;
 				(void) strncpy(puzzleRecord[i][j][k].name,
-					NOACCESS, USERNAMELEN);
+					NOACCESS, USER_NAME_LENGTH);
 			}
 }
 
@@ -295,7 +295,7 @@ ReadRecords(void)
 {
 	FILE *fp;
 	int i, j, k, n;
-	char userName[USERNAMELEN];
+	char userName[USER_NAME_LENGTH];
 	char *buf1 = NULL, *buf2 = NULL;
 	char *fname, *lname;
 
@@ -305,9 +305,9 @@ ReadRecords(void)
 	stringCat(&buf2, buf1, SCOREFILE);
 	free(buf1);
 	fname = buf2;
-	(void) strncpy(fileName, lname, USERNAMELEN);
+	(void) strncpy(fileName, lname, USER_NAME_LENGTH);
 	if ((fp = fopen(fileName, "r")) == NULL) {
-		(void) strncpy(fileName, fname, USERNAMELEN);
+		(void) strncpy(fileName, fname, USER_NAME_LENGTH);
 		/* Try installed directory. */
 		if ((fp = fopen(fileName, "r")) == NULL) {
 			stringCat(&buf1, "Can not read ", fname);
@@ -336,15 +336,15 @@ ReadRecords(void)
 	}
 	free(lname);
 	free(fname);
-	for (i = 0; i < MAXORIENT; i++)
-		for (j = 0; j < MAXTILES - MINTILES + 1; j++)
-			for (k = 0; k < MAXTILES - MINTILES + 1; k++) {
+	for (i = 0; i < MAX_ORIENT; i++)
+		for (j = 0; j < MAX_TILES - MIN_TILES + 1; j++)
+			for (k = 0; k < MAX_TILES - MIN_TILES + 1; k++) {
 				(void) fscanf(fp, "%d %s\n", &n, userName);
 				if (n <= puzzleRecord[i][j][k].score ||
 						puzzleRecord[i][j][k].score <= NEVER) {
 					puzzleRecord[i][j][k].score = n;
 					(void) strncpy(puzzleRecord[i][j][k].name,
-						userName, USERNAMELEN);
+						userName, USER_NAME_LENGTH);
 				}
 			}
 	(void) fclose(fp);
@@ -366,9 +366,9 @@ WriteRecords(void)
 	{
 #if HAVE_FCNTL_H
 		int lfd;
-		char lockFile[FILENAMELEN];
+		char lockFile[FILE_NAME_LENGTH];
 
-		(void) strncpy(lockFile, fileName, FILENAMELEN - 6);
+		(void) strncpy(lockFile, fileName, FILE_NAME_LENGTH - 6);
 		(void) strcat(lockFile, ".lock");
 		while (((lfd = open(lockFile, O_CREAT | O_EXCL, 0644)) < 0) &&
 				errno == EEXIST)
@@ -384,9 +384,9 @@ WriteRecords(void)
 #endif
 		}
 #endif
-		for (i = 0; i < MAXORIENT; i++) {
-			for (j = 0; j < MAXTILES - MINTILES + 1; j++)
-				for (k = 0; k < MAXTILES - MINTILES + 1; k++)
+		for (i = 0; i < MAX_ORIENT; i++) {
+			for (j = 0; j < MAX_TILES - MIN_TILES + 1; j++)
+				for (k = 0; k < MAX_TILES - MIN_TILES + 1; k++)
 					(void) fprintf(fp, "%d %s\n",
 						puzzleRecord[i][j][k].score,
 						puzzleRecord[i][j][k].name);
@@ -404,10 +404,10 @@ static void
 PrintRecord(int sizeX, int sizeY, Boolean corners)
 {
 	int i = (corners) ? 1 : 0;
-	int j = sizeX - MINTILES, k = sizeY - MINTILES;
+	int j = sizeX - MIN_TILES, k = sizeY - MIN_TILES;
 
-	if (sizeX > MAXTILES || sizeY > MAXTILES) {
-		(void) strncpy(recordDsp, "NOT RECORDED", MESSAGELEN);
+	if (sizeX > MAX_TILES || sizeY > MAX_TILES) {
+		(void) strncpy(recordDsp, "NOT RECORDED", MESSAGE_LENGTH);
 	} else if (puzzleRecord[i][j][k].score <= NEVER) {
 		(void) sprintf(recordDsp, "NEVER %s", NOACCESS);
 	} else {
@@ -446,15 +446,15 @@ static Boolean
 HandleSolved(int counter, int sizeX, int sizeY, int corners)
 {
 	int i = (corners) ? 1 : 0;
-	int j = sizeX - MINTILES, k = sizeY - MINTILES;
+	int j = sizeX - MIN_TILES, k = sizeY - MIN_TILES;
 
-	if (sizeX <= MAXTILES && sizeY <= MAXTILES &&
+	if (sizeX <= MAX_TILES && sizeY <= MAX_TILES &&
 			(counter < puzzleRecord[i][j][k].score ||
 			puzzleRecord[i][j][k].score <= NEVER)) {
 		ReadRecords();	/* Maybe its been updated by another */
 		puzzleRecord[i][j][k].score = counter;
 		(void) strncpy(puzzleRecord[i][j][k].name, userNameDsp,
-			USERNAMELEN);
+			USER_NAME_LENGTH);
 		WriteRecords();
 		PrintRecord(sizeX, sizeY, corners);
 		return True;
@@ -484,7 +484,7 @@ Widget w
 	userName = w->hexagons.userName;
 	scoreFile = w->hexagons.scoreFile;
 	if (strcmp(scoreFile, ""))
-		(void) strncpy(scoreFileName, scoreFile, FILENAMELEN);
+		(void) strncpy(scoreFileName, scoreFile, FILE_NAME_LENGTH);
 #else
 	Boolean scoreOnly, versionOnly;
 
@@ -501,7 +501,7 @@ Widget w
 		exit(0);
 	}
 	if (strcmp(scoreFile, ""))
-		(void) strncpy(scoreFileName, scoreFile, FILENAMELEN);
+		(void) strncpy(scoreFileName, scoreFile, FILE_NAME_LENGTH);
 	if (scoreOnly) {
 		InitRecords();
 		ReadRecords();
@@ -509,10 +509,10 @@ Widget w
 		exit(0);
 	}
 #ifdef HAVE_MOTIF
-	if (sizeX > MAXTILES)
+	if (sizeX > MAX_TILES)
 		XtVaSetValues(tileX, XmNmaximum, sizeX, NULL);
 	XmScaleSetValue(tileX, sizeX);
-	if (sizeY > MAXTILES)
+	if (sizeY > MAX_TILES)
 		XtVaSetValues(tileY, XmNmaximum, sizeY, NULL);
 	XmScaleSetValue(tileY, sizeY);
 	XmToggleButtonSetState(cornersSwitch, corners, True);
@@ -521,7 +521,7 @@ Widget w
 		int delay;
 
 		XtVaGetValues(w, XtNdelay, &delay, NULL);
-		XmScaleSetValue(speed, MAXSPEED + MINSPEED - delay - 1);
+		XmScaleSetValue(speed, MAX_SPEED + MIN_SPEED - delay - 1);
 	}
 #endif
 #endif
@@ -530,13 +530,13 @@ Widget w
 	InitRecords();
 	ReadRecords();
 #ifndef WINVER
-	(void) strncpy(userNameDsp, userName, USERNAMELEN);
+	(void) strncpy(userNameDsp, userName, USER_NAME_LENGTH);
 #endif
 	if (!strcmp(userName, "") || !strcmp(userName, "(null)") ||
 			!strcmp(userName, NOACCESS) ||
 			!strcmp(userName, NOBODY)) {
 #ifdef WINVER
-		(void) strncpy(userNameDsp, userName, USERNAMELEN);
+		(void) strncpy(userNameDsp, userName, USER_NAME_LENGTH);
 #else
 		char *login = getlogin();
 
@@ -616,7 +616,7 @@ CallbackPuzzle(Widget w, caddr_t clientData,
 #ifdef HAVE_MOTIF
 		XtManageChild(solveDialog);
 #else
-		(void) strncpy(messageDsp, solveHelp, MESSAGELEN);
+		(void) strncpy(messageDsp, solveHelp, MESSAGE_LENGTH);
 #endif
 #endif
 		break;
@@ -626,10 +626,10 @@ CallbackPuzzle(Widget w, caddr_t clientData,
 		randomized = False;
 		break;
 	case ACTION_AMBIGUOUS:
-		(void) strncpy(messageDsp, "Ambiguous move", MESSAGELEN);
+		(void) strncpy(messageDsp, "Ambiguous move", MESSAGE_LENGTH);
 		break;
 	case ACTION_BLOCKED:
-		(void) strncpy(messageDsp, "Blocked", MESSAGELEN);
+		(void) strncpy(messageDsp, "Blocked", MESSAGE_LENGTH);
 		break;
 	case ACTION_SPACE:
 #if 0
@@ -640,7 +640,7 @@ CallbackPuzzle(Widget w, caddr_t clientData,
 		break;
 	case ACTION_IGNORE:
 		(void) strncpy(messageDsp, "Clear to start",
-			MESSAGELEN);
+			MESSAGE_LENGTH);
 		break;
 	case ACTION_MOVED:
 		movesDsp++;
@@ -656,7 +656,7 @@ CallbackPuzzle(Widget w, caddr_t clientData,
 				"Congratulations %s!!", userNameDsp);
 		else
 			(void) strncpy(messageDsp, "Solved!",
-				MESSAGELEN);
+				MESSAGE_LENGTH);
 		SET_STARTED(w, False);
 		break;
 	case ACTION_COMPUTED:
@@ -676,7 +676,7 @@ CallbackPuzzle(Widget w, caddr_t clientData,
 #else
 		XtVaSetValues(w, XtNsizeX, sizeX, NULL);
 #ifdef HAVE_MOTIF
-		if (sizeX > MAXTILES)
+		if (sizeX > MAX_TILES)
 			XtVaSetValues(tileX, XmNmaximum, sizeX, NULL);
 		XmScaleSetValue(tileX, sizeX);
 #endif
@@ -692,7 +692,7 @@ CallbackPuzzle(Widget w, caddr_t clientData,
 		XtVaSetValues(w, XtNsizeX, sizeX, NULL);
 #ifdef HAVE_MOTIF
 		XmScaleSetValue(tileX, sizeX);
-		if (sizeX >= MAXTILES)
+		if (sizeX >= MAX_TILES)
 			XtVaSetValues(tileX, XmNmaximum, sizeX, NULL);
 #endif
 #endif
@@ -706,7 +706,7 @@ CallbackPuzzle(Widget w, caddr_t clientData,
 #else
 		XtVaSetValues(w, XtNsizeY, sizeY, NULL);
 #ifdef HAVE_MOTIF
-		if (sizeY > MAXTILES)
+		if (sizeY > MAX_TILES)
 			XtVaSetValues(tileY, XmNmaximum, sizeY, NULL);
 		XmScaleSetValue(tileY, sizeY);
 #endif
@@ -722,7 +722,7 @@ CallbackPuzzle(Widget w, caddr_t clientData,
 		XtVaSetValues(w, XtNsizeY, sizeY, NULL);
 #ifdef HAVE_MOTIF
 		XmScaleSetValue(tileY, sizeY);
-		if (sizeY >= MAXTILES)
+		if (sizeY >= MAX_TILES)
 			XtVaSetValues(tileY, XmNmaximum, sizeY, NULL);
 #endif
 #endif
@@ -756,8 +756,8 @@ CallbackPuzzle(Widget w, caddr_t clientData,
 			XtVaGetValues(puzzle,
 				XtNdelay, &delay, NULL);
 			oldDelay = delay;
-			if (delay > MAXSPEED - MINSPEED)
-				delay = MAXSPEED - MINSPEED;
+			if (delay > MAX_SPEED - MIN_SPEED)
+				delay = MAX_SPEED - MIN_SPEED;
 			if (delay < 0)
 				delay = 0;
 			if (delay != oldDelay) {
@@ -765,7 +765,7 @@ CallbackPuzzle(Widget w, caddr_t clientData,
 					XtNdelay, delay, NULL);
 			}
 			XmScaleSetValue(speed,
-				MAXSPEED + MINSPEED - delay - 1);
+				MAX_SPEED + MIN_SPEED - delay - 1);
 		}
 		return;
 #endif
@@ -1075,10 +1075,8 @@ static XrmOptionDescRec options[] =
 	{(char *) "-foreground", (char *) "*hexagons.Foreground", XrmoptionSepArg, NULL},
 	{(char *) "-bg", (char *) "*Background", XrmoptionSepArg, NULL},
 	{(char *) "-background", (char *) "*Background", XrmoptionSepArg, NULL},
-	{(char *) "-bd", (char *) "*hexagons.tileBorder", XrmoptionSepArg, NULL},
-	{(char *) "-border", (char *) "*hexagons.tileBorder", XrmoptionSepArg, NULL},
 	{(char *) "-tile", (char *) "*hexagons.tileColor", XrmoptionSepArg, NULL},
-	{(char *) "-border", (char *) "*hexagons.tileBorder", XrmoptionSepArg, NULL},
+	{(char *) "-text", (char *) "*hexagons.textColor", XrmoptionSepArg, NULL},
 	{(char *) "-install", (char *) "*hexagons.install", XrmoptionNoArg, (char *) "TRUE"},
 	{(char *) "-noinstall", (char *) "*hexagons.install", XrmoptionNoArg, (char *) "FALSE"},
 	{(char *) "-picture", (char *) "*hexagons.picture", XrmoptionSepArg, NULL},
@@ -1188,7 +1186,7 @@ CornersToggle(Widget w, XtPointer clientData,
 static void
 SpeedSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 {
-	int delay = MAXSPEED + MINSPEED - cbs->value - 1, oldDelay;
+	int delay = MAX_SPEED + MIN_SPEED - cbs->value - 1, oldDelay;
 
 	XtVaGetValues(puzzle,
 		XtNdelay, &oldDelay, NULL);
@@ -1220,7 +1218,7 @@ static Widget
 createQuery(Widget w, char *text, char *title, XtCallbackProc callback)
 {
 	Widget button, messageBox;
-	char titleDsp[FILENAMELEN + 8];
+	char titleDsp[FILE_NAME_LENGTH + 8];
 	XmString titleString = NULL, messageString = NULL;
 	static XmStringCharSet charSet =
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
@@ -1246,7 +1244,7 @@ static Widget
 createHelp(Widget w, char *text, char *title)
 {
 	Widget button, messageBox;
-	char titleDsp[FILENAMELEN + 8];
+	char titleDsp[FILE_NAME_LENGTH + 8];
 	XmString titleString = NULL, messageString = NULL, buttonString = NULL;
 	static XmStringCharSet charSet =
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
@@ -1496,9 +1494,9 @@ main(int argc, char **argv)
 	tileX = XtVaCreateManagedWidget("tileX",
 		xmScaleWidgetClass, tilesRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Size X", 7,
-		XmNminimum, MINTILES,
-		XmNmaximum, MAXTILES,
-		XmNvalue, DEFAULTTILESX,
+		XmNminimum, MIN_TILES,
+		XmNmaximum, MAX_TILES,
+		XmNvalue, DEFAULT_TILESX,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
 	XtAddCallback(tileX, XmNvalueChangedCallback,
@@ -1506,16 +1504,16 @@ main(int argc, char **argv)
 	tileY = XtVaCreateManagedWidget("tileY",
 		xmScaleWidgetClass, tilesRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Size Y", 7,
-		XmNminimum, MINTILES,
-		XmNmaximum, MAXTILES,
-		XmNvalue, DEFAULTTILESY,
+		XmNminimum, MIN_TILES,
+		XmNmaximum, MAX_TILES,
+		XmNvalue, DEFAULT_TILESY,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
 	XtAddCallback(tileY, XmNvalueChangedCallback,
 		(XtCallbackProc) TileYSlider, (XtPointer) NULL);
 	cornersSwitch = XtVaCreateManagedWidget("Corners",
 		xmToggleButtonWidgetClass, tilesRowCol,
-		XmNset, DEFAULTCORNERS, NULL);
+		XmNset, DEFAULT_CORNERS, NULL);
 	XtAddCallback(cornersSwitch, XmNvalueChangedCallback,
 		(XtCallbackProc) CornersToggle, (XtPointer) NULL);
 #ifdef ANIMATE
@@ -1527,9 +1525,9 @@ main(int argc, char **argv)
 	speed = XtVaCreateManagedWidget("Animation Speed",
 		xmScaleWidgetClass, speedRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Animation Speed", 16,
-		XmNminimum, MINSPEED,
-		XmNmaximum, MAXSPEED,
-		XmNvalue, MAXSPEED - DEFAULTDELAY,
+		XmNminimum, MIN_SPEED,
+		XmNmaximum, MAX_SPEED,
+		XmNvalue, MAX_SPEED - DEFAULT_DELAY,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
 	XtAddCallback(speed, XmNvalueChangedCallback,
