@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 2007	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1994 - 2007	David A. Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -40,7 +40,7 @@
 
 #define SECTION "setup"
 
-static const char *wedgeColorString[MAXWEDGES] =
+static const char *wedgeColorString[MAX_WEDGES] =
 {
 	"255 255 0",
 	"0 0 255",
@@ -56,7 +56,7 @@ static const char *wedgeColorString[MAXWEDGES] =
 	"205 92 92"
 };
 
-static char wedgeColorChar[MAXWEDGES] =
+static char wedgeColorChar[MAX_WEDGES] =
 {'Y', 'B', 'R', 'M', 'G', 'O', 'C', 'D', 'P', 'L', 'A', 'T'};
 #else
 
@@ -352,7 +352,7 @@ static XtResource resourcesPuzzle[] =
 	 XtRString, (caddr_t) "gray25" /*XtDefaultForeground*/},
 	{XtNdelay, XtCDelay, XtRInt, sizeof (int),
 	 XtOffset(MballWidget, mball.delay),
-	 XtRString, (caddr_t) "10"}, /* DEFAULTDELAY */
+	 XtRString, (caddr_t) "10"}, /* DEFAULT_DELAY */
 	{XtNsound, XtCSound, XtRBoolean, sizeof (Boolean),
 	 XtOffset(MballWidget, mball.sound),
 	 XtRString, (caddr_t) "FALSE"},
@@ -364,19 +364,19 @@ static XtResource resourcesPuzzle[] =
 	 XtRString, (caddr_t) "9x15bold"},
 	{XtNwedges, XtCWedges, XtRInt, sizeof (int),
 	 XtOffset(MballWidget, mball.wedges),
-	 XtRString, (caddr_t) "8"}, /* DEFAULTWEDGES */
+	 XtRString, (caddr_t) "8"}, /* DEFAULT_WEDGES */
 	{XtNrings, XtCRings, XtRInt, sizeof (int),
 	 XtOffset(MballWidget, mball.rings),
-	 XtRString, (caddr_t) "4"}, /* DEFAULTRINGS */
+	 XtRString, (caddr_t) "4"}, /* DEFAULT_RINGS */
 	{XtNorient, XtCOrient, XtRBoolean, sizeof (Boolean),
 	 XtOffset(MballWidget, mball.orient),
-	 XtRString, (caddr_t) "FALSE"}, /* DEFAULTORIENT */
+	 XtRString, (caddr_t) "FALSE"}, /* DEFAULT_ORIENT */
 	{XtNpractice, XtCPractice, XtRBoolean, sizeof (Boolean),
 	 XtOffset(MballWidget, mball.practice),
-	 XtRString, (caddr_t) "TRUE"}, /* DEFAULTPRACTICE */
+	 XtRString, (caddr_t) "TRUE"}, /* DEFAULT_PRACTICE */
 	{XtNbase, XtCBase, XtRInt, sizeof (int),
 	 XtOffset(MballWidget, mball.base),
-	 XtRString, (caddr_t) "16"}, /* DEFAULTBASE */
+	 XtRString, (caddr_t) "16"}, /* DEFAULT_BASE */
 	{XtNuserName, XtCUserName, XtRString, sizeof (String),
 	 XtOffset(MballWidget, mball.userName),
 	 XtRString, (caddr_t) ""},
@@ -502,7 +502,7 @@ loadFont(MballWidget w)
 #define LOGFILE "mball.log"
 #endif
 
-static int mapDirToWedge[(MAXWEDGES - MINWEDGES) / 2 + 1][COORD] =
+static int mapDirToWedge[(MAX_WEDGES - MIN_WEDGES) / 2 + 1][COORD] =
 {
 	{
 		0, 6, 6, 6, 6, 6, 0, 6, 6, 6, 6, 6
@@ -524,7 +524,7 @@ static int mapDirToWedge[(MAXWEDGES - MINWEDGES) / 2 + 1][COORD] =
 	}
 };
 
-static int mapWedgeToDir[(MAXWEDGES - MINWEDGES) / 2 + 1][MAXWEDGES] =
+static int mapWedgeToDir[(MAX_WEDGES - MIN_WEDGES) / 2 + 1][MAX_WEDGES] =
 {
 	{
 		0, 6, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12
@@ -556,33 +556,33 @@ CheckPieces(MballWidget w)
 {
 	char *buf1 = NULL, *buf2 = NULL;
 
-	if (w->mball.wedges < MINWEDGES || w->mball.wedges > MAXWEDGES) {
+	if (w->mball.wedges < MIN_WEDGES || w->mball.wedges > MAX_WEDGES) {
 		intCat(&buf1,
 			"Number of wedges out of bounds, use even ",
-			MINWEDGES);
+			MIN_WEDGES);
 		stringCat(&buf2, buf1, "..");
 		free(buf1);
-		intCat(&buf1, buf2, MAXWEDGES);
+		intCat(&buf1, buf2, MAX_WEDGES);
 		free(buf2);
 		stringCat(&buf2, buf1, ", defaulting to ");
 		free(buf1);
-		intCat(&buf1, buf2, DEFAULTWEDGES);
+		intCat(&buf1, buf2, DEFAULT_WEDGES);
 		free(buf2);
 		DISPLAY_WARNING(buf1);
 		free(buf1);
-		w->mball.wedges = DEFAULTWEDGES;
+		w->mball.wedges = DEFAULT_WEDGES;
 	}
-	if (w->mball.rings < MINRINGS) {
+	if (w->mball.rings < MIN_RINGS) {
 		intCat(&buf1,
 			"Number of rings out of bounds, use at least ",
-			MINRINGS);
+			MIN_RINGS);
 		stringCat(&buf2, buf1, ", defaulting to ");
 		free(buf1);
-		intCat(&buf1, buf2, DEFAULTRINGS);
+		intCat(&buf1, buf2, DEFAULT_RINGS);
 		free(buf2);
 		DISPLAY_WARNING(buf1);
 		free(buf1);
-		w->mball.rings = DEFAULTRINGS;
+		w->mball.rings = DEFAULT_RINGS;
 	}
 #if 0
 	if (w->mball.delay < 0) {
@@ -595,19 +595,19 @@ CheckPieces(MballWidget w)
 		w->mball.delay = -w->mball.delay;
 	}
 #endif
-	if (w->mball.base < MINBASE || w->mball.base > MAXBASE) {
-		intCat(&buf1, "Base out of bounds, use ", MINBASE);
+	if (w->mball.base < MIN_BASE || w->mball.base > MAX_BASE) {
+		intCat(&buf1, "Base out of bounds, use ", MIN_BASE);
 		stringCat(&buf2, buf1, "..");
 		free(buf1);
-		intCat(&buf1, buf2, MAXBASE);
+		intCat(&buf1, buf2, MAX_BASE);
 		free(buf2);
 		stringCat(&buf2, buf1, ", defaulting to ");
 		free(buf1);
-		intCat(&buf1, buf2, DEFAULTBASE);
+		intCat(&buf1, buf2, DEFAULT_BASE);
 		free(buf2);
 		DISPLAY_WARNING(buf1);
 		free(buf1);
-		w->mball.base = DEFAULTBASE;
+		w->mball.base = DEFAULT_BASE;
 	}
 }
 
@@ -835,8 +835,8 @@ DrawSect(const MballWidget w, const GC pieceGC, const GC borderGC,
 				r * 2 * lengthy / w->mball.rings - 2 * w->mball.dr,
 				(r + 1) * 2 * lengthx / (w->mball.rings + 1) - 2 * w->mball.dr,
 				(r + 1) * 2 * lengthy / (w->mball.rings + 1) - 2 * w->mball.dr,
-				CIRCLE_4 - FULLCIRCLE * wedge / w->mball.wedges,
-				-FULLCIRCLE / w->mball.wedges);
+				CIRCLE_4 - FULL_CIRCLE * wedge / w->mball.wedges,
+				-FULL_CIRCLE / w->mball.wedges);
 		else
 			SECTOR(w, pieceGC, borderGC,
 				startx + lengthx / 2 + dx, starty + lengthy / 2 + dy,
@@ -844,8 +844,8 @@ DrawSect(const MballWidget w, const GC pieceGC, const GC borderGC,
 				r * 2 * lengthy / w->mball.rings - 2 * w->mball.dr,
 				(r + 1) * 2 * lengthx / w->mball.rings - 2 * w->mball.dr,
 				(r + 1) * 2 * lengthy / w->mball.rings - 2 * w->mball.dr,
-				CIRCLE_4 - FULLCIRCLE * wedge / w->mball.wedges,
-				-FULLCIRCLE / w->mball.wedges);
+				CIRCLE_4 - FULL_CIRCLE * wedge / w->mball.wedges,
+				-FULL_CIRCLE / w->mball.wedges);
 	} else
 		SECTOR(w, pieceGC, borderGC,
 			startx + lengthx / 2 + dx, starty + lengthy / 2 + dy,
@@ -853,8 +853,8 @@ DrawSect(const MballWidget w, const GC pieceGC, const GC borderGC,
 			r * 2 * lengthy / w->mball.rings - 2 * w->mball.dr,
 			(r + 1) * 2 * lengthx / w->mball.rings - 2 * w->mball.dr,
 			(r + 1) * 2 * lengthy / w->mball.rings - 2 * w->mball.dr,
-			CIRCLE_4 - FULLCIRCLE * wedge / w->mball.wedges,
-			-FULLCIRCLE / w->mball.wedges);
+			CIRCLE_4 - FULL_CIRCLE * wedge / w->mball.wedges,
+			-FULL_CIRCLE / w->mball.wedges);
 #endif
 }
 
@@ -1137,16 +1137,16 @@ DrawSect(const MballWidget w, GC wedgeGC, GC borderGC,
 				r * 2 * lengthy / w->mball.rings - 2 * w->mball.dr,
 				(r + 1) * 2 * lengthx / (w->mball.rings + 1) - 2 * w->mball.dr,
 				(r + 1) * 2 * lengthy / (w->mball.rings + 1) - 2 * w->mball.dr,
-				CIRCLE_4 - FULLCIRCLE * wedge / w->mball.wedges,
-				-FULLCIRCLE / w->mball.wedges);
+				CIRCLE_4 - FULL_CIRCLE * wedge / w->mball.wedges,
+				-FULL_CIRCLE / w->mball.wedges);
 			XDrawSector(XtDisplay(w), XtWindow(w), borderGC,
 				startx + lengthx / 2 + dx, starty + lengthy / 2 + dy,
 				r * 2 * lengthx / w->mball.rings - 2 * w->mball.dr,
 				r * 2 * lengthy / w->mball.rings - 2 * w->mball.dr,
 				(r + 1) * 2 * lengthx / (w->mball.rings + 1) - 2 * w->mball.dr,
 				(r + 1) * 2 * lengthy / (w->mball.rings + 1) - 2 * w->mball.dr,
-				CIRCLE_4 - FULLCIRCLE * wedge / w->mball.wedges,
-				-FULLCIRCLE / w->mball.wedges);
+				CIRCLE_4 - FULL_CIRCLE * wedge / w->mball.wedges,
+				-FULL_CIRCLE / w->mball.wedges);
 		} else {
 			XFillSector(XtDisplay(w), XtWindow(w), wedgeGC,
 				startx + lengthx / 2 + dx, starty + lengthy / 2 + dy,
@@ -1154,16 +1154,16 @@ DrawSect(const MballWidget w, GC wedgeGC, GC borderGC,
 				r * 2 * lengthy / w->mball.rings - 2 * w->mball.dr,
 				(r + 1) * 2 * lengthx / w->mball.rings - 2 * w->mball.dr,
 				(r + 1) * 2 * lengthy / w->mball.rings - 2 * w->mball.dr,
-				CIRCLE_4 - FULLCIRCLE * wedge / w->mball.wedges,
-				-FULLCIRCLE / w->mball.wedges);
+				CIRCLE_4 - FULL_CIRCLE * wedge / w->mball.wedges,
+				-FULL_CIRCLE / w->mball.wedges);
 			XDrawSector(XtDisplay(w), XtWindow(w), borderGC,
 				startx + lengthx / 2 + dx, starty + lengthy / 2 + dy,
 				r * 2 * lengthx / w->mball.rings - 2 * w->mball.dr,
 				r * 2 * lengthy / w->mball.rings - 2 * w->mball.dr,
 				(r + 1) * 2 * lengthx / w->mball.rings - 2 * w->mball.dr,
 				(r + 1) * 2 * lengthy / w->mball.rings - 2 * w->mball.dr,
-				CIRCLE_4 - FULLCIRCLE * wedge / w->mball.wedges,
-				-FULLCIRCLE / w->mball.wedges);
+				CIRCLE_4 - FULL_CIRCLE * wedge / w->mball.wedges,
+				-FULL_CIRCLE / w->mball.wedges);
 		}
 	} else {
 		XFillSector(XtDisplay(w), XtWindow(w), wedgeGC,
@@ -1172,16 +1172,16 @@ DrawSect(const MballWidget w, GC wedgeGC, GC borderGC,
 			r * 2 * lengthy / w->mball.rings - 2 * w->mball.dr,
 			(r + 1) * 2 * lengthx / w->mball.rings - 2 * w->mball.dr,
 			(r + 1) * 2 * lengthy / w->mball.rings - 2 * w->mball.dr,
-			CIRCLE_4 - FULLCIRCLE * wedge / w->mball.wedges,
-			-FULLCIRCLE / w->mball.wedges);
+			CIRCLE_4 - FULL_CIRCLE * wedge / w->mball.wedges,
+			-FULL_CIRCLE / w->mball.wedges);
 		XDrawSector(XtDisplay(w), XtWindow(w), borderGC,
 			startx + lengthx / 2 + dx, starty + lengthy / 2 + dy,
 			r * 2 * lengthx / w->mball.rings - 2 * w->mball.dr,
 			r * 2 * lengthy / w->mball.rings - 2 * w->mball.dr,
 			(r + 1) * 2 * lengthx / w->mball.rings - 2 * w->mball.dr,
 			(r + 1) * 2 * lengthy / w->mball.rings - 2 * w->mball.dr,
-			CIRCLE_4 - FULLCIRCLE * wedge / w->mball.wedges,
-			-FULLCIRCLE / w->mball.wedges);
+			CIRCLE_4 - FULL_CIRCLE * wedge / w->mball.wedges,
+			-FULL_CIRCLE / w->mball.wedges);
 	}
 }
 
@@ -1386,7 +1386,7 @@ DrawRadar(const MballWidget w, GC gc, int thick,
 	double angle, increment;
 
 	DRAWARC(w, dr, gc, thick, startx, starty,
-		lengthx, lengthy, 0, FULLCIRCLE);
+		lengthx, lengthy, 0, FULL_CIRCLE);
 	if (w->mball.rings % 2) {
 		stx = startx - lengthx / (2 * w->mball.rings);
 		sty = starty - lengthy / (2 * w->mball.rings);
@@ -1398,7 +1398,7 @@ DrawRadar(const MballWidget w, GC gc, int thick,
 				w->mball.rings,
 				r * 2 * lengthx / w->mball.rings,
 				r * 2 * lengthy / w->mball.rings,
-				0, FULLCIRCLE);
+				0, FULL_CIRCLE);
 		}
 	} else {
 		for (r = 1; r < w->mball.rings / 2; r++) {
@@ -1409,7 +1409,7 @@ DrawRadar(const MballWidget w, GC gc, int thick,
 				w->mball.rings,
 				r * 2 * lengthx / w->mball.rings,
 				r * 2 * lengthy / w->mball.rings,
-				0, FULLCIRCLE);
+				0, FULL_CIRCLE);
 		}
 	}
 	increment = RADIANS(NUM_DEGREES) / w->mball.wedges;
@@ -1524,7 +1524,7 @@ MovePieces(MballWidget w, int wedge, int ring, int direction)
 			DrawSector(w, newI, ring, FALSE);
 		}
 	} else {		/* flip */
-		int sphereDir = mapDirToWedge[(w->mball.wedges - MINWEDGES) / 2][direction];
+		int sphereDir = mapDirToWedge[(w->mball.wedges - MIN_WEDGES) / 2][direction];
 		int offset = w->mball.wedges / 2;
 		int wedge1, wedge2;
 
@@ -1595,11 +1595,11 @@ PositionToSector(MballWidget w, int x, int y, int *wedge, int *ring, int *view)
 	y -= (w->mball.wedgeLength + 1) / 2;
 	radius = sqrt((double) x * x + y * y);
 	if (y >= 0)
-		angle = atan2(-x, y) + M_PI;
+		angle = atan2((double) -x, (double) y) + M_PI;
 	else if (x < 0)
-		angle = 2 * M_PI - atan2(-x, -y);
+		angle = 2 * M_PI - atan2((double) -x, (double) -y);
 	else
-		angle = -atan2(-x, -y);
+		angle = -atan2((double) -x, (double) -y);
 	*ring = (int) (radius * w->mball.rings / w->mball.wedgeLength);
 	*wedge = (int) (angle * w->mball.wedges / (2.0 * M_PI));
 	if (*view == DOWN) {
@@ -1631,7 +1631,7 @@ PositionSector(MballWidget w, int x, int y, int *wedge, int *ring, int *directio
 			*direction = (COORD - *direction) % COORD;
 	}
 	if (*direction != CW && *direction != CCW &&
-		mapDirToWedge[(w->mball.wedges - MINWEDGES) / 2][*direction] ==
+		mapDirToWedge[(w->mball.wedges - MIN_WEDGES) / 2][*direction] ==
 			CUTS) {
 		return False;
 	}
@@ -1664,7 +1664,7 @@ ResetPieces(MballWidget w)
 {
 	int wedge, ring;
 
-	for (wedge = 0; wedge < MAXWEDGES; wedge++) {
+	for (wedge = 0; wedge < MAX_WEDGES; wedge++) {
 		if (w->mball.mballLoc[wedge])
 			free(w->mball.mballLoc[wedge]);
 		if (!(w->mball.mballLoc[wedge] = (MballLoc *)
@@ -1746,9 +1746,9 @@ GetPieces(MballWidget w)
 	flushMoves(w, &redo, FALSE);
 	while ((c = getc(fp)) != EOF && c != SYMBOL);
 	(void) fscanf(fp, "%d", &wedge);
-	if (wedge >= MINWEDGES && wedge <= MAXWEDGES && !(wedge % 2)) {
+	if (wedge >= MIN_WEDGES && wedge <= MAX_WEDGES && !(wedge % 2)) {
 		if (w->mball.wedges != wedge) {
-			setPuzzle(w, (wedge - MINWEDGES) / 2 + ACTION_WEDGE2);
+			setPuzzle(w, (wedge - MIN_WEDGES) / 2 + ACTION_WEDGE2);
 		}
 	} else {
 		stringCat(&buf1, name, " corrupted: wedge ");
@@ -1756,18 +1756,18 @@ GetPieces(MballWidget w)
 		free(buf1);
 		stringCat(&buf1, buf2, " should be between ");
 		free(buf2);
-		intCat(&buf2, buf1, MINWEDGES);
+		intCat(&buf2, buf1, MIN_WEDGES);
 		free(buf1);
 		stringCat(&buf1, buf2, " and ");
 		free(buf2);
-		intCat(&buf2, buf1, MAXWEDGES);
+		intCat(&buf2, buf1, MAX_WEDGES);
 		free(buf1);
 			DISPLAY_WARNING(buf2);
 		free(buf2);
 	}
 	while ((c = getc(fp)) != EOF && c != SYMBOL);
 	(void) fscanf(fp, "%d", &ring);
-	if (ring >= MINRINGS) {
+	if (ring >= MIN_RINGS) {
 		for (i = w->mball.rings; i < ring; i++) {
 			setPuzzle(w, ACTION_INCREMENT);
 		}
@@ -1780,7 +1780,7 @@ GetPieces(MballWidget w)
 		free(buf1);
 		stringCat(&buf1, buf2, " should be between ");
 		free(buf2);
-		intCat(&buf2, buf1, MINRINGS);
+		intCat(&buf2, buf1, MIN_RINGS);
 		free(buf1);
 		stringCat(&buf1, buf2, " and MAXINT");
 		free(buf2);
@@ -1954,7 +1954,7 @@ RandomizePieces(MballWidget w)
 		do
 			randomDirection = NRAND(2 * COORD);
 		while (randomDirection < COORD &&
-			mapDirToWedge[(w->mball.wedges - MINWEDGES) / 2][randomDirection] ==
+			mapDirToWedge[(w->mball.wedges - MIN_WEDGES) / 2][randomDirection] ==
 				CUTS);
 		if (randomDirection >= COORD) {
 			if (randomDirection - COORD < CUTS)
@@ -1991,7 +1991,7 @@ IncrementPieces(MballWidget w)
 static Boolean
 DecrementPieces(MballWidget w)
 {
-	if (w->mball.rings <= MINRINGS)
+	if (w->mball.rings <= MIN_RINGS)
 		return False;
 	setPuzzle(w, ACTION_DECREMENT);
 	return True;
@@ -2040,19 +2040,19 @@ SetValuesPuzzle(MballWidget w)
 	int wedge;
 
 	w->mball.wedges = GetPrivateProfileInt(SECTION, "wedges",
-		DEFAULTWEDGES, INIFILE);
+		DEFAULT_WEDGES, INIFILE);
 	w->mball.rings = GetPrivateProfileInt(SECTION, "rings",
-		DEFAULTRINGS, INIFILE);
+		DEFAULT_RINGS, INIFILE);
 	w->mball.orient = (BOOL) GetPrivateProfileInt(SECTION, "orient",
-		DEFAULTORIENT, INIFILE);
+		DEFAULT_ORIENT, INIFILE);
 	w->mball.practice = (BOOL) GetPrivateProfileInt(SECTION, "practice",
-		DEFAULTPRACTICE, INIFILE);
+		DEFAULT_PRACTICE, INIFILE);
 	w->mball.base = GetPrivateProfileInt(SECTION, "base",
-		DEFAULTBASE, INIFILE);
+		DEFAULT_BASE, INIFILE);
 	w->mball.mono = (BOOL) GetPrivateProfileInt(SECTION, "mono",
-		DEFAULTMONO, INIFILE);
+		DEFAULT_MONO, INIFILE);
 	w->mball.reverse = (BOOL) GetPrivateProfileInt(SECTION, "reverseVideo",
-		DEFAULTREVERSE, INIFILE);
+		DEFAULT_REVERSE, INIFILE);
 	/* cyan */
 	(void) GetPrivateProfileString(SECTION, "frameColor", "0 255 254",
 		szBuf, sizeof (szBuf), INIFILE);
@@ -2071,7 +2071,7 @@ SetValuesPuzzle(MballWidget w)
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
 	w->mball.inverseGC = RGB(color.red, color.green, color.blue);
-	for (wedge = 0; wedge < MAXWEDGES; wedge++) {
+	for (wedge = 0; wedge < MAX_WEDGES; wedge++) {
 		(void) sprintf(buf, "wedgeColor%d", wedge);
 		(void) GetPrivateProfileString(SECTION,
 			buf, wedgeColorString[wedge],
@@ -2209,7 +2209,7 @@ SetAllColors(MballWidget w)
 	if (w->mball.borderGC)
 		XtReleaseGC((Widget) w, w->mball.borderGC);
 	w->mball.borderGC = XtGetGC((Widget) w, valueMask, &values);
-	for (wedge = 0; wedge < MAXWEDGES; wedge++)
+	for (wedge = 0; wedge < MAX_WEDGES; wedge++)
 		GetColor(w, wedge);
 	if (w->mball.fontInfo)
 		XSetFont(XtDisplay(w), w->mball.borderGC,
@@ -2224,7 +2224,7 @@ SetValuesPuzzle(Widget current, Widget request, Widget renew)
 	int wedge;
 
 	CheckPieces(w);
-	for (wedge = 0; wedge < MAXWEDGES; wedge++) {
+	for (wedge = 0; wedge < MAX_WEDGES; wedge++) {
 		if (strcmp(w->mball.wedgeName[wedge], c->mball.wedgeName[wedge])) {
 			setColors = True;
 			break;
@@ -2319,7 +2319,7 @@ DestroyPuzzle(Widget old)
 	Display *display = XtDisplay(w);
 	int wedge;
 
-	for (wedge = 0; wedge < MAXWEDGES; wedge++)
+	for (wedge = 0; wedge < MAX_WEDGES; wedge++)
 		XtReleaseGC(old, w->mball.wedgeGC[wedge]);
 	XtReleaseGC(old, w->mball.borderGC);
 	XtReleaseGC(old, w->mball.frameGC);
@@ -2411,7 +2411,7 @@ Widget request, Widget renew
 	w->mball.mono = (DefaultDepthOfScreen(XtScreen(w)) < 2 ||
 		w->mball.mono);
 	w->mball.fontInfo = NULL;
-	for (wedge = 0; wedge < MAXWEDGES; wedge++)
+	for (wedge = 0; wedge < MAX_WEDGES; wedge++)
 		w->mball.wedgeGC[wedge] = NULL;
 	w->mball.borderGC = NULL;
 	w->mball.frameGC = NULL;
@@ -2419,7 +2419,7 @@ Widget request, Widget renew
 #endif
 	w->mball.focus = False;
 	loadFont(w);
-	for (wedge = 0; wedge < MAXWEDGES; wedge++)
+	for (wedge = 0; wedge < MAX_WEDGES; wedge++)
 		w->mball.mballLoc[wedge] = NULL;
 	CheckPieces(w);
 	newMoves(&undo);
@@ -2552,11 +2552,11 @@ ReleasePuzzle(MballWidget w
 			setPuzzle(w, ACTION_AMBIGUOUS);
 		} else if (opp == (wedge + 1) % w->mball.wedges)
 			MovePuzzle(w, wedge, ring,
-				mapWedgeToDir[(w->mball.wedges - MINWEDGES) / 2]
+				mapWedgeToDir[(w->mball.wedges - MIN_WEDGES) / 2]
 				[w->mball.currentWedge], control);
 		else if (wedge == (opp + 1) % w->mball.wedges)
 			MovePuzzle(w, wedge, ring,
-				mapWedgeToDir[(w->mball.wedges - MINWEDGES) /
+				mapWedgeToDir[(w->mball.wedges - MIN_WEDGES) /
 				2][wedge], control);
 		else
 			MoveNoPieces(w);
