@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 2007	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1994 - 2007	David A. Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -214,29 +214,29 @@ static const char solveHelp[] = {
 #define SCOREFILE "mball.scores"
 #endif
 
-#define MAXRINGS 6
+#define MAX_RINGS 6
 #define NEVER (-1)
-#define FILENAMELEN 1024
-#define USERNAMELEN 120
-#define MESSAGELEN (USERNAMELEN+64)
-#define TITLELEN 2048
+#define FILE_NAME_LENGTH 1024
+#define USER_NAME_LENGTH 120
+#define MESSAGE_LENGTH (USER_NAME_LENGTH+64)
+#define TITLE_LENGTH 2048
 #define NOACCESS "noaccess"
 #define NOBODY "nobody"
 
 typedef struct {
 	int score;
-	char name[USERNAMELEN];
+	char name[USER_NAME_LENGTH];
 } PuzzleRecord;
 
-static PuzzleRecord puzzleRecord[2][(MAXWEDGES - MINWEDGES) / 2 + 1]
-[MAXRINGS - MINRINGS + 1];
+static PuzzleRecord puzzleRecord[2][(MAX_WEDGES - MIN_WEDGES) / 2 + 1]
+[MAX_RINGS - MIN_RINGS + 1];
 static int movesDsp = 0;
-static char messageDsp[MESSAGELEN] = "Welcome";
-static char recordDsp[MESSAGELEN] = "NOT RECORDED";
+static char messageDsp[MESSAGE_LENGTH] = "Welcome";
+static char recordDsp[MESSAGE_LENGTH] = "NOT RECORDED";
 
 #ifdef HAVE_MOTIF
 static Widget moves, record, message, orientizeSwitch, practiceSwitch;
-static Widget wedge[(MAXWEDGES - MINWEDGES) / 2 + 1], ring;
+static Widget wedge[(MAX_WEDGES - MIN_WEDGES) / 2 + 1], ring;
 static char buff[21];
 static const char *wedgeString[] =
 {
@@ -247,20 +247,20 @@ static Widget optionsDialog, referencesDialog, aboutDialog;
 static Widget solveDialog, practiceDialog, randomizeDialog;
 static Arg arg[3];
 #else
-static char titleDsp[TITLELEN] = "";
+static char titleDsp[TITLE_LENGTH] = "";
 #endif
-static char scoreFileName[FILENAMELEN] = SCOREFILE;
-static char fileName[FILENAMELEN];
+static char scoreFileName[FILE_NAME_LENGTH] = SCOREFILE;
+static char fileName[FILE_NAME_LENGTH];
 static Boolean randomized = False;
 #ifdef WINVER
-#define MAXPROGNAME 80
-static char progDsp[MAXPROGNAME] = TITLE;
-static char userNameDsp[USERNAMELEN] = "Guest";
+#define PROGRAM_NAME_LENGTH 80
+static char progDsp[PROGRAM_NAME_LENGTH] = TITLE;
+static char userNameDsp[USER_NAME_LENGTH] = "Guest";
 #else
 static Pixmap pixmap = None;
 static Widget topLevel, puzzle;
 static char *progDsp;
-static char userNameDsp[USERNAMELEN] = "";
+static char userNameDsp[USER_NAME_LENGTH] = "";
 
 #ifdef HAVE_MOTIF
 static void
@@ -283,8 +283,8 @@ PrintRecords(void)
 	(void) printf("              MBALL  HALL OF FAME\n\n");
 	(void) printf("ORIENT WEDGE RING USER            MOVES\n");
 	for (orient = 0; orient < 2; orient++)
-		for (i = 0; i < (MAXWEDGES - MINWEDGES) / 2 + 1; i++)
-			for (j = 0; j < MAXRINGS - MINRINGS + 1; j++) {
+		for (i = 0; i < (MAX_WEDGES - MIN_WEDGES) / 2 + 1; i++)
+			for (j = 0; j < MAX_RINGS - MIN_RINGS + 1; j++) {
 				if (puzzleRecord[orient][i][j].score > 0)
 					(void) printf("%6d%6d%5d %-12s%9d\n",
 						orient, 2 * i + 1, j + 1,
@@ -300,11 +300,11 @@ InitRecords(void)
 	int i, j, orient;
 
 	for (orient = 0; orient < 2; orient++)
-		for (i = 0; i < (MAXWEDGES - MINWEDGES) / 2 + 1; i++)
-			for (j = 0; j < MAXRINGS - MINRINGS + 1; j++) {
+		for (i = 0; i < (MAX_WEDGES - MIN_WEDGES) / 2 + 1; i++)
+			for (j = 0; j < MAX_RINGS - MIN_RINGS + 1; j++) {
 				puzzleRecord[orient][i][j].score = NEVER;
 				(void) strncpy(puzzleRecord[orient][i][j].name,
-					NOACCESS, USERNAMELEN);
+					NOACCESS, USER_NAME_LENGTH);
 			}
 }
 
@@ -313,7 +313,7 @@ ReadRecords(void)
 {
 	FILE *fp;
 	int i, j, n, orient;
-	char userName[USERNAMELEN];
+	char userName[USER_NAME_LENGTH];
 	char *buf1 = NULL, *buf2 = NULL;
 	char *fname, *lname;
 
@@ -323,9 +323,9 @@ ReadRecords(void)
 	stringCat(&buf2, buf1, SCOREFILE);
 	free(buf1);
 	fname = buf2;
-	(void) strncpy(fileName, lname, USERNAMELEN);
+	(void) strncpy(fileName, lname, USER_NAME_LENGTH);
 	if ((fp = fopen(fileName, "r")) == NULL) {
-		(void) strncpy(fileName, fname, USERNAMELEN);
+		(void) strncpy(fileName, fname, USER_NAME_LENGTH);
 		/* Try installed directory. */
 		if ((fp = fopen(fileName, "r")) == NULL) {
 			stringCat(&buf1, "Can not read ", fname);
@@ -355,14 +355,14 @@ ReadRecords(void)
 	free(lname);
 	free(fname);
 	for (orient = 0; orient < 2; orient++)
-		for (i = 0; i < (MAXWEDGES - MINWEDGES) / 2 + 1; i++)
-			for (j = 0; j < MAXRINGS - MINRINGS + 1; j++) {
+		for (i = 0; i < (MAX_WEDGES - MIN_WEDGES) / 2 + 1; i++)
+			for (j = 0; j < MAX_RINGS - MIN_RINGS + 1; j++) {
 				(void) fscanf(fp, "%d %s\n", &n, userName);
 				if (n <= puzzleRecord[orient][i][j].score ||
 						puzzleRecord[orient][i][j].score <= NEVER) {
 					puzzleRecord[orient][i][j].score = n;
 					(void) strncpy(puzzleRecord[orient][i][j].name,
-						userName, USERNAMELEN);
+						userName, USER_NAME_LENGTH);
 				}
 			}
 	(void) fclose(fp);
@@ -384,9 +384,9 @@ WriteRecords(void)
 	{
 #if HAVE_FCNTL_H
 		int lfd;
-		char lockFile[FILENAMELEN];
+		char lockFile[FILE_NAME_LENGTH];
 
-		(void) strncpy(lockFile, fileName, FILENAMELEN - 6);
+		(void) strncpy(lockFile, fileName, FILE_NAME_LENGTH - 6);
 		(void) strcat(lockFile, ".lock");
 		while (((lfd = open(lockFile, O_CREAT | O_EXCL, 0644)) < 0) &&
 				errno == EEXIST)
@@ -403,8 +403,8 @@ WriteRecords(void)
 		}
 #endif
 		for (orient = 0; orient < 2; orient++) {
-			for (i = 0; i < (MAXWEDGES - MINWEDGES) / 2 + 1; i++) {
-				for (j = 0; j < MAXRINGS - MINRINGS + 1; j++)
+			for (i = 0; i < (MAX_WEDGES - MIN_WEDGES) / 2 + 1; i++) {
+				for (j = 0; j < MAX_RINGS - MIN_RINGS + 1; j++)
 					(void) fprintf(fp, "%d %s\n",
 						puzzleRecord[orient][i][j].score,
 						puzzleRecord[orient][i][j].name);
@@ -424,13 +424,13 @@ static void
 PrintRecord(int wedges, int rings, Boolean orient, Boolean practice)
 {
 	int i = (orient) ? 1 : 0;
-	int w = (wedges - MINWEDGES) / 2;
-	int r = rings - MINRINGS;
+	int w = (wedges - MIN_WEDGES) / 2;
+	int r = rings - MIN_RINGS;
 
 	if (practice) {
-		(void) strncpy(recordDsp, "practice", MESSAGELEN);
-	} else if (rings > MAXRINGS) {
-		(void) strncpy(recordDsp, "NOT RECORDED", MESSAGELEN);
+		(void) strncpy(recordDsp, "practice", MESSAGE_LENGTH);
+	} else if (rings > MAX_RINGS) {
+		(void) strncpy(recordDsp, "NOT RECORDED", MESSAGE_LENGTH);
 	} else if (puzzleRecord[i][w][r].score <= NEVER) {
 		(void) sprintf(recordDsp, "NEVER %s", NOACCESS);
 	} else {
@@ -468,20 +468,20 @@ static Boolean
 HandleSolved(int counter, int wedges, int rings, Boolean orient)
 {
 	int i = (orient) ? 1 : 0;
-	int w = (wedges - MINWEDGES) / 2;
-	int r = rings - MINRINGS;
+	int w = (wedges - MIN_WEDGES) / 2;
+	int r = rings - MIN_RINGS;
 
-	if (rings <= MAXRINGS && (counter < puzzleRecord[i][w][r].score ||
+	if (rings <= MAX_RINGS && (counter < puzzleRecord[i][w][r].score ||
 			puzzleRecord[i][w][r].score <= NEVER)) {
 		ReadRecords();	/* Maybe its been updated by another */
 		puzzleRecord[i][w][r].score = counter;
 		(void) strncpy(puzzleRecord[i][w][r].name, userNameDsp,
-			USERNAMELEN);
+			USER_NAME_LENGTH);
 		if (orient && (counter < puzzleRecord[!i][w][r].score ||
 				puzzleRecord[!i][w][r].score <= NEVER)) {
 			puzzleRecord[!i][w][r].score = counter;
 			(void) strncpy(puzzleRecord[!i][w][r].name, userNameDsp,
-				USERNAMELEN);
+				USER_NAME_LENGTH);
 		}
 		WriteRecords();
 		PrintRecord(wedges, rings, orient, False);
@@ -513,7 +513,7 @@ Widget w
 	userName = w->mball.userName;
 	scoreFile = w->mball.scoreFile;
 	if (strcmp(scoreFile, ""))
-		(void) strncpy(scoreFileName, scoreFile, FILENAMELEN);
+		(void) strncpy(scoreFileName, scoreFile, FILE_NAME_LENGTH);
 #else
 	Boolean scoreOnly, versionOnly;
 
@@ -531,7 +531,7 @@ Widget w
 		exit(0);
 	}
 	if (strcmp(scoreFile, ""))
-		(void) strncpy(scoreFileName, scoreFile, FILENAMELEN);
+		(void) strncpy(scoreFileName, scoreFile, FILE_NAME_LENGTH);
 	if (scoreOnly) {
 		InitRecords();
 		ReadRecords();
@@ -539,8 +539,8 @@ Widget w
 		exit(0);
 	}
 #ifdef HAVE_MOTIF
-	XmToggleButtonSetState(wedge[(wedges - MINWEDGES) / 2], True, False);
-	if (rings > MAXRINGS)
+	XmToggleButtonSetState(wedge[(wedges - MIN_WEDGES) / 2], True, False);
+	if (rings > MAX_RINGS)
 		XtVaSetValues(ring, XmNmaximum, rings, NULL);
 	XmScaleSetValue(ring, rings);
 	XmToggleButtonSetState(orientizeSwitch, orient, True);
@@ -551,13 +551,13 @@ Widget w
 	InitRecords();
 	ReadRecords();
 #ifndef WINVER
-	(void) strncpy(userNameDsp, userName, USERNAMELEN);
+	(void) strncpy(userNameDsp, userName, USER_NAME_LENGTH);
 #endif
 	if (!strcmp(userName, "") || !strcmp(userName, "(null)") ||
 			!strcmp(userName, NOACCESS) ||
 			!strcmp(userName, NOBODY)) {
 #ifdef WINVER
-		(void) strncpy(userNameDsp, userName, USERNAMELEN);
+		(void) strncpy(userNameDsp, userName, USER_NAME_LENGTH);
 #else
 		char *login = getlogin();
 
@@ -647,14 +647,14 @@ CallbackPuzzle(Widget w, caddr_t clientData, mballCallbackStruct *callData)
 #ifdef HAVE_MOTIF
 		XtManageChild(solveDialog);
 #else
-		(void) strncpy(messageDsp, solveHelp, MESSAGELEN);
+		(void) strncpy(messageDsp, solveHelp, MESSAGE_LENGTH);
 #endif
 #endif
 		break;
 	case ACTION_RESTORE:
 		if (practice) {
 			(void) strncpy(recordDsp, "practice",
-				MESSAGELEN);
+				MESSAGE_LENGTH);
 #ifdef HAVE_MOTIF
 			PrintState(record, recordDsp);
 #endif
@@ -668,15 +668,15 @@ CallbackPuzzle(Widget w, caddr_t clientData, mballCallbackStruct *callData)
 		break;
 	case ACTION_AMBIGUOUS:
 		(void) strncpy(messageDsp, "Ambiguous move",
-			MESSAGELEN);
+			MESSAGE_LENGTH);
 		break;
 	case ACTION_ILLEGAL:
 		if (practice || randomized)
 			(void) strncpy(messageDsp, "Illegal move",
-				MESSAGELEN);
+				MESSAGE_LENGTH);
 		else
 			(void) strncpy(messageDsp,
-				"Randomize to start", MESSAGELEN);
+				"Randomize to start", MESSAGE_LENGTH);
 		break;
 	case ACTION_MOVED:
 		movesDsp++;
@@ -695,7 +695,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, mballCallbackStruct *callData)
 				"Congratulations %s!!", userNameDsp);
 		else
 			(void) strncpy(messageDsp, "Solved!",
-				MESSAGELEN);
+				MESSAGE_LENGTH);
 		SET_STARTED(w, False);
 		randomized = False;
 		break;
@@ -708,7 +708,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, mballCallbackStruct *callData)
 		practice = !practice;
 		if (!practice)
 			(void) strncpy(messageDsp, "Randomize to start",
-				MESSAGELEN);
+				MESSAGE_LENGTH);
 		PrintRecord(wedges, rings, orient, practice);
 #ifdef WINVER
 		w->mball.practice = practice;
@@ -743,7 +743,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, mballCallbackStruct *callData)
 #else
 		XtVaSetValues(w, XtNrings, rings, NULL);
 #ifdef HAVE_MOTIF
-		if (rings > MAXRINGS)
+		if (rings > MAX_RINGS)
 			XtVaSetValues(ring, XmNmaximum, rings, NULL);
 		XmScaleSetValue(ring, rings);
 #endif
@@ -759,7 +759,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, mballCallbackStruct *callData)
 		XtVaSetValues(w, XtNrings, rings, NULL);
 #ifdef HAVE_MOTIF
 		XmScaleSetValue(ring, rings);
-		if (rings >= MAXRINGS)
+		if (rings >= MAX_RINGS)
 			XtVaSetValues(ring, XmNmaximum, rings, NULL);
 #endif
 #endif
@@ -784,14 +784,14 @@ CallbackPuzzle(Widget w, caddr_t clientData, mballCallbackStruct *callData)
 	case ACTION_WEDGE10:
 	case ACTION_WEDGE12:
 		movesDsp = 0;
-		wedges = 2 * (reason - ACTION_WEDGE2) + MINWEDGES;
+		wedges = 2 * (reason - ACTION_WEDGE2) + MIN_WEDGES;
 		PrintRecord(wedges, rings, orient, practice);
 #ifdef WINVER
 		w->mball.wedges = wedges;
 #else
 		XtVaSetValues(w, XtNwedges, wedges, NULL);
 #ifdef HAVE_MOTIF
-		XmToggleButtonSetState(wedge[(wedges - MINWEDGES) / 2],
+		XmToggleButtonSetState(wedge[(wedges - MIN_WEDGES) / 2],
 			True, True);
 #endif
 #endif
@@ -1236,7 +1236,7 @@ WedgeToggle(Widget w, int bit, XmToggleButtonCallbackStruct *cbs)
 			XtNrings, &rings,
 			XtNorient, &orient,
 			XtNpractice, &practice, NULL);
-		wedges = bit * 2 + MINWEDGES;
+		wedges = bit * 2 + MIN_WEDGES;
 		XtVaSetValues(puzzle,
 			XtNwedges, wedges, NULL);
 		movesDsp = 0;
@@ -1318,7 +1318,7 @@ PracticeToggle(Widget w, XtPointer clientData,
 	if (practice)
 		(void) strcpy(messageDsp, "");
 	else
-		(void) strncpy(messageDsp, "Randomize to start", MESSAGELEN);
+		(void) strncpy(messageDsp, "Randomize to start", MESSAGE_LENGTH);
 	PrintState(message, messageDsp);
 }
 
@@ -1344,7 +1344,7 @@ static Widget
 createQuery(Widget w, char *text, char *title, XtCallbackProc callback)
 {
 	Widget button, messageBox;
-	char titleDsp[FILENAMELEN + 8];
+	char titleDsp[FILE_NAME_LENGTH + 8];
 	XmString titleString = NULL, messageString = NULL;
 	static XmStringCharSet charSet =
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
@@ -1370,7 +1370,7 @@ static Widget
 createHelp(Widget w, char *text, char *title)
 {
 	Widget button, messageBox;
-	char titleDsp[FILENAMELEN + 8];
+	char titleDsp[FILE_NAME_LENGTH + 8];
 	XmString titleString = NULL, messageString = NULL, buttonString = NULL;
 	static XmStringCharSet charSet =
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
@@ -1653,21 +1653,21 @@ main(int argc, char **argv)
 	ring = XtVaCreateManagedWidget("ring",
 		xmScaleWidgetClass, ringsRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Rings", 6,
-		XmNminimum, MINRINGS,
-		XmNmaximum, MAXRINGS,
-		XmNvalue, DEFAULTRINGS,
+		XmNminimum, MIN_RINGS,
+		XmNmaximum, MAX_RINGS,
+		XmNvalue, DEFAULT_RINGS,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
 	XtAddCallback(ring, XmNvalueChangedCallback,
 		(XtCallbackProc) RingSlider, (XtPointer) NULL);
 	orientizeSwitch = XtVaCreateManagedWidget("Oriented",
 		xmToggleButtonWidgetClass, ringsRowCol,
-		XmNset, DEFAULTORIENT, NULL);
+		XmNset, DEFAULT_ORIENT, NULL);
 	XtAddCallback(orientizeSwitch, XmNvalueChangedCallback,
 		(XtCallbackProc) OrientToggle, (XtPointer) NULL);
 	practiceSwitch = XtVaCreateManagedWidget("Practice",
 		xmToggleButtonWidgetClass, ringsRowCol,
-		XmNset, DEFAULTPRACTICE, NULL);
+		XmNset, DEFAULT_PRACTICE, NULL);
 	XtAddCallback(practiceSwitch, XmNvalueChangedCallback,
 		(XtCallbackProc) PracticeToggle, (XtPointer) NULL);
 	messageRowCol = XtVaCreateManagedWidget("messageRowCol",
