@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 2007	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1994 - 2008	David A. Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -55,7 +55,7 @@
 #endif
 #define SECTION "setup"
 
-static const char *faceColorString[MAXFACES] =
+static const char *faceColorString[MAX_FACES] =
 {
 	"255 255 255",
 	"255 255 0",
@@ -67,7 +67,7 @@ static const char *faceColorString[MAXFACES] =
 	"255 165 0"
 };
 
-static char faceColorChar[MAXFACES] =
+static char faceColorChar[MAX_FACES] =
 {'W', 'Y', 'G', 'R', 'B', 'M', 'C', 'O'};
 #else
 #include "picture.h"
@@ -278,7 +278,7 @@ static XtResource resourcesPuzzle[] =
 	 XtRString, (caddr_t) PICTURE},
 	{XtNdelay, XtCDelay, XtRInt, sizeof (int),
 	 XtOffset(MlinkWidget, mlink.delay),
-	 XtRString, (caddr_t) "10"}, /* DEFAULTDELAY */
+	 XtRString, (caddr_t) "10"}, /* DEFAULT_DELAY */
 	{XtNsound, XtCSound, XtRBoolean, sizeof (Boolean),
 	 XtOffset(MlinkWidget, mlink.sound),
 	 XtRString, (caddr_t) "FALSE"},
@@ -293,22 +293,22 @@ static XtResource resourcesPuzzle[] =
 	 XtRString, (caddr_t) "9x15bold"},
 	{XtNtiles, XtCTiles, XtRInt, sizeof (int),
 	 XtOffset(MlinkWidget, mlink.tiles),
-	 XtRString, (caddr_t) "4"}, /* DEFAULTTILES */
+	 XtRString, (caddr_t) "4"}, /* DEFAULT_TILES */
 	{XtNfaces, XtCFaces, XtRInt, sizeof (int),
 	 XtOffset(MlinkWidget, mlink.faces),
-	 XtRString, (caddr_t) "4"}, /* DEFAULTFACES */
+	 XtRString, (caddr_t) "4"}, /* DEFAULT_FACES */
 	{XtNorient, XtCOrient, XtRBoolean, sizeof (Boolean),
 	 XtOffset(MlinkWidget, mlink.orient),
-	 XtRString, (caddr_t) "FALSE"}, /* DEFAULTORIENT */
+	 XtRString, (caddr_t) "FALSE"}, /* DEFAULT_ORIENT */
 	{XtNmiddle, XtCMiddle, XtRBoolean, sizeof (Boolean),
 	 XtOffset(MlinkWidget, mlink.middle),
-	 XtRString, (caddr_t) "TRUE"}, /* DEFAULTMIDDLE */
+	 XtRString, (caddr_t) "TRUE"}, /* DEFAULT_MIDDLE */
 	{XtNpractice, XtCPractice, XtRBoolean, sizeof (Boolean),
 	 XtOffset(MlinkWidget, mlink.practice),
-	 XtRString, (caddr_t) "TRUE"}, /* DEFAULTPRACTICE */
+	 XtRString, (caddr_t) "TRUE"}, /* DEFAULT_PRACTICE */
 	{XtNbase, XtCBase, XtRInt, sizeof (int),
 	 XtOffset(MlinkWidget, mlink.base),
-	 XtRString, (caddr_t) "10"}, /* DEFAULTBASE */
+	 XtRString, (caddr_t) "10"}, /* DEFAULT_BASE */
 	{XtNuserName, XtCUserName, XtRString, sizeof (String),
 	 XtOffset(MlinkWidget, mlink.userName),
 	 XtRString, (caddr_t) ""},
@@ -442,47 +442,47 @@ CheckTiles(MlinkWidget w)
 {
 	char *buf1 = NULL, *buf2 = NULL;
 
-	if (w->mlink.tiles < MINTILES) {
+	if (w->mlink.tiles < MIN_TILES) {
 		intCat(&buf1,
 			"Number of tiles in X direction out of bounds, use at least ",
-			MINTILES);
+			MIN_TILES);
 		stringCat(&buf2, buf1, ", defaulting to ");
 		free(buf1);
-		intCat(&buf1, buf2, DEFAULTTILES);
+		intCat(&buf1, buf2, DEFAULT_TILES);
 		free(buf2);
 		DISPLAY_WARNING(buf1);
 		free(buf1);
-		w->mlink.tiles = DEFAULTTILES;
+		w->mlink.tiles = DEFAULT_TILES;
 	}
-	if (w->mlink.faces < MINFACES || w->mlink.faces > MAXFACES) {
+	if (w->mlink.faces < MIN_FACES || w->mlink.faces > MAX_FACES) {
 		intCat(&buf1,
 			"Number of faces out of bounds, use ",
-			MINFACES);
+			MIN_FACES);
 		stringCat(&buf2, buf1, "..");
 		free(buf1);
-		intCat(&buf1, buf2, MAXFACES);
+		intCat(&buf1, buf2, MAX_FACES);
 		free(buf2);
 		stringCat(&buf2, buf1, ", defaulting to ");
 		free(buf1);
-		intCat(&buf1, buf2, DEFAULTFACES);
+		intCat(&buf1, buf2, DEFAULT_FACES);
 		free(buf2);
 		DISPLAY_WARNING(buf1);
 		free(buf1);
-		w->mlink.faces = DEFAULTFACES;
+		w->mlink.faces = DEFAULT_FACES;
 	}
-	if (w->mlink.base < MINBASE || w->mlink.base > MAXBASE) {
-		intCat(&buf1, "Base out of bounds, use ", MINBASE);
+	if (w->mlink.base < MIN_BASE || w->mlink.base > MAX_BASE) {
+		intCat(&buf1, "Base out of bounds, use ", MIN_BASE);
 		stringCat(&buf2, buf1, "..");
 		free(buf1);
-		intCat(&buf1, buf2, MAXBASE);
+		intCat(&buf1, buf2, MAX_BASE);
 		free(buf2);
 		stringCat(&buf2, buf1, ", defaulting to ");
 		free(buf1);
-		intCat(&buf1, buf2, DEFAULTBASE);
+		intCat(&buf1, buf2, DEFAULT_BASE);
 		free(buf2);
 		DISPLAY_WARNING(buf1);
 		free(buf1);
-		w->mlink.base = DEFAULTBASE;
+		w->mlink.base = DEFAULT_BASE;
 	}
 }
 
@@ -783,7 +783,7 @@ DrawTile(MlinkWidget w, int pos, Boolean blank, Boolean erase,
 	sy = CartesianY(w, tile);
 	if (blank) {
 		FILLRECTANGLE(w, dr,
-			(erase) ? w->mlink.inverseGC : w->mlink.tileGC,
+			(erase) ? w->mlink.inverseGC : w->mlink.tileGC[1],
 			dx, dy,
 			w->mlink.tileSize.x, w->mlink.tileSize.y);
 		return;
@@ -799,11 +799,11 @@ DrawTile(MlinkWidget w, int pos, Boolean blank, Boolean erase,
 		SRCCOPY);
 	(void) SelectObject(w->core.memDC, w->core.hOldBitmap);
 #else
-	XSetGraphicsExposures(XtDisplay(w), w->mlink.tileGC, False);
+	XSetGraphicsExposures(XtDisplay(w), w->mlink.tileGC[1], False);
 	XCopyArea(XtDisplay(w),
 		w->mlink.bufferTiles[pressedOffset],
 		XtWindow(w),
-		w->mlink.tileGC,
+		w->mlink.tileGC[1],
 		sx, sy,
 		w->mlink.tileSize.x, w->mlink.tileSize.y,
 		dx, dy);
@@ -820,7 +820,7 @@ DrawBufferedTile(MlinkWidget w, int pos, int pressedOffset)
 	char buf[66];
 
 	dr = &(w->mlink.bufferTiles[pressedOffset]);
-	tileGC = w->mlink.tileGC;
+	tileGC = w->mlink.tileGC[1];
 	borderGC = w->mlink.borderGC;
 	if (w->mlink.mono && pressedOffset) {
 		linkGC = borderGC;
@@ -839,12 +839,12 @@ DrawBufferedTile(MlinkWidget w, int pos, int pressedOffset)
 	dx = CartesianX(w, pos) + pressedOffset;
 	dy = CartesianY(w, pos) + pressedOffset;
 	if (pressedOffset != 0) {
-		drawShadow(w, *dr, w->mlink.tileDarkerGC,
+		drawShadow(w, *dr, w->mlink.tileGC[2],
 			dx - pressedOffset, dy - pressedOffset,
 			w->mlink.tileSize.x - 1, w->mlink.tileSize.y - 1);
 	}
 	fill3DRect(w, *dr, tileGC,
-		w->mlink.tileDarkerGC, w->mlink.tileBrighterGC,
+		w->mlink.tileGC[2], w->mlink.tileGC[0],
 		dx, dy, w->mlink.tileSize.x, w->mlink.tileSize.y,
 		pressedOffset == 0);
 	buf[0] = '\0';
@@ -1354,7 +1354,7 @@ ControlPuzzle(MlinkWidget w, int direction)
 {
 	switch (direction) {
 	case TOP:
-		if (w->mlink.faces <= MINFACES)
+		if (w->mlink.faces <= MIN_FACES)
 			return;
 		setPuzzle(w, ACTION_DECY);
 		break;
@@ -1362,12 +1362,12 @@ ControlPuzzle(MlinkWidget w, int direction)
 		setPuzzle(w, ACTION_INCX);
 		break;
 	case BOTTOM:
-		if (w->mlink.faces >= MAXFACES)
+		if (w->mlink.faces >= MAX_FACES)
 			return;
 		setPuzzle(w, ACTION_INCY);
 		break;
 	case LEFT:
-		if (w->mlink.tiles <= MINTILES)
+		if (w->mlink.tiles <= MIN_TILES)
 			return;
 		setPuzzle(w, ACTION_DECX);
 		break;
@@ -1674,7 +1674,7 @@ GetTiles(MlinkWidget w)
 	flushMoves(w, &redo, FALSE);
 	while ((c = getc(fp)) != EOF && c != SYMBOL);
 	(void) fscanf(fp, "%d", &tiles);
-	if (tiles >= MINTILES) {
+	if (tiles >= MIN_TILES) {
 		for (i = w->mlink.tiles; i < tiles; i++) {
 			setPuzzle(w, ACTION_INCX);
 		}
@@ -1687,7 +1687,7 @@ GetTiles(MlinkWidget w)
 		free(buf1);
 		stringCat(&buf1, buf2, " should be between ");
 		free(buf2);
-		intCat(&buf2, buf1, MINTILES);
+		intCat(&buf2, buf1, MIN_TILES);
 		free(buf1);
 		stringCat(&buf1, buf2, " and MAXINT");
 		free(buf2);
@@ -1696,7 +1696,7 @@ GetTiles(MlinkWidget w)
 	}
 	while ((c = getc(fp)) != EOF && c != SYMBOL);
 	(void) fscanf(fp, "%d", &faces);
-	if (faces >= MINFACES && faces <= MAXFACES) {
+	if (faces >= MIN_FACES && faces <= MAX_FACES) {
 		for (i = w->mlink.faces; i < faces; i++) {
 			setPuzzle(w, ACTION_INCY);
 		}
@@ -1709,11 +1709,11 @@ GetTiles(MlinkWidget w)
 		free(buf1);
 		stringCat(&buf1, buf2, " should be between ");
 		free(buf2);
-		intCat(&buf2, buf1, MINFACES);
+		intCat(&buf2, buf1, MIN_FACES);
 		free(buf1);
 		stringCat(&buf1, buf2, " and ");
 		free(buf2);
-		intCat(&buf2, buf1, MAXFACES);
+		intCat(&buf2, buf1, MAX_FACES);
 		free(buf1);
 		DISPLAY_WARNING(buf2);
 		free(buf2);
@@ -2041,24 +2041,26 @@ SoundTiles(MlinkWidget w)
 	w->mlink.sound = !w->mlink.sound;
 }
 
-#define FACTOR 0.7
+#define BRIGHT_FACTOR 0.8
+#define DARK_FACTOR 0.75
+
 #ifdef WINVER
-#define MAXINTENSITY 0xFF
+#define MAX_INTENSITY 0xFF
 static int
 brighter(const int light)
 {
-	int i = (int) ((1 - FACTOR) * MAXINTENSITY);
+	int i = (int) ((1 - BRIGHT_FACTOR) * MAX_INTENSITY);
 	int temp = light;
 
 	if (temp < i)
 		temp = i;
-	return MIN(temp / FACTOR, MAXINTENSITY);
+	return MIN(temp / BRIGHT_FACTOR, MAX_INTENSITY);
 }
 
 static int
 darker(const int light)
 {
-	return (int) (light * FACTOR);
+	return (int) (light * DARK_FACTOR);
 }
 
 static void
@@ -2071,21 +2073,21 @@ SetValuesPuzzle(MlinkWidget w)
 	int face;
 
 	w->mlink.tiles = GetPrivateProfileInt(SECTION, "tiles",
-		DEFAULTTILES, INIFILE);
+		DEFAULT_TILES, INIFILE);
 	w->mlink.faces = GetPrivateProfileInt(SECTION, "faces",
-		DEFAULTFACES, INIFILE);
+		DEFAULT_FACES, INIFILE);
 	w->mlink.orient = (BOOL) GetPrivateProfileInt(SECTION, "orient",
-		DEFAULTORIENT, INIFILE);
+		DEFAULT_ORIENT, INIFILE);
 	w->mlink.middle = (BOOL) GetPrivateProfileInt(SECTION, "middle",
-		DEFAULTMIDDLE, INIFILE);
+		DEFAULT_MIDDLE, INIFILE);
 	w->mlink.practice = (BOOL) GetPrivateProfileInt(SECTION, "practice",
-		DEFAULTPRACTICE, INIFILE);
+		DEFAULT_PRACTICE, INIFILE);
 	w->mlink.base = GetPrivateProfileInt(SECTION, "base",
-		DEFAULTBASE, INIFILE);
+		DEFAULT_BASE, INIFILE);
 	w->mlink.mono = (BOOL) GetPrivateProfileInt(SECTION, "mono",
-		DEFAULTMONO, INIFILE);
+		DEFAULT_MONO, INIFILE);
 	w->mlink.reverse = (BOOL) GetPrivateProfileInt(SECTION, "reverseVideo",
-		DEFAULTREVERSE, INIFILE);
+		DEFAULT_REVERSE, INIFILE);
 	/* cyan */
 	(void) GetPrivateProfileString(SECTION, "frameColor", "0 255 255",
 		szBuf, sizeof (szBuf), INIFILE);
@@ -2097,15 +2099,15 @@ SetValuesPuzzle(MlinkWidget w)
 		szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
-	w->mlink.tileGC = RGB(color.red, color.green, color.blue);
+	w->mlink.tileGC[1] = RGB(color.red, color.green, color.blue);
 	/* gray25 */
 	(void) GetPrivateProfileString(SECTION, "tileBorder", "64 64 64",
 		szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
-	w->mlink.tileBrighterGC = RGB(brighter(color.red),
+	w->mlink.tileGC[0] = RGB(brighter(color.red),
 		brighter(color.green), brighter(color.blue));
-	w->mlink.tileDarkerGC = RGB(darker(color.red),
+	w->mlink.tileGC[2] = RGB(darker(color.red),
 		darker(color.green), darker(color.blue));
 	w->mlink.borderGC = RGB(color.red, color.green, color.blue);
 	/* #AEB2C3 */
@@ -2114,7 +2116,7 @@ SetValuesPuzzle(MlinkWidget w)
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
 	w->mlink.inverseGC = RGB(color.red, color.green, color.blue);
-	for (face = 0; face < MAXFACES; face++) {
+	for (face = 0; face < MAX_FACES; face++) {
 		(void) sprintf(buf, "faceColor%d", face);
 		(void) GetPrivateProfileString(SECTION,
 			buf, faceColorString[face],
@@ -2135,7 +2137,7 @@ SetValuesPuzzle(MlinkWidget w)
 	(void) strcpy(w->mlink.picture, szBuf);
 	w->mlink.picture[80] = 0;
 	w->mlink.delay = GetPrivateProfileInt(SECTION, "delay",
-		DEFAULTDELAY, INIFILE);
+		DEFAULT_DELAY, INIFILE);
 	w->mlink.sound = (BOOL)
 		GetPrivateProfileInt(SECTION, "sound", 0, INIFILE);
 	(void) GetPrivateProfileString(SECTION, "bumpSound", BUMPSOUND,
@@ -2173,7 +2175,7 @@ DestroyPuzzle(MlinkWidget w, HBRUSH brush)
 }
 
 #else
-#define MAXINTENSITY 0xFFFF
+#define MAX_INTENSITY 0xFFFF
 
 static Pixel
 brighter(MlinkWidget w, Pixel pixel)
@@ -2181,19 +2183,19 @@ brighter(MlinkWidget w, Pixel pixel)
 	XColor color;
 	Colormap colormap = (w->mlink.colormap == None) ?
 		w->mlink.oldColormap : w->mlink.colormap;
-	int i = (int) ((1 - FACTOR) * MAXINTENSITY);
+	int i = (int) ((1 - BRIGHT_FACTOR) * MAX_INTENSITY);
 
 	color.pixel = pixel;
-	XQueryColor(XtDisplay(w), colormap, &color);
+	VOID XQueryColor(XtDisplay(w), colormap, &color);
 	if (color.red < i)
 		color.red = i;
 	if (color.green < i)
 		color.green = i;
 	if (color.blue < i)
 		color.blue = i;
-	color.red = (unsigned short) MIN(color.red / FACTOR, MAXINTENSITY);
-	color.green = (unsigned short) MIN(color.green / FACTOR, MAXINTENSITY);
-	color.blue = (unsigned short) MIN(color.blue / FACTOR, MAXINTENSITY);
+	color.red = (unsigned short) MIN(color.red / BRIGHT_FACTOR, MAX_INTENSITY);
+	color.green = (unsigned short) MIN(color.green / BRIGHT_FACTOR, MAX_INTENSITY);
+	color.blue = (unsigned short) MIN(color.blue / BRIGHT_FACTOR, MAX_INTENSITY);
 	if (XAllocColor(XtDisplay(w), colormap, &color))
 		return color.pixel;
 	return pixel;
@@ -2207,10 +2209,10 @@ darker(MlinkWidget w, Pixel pixel)
 		w->mlink.oldColormap : w->mlink.colormap;
 
 	color.pixel = pixel;
-	XQueryColor(XtDisplay(w), colormap, &color);
-	color.red = (unsigned short) (color.red * FACTOR);
-	color.green = (unsigned short) (color.green * FACTOR);
-	color.blue = (unsigned short) (color.blue * FACTOR);
+	VOID XQueryColor(XtDisplay(w), colormap, &color);
+	color.red = (unsigned short) (color.red * DARK_FACTOR);
+	color.green = (unsigned short) (color.green * DARK_FACTOR);
+	color.blue = (unsigned short) (color.blue * DARK_FACTOR);
 	if (XAllocColor(XtDisplay(w), colormap, &color))
 		return color.pixel;
 	return pixel;
@@ -2317,20 +2319,20 @@ SetAllColors(MlinkWidget w)
 		values.background = w->mlink.borderColor;
 	}
 	if (w->mlink.tileGC)
-		XtReleaseGC((Widget) w, w->mlink.tileGC);
-	w->mlink.tileGC = XtGetGC((Widget) w, valueMask, &values);
+		XtReleaseGC((Widget) w, w->mlink.tileGC[1]);
+	w->mlink.tileGC[1] = XtGetGC((Widget) w, valueMask, &values);
 	if (!w->mlink.mono) {
 		values.foreground = darker(w, w->mlink.tileColor);
 	}
-	if (w->mlink.tileBrighterGC)
-		XtReleaseGC((Widget) w, w->mlink.tileBrighterGC);
-	w->mlink.tileBrighterGC = XtGetGC((Widget) w, valueMask, &values);
+	if (w->mlink.tileGC[0])
+		XtReleaseGC((Widget) w, w->mlink.tileGC[0]);
+	w->mlink.tileGC[0] = XtGetGC((Widget) w, valueMask, &values);
 	if (!w->mlink.mono) {
 		values.foreground = brighter(w, w->mlink.tileColor);
 	}
-	if (w->mlink.tileDarkerGC)
-		XtReleaseGC((Widget) w, w->mlink.tileDarkerGC);
-	w->mlink.tileDarkerGC = XtGetGC((Widget) w, valueMask, &values);
+	if (w->mlink.tileGC[2])
+		XtReleaseGC((Widget) w, w->mlink.tileGC[2]);
+	w->mlink.tileGC[2] = XtGetGC((Widget) w, valueMask, &values);
 	if (w->mlink.mono) {
 		if (w->mlink.reverse) {
 			values.foreground = w->mlink.foreground;
@@ -2349,7 +2351,7 @@ SetAllColors(MlinkWidget w)
 	if (w->mlink.fontInfo)
 		XSetFont(XtDisplay(w), w->mlink.borderGC,
 			w->mlink.fontInfo->fid);
-	for (face = 0; face < MAXFACES; face++)
+	for (face = 0; face < MAX_FACES; face++)
 		GetColor(w, face);
 }
 
@@ -2362,7 +2364,7 @@ SetValuesPuzzle(Widget current, Widget request, Widget renew)
 	int face;
 
 	CheckTiles(w);
-	for (face = 0; face < MAXFACES; face++) {
+	for (face = 0; face < MAX_FACES; face++) {
 		if (strcmp(w->mlink.faceName[face], c->mlink.faceName[face])) {
 			setColors = True;
 			break;
@@ -2396,8 +2398,8 @@ SetValuesPuzzle(Widget current, Widget request, Widget renew)
 		redraw = True;
 	}
 	if (w->mlink.delay != c->mlink.delay) {
-		w->mlink.numSlices = ((w->mlink.delay < MAXSLICES) ?
-			w->mlink.delay + 1 : MAXSLICES);
+		w->mlink.numSlices = ((w->mlink.delay < MAX_SLICES) ?
+			w->mlink.delay + 1 : MAX_SLICES);
 	}
 	if (w->mlink.menu != ACTION_IGNORE) {
 		int menu = w->mlink.menu;
@@ -2461,14 +2463,13 @@ DestroyPuzzle(Widget old)
 {
 	MlinkWidget w = (MlinkWidget) old;
 	Display *display = XtDisplay(w);
-	int face, sel;
+	int i;
 
-	for (face = 0; face < MAXFACES; face++)
-		XtReleaseGC(old, w->mlink.faceGC[face]);
-	XtReleaseGC(old, w->mlink.tileGC);
+	for (i = 0; i < MAX_FACES; i++)
+		XtReleaseGC(old, w->mlink.faceGC[i]);
 	XtReleaseGC(old, w->mlink.borderGC);
-	XtReleaseGC(old, w->mlink.tileBrighterGC);
-	XtReleaseGC(old, w->mlink.tileDarkerGC);
+	for (i = 0; i < FG_SHADES; i++)
+		XtReleaseGC(old, w->mlink.tileGC[i]);
 	XtReleaseGC(old, w->mlink.frameGC);
 	XtReleaseGC(old, w->mlink.inverseGC);
 	XtRemoveCallbacks(old, XtNselectCallback, w->mlink.select);
@@ -2476,9 +2477,9 @@ DestroyPuzzle(Widget old)
 		XInstallColormap(display, w->mlink.oldColormap);
 		XFreeColormap(display, w->mlink.colormap);
 	}
-	for (sel = 0; sel < 2; sel++)
-		if (w->mlink.bufferTiles[sel] != None)
-			XFreePixmap(display, w->mlink.bufferTiles[sel]);
+	for (i = 0; i < 2; i++)
+		if (w->mlink.bufferTiles[i] != None)
+			XFreePixmap(display, w->mlink.bufferTiles[i]);
 	if (w->mlink.fontInfo) {
 		XUnloadFont(display, w->mlink.fontInfo->fid);
 		XFreeFont(display, w->mlink.fontInfo);
@@ -2657,7 +2658,7 @@ Widget request, Widget renew
 	w->mlink.bufferTiles[1] = NULL;
 #else
 	MlinkWidget w = (MlinkWidget) renew;
-	int face;
+	int i;
 
 	(void) SRAND(getpid());
 	w->mlink.bufferTiles[0] = None;
@@ -2665,12 +2666,11 @@ Widget request, Widget renew
 	w->mlink.colormap = None;
 	w->mlink.oldColormap = None;
 	w->mlink.fontInfo = NULL;
-	for (face = 0; face < MAXFACES; face++)
-		w->mlink.faceGC[face] = NULL;
-	w->mlink.tileGC = NULL;
+	for (i = 0; i < MAX_FACES; i++)
+		w->mlink.faceGC[i] = NULL;
+	for (i = 0; i < FG_SHADES; i++)
+		w->mlink.tileGC[i] = NULL;
 	w->mlink.borderGC = NULL;
-	w->mlink.tileBrighterGC = NULL;
-	w->mlink.tileDarkerGC = NULL;
 	w->mlink.frameGC = NULL;
 	w->mlink.inverseGC = NULL;
 	w->mlink.image = NULL;
@@ -2681,8 +2681,8 @@ Widget request, Widget renew
 	CheckTiles(w);
 	newMoves(&undo);
 	newMoves(&redo);
-	w->mlink.numSlices = ((w->mlink.delay < MAXSLICES) ?
-		w->mlink.delay + 1 : MAXSLICES);
+	w->mlink.numSlices = ((w->mlink.delay < MAX_SLICES) ?
+		w->mlink.delay + 1 : MAX_SLICES);
 	w->mlink.cheat = False;
 	SizePuzzle(w);
 }
