@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 2007	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1994 - 2007	David A. Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -204,29 +204,29 @@ static const char solveHelp[] = {
 #define SCOREFILE "mlink.scores"
 #endif
 
-#define MAXTILES 8
+#define MAX_TILES 8
 #define NEVER (-1)
-#define FILENAMELEN 1024
-#define USERNAMELEN 120
-#define MESSAGELEN (USERNAMELEN+64)
-#define TITLELEN 2048
+#define FILE_NAME_LENGTH 1024
+#define USER_NAME_LENGTH 120
+#define MESSAGE_LENGTH (USER_NAME_LENGTH+64)
+#define TITLE_LENGTH 2048
 #define NOACCESS "noaccess"
 #define NOBODY "nobody"
 
 typedef struct {
 	int score;
-	char name[USERNAMELEN];
+	char name[USER_NAME_LENGTH];
 } PuzzleRecord;
 
 static PuzzleRecord puzzleRecord[2][2]
-[MAXFACES - MINFACES + 1][MAXTILES - MINTILES + 1];
+[MAX_FACES - MIN_FACES + 1][MAX_TILES - MIN_TILES + 1];
 static int movesDsp = 0;
-static char messageDsp[MESSAGELEN] = "Welcome";
-static char recordDsp[MESSAGELEN] = "NOT RECORDED";
+static char messageDsp[MESSAGE_LENGTH] = "Welcome";
+static char recordDsp[MESSAGE_LENGTH] = "NOT RECORDED";
 
 #ifdef HAVE_MOTIF
-#define MINSPEED 1
-#define MAXSPEED 50
+#define MIN_SPEED 1
+#define MAX_SPEED 50
 static Widget moves, record, message;
 static Widget orientizeSwitch, middleSwitch, practiceSwitch, tile, face, speed;
 static char buff[21];
@@ -235,19 +235,19 @@ static Widget optionsDialog, referencesDialog, aboutDialog;
 static Widget solveDialog, practiceDialog, randomizeDialog;
 static Arg arg[3];
 #else
-static char titleDsp[TITLELEN] = "";
+static char titleDsp[TITLE_LENGTH] = "";
 #endif
-static char scoreFileName[FILENAMELEN] = SCOREFILE;
-static char fileName[FILENAMELEN];
+static char scoreFileName[FILE_NAME_LENGTH] = SCOREFILE;
+static char fileName[FILE_NAME_LENGTH];
 #ifdef WINVER
-#define MAXPROGNAME 80
-static char progDsp[MAXPROGNAME] = TITLE;
-static char userNameDsp[USERNAMELEN] = "Guest";
+#define PROGRAM_NAME_LENGTH 80
+static char progDsp[PROGRAM_NAME_LENGTH] = TITLE;
+static char userNameDsp[USER_NAME_LENGTH] = "Guest";
 #else
 static Pixmap pixmap = None;
 static Widget topLevel, puzzle;
 static char *progDsp;
-static char userNameDsp[USERNAMELEN] = "";
+static char userNameDsp[USER_NAME_LENGTH] = "";
 
 #ifdef HAVE_MOTIF
 static void
@@ -271,8 +271,8 @@ PrintRecords(void)
 	(void) printf("MIDDLE ORIENT FACE TILE USER            MOVES\n");
 	for (l = 0; l < 2; l++)
 		for (k = 0; k < 2; k++)
-			for (j = 0; j < MAXFACES - MINFACES + 1; j++)
-				for (i = 0; i < MAXTILES - MINTILES + 1; i++) {
+			for (j = 0; j < MAX_FACES - MIN_FACES + 1; j++)
+				for (i = 0; i < MAX_TILES - MIN_TILES + 1; i++) {
 					if (puzzleRecord[l][k][j][i].score > 0)
 						(void) printf("%6d%7d%5d%5d %-12s%9d\n",
 							l, k, j + 1, i + 1,
@@ -289,11 +289,11 @@ InitRecords(void)
 
 	for (l = 0; l < 2; l++)
 		for (k = 0; k < 2; k++)
-			for (j = 0; j < MAXFACES - MINFACES + 1; j++)
-				for (i = 0; i < MAXTILES - MINTILES + 1; i++) {
+			for (j = 0; j < MAX_FACES - MIN_FACES + 1; j++)
+				for (i = 0; i < MAX_TILES - MIN_TILES + 1; i++) {
 					puzzleRecord[l][k][j][i].score = NEVER;
 					(void) strncpy(puzzleRecord[l][k][j][i].name,
-						NOACCESS, USERNAMELEN);
+						NOACCESS, USER_NAME_LENGTH);
 				}
 }
 
@@ -302,7 +302,7 @@ ReadRecords(void)
 {
 	FILE *fp;
 	int i, j, k, l, n;
-	char userName[USERNAMELEN];
+	char userName[USER_NAME_LENGTH];
 	char *buf1 = NULL, *buf2 = NULL;
 	char *fname, *lname;
 
@@ -312,9 +312,9 @@ ReadRecords(void)
 	stringCat(&buf2, buf1, SCOREFILE);
 	free(buf1);
 	fname = buf2;
-	(void) strncpy(fileName, lname, USERNAMELEN);
+	(void) strncpy(fileName, lname, USER_NAME_LENGTH);
 	if ((fp = fopen(fileName, "r")) == NULL) {
-		(void) strncpy(fileName, fname, USERNAMELEN);
+		(void) strncpy(fileName, fname, USER_NAME_LENGTH);
 		/* Try installed directory. */
 		if ((fp = fopen(fileName, "r")) == NULL) {
 			stringCat(&buf1, "Can not read ", fname);
@@ -345,14 +345,14 @@ ReadRecords(void)
 	free(fname);
 	for (l = 0; l < 2; l++)
 		for (k = 0; k < 2; k++)
-			for (j = 0; j < MAXFACES - MINFACES + 1; j++)
-				for (i = 0; i < MAXTILES - MINTILES + 1; i++) {
+			for (j = 0; j < MAX_FACES - MIN_FACES + 1; j++)
+				for (i = 0; i < MAX_TILES - MIN_TILES + 1; i++) {
 					(void) fscanf(fp, "%d %s\n", &n, userName);
 					if (n <= puzzleRecord[l][k][j][i].score ||
 							puzzleRecord[l][k][j][i].score <= NEVER) {
 						puzzleRecord[l][k][j][i].score = n;
 						(void) strncpy(puzzleRecord[l][k][j][i].name,
-							userName, USERNAMELEN);
+							userName, USER_NAME_LENGTH);
 					}
 				}
 	(void) fclose(fp);
@@ -374,9 +374,9 @@ WriteRecords(void)
 	{
 #if HAVE_FCNTL_H
 		int lfd;
-		char lockFile[FILENAMELEN];
+		char lockFile[FILE_NAME_LENGTH];
 
-		(void) strncpy(lockFile, fileName, FILENAMELEN - 6);
+		(void) strncpy(lockFile, fileName, FILE_NAME_LENGTH - 6);
 		(void) strcat(lockFile, ".lock");
 		while (((lfd = open(lockFile, O_CREAT | O_EXCL, 0644)) < 0) &&
 				errno == EEXIST)
@@ -394,8 +394,8 @@ WriteRecords(void)
 #endif
 		for (l = 0; l < 2; l++) {
 			for (k = 0; k < 2; k++) {
-				for (j = 0; j < MAXFACES - MINFACES + 1; j++) {
-					for (i = 0; i < MAXTILES - MINTILES + 1; i++)
+				for (j = 0; j < MAX_FACES - MIN_FACES + 1; j++) {
+					for (i = 0; i < MAX_TILES - MIN_TILES + 1; i++)
 						(void) fprintf(fp, "%d %s\n",
 							puzzleRecord[l][k][j][i].score, puzzleRecord[l][k][j][i].name);
 					(void) fprintf(fp, "\n");
@@ -416,13 +416,13 @@ static void
 PrintRecord(int tiles, int faces, Boolean orient, Boolean middle,
 		Boolean practice)
 {
-	int i = tiles - MINTILES, j = faces - MINFACES;
+	int i = tiles - MIN_TILES, j = faces - MIN_FACES;
 	int k = (orient) ? 1 : 0, l = (middle) ? 1 : 0;
 
 	if (practice) {
-		(void) strncpy(recordDsp, "practice", MESSAGELEN);
-	} else if (tiles > MAXTILES) {
-		(void) strncpy(recordDsp, "NOT RECORDED", MESSAGELEN);
+		(void) strncpy(recordDsp, "practice", MESSAGE_LENGTH);
+	} else if (tiles > MAX_TILES) {
+		(void) strncpy(recordDsp, "NOT RECORDED", MESSAGE_LENGTH);
 	} else if (puzzleRecord[l][k][j][i].score <= NEVER) {
 		(void) sprintf(recordDsp, "NEVER %s", NOACCESS);
 	} else {
@@ -464,19 +464,19 @@ PrintStatus(char *msg, int nMoves
 static Boolean
 HandleSolved(int counter, int tiles, int faces, Boolean orient, Boolean middle)
 {
-	int i = tiles - MINTILES, j = faces - MINFACES;
+	int i = tiles - MIN_TILES, j = faces - MIN_FACES;
 	int k = (orient) ? 1 : 0, l = (middle) ? 1 : 0;
 
-	if (tiles <= MAXTILES && (counter < puzzleRecord[l][k][j][i].score ||
+	if (tiles <= MAX_TILES && (counter < puzzleRecord[l][k][j][i].score ||
 			puzzleRecord[l][k][j][i].score <= NEVER)) {
 		ReadRecords();	/* Maybe its been updated by another */
 		puzzleRecord[l][k][j][i].score = counter;
 		(void) strncpy(puzzleRecord[l][k][j][i].name, userNameDsp,
-			USERNAMELEN);
+			USER_NAME_LENGTH);
 		if (tiles < 4 || faces < 2) {
 			puzzleRecord[!l][k][j][i].score = counter;
 			(void) strncpy(puzzleRecord[!l][k][j][i].name,
-				userNameDsp, USERNAMELEN);
+				userNameDsp, USER_NAME_LENGTH);
 		}
 		WriteRecords();
 		PrintRecord(tiles, faces, orient, middle, False);
@@ -509,7 +509,7 @@ Widget w
 	userName = w->mlink.userName;
 	scoreFile = w->mlink.scoreFile;
 	if (strcmp(scoreFile, ""))
-		(void) strncpy(scoreFileName, scoreFile, FILENAMELEN);
+		(void) strncpy(scoreFileName, scoreFile, FILE_NAME_LENGTH);
 #else
 	Boolean scoreOnly, versionOnly;
 
@@ -528,7 +528,7 @@ Widget w
 		exit(0);
 	}
 	if (strcmp(scoreFile, ""))
-		(void) strncpy(scoreFileName, scoreFile, FILENAMELEN);
+		(void) strncpy(scoreFileName, scoreFile, FILE_NAME_LENGTH);
 	if (scoreOnly) {
 		InitRecords();
 		ReadRecords();
@@ -536,7 +536,7 @@ Widget w
 		exit(0);
 	}
 #ifdef HAVE_MOTIF
-	if (tiles > MAXTILES)
+	if (tiles > MAX_TILES)
 		XtVaSetValues(tile, XmNmaximum, tiles, NULL);
 	XmScaleSetValue(tile, tiles);
 	XmScaleSetValue(face, faces);
@@ -547,7 +547,7 @@ Widget w
 		int delay;
 
 		XtVaGetValues(w, XtNdelay, &delay, NULL);
-		XmScaleSetValue(speed, MAXSPEED + MINSPEED - delay - 1);
+		XmScaleSetValue(speed, MAX_SPEED + MIN_SPEED - delay - 1);
 	}
 #endif
 #endif
@@ -555,13 +555,13 @@ Widget w
 	InitRecords();
 	ReadRecords();
 #ifndef WINVER
-	(void) strncpy(userNameDsp, userName, USERNAMELEN);
+	(void) strncpy(userNameDsp, userName, USER_NAME_LENGTH);
 #endif
 	if (!strcmp(userName, "") || !strcmp(userName, "(null)") ||
 			!strcmp(userName, NOACCESS) ||
 			!strcmp(userName, NOBODY)) {
 #ifdef WINVER
-		(void) strncpy(userNameDsp, userName, USERNAMELEN);
+		(void) strncpy(userNameDsp, userName, USER_NAME_LENGTH);
 #else
 		char *login = getlogin();
 
@@ -651,13 +651,13 @@ CallbackPuzzle(Widget w, caddr_t clientData, mlinkCallbackStruct *callData)
 #ifdef HAVE_MOTIF
 		XtManageChild(solveDialog);
 #else
-		(void) strncpy(messageDsp, solveHelp, MESSAGELEN);
+		(void) strncpy(messageDsp, solveHelp, MESSAGE_LENGTH);
 #endif
 #endif
 		break;
 	case ACTION_RESTORE:
 		if (practice) {
-			(void) strncpy(recordDsp, "practice", MESSAGELEN);
+			(void) strncpy(recordDsp, "practice", MESSAGE_LENGTH);
 #ifdef HAVE_MOTIF
 			PrintState(record, recordDsp);
 #endif
@@ -668,18 +668,18 @@ CallbackPuzzle(Widget w, caddr_t clientData, mlinkCallbackStruct *callData)
 		movesDsp = 0;
 		break;
 	case ACTION_BLOCKED:
-		(void) strncpy(messageDsp, "Blocked", MESSAGELEN);
+		(void) strncpy(messageDsp, "Blocked", MESSAGE_LENGTH);
 		break;
 	case ACTION_SPACE:
 #if 0
 		/* Too annoying */
 		(void) strncpy(messageDsp, "A space can not slide",
-			MESSAGELEN);
+			MESSAGE_LENGTH);
 #endif
 		break;
 	case ACTION_IGNORE:
 		(void) strncpy(messageDsp, "Randomize to start",
-			MESSAGELEN);
+			MESSAGE_LENGTH);
 		break;
 	case ACTION_MOVED:
 		movesDsp++;
@@ -699,7 +699,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, mlinkCallbackStruct *callData)
 				"Congratulations %s!!", userNameDsp);
 		else
 			(void) strncpy(messageDsp, "Solved!",
-				MESSAGELEN);
+				MESSAGE_LENGTH);
 		SET_STARTED(w, False);
 		break;
 	case ACTION_COMPUTED:
@@ -710,7 +710,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, mlinkCallbackStruct *callData)
 		practice = !practice;
 		if (!practice)
 			(void) strncpy(messageDsp, "Randomize to start",
-				MESSAGELEN);
+				MESSAGE_LENGTH);
 		PrintRecord(tiles, faces, orient, middle, practice);
 #ifdef WINVER
 		w->mlink.practice = practice;
@@ -770,7 +770,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, mlinkCallbackStruct *callData)
 #else
 		XtVaSetValues(w, XtNtiles, tiles, NULL);
 #ifdef HAVE_MOTIF
-		if (tiles > MAXTILES)
+		if (tiles > MAX_TILES)
 			XtVaSetValues(tile, XmNmaximum, tiles, NULL);
 		XmScaleSetValue(tile, tiles);
 #endif
@@ -786,7 +786,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, mlinkCallbackStruct *callData)
 		XtVaSetValues(w, XtNtiles, tiles, NULL);
 #ifdef HAVE_MOTIF
 		XmScaleSetValue(tile, tiles);
-		if (tiles >= MAXTILES)
+		if (tiles >= MAX_TILES)
 			XtVaSetValues(tile, XmNmaximum, tiles, NULL);
 #endif
 #endif
@@ -833,8 +833,8 @@ CallbackPuzzle(Widget w, caddr_t clientData, mlinkCallbackStruct *callData)
 			XtVaGetValues(puzzle,
 				XtNdelay, &delay, NULL);
 			oldDelay = delay;
-			if (delay > MAXSPEED - MINSPEED)
-				delay = MAXSPEED - MINSPEED;
+			if (delay > MAX_SPEED - MIN_SPEED)
+				delay = MAX_SPEED - MIN_SPEED;
 			if (delay < 0)
 				delay = 0;
 			if (delay != oldDelay) {
@@ -842,7 +842,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, mlinkCallbackStruct *callData)
 					XtNdelay, delay, NULL);
 			}
 			XmScaleSetValue(speed,
-				MAXSPEED + MINSPEED - delay - 1);
+				MAX_SPEED + MIN_SPEED - delay - 1);
 		}
 		return;
 #endif
@@ -1397,14 +1397,14 @@ PracticeToggle(Widget w, XtPointer clientData,
 	if (practice)
 		(void) strcpy(messageDsp, "");
 	else
-		(void) strncpy(messageDsp, "Randomize to start", MESSAGELEN);
+		(void) strncpy(messageDsp, "Randomize to start", MESSAGE_LENGTH);
 	PrintState(message, messageDsp);
 }
 
 static void
 SpeedSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 {
-	int delay = MAXSPEED + MINSPEED - cbs->value - 1, oldDelay;
+	int delay = MAX_SPEED + MIN_SPEED - cbs->value - 1, oldDelay;
 
 	XtVaGetValues(puzzle,
 		XtNdelay, &oldDelay, NULL);
@@ -1435,7 +1435,7 @@ static Widget
 createQuery(Widget w, char *text, char *title, XtCallbackProc callback)
 {
 	Widget button, messageBox;
-	char titleDsp[FILENAMELEN + 8];
+	char titleDsp[FILE_NAME_LENGTH + 8];
 	XmString titleString = NULL, messageString = NULL;
 	static XmStringCharSet charSet =
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
@@ -1461,7 +1461,7 @@ static Widget
 createHelp(Widget w, char *text, char *title)
 {
 	Widget button, messageBox;
-	char titleDsp[FILENAMELEN + 8];
+	char titleDsp[FILE_NAME_LENGTH + 8];
 	XmString titleString = NULL, messageString = NULL, buttonString = NULL;
 	static XmStringCharSet charSet =
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
@@ -1722,9 +1722,9 @@ main(int argc, char **argv)
 	tile = XtVaCreateManagedWidget("tile",
 		xmScaleWidgetClass, tilesRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Tiles", 6,
-		XmNminimum, MINTILES,
-		XmNmaximum, MAXTILES,
-		XmNvalue, DEFAULTTILES,
+		XmNminimum, MIN_TILES,
+		XmNmaximum, MAX_TILES,
+		XmNvalue, DEFAULT_TILES,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
 	XtAddCallback(tile, XmNvalueChangedCallback,
@@ -1732,9 +1732,9 @@ main(int argc, char **argv)
 	face = XtVaCreateManagedWidget("face",
 		xmScaleWidgetClass, tilesRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Faces", 6,
-		XmNminimum, MINFACES,
-		XmNmaximum, MAXFACES,
-		XmNvalue, DEFAULTFACES,
+		XmNminimum, MIN_FACES,
+		XmNmaximum, MAX_FACES,
+		XmNvalue, DEFAULT_FACES,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
 	XtAddCallback(face, XmNvalueChangedCallback,
@@ -1747,9 +1747,9 @@ main(int argc, char **argv)
 	speed = XtVaCreateManagedWidget("Animation Speed",
 		xmScaleWidgetClass, speedRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Animation Speed", 16,
-		XmNminimum, MINSPEED,
-		XmNmaximum, MAXSPEED,
-		XmNvalue, MAXSPEED - DEFAULTDELAY,
+		XmNminimum, MIN_SPEED,
+		XmNmaximum, MAX_SPEED,
+		XmNvalue, MAX_SPEED - DEFAULT_DELAY,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
 	XtAddCallback(speed, XmNvalueChangedCallback,
@@ -1761,17 +1761,17 @@ main(int argc, char **argv)
 		XmNpacking, XmPACK_COLUMN, NULL);
 	orientizeSwitch = XtVaCreateManagedWidget("Oriented",
 		xmToggleButtonWidgetClass, switchRowCol,
-		XmNset, DEFAULTORIENT, NULL);
+		XmNset, DEFAULT_ORIENT, NULL);
 	XtAddCallback(orientizeSwitch, XmNvalueChangedCallback,
 		(XtCallbackProc) OrientToggle, (XtPointer) NULL);
 	middleSwitch = XtVaCreateManagedWidget("Middle rigid",
 		xmToggleButtonWidgetClass, switchRowCol,
-		XmNset, DEFAULTMIDDLE, NULL);
+		XmNset, DEFAULT_MIDDLE, NULL);
 	XtAddCallback(middleSwitch, XmNvalueChangedCallback,
 		(XtCallbackProc) MiddleToggle, (XtPointer) NULL);
 	practiceSwitch = XtVaCreateManagedWidget("Practice",
 		xmToggleButtonWidgetClass, switchRowCol,
-		XmNset, DEFAULTPRACTICE, NULL);
+		XmNset, DEFAULT_PRACTICE, NULL);
 	XtAddCallback(practiceSwitch, XmNvalueChangedCallback,
 		(XtCallbackProc) PracticeToggle, (XtPointer) NULL);
 	messageRowCol = XtVaCreateManagedWidget("messageRowCol",
