@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 2007	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1994 - 2007	David A. Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -40,7 +40,7 @@
 
 #define SECTION "setup"
 
-static const char *faceColorString[MAXFACES] =
+static const char *faceColorString[MAX_FACES] =
 {
 	"255 0 0",
 	"0 0 255",
@@ -52,7 +52,7 @@ static const char *faceColorString[MAXFACES] =
 	"255 255 0"
 };
 
-static char faceColorChar[MAXFACES] =
+static char faceColorChar[MAX_FACES] =
 {'R', 'B', 'W', 'M', 'O', 'P', 'G', 'Y'};
 #else
 
@@ -298,7 +298,7 @@ static XtResource resourcesPuzzle[] =
 	 XtRString, (caddr_t) "gray25" /*XtDefaultForeground*/},
 	{XtNdelay, XtCDelay, XtRInt, sizeof (int),
 	 XtOffset(OctWidget, oct.delay),
-	 XtRString, (caddr_t) "10"}, /* DEFAULTDELAY */
+	 XtRString, (caddr_t) "10"}, /* DEFAULT_DELAY */
 	{XtNsound, XtCSound, XtRBoolean, sizeof (Boolean),
 	 XtOffset(OctWidget, oct.sound),
 	 XtRString, (caddr_t) "FALSE"},
@@ -316,13 +316,13 @@ static XtResource resourcesPuzzle[] =
 	 XtRString, (caddr_t) "FALSE"}, /* DEFAULTSTICKY */
 	{XtNmode, XtCMode, XtRInt, sizeof (int),
 	 XtOffset(OctWidget, oct.mode),
-	 XtRString, (caddr_t) "4"}, /*DEFAULTMODE */
+	 XtRString, (caddr_t) "4"}, /*DEFAULT_MODE */
 	{XtNorient, XtCOrient, XtRBoolean, sizeof (Boolean),
 	 XtOffset(OctWidget, oct.orient),
-	 XtRString, (caddr_t) "FALSE"}, /*DEFAULTORIENT */
+	 XtRString, (caddr_t) "FALSE"}, /*DEFAULT_ORIENT */
 	{XtNpractice, XtCPractice, XtRBoolean, sizeof (Boolean),
 	 XtOffset(OctWidget, oct.practice),
-	 XtRString, (caddr_t) "TRUE"}, /*DEFAULTPRACTICE */
+	 XtRString, (caddr_t) "TRUE"}, /*DEFAULT_PRACTICE */
 	{XtNuserName, XtCUserName, XtRString, sizeof (String),
 	 XtOffset(OctWidget, oct.userName),
 	 XtRString, (caddr_t) ""},
@@ -457,7 +457,7 @@ typedef struct _RTT {
 typedef struct _RowNextP3 {
 	int viewChanged, face, direction;
 } RowNextP3;
-static int directionNextFace[COORD][MAXFACES] =
+static int directionNextFace[COORD][MAX_FACES] =
 {
 	{-1, 0, -1, 0, -1, 4, -1, 4},
 	{6, 5, 1, 0, 2, 1, 5, 4},
@@ -468,7 +468,7 @@ static int directionNextFace[COORD][MAXFACES] =
 	{3, -1, 3, -1, 7, -1, 7, -1},
 	{6, 0, 3, 7, 2, 4, 7, 3}
 };
-static int directionNextFaceP3[COORD][MAXFACES] =
+static int directionNextFaceP3[COORD][MAX_FACES] =
 {
 	{-1, 6, -1, 6, -1, 2, -1, 2},
 	{5, 6, 0, 1, 1, 2, 4, 5},
@@ -479,7 +479,7 @@ static int directionNextFaceP3[COORD][MAXFACES] =
 	{7, -1, 7, -1, 3, -1, 3, -1},
 	{7, 3, 0, 6, 3, 7, 4, 2}
 };
-static OctLoc rowToRotate[MAXFACES][COORD] =
+static OctLoc rowToRotate[MAX_FACES][COORD] =
 {
 	{
 		{IGNORE_DIR, IGNORE_DIR},
@@ -562,7 +562,7 @@ static OctLoc rowToRotate[MAXFACES][COORD] =
 		{0, CCW}
 	}
 };
-static RowNextP3 slideNextRowP3[MAXSIDES][COORD] =
+static RowNextP3 slideNextRowP3[MAX_SIDES][COORD] =
 {
 	{
 		{IGNORE_DIR, IGNORE_DIR, IGNORE_DIR},
@@ -605,14 +605,14 @@ static RowNextP3 slideNextRowP3[MAXSIDES][COORD] =
 		{TRUE, 3, BR}
 	}
 };
-static int reverseP3[MAXSIDES][COORD] =
+static int reverseP3[MAX_SIDES][COORD] =
 {
 	{IGNORE_DIR, FALSE, FALSE, TRUE, IGNORE_DIR, TRUE, TRUE, TRUE},
 	{TRUE, TRUE, IGNORE_DIR, FALSE, FALSE, TRUE, IGNORE_DIR, TRUE},
 	{IGNORE_DIR, TRUE, TRUE, TRUE, IGNORE_DIR, FALSE, FALSE, TRUE},
 	{FALSE, TRUE, IGNORE_DIR, TRUE, TRUE, TRUE, IGNORE_DIR, FALSE}
 };
-static int rotateOrientP3[MAXSIDES][COORD] =
+static int rotateOrientP3[MAX_SIDES][COORD] =
 {
 	{IGNORE_DIR, 11, 7, 2, IGNORE_DIR, 10, 5, 1},
 	{11, 7, IGNORE_DIR, 5, 1, 2, IGNORE_DIR, 10},
@@ -620,7 +620,7 @@ static int rotateOrientP3[MAXSIDES][COORD] =
 	{1, 2, IGNORE_DIR, 10, 11, 7, IGNORE_DIR, 5}
 };
 
-static Point triangleUnit[MAXSIDES][4] =
+static Point triangleUnit[MAX_SIDES][4] =
 {
 	{
 		{0, 0},
@@ -647,7 +647,7 @@ static Point triangleUnit[MAXSIDES][4] =
 		{-1, -1}
 	}
 };
-static Point triangleList[MAXSIDES][4], letterList[MAXSIDES];
+static Point triangleList[MAX_SIDES][4], letterList[MAX_SIDES];
 
 static Pixmap dr = 0; /* dummy for future double buffering */
 
@@ -659,10 +659,10 @@ CheckPieces(OctWidget w)
 {
 	char *buf1 = NULL, *buf2 = NULL;
 
-	if (w->oct.size < MINFACETS) {
+	if (w->oct.size < MIN_FACETS) {
 		intCat(&buf1,
 			"Number of triangles on an edge out of bounds, use at least ",
-			MINFACETS);
+			MIN_FACETS);
 		stringCat(&buf2, buf1, ", defaulting to ");
 		free(buf1);
 		intCat(&buf1, buf2, DEFAULTFACETS);
@@ -673,10 +673,10 @@ CheckPieces(OctWidget w)
 	}
 	if (w->oct.mode < PERIOD3 || w->oct.mode > BOTH) {
 		intCat(&buf1, "Mode is in error, use 3 for Period3, 4 for Period4, 5 for Both, defaulting to ",
-			DEFAULTMODE);
+			DEFAULT_MODE);
 		DISPLAY_WARNING(buf1);
 		free(buf1);
-		w->oct.mode = DEFAULTMODE;
+		w->oct.mode = DEFAULT_MODE;
 	}
 }
 
@@ -686,12 +686,12 @@ CheckSolved(OctWidget w)
 	int face, position;
 	OctLoc test = {0, FALSE};
 
-	for (face = 0; face < MAXFACES; face++)
+	for (face = 0; face < MAX_FACES; face++)
 		for (position = 0; position < w->oct.sizeSize; position++) {
 			if (!position) {
 				test.face = w->oct.facetLoc[face][position].face;
 				test.rotation = w->oct.facetLoc[face][position].rotation;
-			} else if (test.face !=		/* MAXSIDES * view + face */
+			} else if (test.face !=		/* MAX_SIDES * view + face */
 					w->oct.facetLoc[face][position].face ||
 					(w->oct.orient && test.rotation !=
 					w->oct.facetLoc[face][position].rotation))
@@ -707,7 +707,7 @@ PrintFacet(OctWidget w)
 {
 	int face, position, square;
 
-	for (face = 0; face < MAXSIDES; face++) {
+	for (face = 0; face < MAX_SIDES; face++) {
 		square = 1;
 		for (position = 0; position < w->oct.sizeSize; position++) {
 			(void) printf("%d %d  ",
@@ -801,7 +801,7 @@ DrawOrientLine(OctWidget w, int orient, int face, int side, int dx, int dy,
 
 	/* clock positions */
 	switch ((side == face) ? orient :
-			(orient + MAXORIENT / 2) % MAXORIENT) {
+			(orient + MAX_ORIENT / 2) % MAX_ORIENT) {
 	case 0:
 		x_2 = x_1 = dx;
 		y_1 = dy + temp1 - 2;
@@ -895,10 +895,10 @@ DrawTriangle(OctWidget w, int face, int position, int offset)
 	int pos = row * (w->oct.facetLength + w->oct.delta);
 	int orient, view, faceOnView;
 
-	view = (face / MAXSIDES == UP) ? DOWN : UP;
-	faceOnView = face - MAXSIDES * (!view);
+	view = (face / MAX_SIDES == UP) ? DOWN : UP;
+	faceOnView = face - MAX_SIDES * (!view);
 	orient = (!w->oct.vertical && view == DOWN) ?
-		(faceOnView + MAXSIDES / 2) % MAXSIDES : faceOnView;
+		(faceOnView + MAX_SIDES / 2) % MAX_SIDES : faceOnView;
 	switch (orient) {
 	case 0:
 		dy = w->oct.viewMiddle - w->oct.delta - 2 - pos;
@@ -934,7 +934,7 @@ DrawTriangle(OctWidget w, int face, int position, int offset)
 	else	/* faceOnView == (RIGHT / 2) || faceOnView == (LEFT / 2) */
 		side = ((faceOnView) ? s : !s) * 2;
 	side = (!w->oct.vertical && view == DOWN) ?
-		(side + MAXSIDES / 2) % MAXSIDES : side;
+		(side + MAX_SIDES / 2) % MAX_SIDES : side;
 	if (s == OPPOSITE)
 		switch (side) {
 		case 0:
@@ -1013,7 +1013,7 @@ DrawAllPieces(OctWidget w)
 {
 	int position, face;
 
-	for (face = 0; face < MAXFACES; face++)
+	for (face = 0; face < MAX_FACES; face++)
 		for (position = 0; position < w->oct.sizeSize; position++)
 			DrawTriangle(w, face, position, FALSE);
 }
@@ -1119,17 +1119,17 @@ RotateFace(OctWidget w, int view, int side, int direction)
 			i_1 = w->oct.size - 1 - k;
 		}
 		position = k_1 * k_1 + 2 * j_1 + (j_1 != k_1 - i_1);
-		w->oct.faceLoc[position] = w->oct.facetLoc[view * MAXSIDES + side][g];
+		w->oct.faceLoc[position] = w->oct.facetLoc[view * MAX_SIDES + side][g];
 	}
 	/* Write Face */
 	square = 1;
 	s = 0;
 	for (g = 0; g < w->oct.sizeSize; g++) {
-		w->oct.facetLoc[view * MAXSIDES + side][g] = w->oct.faceLoc[g];
-		w->oct.facetLoc[view * MAXSIDES + side][g].rotation = (direction == CW) ?
-			(w->oct.facetLoc[view * MAXSIDES + side][g].rotation + 4) % MAXORIENT :
-			(w->oct.facetLoc[view * MAXSIDES + side][g].rotation + 8) % MAXORIENT;
-		DrawTriangle(w, view * MAXSIDES + side, g, FALSE);
+		w->oct.facetLoc[view * MAX_SIDES + side][g] = w->oct.faceLoc[g];
+		w->oct.facetLoc[view * MAX_SIDES + side][g].rotation = (direction == CW) ?
+			(w->oct.facetLoc[view * MAX_SIDES + side][g].rotation + 4) % MAX_ORIENT :
+			(w->oct.facetLoc[view * MAX_SIDES + side][g].rotation + 8) % MAX_ORIENT;
+		DrawTriangle(w, view * MAX_SIDES + side, g, FALSE);
 		s = !s;
 		if (g == square * square - 1) {
 			s = 0;
@@ -1147,13 +1147,13 @@ ReadRTT(OctWidget w, int view, int side, int dir, int h, int len, int orient)
 	if (!(dir % 2) || dir > COORD)
 		for (g = 0; g < len; g++)
 			w->oct.rowLoc[orient][g] =
-				w->oct.facetLoc[view * MAXSIDES + side][base + g];
+				w->oct.facetLoc[view * MAX_SIDES + side][base + g];
 	else if ((dir / 2 + side) % 2) {
 		f = -1;
 		for (g = 0; g < len; g++) {
 			s = g % 2;
 			w->oct.rowLoc[orient][g] =
-				w->oct.facetLoc[view * MAXSIDES + side][base + f + !s];
+				w->oct.facetLoc[view * MAX_SIDES + side][base + f + !s];
 			if (s == SAME)
 				f += g + 2 * (h + 1) + 1;
 		}
@@ -1163,7 +1163,7 @@ ReadRTT(OctWidget w, int view, int side, int dir, int h, int len, int orient)
 		for (g = 0; g < len; g++) {
 			s = g % 2;
 			w->oct.rowLoc[orient][g] =
-				w->oct.facetLoc[view * MAXSIDES + side][base + f - !s];
+				w->oct.facetLoc[view * MAX_SIDES + side][base + f - !s];
 			if (s == SAME)
 				f += g + 2 * h + 1;
 		}
@@ -1177,7 +1177,7 @@ RotateRTT(OctWidget w, int rotate, int len, int orient)
 
 	for (g = 0; g < len; g++)
 		w->oct.rowLoc[orient][g].rotation =
-			(w->oct.rowLoc[orient][g].rotation + rotate) % MAXORIENT;
+			(w->oct.rowLoc[orient][g].rotation + rotate) % MAX_ORIENT;
 }
 
 static void
@@ -1202,17 +1202,17 @@ WriteRTT(OctWidget w, int view, int side, int dir, int h, int len, int orient)
 	if (!(dir % 2) || dir > COORD) {	/* CW || CCW */
 		for (g = 0; g < len; g++) {
 			s = g % 2;
-			w->oct.facetLoc[view * MAXSIDES + side][base + g] =
+			w->oct.facetLoc[view * MAX_SIDES + side][base + g] =
 				w->oct.rowLoc[orient][g];
-			DrawTriangle(w, view * MAXSIDES + side, base + g, FALSE);
+			DrawTriangle(w, view * MAX_SIDES + side, base + g, FALSE);
 		}
 	} else if ((dir / 2 + side) % 2) {
 		f = -1;
 		for (g = 0; g < len; g++) {
 			s = g % 2;
-			w->oct.facetLoc[view * MAXSIDES + side][base + f + !s] =
+			w->oct.facetLoc[view * MAX_SIDES + side][base + f + !s] =
 				w->oct.rowLoc[orient][g];
-			DrawTriangle(w, view * MAXSIDES + side, base + f + !s, FALSE);
+			DrawTriangle(w, view * MAX_SIDES + side, base + f + !s, FALSE);
 			if (s == SAME)
 				f += g + 2 * (h + 1) + 1;
 		}
@@ -1221,9 +1221,9 @@ WriteRTT(OctWidget w, int view, int side, int dir, int h, int len, int orient)
 		f = 1;
 		for (g = 0; g < len; g++) {
 			s = g % 2;
-			w->oct.facetLoc[view * MAXSIDES + side][base + f - !s] =
+			w->oct.facetLoc[view * MAX_SIDES + side][base + f - !s] =
 				w->oct.rowLoc[orient][g];
-			DrawTriangle(w, view * MAXSIDES + side, base + f - !s, FALSE);
+			DrawTriangle(w, view * MAX_SIDES + side, base + f - !s, FALSE);
 			if (s == SAME)
 				f += g + 2 * h + 1;
 		}
@@ -1236,13 +1236,13 @@ MovePieces(OctWidget w, int face, RTT rtt, int direction, int style)
 	int view, side, orient, newView, rotate, g, h, len;
 	int newSide, oldSide, newDirection, bound, l = 0;
 
-	view = face / MAXSIDES;
-	side = face % MAXSIDES;
+	view = face / MAX_SIDES;
+	side = face % MAX_SIDES;
 	if (style == PERIOD3) {
 		if (direction == CW || direction == CCW) { /* Remap to row movement */
-			side = (side + 2) % MAXSIDES;
-			direction = ((side + direction) % MAXSIDES) * 2;
-			face = side + MAXSIDES * (!view);
+			side = (side + 2) % MAX_SIDES;
+			direction = ((side + direction) % MAX_SIDES) * 2;
+			face = side + MAX_SIDES * (!view);
 			rtt.row = rtt.trbl = rtt.tlbr = 0;
 		}
 		if ((!rtt.row && !(direction % 2)) ||
@@ -1259,8 +1259,8 @@ MovePieces(OctWidget w, int face, RTT rtt, int direction, int style)
 				(rtt.tlbr == w->oct.size - 1 &&
 				(direction % 2) &&
 				(side + direction / 2) % 2))
-			RotateFace(w, !view, rowToRotate[MAXSIDES + side][direction].face,
-				rowToRotate[MAXSIDES + side][direction].rotation);
+			RotateFace(w, !view, rowToRotate[MAX_SIDES + side][direction].face,
+				rowToRotate[MAX_SIDES + side][direction].rotation);
 		if (!(direction % 2))
 			h = rtt.row;
 		else if ((direction / 2 + side) % 2)
@@ -1332,34 +1332,34 @@ MovePieces(OctWidget w, int face, RTT rtt, int direction, int style)
 					direction = (direction == CW) ? CCW : CW;
 					view = !view;
 				} else
-					side = (side + 2) % MAXSIDES;
+					side = (side + 2) % MAX_SIDES;
 			}
 			ReadRTT(w, view, side, direction, h, len, 0);
 			for (orient = 1; orient <= 4; orient++) {
 				if (direction <= TL) {
-					if ((side - direction / 2 + COORD) % MAXSIDES < 2) {
+					if ((side - direction / 2 + COORD) % MAX_SIDES < 2) {
 						newView = !view;
-						newSide = ((side % 2)) ? side : (side + 2) % MAXSIDES;
+						newSide = ((side % 2)) ? side : (side + 2) % MAX_SIDES;
 						newDirection = (!((direction / 2) % 2)) ?
-							((direction + 6) % MAXFACES) : ((direction + 2) % MAXFACES);
+							((direction + 6) % MAX_FACES) : ((direction + 2) % MAX_FACES);
 						if (side % 2)
-							rotate = (((newDirection - direction) / 2 + MAXSIDES) %
-								MAXSIDES == 1) ? 4 : MAXORIENT - 4;
+							rotate = (((newDirection - direction) / 2 + MAX_SIDES) %
+								MAX_SIDES == 1) ? 4 : MAX_ORIENT - 4;
 						else
-							rotate = (((newDirection - direction) / 2 + MAXSIDES) %
-								MAXSIDES == 1) ? 2 : MAXORIENT - 2;
+							rotate = (((newDirection - direction) / 2 + MAX_SIDES) %
+								MAX_SIDES == 1) ? 2 : MAX_ORIENT - 2;
 					} else {	/* Next is on same view */
 						newView = view;
-						newSide = MAXSIDES - side - 1;
+						newSide = MAX_SIDES - side - 1;
 						if ((direction / 2) % 2 == 1)
-							newSide = (newSide + 2) % MAXSIDES;
+							newSide = (newSide + 2) % MAX_SIDES;
 						newDirection = direction;
-						rotate = ((side - newSide + MAXSIDES) % MAXSIDES == 1) ?
-							1 : MAXORIENT - 1;
+						rotate = ((side - newSide + MAX_SIDES) % MAX_SIDES == 1) ?
+							1 : MAX_ORIENT - 1;
 					}
 				} else {	/* direction == CW || direction == CCW */
 					newView = view;
-					newSide = (side + direction) % MAXSIDES;
+					newSide = (side + direction) % MAX_SIDES;
 					newDirection = direction;
 					rotate = 3 * newDirection;
 				}
@@ -1420,8 +1420,8 @@ MoveControlCb(OctWidget w, int face, int direction, int style)
 						rtt.trbl = j;
 						rtt.tlbr = j;
 						MovePieces(w,
-							(!(face / MAXSIDES)) * MAXSIDES + ((face % 2) ?
-							(face + MAXSIDES / 2) % MAXSIDES : face % MAXSIDES), rtt,
+							(!(face / MAX_SIDES)) * MAX_SIDES + ((face % 2) ?
+							(face + MAX_SIDES / 2) % MAX_SIDES : face % MAX_SIDES), rtt,
 							(direction == CW) ? CCW : CW, style);
 					} else {
 						j = i + 1;
@@ -1429,10 +1429,10 @@ MoveControlCb(OctWidget w, int face, int direction, int style)
 						rtt.trbl = j;
 						rtt.tlbr = j;
 						MovePieces(w,
-							(!(face / MAXSIDES)) * MAXSIDES + ((face % 2) ?
-							(face + MAXSIDES / 2) % MAXSIDES : face % MAXSIDES), rtt,
-							((direction / 2) % 2) ? (direction + 2) % MAXFACES :
-							(direction + 6) % MAXFACES, style);
+							(!(face / MAX_SIDES)) * MAX_SIDES + ((face % 2) ?
+							(face + MAX_SIDES / 2) % MAX_SIDES : face % MAX_SIDES), rtt,
+							((direction / 2) % 2) ? (direction + 2) % MAX_FACES :
+							(direction + 6) % MAX_FACES, style);
 					}
 				}
 				setPuzzle(w, ACTION_CONTROL);
@@ -1459,8 +1459,8 @@ MoveControlCb(OctWidget w, int face, int direction, int style)
 						rtt.trbl = j;
 						rtt.tlbr = j;
 						MovePieces(w,
-							(!(face / MAXSIDES)) * MAXSIDES + ((face % 2) ?
-							(face + MAXSIDES / 2) % MAXSIDES : face % MAXSIDES), rtt,
+							(!(face / MAX_SIDES)) * MAX_SIDES + ((face % 2) ?
+							(face + MAX_SIDES / 2) % MAX_SIDES : face % MAX_SIDES), rtt,
 							(direction == CW) ? CCW : CW, style);
 					} else {
 						j = i - w->oct.size + 1;
@@ -1468,10 +1468,10 @@ MoveControlCb(OctWidget w, int face, int direction, int style)
 						rtt.trbl = j;
 						rtt.tlbr = j;
 						MovePieces(w,
-							(!(face / MAXSIDES)) * MAXSIDES + ((face % 2) ?
-							(face + MAXSIDES / 2) % MAXSIDES : face % MAXSIDES), rtt,
-							((direction / 2) % 2) ? (direction + 2) % MAXFACES :
-							(direction + 6) % MAXFACES, style);
+							(!(face / MAX_SIDES)) * MAX_SIDES + ((face % 2) ?
+							(face + MAX_SIDES / 2) % MAX_SIDES : face % MAX_SIDES), rtt,
+							((direction / 2) % 2) ? (direction + 2) % MAX_FACES :
+							(direction + 6) % MAX_FACES, style);
 					}
 				}
 				setPuzzle(w, ACTION_CONTROL);
@@ -1559,8 +1559,8 @@ SelectPieces(OctWidget w, int x, int y, int *face, RTT * rtt)
 			(w->oct.facetLength + w->oct.delta) - 2)
 		rtt->tlbr++;
 	if (!w->oct.vertical && view == DOWN)
-		*face = (*face + MAXSIDES / 2) % MAXSIDES;
-	*face += MAXSIDES * (!view);
+		*face = (*face + MAX_SIDES / 2) % MAX_SIDES;
+	*face += MAX_SIDES * (!view);
 	if (*face % 2) {
 		view = rtt->tlbr;
 		rtt->tlbr = rtt->trbl;
@@ -1607,8 +1607,8 @@ CheckMoveDir(OctWidget w, int face1, RTT rtt1, int face2, RTT rtt2,
 					*direction = (2 * face1 + BR) % COORD;
 				break;
 			}
-		if (!w->oct.vertical && face1 >= MAXSIDES && *direction > TL)
-			*direction = (*direction + MAXSIDES) % MAXFACES;
+		if (!w->oct.vertical && face1 >= MAX_SIDES && *direction > TL)
+			*direction = (*direction + MAX_SIDES) % MAX_FACES;
 	} else {
 		if (style == 3) {
 			if ((face1 == 0 && face2 == 1) ||
@@ -1912,14 +1912,14 @@ NarrowSelection(int style, int *face, int *direction)
 {
 	int side;
 
-	side = *face % MAXSIDES;
+	side = *face % MAX_SIDES;
 	if (!(*direction % 2) && !((*direction / 2 + side) % 2))
 		return False;
 	if (style == PERIOD4) {
 		if (!(*direction % 2)) {
-			if (*direction == (2 * side + 2) % MAXFACES)
+			if (*direction == (2 * side + 2) % MAX_FACES)
 				*direction = CW;
-			else	/* *direction == (2 * side + 6) % MAXFACES */
+			else	/* *direction == (2 * side + 6) % MAX_FACES */
 				*direction = CCW;
 		}
 #if 0
@@ -1939,9 +1939,9 @@ PositionPieces(OctWidget w, int x, int y, int style, int *face, RTT * rtt, int *
 {
 	if (!SelectPieces(w, x, y, face, rtt))
 		return False;
-	if (!w->oct.vertical && *face >= MAXSIDES &&
-		*direction < MAXFACES)
-		*direction = (*direction + MAXSIDES) % MAXFACES;
+	if (!w->oct.vertical && *face >= MAX_SIDES &&
+		*direction < MAX_FACES)
+		*direction = (*direction + MAX_SIDES) % MAX_FACES;
 	return NarrowSelection(style, face, direction);
 }
 
@@ -1980,7 +1980,7 @@ ResetPieces(OctWidget w)
 	int face, position, orient;
 
 	w->oct.sizeSize = w->oct.size * w->oct.size;
-	for (face = 0; face < MAXFACES; face++) {
+	for (face = 0; face < MAX_FACES; face++) {
 		if (w->oct.facetLoc[face])
 			free(w->oct.facetLoc[face]);
 		if (!(w->oct.facetLoc[face] = (OctLoc *)
@@ -1994,7 +1994,7 @@ ResetPieces(OctWidget w)
 			DISPLAY_ERROR("Not enough memory, exiting.");
 		}
 	}
-	for (orient = 0; orient < MAXORIENT / 2; orient++) {
+	for (orient = 0; orient < MAX_ORIENT / 2; orient++) {
 		if (w->oct.rowLoc[orient])
 			free(w->oct.rowLoc[orient]);
 		if (!(w->oct.rowLoc[orient] = (OctLoc *)
@@ -2008,11 +2008,11 @@ ResetPieces(OctWidget w)
 			malloc(sizeof (OctLoc) * w->oct.sizeSize))) {
 		DISPLAY_ERROR("Not enough memory, exiting.");
 	}
-	for (face = 0; face < MAXFACES; face++)
+	for (face = 0; face < MAX_FACES; face++)
 		for (position = 0; position < w->oct.sizeSize; position++) {
 			w->oct.facetLoc[face][position].face = face;
 			w->oct.facetLoc[face][position].rotation =
-				3 * face % MAXORIENT;
+				3 * face % MAX_ORIENT;
 		}
 	flushMoves(w, &undo, TRUE);
 	flushMoves(w, &redo, FALSE);
@@ -2028,7 +2028,7 @@ ResizePieces(OctWidget w)
 	w->oct.facetLength = w->oct.faceLength / (2 * w->oct.size) -
 		w->oct.delta - 1;
 	for (i = 0; i <= 3; i++)
-		for (j = 0; j < MAXSIDES; j++) {
+		for (j = 0; j < MAX_SIDES; j++) {
 			triangleList[j][i].x = triangleUnit[j][i].x *
 				w->oct.facetLength;
 			triangleList[j][i].y = triangleUnit[j][i].y *
@@ -2096,7 +2096,7 @@ GetPieces(OctWidget w)
 	flushMoves(w, &redo, FALSE);
 	while ((c = getc(fp)) != EOF && c != SYMBOL);
 	(void) fscanf(fp, "%d", &size);
-	if (size >= MINFACETS) {
+	if (size >= MIN_FACETS) {
 		for (i = w->oct.size; i < size; i++) {
 			setPuzzle(w, ACTION_INCREMENT);
 		}
@@ -2109,7 +2109,7 @@ GetPieces(OctWidget w)
 		free(buf1);
 		stringCat(&buf1, buf2, " should be between ");
 		free(buf2);
-		intCat(&buf2, buf1, MINFACETS);
+		intCat(&buf2, buf1, MIN_FACETS);
 		free(buf1);
 		stringCat(&buf1, buf2, " and MAXINT");
 		free(buf2);
@@ -2247,7 +2247,7 @@ UndoPieces(OctWidget w)
 		setMove(&redo,
 			face, position, direction, style, control);
 		direction = (direction < COORD) ?
-			(direction + MAXSIDES) % MAXFACES : 3 * COORD - direction;
+			(direction + MAX_SIDES) % MAX_FACES : 3 * COORD - direction;
 		if (control)
 			MoveControlCb(w, face, direction, style);
 		else {
@@ -2326,16 +2326,16 @@ RandomizePieces(OctWidget w)
 #endif
 
 	while (big--) {
-		face = NRAND(MAXFACES);
+		face = NRAND(MAX_FACES);
 		if (w->oct.mode == BOTH)
-			style = NRAND(MAXMODES - 1) + PERIOD3;
+			style = NRAND(MAX_MODES - 1) + PERIOD3;
 		else
 			style = w->oct.mode;
 		if (w->oct.sticky) {
 			if (style == PERIOD3) {
 				position = 6;
 				randomDirection = NRAND(6);
-				if (randomDirection >= MAXSIDES) {
+				if (randomDirection >= MAX_SIDES) {
 					if (randomDirection == 4)
 						randomDirection = CW;
 					else if (randomDirection == 5)
@@ -2359,8 +2359,8 @@ RandomizePieces(OctWidget w)
 			}
 		} else {	/* (!w->oct.sticky) */
 			if (style == PERIOD3) {
-				randomDirection = NRAND(MAXORIENT / 2);
-				if (randomDirection >= MAXSIDES) {
+				randomDirection = NRAND(MAX_ORIENT / 2);
+				if (randomDirection >= MAX_SIDES) {
 					if (randomDirection == 4) {
 						if (face % 2)
 							randomDirection = BOTTOM;
@@ -2375,7 +2375,7 @@ RandomizePieces(OctWidget w)
 				} else
 					randomDirection = randomDirection * 2 + 1;;
 			} else {	/* style == PERIOD4 */
-				randomDirection = NRAND(MAXORIENT / 2);
+				randomDirection = NRAND(MAX_ORIENT / 2);
 				if (randomDirection == 4)
 					randomDirection = CW;
 				else if (randomDirection == 5)
@@ -2415,7 +2415,7 @@ IncrementPieces(OctWidget w)
 static Boolean
 DecrementPieces(OctWidget w)
 {
-	if (w->oct.size <= MINFACETS)
+	if (w->oct.size <= MIN_FACETS)
 		return False;
 	setPuzzle(w, ACTION_DECREMENT);
 	return True;
@@ -2472,17 +2472,17 @@ SetValuesPuzzle(OctWidget w)
 	w->oct.size = GetPrivateProfileInt(SECTION, "size",
 		DEFAULTFACETS, INIFILE);
 	w->oct.mode = GetPrivateProfileInt(SECTION, "mode",
-		DEFAULTMODE, INIFILE);
+		DEFAULT_MODE, INIFILE);
 	w->oct.sticky = (BOOL) GetPrivateProfileInt(SECTION, "sticky",
 		DEFAULTSTICKY, INIFILE);
 	w->oct.orient = (BOOL) GetPrivateProfileInt(SECTION, "orient",
-		DEFAULTORIENT, INIFILE);
+		DEFAULT_ORIENT, INIFILE);
 	w->oct.practice = (BOOL) GetPrivateProfileInt(SECTION, "practice",
-		DEFAULTPRACTICE, INIFILE);
+		DEFAULT_PRACTICE, INIFILE);
 	w->oct.mono = (BOOL) GetPrivateProfileInt(SECTION, "mono",
-		DEFAULTMONO, INIFILE);
+		DEFAULT_MONO, INIFILE);
 	w->oct.reverse = (BOOL) GetPrivateProfileInt(SECTION, "reverseVideo",
-		DEFAULTREVERSE, INIFILE);
+		DEFAULT_REVERSE, INIFILE);
 	/* cyan */
 	(void) GetPrivateProfileString(SECTION, "frameColor", "0 255 255",
 		szBuf, sizeof (szBuf), INIFILE);
@@ -2501,7 +2501,7 @@ SetValuesPuzzle(OctWidget w)
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
 	w->oct.inverseGC = RGB(color.red, color.green, color.blue);
-	for (face = 0; face < MAXFACES; face++) {
+	for (face = 0; face < MAX_FACES; face++) {
 		(void) sprintf(buf, "faceColor%d", face);
 		(void) GetPrivateProfileString(SECTION, buf,
 			faceColorString[face],
@@ -2633,7 +2633,7 @@ SetAllColors(OctWidget w)
 	if (w->oct.borderGC)
 		XtReleaseGC((Widget) w, w->oct.borderGC);
 	w->oct.borderGC = XtGetGC((Widget) w, valueMask, &values);
-	for (face = 0; face < MAXFACES; face++)
+	for (face = 0; face < MAX_FACES; face++)
 		GetColor(w, face);
 	if (w->oct.fontInfo)
 		XSetFont(XtDisplay(w), w->oct.borderGC,
@@ -2648,7 +2648,7 @@ SetValuesPuzzle(Widget current, Widget request, Widget renew)
 	int face;
 
 	CheckPieces(w);
-	for (face = 0; face < MAXFACES; face++) {
+	for (face = 0; face < MAX_FACES; face++) {
 		if (strcmp(w->oct.faceName[face], c->oct.faceName[face])) {
 			setColors = True;
 			break;
@@ -2748,7 +2748,7 @@ DestroyPuzzle(Widget old)
 	Display *display = XtDisplay(w);
 	int face;
 
-	for (face = 0; face < MAXFACES; face++)
+	for (face = 0; face < MAX_FACES; face++)
 		XtReleaseGC(old, w->oct.faceGC[face]);
 	XtReleaseGC(old, w->oct.borderGC);
 	XtReleaseGC(old, w->oct.frameGC);
@@ -2839,7 +2839,7 @@ Widget request, Widget renew
 	w->oct.mono = (DefaultDepthOfScreen(XtScreen(w)) < 2 ||
 		w->oct.mono);
 	w->oct.fontInfo = NULL;
-	for (face = 0; face < MAXFACES; face++)
+	for (face = 0; face < MAX_FACES; face++)
 		w->oct.faceGC[face] = NULL;
 	w->oct.borderGC = NULL;
 	w->oct.frameGC = NULL;
@@ -2847,9 +2847,9 @@ Widget request, Widget renew
 #endif
 	w->oct.focus = False;
 	loadFont(w);
-	for (face = 0; face < MAXFACES; face++)
+	for (face = 0; face < MAX_FACES; face++)
 		w->oct.facetLoc[face] = NULL;
-	for (orient = 0; orient < MAXORIENT / 2; orient++)
+	for (orient = 0; orient < MAX_ORIENT / 2; orient++)
 		w->oct.rowLoc[orient] = NULL;
 	w->oct.faceLoc = NULL;
 	CheckPieces(w);
