@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1993 - 2007	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1993 - 2007	David A. Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -234,28 +234,28 @@ static const char solveHelp[] = {
 #define SCOREFILE "oct.scores"
 #endif
 
-#define MAXFACETS 6
+#define MAX_FACETS 6
 #define NEVER (-1)
-#define FILENAMELEN 1024
-#define USERNAMELEN 120
-#define MESSAGELEN (USERNAMELEN+64)
-#define TITLELEN 2048
+#define FILE_NAME_LENGTH 1024
+#define USER_NAME_LENGTH 120
+#define MESSAGE_LENGTH (USER_NAME_LENGTH+64)
+#define TITLE_LENGTH 2048
 #define NOACCESS "noaccess"
 #define NOBODY "nobody"
 
 typedef struct {
 	int score;
-	char name[USERNAMELEN];
+	char name[USER_NAME_LENGTH];
 } PuzzleRecord;
 
-static PuzzleRecord puzzleRecord[MAXMODES][2][MAXFACETS - MINFACETS + 2];
+static PuzzleRecord puzzleRecord[MAX_MODES][2][MAX_FACETS - MIN_FACETS + 2];
 static int movesDsp = 0;
-static char messageDsp[MESSAGELEN] = "Welcome";
-static char recordDsp[MESSAGELEN] = "NOT RECORDED";
+static char messageDsp[MESSAGE_LENGTH] = "Welcome";
+static char recordDsp[MESSAGE_LENGTH] = "NOT RECORDED";
 static int oldSize;
 
 #ifdef HAVE_MOTIF
-static Widget moves, record, message, modes[MAXMODES], orientizeSwitch;
+static Widget moves, record, message, modes[MAX_MODES], orientizeSwitch;
 static Widget stickySwitch, practiceSwitch, facets;
 static char buff[21];
 static const char *modeString[] =
@@ -267,20 +267,20 @@ static Widget optionsDialog, referencesDialog, aboutDialog;
 static Widget solveDialog, practiceDialog, randomizeDialog;
 static Arg arg[3];
 #else
-static char titleDsp[TITLELEN] = "";
+static char titleDsp[TITLE_LENGTH] = "";
 #endif
-static char scoreFileName[FILENAMELEN] = SCOREFILE;
-static char fileName[FILENAMELEN];
+static char scoreFileName[FILE_NAME_LENGTH] = SCOREFILE;
+static char fileName[FILE_NAME_LENGTH];
 static Boolean randomized = False;
 #ifdef WINVER
-#define MAXPROGNAME 80
-static char progDsp[MAXPROGNAME] = TITLE;
-static char userNameDsp[USERNAMELEN] = "Guest";
+#define PROGRAM_NAME_LENGTH 80
+static char progDsp[PROGRAM_NAME_LENGTH] = TITLE;
+static char userNameDsp[USER_NAME_LENGTH] = "Guest";
 #else
 static Pixmap pixmap = None;
 static Widget topLevel, puzzle;
 static char *progDsp;
-static char userNameDsp[USERNAMELEN] = "";
+static char userNameDsp[USER_NAME_LENGTH] = "";
 
 #ifdef HAVE_MOTIF
 static void
@@ -302,9 +302,9 @@ PrintRecords(void)
 
 	(void) printf("                 OCT  HALL OF FAME\n\n");
 	(void) printf("MODE ORIENT FACET USER            MOVES\n");
-	for (mode = 0; mode < MAXMODES; mode++)
+	for (mode = 0; mode < MAX_MODES; mode++)
 		for (orient = 0; orient < 2; orient++)
-			for (i = 0; i <= MAXFACETS - MINFACETS + 1; i++) {
+			for (i = 0; i <= MAX_FACETS - MIN_FACETS + 1; i++) {
 				if (puzzleRecord[mode][orient][i].score > 0)
 					(void) printf("%4d%7d%6d %-12s%9d\n",
 						mode + 3, orient, i + 1,
@@ -319,12 +319,12 @@ InitRecords(void)
 {
 	int i, mode, orient;
 
-	for (mode = 0; mode < MAXMODES; mode++)
+	for (mode = 0; mode < MAX_MODES; mode++)
 		for (orient = 0; orient < 2; orient++)
-			for (i = 0; i <= MAXFACETS - MINFACETS + 1; i++) {
+			for (i = 0; i <= MAX_FACETS - MIN_FACETS + 1; i++) {
 				puzzleRecord[mode][orient][i].score = NEVER;
 				(void) strncpy(puzzleRecord[mode][orient][i].name,
-					NOACCESS, USERNAMELEN);
+					NOACCESS, USER_NAME_LENGTH);
 			}
 }
 
@@ -333,7 +333,7 @@ ReadRecords(void)
 {
 	FILE *fp;
 	int i, n, mode, orient;
-	char userName[USERNAMELEN];
+	char userName[USER_NAME_LENGTH];
 	char *buf1 = NULL, *buf2 = NULL;
 	char *fname, *lname;
 
@@ -343,9 +343,9 @@ ReadRecords(void)
 	stringCat(&buf2, buf1, SCOREFILE);
 	free(buf1);
 	fname = buf2;
-	(void) strncpy(fileName, lname, USERNAMELEN);
+	(void) strncpy(fileName, lname, USER_NAME_LENGTH);
 	if ((fp = fopen(fileName, "r")) == NULL) {
-		(void) strncpy(fileName, fname, USERNAMELEN);
+		(void) strncpy(fileName, fname, USER_NAME_LENGTH);
 		/* Try installed directory. */
 		if ((fp = fopen(fileName, "r")) == NULL) {
 			stringCat(&buf1, "Can not read ", fname);
@@ -374,15 +374,15 @@ ReadRecords(void)
 	}
 	free(lname);
 	free(fname);
-	for (mode = 0; mode < MAXMODES; mode++)
+	for (mode = 0; mode < MAX_MODES; mode++)
 		for (orient = 0; orient < 2; orient++)
-			for (i = 0; i <= MAXFACETS - MINFACETS + 1; i++) {
+			for (i = 0; i <= MAX_FACETS - MIN_FACETS + 1; i++) {
 				(void) fscanf(fp, "%d %s\n", &n, userName);
 				if (n <= puzzleRecord[mode][orient][i].score ||
 						puzzleRecord[mode][orient][i].score <= NEVER) {
 					puzzleRecord[mode][orient][i].score = n;
 					(void) strncpy(puzzleRecord[mode][orient][i].name,
-						userName, USERNAMELEN);
+						userName, USER_NAME_LENGTH);
 				}
 			}
 	(void) fclose(fp);
@@ -404,9 +404,9 @@ WriteRecords(void)
 	{
 #if HAVE_FCNTL_H
 		int lfd;
-		char lockFile[FILENAMELEN];
+		char lockFile[FILE_NAME_LENGTH];
 
-		(void) strncpy(lockFile, fileName, FILENAMELEN - 6);
+		(void) strncpy(lockFile, fileName, FILE_NAME_LENGTH - 6);
 		(void) strcat(lockFile, ".lock");
 		while (((lfd = open(lockFile, O_CREAT | O_EXCL, 0644)) < 0) &&
 				errno == EEXIST)
@@ -422,9 +422,9 @@ WriteRecords(void)
 #endif
 		}
 #endif
-		for (mode = 0; mode < MAXMODES; mode++) {
+		for (mode = 0; mode < MAX_MODES; mode++) {
 			for (orient = 0; orient < 2; orient++) {
-				for (i = 0; i <= MAXFACETS - MINFACETS + 1; i++)
+				for (i = 0; i <= MAX_FACETS - MIN_FACETS + 1; i++)
 					(void) fprintf(fp, "%d %s\n",
 						puzzleRecord[mode][orient][i].score, puzzleRecord[mode][orient][i].name);
 				(void) fprintf(fp, "\n");
@@ -445,12 +445,12 @@ PrintRecord(int size, int mode,
 {
 	int i = mode - PERIOD3;
 	int j = (orient) ? 1 : 0;
-	int k = (sticky) ? MAXFACETS - MINFACETS + 1 : size - MINFACETS;
+	int k = (sticky) ? MAX_FACETS - MIN_FACETS + 1 : size - MIN_FACETS;
 
 	if (practice) {
-		(void) strncpy(recordDsp, "practice", MESSAGELEN);
-	} else if (!sticky && size > MAXFACETS) {
-		(void) strncpy(recordDsp, "NOT RECORDED", MESSAGELEN);
+		(void) strncpy(recordDsp, "practice", MESSAGE_LENGTH);
+	} else if (!sticky && size > MAX_FACETS) {
+		(void) strncpy(recordDsp, "NOT RECORDED", MESSAGE_LENGTH);
 	} else if (puzzleRecord[i][j][k].score <= NEVER) {
 		(void) sprintf(recordDsp, "NEVER %s", NOACCESS);
 	} else {
@@ -499,21 +499,21 @@ HandleSolved(int counter, int size, int mode, Boolean orient, Boolean sticky)
 {
 	int i = mode - PERIOD3;
 	int j = (orient) ? 1 : 0;
-	int k = (sticky) ? MAXFACETS - MINFACETS + 1 : size - MINFACETS;
+	int k = (sticky) ? MAX_FACETS - MIN_FACETS + 1 : size - MIN_FACETS;
 
-	if ((sticky || size <= MAXFACETS) &&
+	if ((sticky || size <= MAX_FACETS) &&
 			(counter < puzzleRecord[i][j][k].score ||
 			puzzleRecord[i][j][k].score <= NEVER)) {
 		ReadRecords();	/* Maybe its been updated by another */
 		puzzleRecord[i][j][k].score = counter;
-		(void) strncpy(puzzleRecord[i][j][k].name, userNameDsp, USERNAMELEN);
+		(void) strncpy(puzzleRecord[i][j][k].name, userNameDsp, USER_NAME_LENGTH);
 		if ((size < 2 && mode != PERIOD4) ||
 				(size < 4 && mode == PERIOD4) || (orient &&
 				(counter < puzzleRecord[i][!j][k].score ||
 				puzzleRecord[i][!j][k].score <= NEVER))) {
 			puzzleRecord[i][!j][k].score = counter;
 			(void) strncpy(puzzleRecord[i][!j][k].name, userNameDsp,
-				USERNAMELEN);
+				USER_NAME_LENGTH);
 		}
 		WriteRecords();
 		PrintRecord(size, mode, orient, sticky, False);
@@ -546,7 +546,7 @@ Widget w
 	userName = w->oct.userName;
 	scoreFile = w->oct.scoreFile;
 	if (strcmp(scoreFile, ""))
-		(void) strncpy(scoreFileName, scoreFile, FILENAMELEN);
+		(void) strncpy(scoreFileName, scoreFile, FILE_NAME_LENGTH);
 #else
 	Boolean scoreOnly, versionOnly;
 
@@ -565,7 +565,7 @@ Widget w
 		exit(0);
 	}
 	if (strcmp(scoreFile, ""))
-		(void) strncpy(scoreFileName, scoreFile, FILENAMELEN);
+		(void) strncpy(scoreFileName, scoreFile, FILE_NAME_LENGTH);
 	if (scoreOnly) {
 		InitRecords();
 		ReadRecords();
@@ -573,7 +573,7 @@ Widget w
 		exit(0);
 	}
 #ifdef HAVE_MOTIF
-	if (size > MAXFACETS)
+	if (size > MAX_FACETS)
 		XtVaSetValues(facets, XmNmaximum, size, NULL);
 	XmScaleSetValue(facets, size);
 	XmToggleButtonSetState(modes[mode - PERIOD3], True, False);
@@ -586,13 +586,13 @@ Widget w
 	InitRecords();
 	ReadRecords();
 #ifndef WINVER
-	(void) strncpy(userNameDsp, userName, USERNAMELEN);
+	(void) strncpy(userNameDsp, userName, USER_NAME_LENGTH);
 #endif
 	if (!strcmp(userName, "") || !strcmp(userName, "(null)") ||
 			!strcmp(userName, NOACCESS) ||
 			!strcmp(userName, NOBODY)) {
 #ifdef WINVER
-		(void) strncpy(userNameDsp, userName, USERNAMELEN);
+		(void) strncpy(userNameDsp, userName, USER_NAME_LENGTH);
 #else
 		char *login = getlogin();
 
@@ -685,14 +685,14 @@ CallbackPuzzle(Widget w, caddr_t clientData, octCallbackStruct *callData)
 #ifdef HAVE_MOTIF
 		XtManageChild(solveDialog);
 #else
-		(void) strncpy(messageDsp, solveHelp, MESSAGELEN);
+		(void) strncpy(messageDsp, solveHelp, MESSAGE_LENGTH);
 #endif
 #endif
 		break;
 	case ACTION_RESTORE:
 		if (practice) {
 			(void) strncpy(recordDsp, "practice",
-				MESSAGELEN);
+				MESSAGE_LENGTH);
 #ifdef HAVE_MOTIF
 			PrintState(record, recordDsp);
 #endif
@@ -706,15 +706,15 @@ CallbackPuzzle(Widget w, caddr_t clientData, octCallbackStruct *callData)
 		break;
 	case ACTION_AMBIGUOUS:
 		(void) strncpy(messageDsp, "Ambiguous move",
-			MESSAGELEN);
+			MESSAGE_LENGTH);
 		break;
 	case ACTION_ILLEGAL:
 		if (practice || randomized)
 			(void) strncpy(messageDsp, "Illegal move",
-				MESSAGELEN);
+				MESSAGE_LENGTH);
 		else
 			(void) strncpy(messageDsp,
-				"Randomize to start", MESSAGELEN);
+				"Randomize to start", MESSAGE_LENGTH);
 		break;
 	case ACTION_MOVED:
 		movesDsp++;
@@ -733,7 +733,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, octCallbackStruct *callData)
 				"Congratulations %s!!", userNameDsp);
 		else
 			(void) strncpy(messageDsp, "Solved!",
-				MESSAGELEN);
+				MESSAGE_LENGTH);
 		SET_STARTED(w, False);
 		randomized = False;
 		break;
@@ -746,7 +746,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, octCallbackStruct *callData)
 		practice = !practice;
 		if (!practice)
 			(void) strncpy(messageDsp, "Randomize to start",
-				MESSAGELEN);
+				MESSAGE_LENGTH);
 		PrintRecord(size, mode, orient, sticky, practice);
 #ifdef WINVER
 		w->oct.practice = practice;
@@ -783,7 +783,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, octCallbackStruct *callData)
 #else
 			XtVaSetValues(w, XtNsize, size, NULL);
 #ifdef HAVE_MOTIF
-			if (size > MAXFACETS)
+			if (size > MAX_FACETS)
 				XtVaSetValues(facets, XmNmaximum, size, NULL);
 			XmScaleSetValue(facets, size);
 #endif
@@ -802,7 +802,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, octCallbackStruct *callData)
 			XtVaSetValues(w, XtNsize, size, NULL);
 #ifdef HAVE_MOTIF
 			XmScaleSetValue(facets, size);
-			if (size >= MAXFACETS)
+			if (size >= MAX_FACETS)
 				XtVaSetValues(facets, XmNmaximum, size, NULL);
 #endif
 #endif
@@ -1094,16 +1094,16 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 				(void) ReleaseDC(hWnd, widget.core.hDC);
 			}
 			break;
-		case ACTION_SHIFTCONTROL_TOP:
-		case ACTION_SHIFTCONTROL_TR:
-		case ACTION_SHIFTCONTROL_RIGHT:
-		case ACTION_SHIFTCONTROL_BR:
-		case ACTION_SHIFTCONTROL_BOTTOM:
-		case ACTION_SHIFTCONTROL_BL:
-		case ACTION_SHIFTCONTROL_LEFT:
-		case ACTION_SHIFTCONTROL_TL:
-		case ACTION_SHIFTCONTROL_CW:
-		case ACTION_SHIFTCONTROL_CCW:
+		case ACTION_SHIFT_CONTROL_TOP:
+		case ACTION_SHIFT_CONTROL_TR:
+		case ACTION_SHIFT_CONTROL_RIGHT:
+		case ACTION_SHIFT_CONTROL_BR:
+		case ACTION_SHIFT_CONTROL_BOTTOM:
+		case ACTION_SHIFT_CONTROL_BL:
+		case ACTION_SHIFT_CONTROL_LEFT:
+		case ACTION_SHIFT_CONTROL_TL:
+		case ACTION_SHIFT_CONTROL_CW:
+		case ACTION_SHIFT_CONTROL_CCW:
 			shift = 1;
 		case ACTION_CONTROL_TOP:
 		case ACTION_CONTROL_TR:
@@ -1128,7 +1128,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 					cursor.x - origin.x,
 					cursor.y - origin.y,
 					(int) LOWORD(wParam) -
-					((shift) ? ACTION_SHIFTCONTROL_TOP :
+					((shift) ? ACTION_SHIFT_CONTROL_TOP :
 					ACTION_CONTROL_TOP),
 					shift, TRUE);
 				(void) ReleaseDC(hWnd, widget.core.hDC);
@@ -1398,7 +1398,7 @@ StickyToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
 			size = 4;
 		else
 			size = oldSize;
-		if (size <= MAXFACETS)
+		if (size <= MAX_FACETS)
 			XmScaleSetValue(facets, size);
 		XtVaSetValues(puzzle,
 			XtNsize, size, NULL);
@@ -1433,7 +1433,7 @@ PracticeToggle(Widget w, XtPointer clientData,
 	if (practice)
 		(void) strcpy(messageDsp, "");
 	else
-		(void) strncpy(messageDsp, "Randomize to start", MESSAGELEN);
+		(void) strncpy(messageDsp, "Randomize to start", MESSAGE_LENGTH);
 	PrintState(message, messageDsp);
 }
 
@@ -1459,7 +1459,7 @@ static Widget
 createQuery(Widget w, char *text, char *title, XtCallbackProc callback)
 {
 	Widget button, messageBox;
-	char titleDsp[FILENAMELEN + 8];
+	char titleDsp[FILE_NAME_LENGTH + 8];
 	XmString titleString = NULL, messageString = NULL;
 	static XmStringCharSet charSet =
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
@@ -1485,7 +1485,7 @@ static Widget
 createHelp(Widget w, char *text, char *title)
 {
 	Widget button, messageBox;
-	char titleDsp[FILENAMELEN + 8];
+	char titleDsp[FILE_NAME_LENGTH + 8];
 	XmString titleString = NULL, messageString = NULL, buttonString = NULL;
 	static XmStringCharSet charSet =
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
@@ -1753,9 +1753,9 @@ main(int argc, char **argv)
 	facets = XtVaCreateManagedWidget("facets",
 		xmScaleWidgetClass, facetsRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Size", 5,
-		XmNminimum, MINFACETS,
-		XmNmaximum, MAXFACETS,
-		XmNvalue, MINFACETS,
+		XmNminimum, MIN_FACETS,
+		XmNmaximum, MAX_FACETS,
+		XmNvalue, MIN_FACETS,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
 	XtAddCallback(facets, XmNvalueChangedCallback,
@@ -1785,7 +1785,7 @@ main(int argc, char **argv)
 		XmNpacking, XmPACK_COLUMN, NULL);
 	orientizeSwitch = XtVaCreateManagedWidget("Oriented",
 		xmToggleButtonWidgetClass, switchRowCol,
-		XmNset, DEFAULTORIENT, NULL);
+		XmNset, DEFAULT_ORIENT, NULL);
 	XtAddCallback(orientizeSwitch, XmNvalueChangedCallback,
 		(XtCallbackProc) OrientToggle, (XtPointer) NULL);
 	stickySwitch = XtVaCreateManagedWidget("Sticky",
@@ -1795,7 +1795,7 @@ main(int argc, char **argv)
 		(XtCallbackProc) StickyToggle, (XtPointer) NULL);
 	practiceSwitch = XtVaCreateManagedWidget("Practice",
 		xmToggleButtonWidgetClass, switchRowCol,
-		XmNset, DEFAULTPRACTICE, NULL);
+		XmNset, DEFAULT_PRACTICE, NULL);
 	XtAddCallback(practiceSwitch, XmNvalueChangedCallback,
 		(XtCallbackProc) PracticeToggle, (XtPointer) NULL);
 	messageRowCol = XtVaCreateManagedWidget("messageRowCol",
