@@ -5,9 +5,9 @@
 #
 ###
 #
-#  Copyright (c) 1996 - 2007	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1996 - 2007	David A. Bagley, bagleyd@tux.org
 #
-#                   All Rights Reserved
+#		   All Rights Reserved
 #
 #  Permission to use, copy, modify, and distribute this software and
 #  its documentation for any purpose and without fee is hereby granted,
@@ -40,13 +40,13 @@
 
 #define SECTION "setup"
 
-static const char *pyramidColorString[MAXSTACKS - 1] =
+static const char *pyramidColorString[MAX_STACKS - 1] =
 {
 	"255 0 255",
-	"255 255 0"
+	"255 165 0"
 };
-static char pyramidColorChar[MAXSTACKS - 1] =
-{'M', 'Y'};
+static char pyramidColorChar[MAX_STACKS - 1] =
+{'M', 'O'};
 #else
 
 #ifndef LOGPATH
@@ -164,9 +164,6 @@ static XtResource resourcesPuzzle[] =
 	{XtNbackground, XtCBackground, XtRPixel, sizeof (Pixel),
 	 XtOffset(PanexWidget, panex.background),
 	 XtRString, (caddr_t) XtDefaultBackground},
-	{XtNframeColor, XtCColor, XtRPixel, sizeof (Pixel),
-	 XtOffset(PanexWidget, panex.frameColor),
-	 XtRString, (caddr_t) "cyan" /*XtDefaultForeground*/},
 	{XtNtileColor, XtCColor, XtRPixel, sizeof (Pixel),
 	 XtOffset(PanexWidget, panex.tileColor),
 	 XtRString, (caddr_t) "gray75" /*XtDefaultBackground*/},
@@ -175,13 +172,10 @@ static XtResource resourcesPuzzle[] =
 	 XtRString, (caddr_t) "magenta"},
 	{XtNpyramidColor1, XtCLabel, XtRString, sizeof (String),
 	 XtOffset(PanexWidget, panex.pyramidName[1]),
-	 XtRString, (caddr_t) "yellow"},
-	{XtNtileBorder, XtCColor, XtRPixel, sizeof (Pixel),
-	 XtOffset(PanexWidget, panex.borderColor),
-	 XtRString, (caddr_t) "gray25" /*XtDefaultForeground*/},
+	 XtRString, (caddr_t) "orange"},
 	{XtNdelay, XtCDelay, XtRInt, sizeof (int),
 	 XtOffset(PanexWidget, panex.delay),
-	 XtRString, (caddr_t) "10"}, /* DEFAULTDELAY */
+	 XtRString, (caddr_t) "10"}, /* DEFAULT_DELAY */
 	{XtNsound, XtCSound, XtRBoolean, sizeof (Boolean),
 	 XtOffset(PanexWidget, panex.sound),
 	 XtRString, (caddr_t) "FALSE"},
@@ -193,10 +187,10 @@ static XtResource resourcesPuzzle[] =
 	 XtRString, (caddr_t) "9x15bold"},
 	{XtNtiles, XtCTiles, XtRInt, sizeof (int),
 	 XtOffset(PanexWidget, panex.tiles),
-	 XtRString, (caddr_t) "10"}, /* DEFAULTTILES */
+	 XtRString, (caddr_t) "10"}, /* DEFAULT_TILES */
 	{XtNmode, XtCMode, XtRInt, sizeof (int),
 	 XtOffset(PanexWidget, panex.mode),
-	 XtRString, (caddr_t) "1"}, /* DEFAULTMODE */
+	 XtRString, (caddr_t) "1"}, /* DEFAULT_MODE */
 	{XtNuserName, XtCUserName, XtRString, sizeof (String),
 	 XtOffset(PanexWidget, panex.userName),
 	 XtRString, (caddr_t) ""},
@@ -321,12 +315,12 @@ loadFont(PanexWidget w)
 #define LOGFILE "panex.log"
 #endif
 
-static int startPositions[MAXMODES][MAXSTACKS] =
+static int startPositions[MAX_MODES][MAX_STACKS] =
 {
 	{0, -1, -1},
 	{0, -1, 1}
 };
-static int finishPositions[MAXMODES][MAXSTACKS] =
+static int finishPositions[MAX_MODES][MAX_STACKS] =
 {
 	{-1, -1, 0},
 	{1, -1, 0}
@@ -351,24 +345,24 @@ CheckTiles(PanexWidget w)
 {
 	char *buf1 = NULL, *buf2 = NULL;
 
-	if (w->panex.tiles < MINTILES) {
+	if (w->panex.tiles < MIN_TILES) {
 		intCat(&buf1, "Number of tiles out of bounds, use at least ",
-			MINTILES);
+			MIN_TILES);
 		stringCat(&buf2, buf1, ", defaulting to ");
 		free(buf1);
-		intCat(&buf1, buf2, DEFAULTTILES);
+		intCat(&buf1, buf2, DEFAULT_TILES);
 		free(buf2);
 		DISPLAY_WARNING(buf1);
 		free(buf1);
-		w->panex.tiles = DEFAULTTILES;
+		w->panex.tiles = DEFAULT_TILES;
 	}
 	if (w->panex.mode < HANOI || w->panex.mode > PANEX) {
 		intCat(&buf1,
 			"Mode is in error, use 0 for Hanoi, 1 for Panex, defaulting to ",
-			DEFAULTMODE);
+			DEFAULT_MODE);
 		DISPLAY_WARNING(buf1);
 		free(buf1);
-		w->panex.mode = DEFAULTMODE;
+		w->panex.mode = DEFAULT_MODE;
 	}
 	if (w->panex.delay < 0) {
 		intCat(&buf1, "Delay can not be negative (",
@@ -395,7 +389,7 @@ CartesianY(PanexWidget w, int loc)
 
 #if 0
 /* Only applies to Panex */
-static int middlePositions[MAXSTACKS] =
+static int middlePositions[MAX_STACKS] =
 {-1, 0, 1};
 
 Boolean
@@ -404,7 +398,7 @@ CheckMiddle(PanexWidget w)
 	int stack, loc;
 	PanexLoc i;
 
-	for (stack = 0; stack < MAXSTACKS; stack++)
+	for (stack = 0; stack < MAX_STACKS; stack++)
 		if ((i.stack = middlePositions[stack]) >= 0)
 			for (loc = 1; loc <= w->panex.tiles; loc++) {
 				i.loc = loc - 1;
@@ -422,7 +416,7 @@ CheckSolved(PanexWidget w)
 	int stack, loc;
 	PanexLoc i;
 
-	for (stack = 0; stack < MAXSTACKS; stack++)
+	for (stack = 0; stack < MAX_STACKS; stack++)
 		if ((i.stack = finishPositions[w->panex.mode][stack]) >= 0)
 			for (loc = 1; loc <= w->panex.tiles; loc++) {
 				i.loc = loc - 1;
@@ -441,10 +435,10 @@ PrintStacks(PanexWidget w)
 
 	(void) printf("top: where are the tiles in the stack\n");
 	for (position = 0; position <= w->panex.tiles; position++)
-		for (stack = 0; stack < MAXSTACKS; stack++) {
+		for (stack = 0; stack < MAX_STACKS; stack++) {
 			printf("%d,%d", w->panex.tileOfPosition[stack][position].stack,
 				w->panex.tileOfPosition[stack][position].loc);
-			if (stack + 1 == MAXSTACKS)
+			if (stack + 1 == MAX_STACKS)
 				(void) printf("\n");
 			else
 				(void) printf(" | ");
@@ -540,16 +534,16 @@ DrawPyramid(PanexWidget w, Pixmap dr, int color, int i, int j, int size,
 	trapazoidList[0].y = j * w->panex.pos.y + w->panex.delta.y +
 		w->panex.puzzleOffset.y + offsetPosition + 2;
 	if (w->panex.mono) {
-		pyramidGC = (offsetPosition) ? w->panex.tileGC :
-			w->panex.borderGC;
+		pyramidGC = (offsetPosition) ? w->panex.tileGC[1] :
+			w->panex.inverseGC[4];
 	} else {
 #ifndef WINVER
 		if ((w->panex.pyramidColor[color] == w->panex.borderColor)
 				&& offsetPosition)
-			pyramidGC = w->panex.tileGC;
+			pyramidGC = w->panex.tileGC[1];
 		else if ((w->panex.pyramidColor[color] == w->panex.tileColor)
 				&& !offsetPosition)
-			pyramidGC = w->panex.borderGC;
+			pyramidGC = w->panex.inverseGC[4];
 		else
 #endif
 			pyramidGC = w->panex.pyramidGC[color];
@@ -566,8 +560,8 @@ DrawPyramid(PanexWidget w, Pixmap dr, int color, int i, int j, int size,
 #else
 			w->panex.pyramidName[color][0];
 #endif
-		DRAWTEXT(w, dr, (offsetPosition) ? w->panex.borderGC :
-			w->panex.tileGC,
+		DRAWTEXT(w, dr, (offsetPosition) ? w->panex.inverseGC[4] :
+			w->panex.tileGC[1],
 			k - w->panex.letterOffset.x, trapazoidList[0].y +
 			w->panex.tileSize.y / 2 + w->panex.letterOffset.y, buf, 1);
 	}
@@ -606,19 +600,19 @@ static void
 DrawSlot(PanexWidget w, int stack, int x, int y, int width, int height)
 {
 	Pixmap dr = 0;
-	GC gc = w->panex.inverseGC;
+	GC gc = w->panex.inverseGC[1];
 	int sizex = w->panex.tileSize.x / 3;
 	int sizey = w->panex.tileSize.y / 3;
 
 	FILLRECTANGLE(w, dr, gc, x, y, width, height);
-	FillRectClip(w, dr, w->panex.borderGC,
+	FillRectClip(w, dr, w->panex.inverseGC[4],
 		sizex + w->panex.delta.x +
 		w->panex.puzzleOffset.x,
 		w->panex.delta.y / 2 + w->panex.puzzleOffset.y + sizey,
-		sizex + (MAXSTACKS - 1) * w->panex.pos.x,
+		sizex + (MAX_STACKS - 1) * w->panex.pos.x,
 		sizey,
 		x, y, width, height);
-	FillRectClip(w, dr, w->panex.borderGC,
+	FillRectClip(w, dr, w->panex.inverseGC[4],
 		sizex + w->panex.delta.x +
 		w->panex.puzzleOffset.x + stack * w->panex.pos.x,
 		w->panex.delta.y / 2 + w->panex.puzzleOffset.y + sizey,
@@ -626,7 +620,7 @@ DrawSlot(PanexWidget w, int stack, int x, int y, int width, int height)
 		(w->panex.tiles + 1) * w->panex.pos.y + w->panex.delta.y -
 		1 - 2 * sizey,
 		x, y, width, height);
-	FillRectClip(w, dr, w->panex.borderGC,
+	FillRectClip(w, dr, w->panex.inverseGC[4],
 		sizex + w->panex.delta.x +
 		w->panex.puzzleOffset.x + w->panex.pos.x,
 		w->panex.delta.y / 2 + w->panex.puzzleOffset.y + sizey,
@@ -651,20 +645,20 @@ DrawTile(PanexWidget w, int i, int j, Boolean erase, int pressedOffset,
 	sy = CartesianY(w, tileJ);
 	if (erase) {
 		/* Draw Slots */
-		FILLRECTANGLE(w, dr, w->panex.inverseGC,
+		FILLRECTANGLE(w, dr, w->panex.inverseGC[1],
 			dx, dy,
 			w->panex.tileSize.x + 1,
 			w->panex.tileSize.y + 1 - pressedOffset);
 		if (j == 0) {
 			if (i == 0) {
-				FILLRECTANGLE(w, dr, w->panex.borderGC,
+				FILLRECTANGLE(w, dr, w->panex.inverseGC[4],
 					dx + w->panex.tileSize.x / 3,
 					dy + w->panex.tileSize.y / 3 - 1 -
 					pressedOffset,
 					2 * w->panex.tileSize.x / 3 + 2,
 					w->panex.tileSize.y / 3);
-			} else if (i == MAXSTACKS - 1) {
-				FILLRECTANGLE(w, dr, w->panex.borderGC,
+			} else if (i == MAX_STACKS - 1) {
+				FILLRECTANGLE(w, dr, w->panex.inverseGC[4],
 					dx,
 					dy + w->panex.tileSize.y / 3 - 1 -
 					pressedOffset,
@@ -672,27 +666,27 @@ DrawTile(PanexWidget w, int i, int j, Boolean erase, int pressedOffset,
 					w->panex.tileSize.y / 3 +
 					pressedOffset);
 			} else {
-				FILLRECTANGLE(w, dr, w->panex.borderGC,
+				FILLRECTANGLE(w, dr, w->panex.inverseGC[4],
 					dx,
 					dy + w->panex.tileSize.y / 3 - 1 -
 					pressedOffset,
 					w->panex.tileSize.x + 1,
 					w->panex.tileSize.y / 3);
 			}
-			FILLRECTANGLE(w, dr, w->panex.borderGC,
+			FILLRECTANGLE(w, dr, w->panex.inverseGC[4],
 				dx + w->panex.tileSize.x / 3 - pressedOffset,
 				dy + w->panex.tileSize.y / 3 - 1,
 				w->panex.tileSize.x / 3,
 				w->panex.tileSize.y - w->panex.tileSize.y / 3 +
 				2 - pressedOffset);
 		} else if (j == w->panex.tiles) {
-			FILLRECTANGLE(w, dr, w->panex.borderGC,
+			FILLRECTANGLE(w, dr, w->panex.inverseGC[4],
 				dx + w->panex.tileSize.x / 3 - pressedOffset,
 				dy - pressedOffset,
 				w->panex.tileSize.x / 3,
 				2 * w->panex.tileSize.y / 3 + 2);
 		} else {
-			FILLRECTANGLE(w, dr, w->panex.borderGC,
+			FILLRECTANGLE(w, dr, w->panex.inverseGC[4],
 				dx + w->panex.tileSize.x / 3 - pressedOffset,
 				dy - pressedOffset,
 				w->panex.tileSize.x / 3,
@@ -711,11 +705,11 @@ DrawTile(PanexWidget w, int i, int j, Boolean erase, int pressedOffset,
 		SRCCOPY);
 	SelectObject(w->core.memDC, w->core.hOldBitmap);
 #else
-	XSetGraphicsExposures(XtDisplay(w), w->panex.tileGC, False);
+	XSetGraphicsExposures(XtDisplay(w), w->panex.tileGC[1], False);
 	XCopyArea(XtDisplay(w),
 		w->panex.bufferTiles[pressedOffset],
 		XtWindow(w),
-		w->panex.tileGC,
+		w->panex.tileGC[1],
 		sx, sy,
 		w->panex.tileSize.x, w->panex.tileSize.y,
 		dx, dy);
@@ -731,22 +725,22 @@ DrawBufferedTile(PanexWidget w, int i, int j, int pressedOffset)
 	GC tileGC;
 
 	dr = &(w->panex.bufferTiles[pressedOffset]);
-	tileGC = w->panex.tileGC;
+	tileGC = w->panex.tileGC[1];
 	dx = CartesianX(w, i) + pressedOffset;
 	dy = CartesianY(w, j) + pressedOffset;
 	if (pressedOffset != 0) {
-		drawShadow(w, *dr, w->panex.tileDarkerGC,
+		drawShadow(w, *dr, w->panex.tileGC[2],
 			dx - pressedOffset, dy - pressedOffset,
 			w->panex.tileSize.x, w->panex.tileSize.y);
 	}
 	fill3DRect(w, *dr, tileGC,
-		w->panex.tileDarkerGC, w->panex.tileBrighterGC,
+		w->panex.tileGC[2], w->panex.tileGC[0],
 		dx, dy, w->panex.tileSize.x, w->panex.tileSize.y,
 		pressedOffset == 0);
 	if (pressedOffset != 0) {
-		FILLRECTANGLE(w, *dr, w->panex.tileGC,
+		FILLRECTANGLE(w, *dr, w->panex.tileGC[1],
 			dx + w->panex.tileSize.x - 2, dy - 1, 1, 3);
-		FILLRECTANGLE(w, *dr, w->panex.tileGC,
+		FILLRECTANGLE(w, *dr, w->panex.tileGC[1],
 			dx - 1, dy + w->panex.tileSize.y - 2, 3, 1);
 	}
 	DrawPyramid(w, *dr,
@@ -884,30 +878,61 @@ DrawSlots(PanexWidget w, Pixmap dr)
 	dx = sizex + w->panex.delta.x + w->panex.puzzleOffset.x;
 	y = (w->panex.tiles + 1) * w->panex.pos.y + w->panex.delta.y;
 	dy = w->panex.delta.y / 2 + w->panex.puzzleOffset.y + sizey;
-	FILLRECTANGLE(w, dr, w->panex.borderGC, dx, dy,
-		sizex + (MAXSTACKS - 1) * w->panex.pos.x,
+	FILLRECTANGLE(w, dr, w->panex.inverseGC[4], dx, dy,
+		sizex + (MAX_STACKS - 1) * w->panex.pos.x,
 		sizey);
-	for (i = 0; i < MAXSTACKS; i++) {
-		FILLRECTANGLE(w, dr, w->panex.borderGC, dx, dy,
+	for (i = 0; i < MAX_STACKS; i++) {
+		FILLRECTANGLE(w, dr, w->panex.inverseGC[4], dx, dy,
 			sizex, y - 1 - 2 * sizey);
 		dx += w->panex.pos.x;
 	}
 }
 
+static void
+Draw3DFrame(const PanexWidget w, Pixmap dr, Boolean inside,
+	int x, int y, int width, int height)
+{
+	GC gc;
+
+	if (inside)
+		gc = w->panex.inverseGC[2];
+	else
+		gc = w->panex.inverseGC[1];
+	FILLRECTANGLE(w, dr, gc,
+		x, y, width, 1);
+	FILLRECTANGLE(w, dr, gc,
+		x, y + 1, 1, height - 1);
+	FILLRECTANGLE(w, dr, gc,
+		x + 1, y + 1, width - 2, 1);
+	FILLRECTANGLE(w, dr, gc,
+		x + 1, y + 2, 1, height - 3);
+	if (inside)
+		gc = w->panex.inverseGC[0];
+	else
+		gc = w->panex.inverseGC[1];
+	FILLRECTANGLE(w, dr, gc,
+		x + 1, y + height - 1, width - 1, 1);
+	FILLRECTANGLE(w, dr, gc,
+		x + width - 1, y + 1, 1, height - 2);
+	FILLRECTANGLE(w, dr, gc,
+		x + 2, y + height - 2, width - 3, 1);
+	FILLRECTANGLE(w, dr, gc,
+		x + width - 2, y + 2, 1, height - 4);
+}
+
 static void
 EraseFrame(PanexWidget w, Pixmap dr, Boolean focus)
 {
-	DRAWRECTANGLE(w, dr, (focus) ? w->panex.frameGC : w->panex.inverseGC,
-		0, 0, w->core.width - 1, w->core.height - 1);
-	FILLRECTANGLE(w, dr, w->panex.inverseGC,
-		1, 1, w->core.width - 2, w->core.height - 2);
+	FILLRECTANGLE(w, dr, (focus) ?
+		w->panex.inverseGC[2] : w->panex.inverseGC[1],
+		0, 0, w->core.width, w->core.height);
 }
 
 static void
 DrawFrame(PanexWidget w, Pixmap dr, Boolean focus)
 {
-	DRAWRECTANGLE(w, dr, (focus) ? w->panex.frameGC : w->panex.borderGC,
-		0, 0, w->core.width - 1, w->core.height - 1);
+	Draw3DFrame(w, dr, focus,
+		0, 0, w->core.width, w->core.height);
 }
 
 static void
@@ -975,8 +1000,8 @@ SelectTile(PanexWidget w, int x)
 	i = (x - w->panex.delta.x / 2) / w->panex.pos.x;
 	if (i < 0)
 		i = 0;
-	else if (i >= MAXSTACKS)
-		i = MAXSTACKS - 1;
+	else if (i >= MAX_STACKS)
+		i = MAX_STACKS - 1;
 #if 0
 	y -= w->panex.puzzleOffset.y;
 	j = (y - w->panex.delta.y / 2) / w->panex.pos.y;
@@ -1010,7 +1035,7 @@ DiscreteMoves(PanexWidget w, int currentStack, int currentPosition,
 	DrawTile(w, nextStack, nextPosition, False, FALSE, 0, 0);
 	FLUSH(w);
 	Sleep((unsigned int) MULTDELAY * w->panex.delay /
-		(w->panex.tiles + MAXSTACKS - 1));
+		(w->panex.tiles + MAX_STACKS - 1));
 }
 
 static void
@@ -1121,7 +1146,7 @@ ResetTiles(PanexWidget w)
 	PanexLoc i;
 
 	w->panex.currentStack = -1;
-	for (stack = 0; stack < MAXMODES; stack++) {
+	for (stack = 0; stack < MAX_MODES; stack++) {
 		if (w->panex.positionOfTile[stack]) {
 			free(w->panex.positionOfTile[stack]);
 			w->panex.positionOfTile[stack] = NULL;
@@ -1141,7 +1166,7 @@ ResetTiles(PanexWidget w)
 			DISPLAY_ERROR("Not enough memory, exiting.");
 		}
 	}
-	for (stack = 0; stack < MAXSTACKS; stack++) {
+	for (stack = 0; stack < MAX_STACKS; stack++) {
 		if (w->panex.tileOfPosition[stack])
 			free(w->panex.tileOfPosition[stack]);
 		if (!(w->panex.tileOfPosition[stack] = (PanexLoc *)
@@ -1157,7 +1182,7 @@ ResetTiles(PanexWidget w)
 			w->panex.positionOfTile[stack][loc] = i;
 		}
 	}
-	for (stack = 0; stack < MAXSTACKS; stack++) {
+	for (stack = 0; stack < MAX_STACKS; stack++) {
 		i.stack = -1;
 		i.loc = -1;
 		w->panex.tileOfPosition[stack][0] = i;
@@ -1222,7 +1247,7 @@ GetTiles(PanexWidget w)
 	flushMoves(w, &redo, FALSE);
 	while ((c = getc(fp)) != EOF && c != SYMBOL);
 	(void) fscanf(fp, "%d", &tiles);
-	if (tiles >= MINTILES) {
+	if (tiles >= MIN_TILES) {
 		for (i = w->panex.tiles; i < tiles; i++) {
 			setPuzzle(w, ACTION_INCREMENT);
 		}
@@ -1235,7 +1260,7 @@ GetTiles(PanexWidget w)
 		free(buf1);
 		stringCat(&buf1, buf2, " should be between ");
 		free(buf2);
-		intCat(&buf2, buf1, MINTILES);
+		intCat(&buf2, buf1, MIN_TILES);
 		free(buf1);
 		stringCat(&buf1, buf2, " and MAXINT");
 		free(buf2);
@@ -1455,7 +1480,7 @@ IncrementTiles(PanexWidget w)
 static void
 DecrementTiles(PanexWidget w)
 {
-	if (w->panex.tiles <= MINTILES)
+	if (w->panex.tiles <= MIN_TILES)
 		return;
 	setPuzzle(w, ACTION_DECREMENT);
 }
@@ -1481,28 +1506,28 @@ MovePuzzle(PanexWidget w, int fromStack, int fromPosition, int toStack,
 	return toPosition;
 }
 
-#define FACTOR 0.7
+#define BRIGHT_FACTOR 0.8
+#define DARK_FACTOR 0.75
 
 #ifdef WINVER
-#define MAXINTENSITY 0xFF
+#define MAX_INTENSITY 0xFF
 static int
 brighter(const int light)
 {
-	int i = (int) ((1 - FACTOR) * MAXINTENSITY);
+	int i = (int) ((1 - BRIGHT_FACTOR) * MAX_INTENSITY);
 	int temp = light;
 
 	if (temp < i)
 		temp = i;
-	return MIN(temp / FACTOR, MAXINTENSITY);
+	return MIN(temp / BRIGHT_FACTOR, MAX_INTENSITY);
 }
 
 static int
 darker(const int light)
 {
-	return (int) (light * FACTOR);
+	return (int) (light * DARK_FACTOR);
 }
 
-
 static void
 SetValuesPuzzle(PanexWidget w)
 {
@@ -1513,42 +1538,39 @@ SetValuesPuzzle(PanexWidget w)
 	int pyramid;
 
 	w->panex.tiles = GetPrivateProfileInt(SECTION, "tiles",
-		DEFAULTTILES, INIFILE);
+		DEFAULT_TILES, INIFILE);
 	w->panex.mode = GetPrivateProfileInt(SECTION, "mode",
-		DEFAULTMODE, INIFILE);
+		DEFAULT_MODE, INIFILE);
 	w->panex.mono = (BOOL) GetPrivateProfileInt(SECTION, "mono",
-		DEFAULTMONO, INIFILE);
+		DEFAULT_MONO, INIFILE);
 	w->panex.reverse = (BOOL) GetPrivateProfileInt(SECTION, "reverseVideo",
-		DEFAULTREVERSE, INIFILE);
-	/* cyan */
-	(void) GetPrivateProfileString(SECTION, "frameColor", "0 255 255",
-		szBuf, sizeof (szBuf), INIFILE);
-	(void) sscanf(szBuf, "%d %d %d",
-		&(color.red), &(color.green), &(color.blue));
-	w->panex.frameGC = RGB(color.red, color.green, color.blue);
+		DEFAULT_REVERSE, INIFILE);
 	/* gray75 */
 	(void) GetPrivateProfileString(SECTION, "tileColor", "191 191 191",
 		szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
-	w->panex.tileGC = RGB(color.red, color.green, color.blue);
-	w->panex.tileBrighterGC = RGB(brighter(color.red),
+	w->panex.tileGC[1] = RGB(color.red, color.green, color.blue);
+	w->panex.tileGC[0] = RGB(brighter(color.red),
 		brighter(color.green), brighter(color.blue));
-	w->panex.tileDarkerGC = RGB(darker(color.red),
+	w->panex.tileGC[2] = RGB(darker(color.red),
 		darker(color.green), darker(color.blue));
-	/* gray25 */
-	(void) GetPrivateProfileString(SECTION, "tileBorder", "64 64 64",
-		szBuf, sizeof (szBuf), INIFILE);
-	(void) sscanf(szBuf, "%d %d %d",
-		&(color.red), &(color.green), &(color.blue));
-	w->panex.borderGC = RGB(color.red, color.green, color.blue);
 	/* #AEB2C3 */
 	(void) GetPrivateProfileString(SECTION, "background", "174 178 195",
 		szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
-	w->panex.inverseGC = RGB(color.red, color.green, color.blue);
-	for (pyramid = 0; pyramid < MAXSTACKS - 1; pyramid++) {
+	w->panex.inverseGC[1] = RGB(color.red, color.green, color.blue);
+	w->panex.inverseGC[0] = RGB(brighter(color.red),
+		brighter(color.green), brighter(color.blue));
+	w->panex.inverseGC[2] = RGB(darker(color.red),
+		darker(color.green), darker(color.blue));
+	w->panex.inverseGC[3] = RGB(darker(darker(color.red)),
+		darker(darker(color.green)), darker(darker(color.blue)));
+	w->panex.inverseGC[4] = RGB(darker(darker(darker(color.red))),
+		darker(darker(darker(color.green))),
+		darker(darker(darker(color.blue))));
+	for (pyramid = 0; pyramid < MAX_STACKS - 1; pyramid++) {
 		(void) sprintf(buf, "pyramidColor%d", pyramid);
 		(void) GetPrivateProfileString(SECTION,
 			buf, pyramidColorString[pyramid],
@@ -1565,7 +1587,37 @@ SetValuesPuzzle(PanexWidget w)
 		w->panex.pyramidChar[pyramid] = szBuf[0];
 	}
 	w->panex.delay = GetPrivateProfileInt(SECTION, "delay",
-		DEFAULTDELAY, INIFILE);
+		DEFAULT_DELAY, INIFILE);
+	w->panex.sound = (BOOL)
+		GetPrivateProfileInt(SECTION, "sound", 0, INIFILE);
+	(void) GetPrivateProfileString(SECTION, "moveSound", MOVESOUND,
+		szBuf, sizeof (szBuf), INIFILE);
+	(void) strcpy(w->panex.moveSound, szBuf);
+		w->panex.moveSound[80] = 0;
+	(void) GetPrivateProfileString(SECTION, "userName", "Guest",
+		szBuf, sizeof (szBuf), INIFILE);
+	(void) strcpy(w->panex.userName, szBuf);
+	w->panex.userName[80] = 0;
+	(void) GetPrivateProfileString(SECTION, "scoreFile", "",
+		szBuf, sizeof (szBuf), INIFILE);
+	for (pyramid = 0; pyramid < MAX_STACKS - 1; pyramid++) {
+		(void) sprintf(buf, "pyramidColor%d", pyramid);
+		(void) GetPrivateProfileString(SECTION,
+			buf, pyramidColorString[pyramid],
+			szBuf, sizeof (szBuf), INIFILE);
+		(void) sscanf(szBuf, "%d %d %d",
+			&(color.red), &(color.green), &(color.blue));
+		w->panex.pyramidGC[pyramid] =
+			RGB(color.red, color.green, color.blue);
+		(void) sprintf(buf, "pyramidChar%d", pyramid);
+		charbuf[0] = pyramidColorChar[pyramid];
+		charbuf[1] = '\0';
+		(void) GetPrivateProfileString(SECTION, buf, charbuf,
+			szBuf, sizeof (szBuf), INIFILE);
+		w->panex.pyramidChar[pyramid] = szBuf[0];
+	}
+	w->panex.delay = GetPrivateProfileInt(SECTION, "delay",
+		DEFAULT_DELAY, INIFILE);
 	w->panex.sound = (BOOL)
 		GetPrivateProfileInt(SECTION, "sound", 0, INIFILE);
 	(void) GetPrivateProfileString(SECTION, "moveSound", MOVESOUND,
@@ -1592,28 +1644,27 @@ DestroyPuzzle(HBRUSH brush)
 }
 
 #else
-#define MAXINTENSITY 0xFFFF
+#define MAX_INTENSITY 0xFFFF
 
 static Pixel
 brighter(PanexWidget w, Pixel pixel)
 {
 	XColor color;
-	int i = (int) ((1 - FACTOR) * MAXINTENSITY);
+	Colormap colormap = DefaultColormapOfScreen(XtScreen(w));
+	int i = (int) ((1 - BRIGHT_FACTOR) * MAX_INTENSITY);
 
 	color.pixel = pixel;
-	XQueryColor(XtDisplay(w), DefaultColormapOfScreen(XtScreen(w)),
-		&color);
+	VOID XQueryColor(XtDisplay(w), colormap, &color);
 	if (color.red < i)
 		color.red = i;
 	if (color.green < i)
 		color.green = i;
 	if (color.blue < i)
 		color.blue = i;
-	color.red = (unsigned short) MIN(color.red / FACTOR, MAXINTENSITY);
-	color.green = (unsigned short) MIN(color.green / FACTOR, MAXINTENSITY);
-	color.blue = (unsigned short) MIN(color.blue / FACTOR, MAXINTENSITY);
-	if (XAllocColor(XtDisplay(w), DefaultColormapOfScreen(XtScreen(w)),
-			&color))
+	color.red = (unsigned short) MIN(color.red / BRIGHT_FACTOR, MAX_INTENSITY);
+	color.green = (unsigned short) MIN(color.green / BRIGHT_FACTOR, MAX_INTENSITY);
+	color.blue = (unsigned short) MIN(color.blue / BRIGHT_FACTOR, MAX_INTENSITY);
+	if (XAllocColor(XtDisplay(w), colormap, &color))
 		return color.pixel;
 	return pixel;
 }
@@ -1622,15 +1673,14 @@ static Pixel
 darker(PanexWidget w, Pixel pixel)
 {
 	XColor color;
+	Colormap colormap = DefaultColormapOfScreen(XtScreen(w));
 
 	color.pixel = pixel;
-	XQueryColor(XtDisplay(w), DefaultColormapOfScreen(XtScreen(w)),
-		&color);
-	color.red = (unsigned short) (color.red * FACTOR);
-	color.green = (unsigned short) (color.green * FACTOR);
-	color.blue = (unsigned short) (color.blue * FACTOR);
-	if (XAllocColor(XtDisplay(w), DefaultColormapOfScreen(XtScreen(w)),
-			&color))
+	VOID XQueryColor(XtDisplay(w), colormap, &color);
+	color.red = (unsigned short) (color.red * DARK_FACTOR);
+	color.green = (unsigned short) (color.green * DARK_FACTOR);
+	color.blue = (unsigned short) (color.blue * DARK_FACTOR);
+	if (XAllocColor(XtDisplay(w), colormap, &color))
 		return color.pixel;
 	return pixel;
 }
@@ -1695,30 +1745,44 @@ SetAllColors(PanexWidget w)
 
 	valueMask = GCForeground | GCBackground;
 	if (w->panex.reverse) {
-		values.background = w->panex.foreground;
-		values.foreground = w->panex.background;
+		values.foreground = w->panex.foreground;
+		values.background = w->panex.background;
 	} else {
 		values.foreground = w->panex.background;
 		values.background = w->panex.foreground;
 	}
-	if (w->panex.inverseGC)
-		XtReleaseGC((Widget) w, w->panex.inverseGC);
-	w->panex.inverseGC = XtGetGC((Widget) w, valueMask, &values);
-	if (w->panex.mono) {
-		if (w->panex.reverse) {
-			values.foreground = w->panex.background;
-			values.background = w->panex.foreground;
-		} else {
-			values.foreground = w->panex.foreground;
-			values.background = w->panex.background;
-		}
-	} else {
-		values.foreground = w->panex.frameColor;
-		values.background = w->panex.borderColor;
+	if (w->panex.inverseGC[1])
+		XtReleaseGC((Widget) w, w->panex.inverseGC[1]);
+	w->panex.inverseGC[1] = XtGetGC((Widget) w, valueMask, &values);
+	if (!w->panex.mono) {
+		values.foreground = brighter(w, (w->panex.reverse) ?
+			w->panex.foreground : w->panex.background);
 	}
-	if (w->panex.frameGC)
-		XtReleaseGC((Widget) w, w->panex.frameGC);
-	w->panex.frameGC = XtGetGC((Widget) w, valueMask, &values);
+	if (w->panex.inverseGC[0])
+		XtReleaseGC((Widget) w, w->panex.inverseGC[0]);
+	w->panex.inverseGC[0] = XtGetGC((Widget) w, valueMask, &values);
+	if (!w->panex.mono) {
+		values.foreground = darker(w, (w->panex.reverse) ?
+			w->panex.foreground : w->panex.background);
+	}
+	if (w->panex.inverseGC[2])
+		XtReleaseGC((Widget) w, w->panex.inverseGC[2]);
+	w->panex.inverseGC[2] = XtGetGC((Widget) w, valueMask, &values);
+	if (!w->panex.mono) {
+		values.foreground = darker(w, darker(w, (w->panex.reverse) ?
+			w->panex.foreground : w->panex.background));
+	}
+	if (w->panex.inverseGC[3])
+		XtReleaseGC((Widget) w, w->panex.inverseGC[3]);
+	w->panex.inverseGC[3] = XtGetGC((Widget) w, valueMask, &values);
+	if (!w->panex.mono) {
+		values.foreground = darker(w, darker(w, darker(w,
+			(w->panex.reverse) ?
+			w->panex.foreground : w->panex.background)));
+	}
+	if (w->panex.inverseGC[4])
+		XtReleaseGC((Widget) w, w->panex.inverseGC[4]);
+	w->panex.inverseGC[4] = XtGetGC((Widget) w, valueMask, &values);
 	if (w->panex.reverse) {
 		if (w->panex.mono) {
 			values.background = w->panex.foreground;
@@ -1736,45 +1800,25 @@ SetAllColors(PanexWidget w)
 			values.background = w->panex.borderColor;
 		}
 	}
-	if (w->panex.tileGC)
-		XtReleaseGC((Widget) w, w->panex.tileGC);
-	w->panex.tileGC = XtGetGC((Widget) w, valueMask, &values);
+	if (w->panex.tileGC[1])
+		XtReleaseGC((Widget) w, w->panex.tileGC[1]);
+	w->panex.tileGC[1] = XtGetGC((Widget) w, valueMask, &values);
 	if (!w->panex.mono) {
 		values.foreground = brighter(w, w->panex.tileColor);
 	}
-	if (w->panex.tileBrighterGC)
-		XtReleaseGC((Widget) w, w->panex.tileBrighterGC);
-	w->panex.tileBrighterGC = XtGetGC((Widget) w, valueMask, &values);
+	if (w->panex.tileGC[0])
+		XtReleaseGC((Widget) w, w->panex.tileGC[0]);
+	w->panex.tileGC[0] = XtGetGC((Widget) w, valueMask, &values);
 	if (!w->panex.mono) {
 		values.foreground = darker(w, w->panex.tileColor);
 	}
-	if (w->panex.tileDarkerGC)
-		XtReleaseGC((Widget) w, w->panex.tileDarkerGC);
-	w->panex.tileDarkerGC = XtGetGC((Widget) w, valueMask, &values);
-	if (w->panex.reverse) {
-		if (w->panex.mono) {
-			values.foreground = w->panex.foreground;
-			values.background = w->panex.background;
-		} else {
-			values.foreground = w->panex.tileColor;
-			values.background = w->panex.borderColor;
-		}
-	} else {
-		if (w->panex.mono) {
-			values.background = w->panex.foreground;
-			values.foreground = w->panex.background;
-		} else {
-			values.background = w->panex.tileColor;
-			values.foreground = w->panex.borderColor;
-		}
-	}
-	if (w->panex.borderGC)
-		XtReleaseGC((Widget) w, w->panex.borderGC);
-	w->panex.borderGC = XtGetGC((Widget) w, valueMask, &values);
+	if (w->panex.tileGC[2])
+		XtReleaseGC((Widget) w, w->panex.tileGC[2]);
+	w->panex.tileGC[2] = XtGetGC((Widget) w, valueMask, &values);
 	for (pyramid = 0; pyramid <= w->panex.mode; pyramid++)
 		GetColor(w, pyramid);
 	if (w->panex.fontInfo)
-		XSetFont(XtDisplay(w), w->panex.borderGC,
+		XSetFont(XtDisplay(w), w->panex.inverseGC[4],
 			w->panex.fontInfo->fid);
 }
 
@@ -1795,7 +1839,6 @@ SetValuesPuzzle(Widget current, Widget request, Widget renew)
 		}
 	}
 	if (w->panex.font != c->panex.font ||
-			w->panex.borderColor != c->panex.borderColor ||
 			w->panex.reverse != c->panex.reverse ||
 			w->panex.mono != c->panex.mono ||
 			setColors) {
@@ -1804,7 +1847,6 @@ SetValuesPuzzle(Widget current, Widget request, Widget renew)
 		redrawTiles = True;
 	} else if (w->panex.background != c->panex.background ||
 			w->panex.foreground != c->panex.foreground ||
-			w->panex.borderColor != c->panex.borderColor ||
 			w->panex.tileColor != c->panex.tileColor ||
 			w->panex.reverse != c->panex.reverse ||
 			w->panex.mono != c->panex.mono ||
@@ -1826,8 +1868,8 @@ SetValuesPuzzle(Widget current, Widget request, Widget renew)
 		redraw = True;
 	}
 	if (w->panex.delay != c->panex.delay) {
-		w->panex.numSlices = ((w->panex.delay < MAXSLICES) ?
-			w->panex.delay + 1 : MAXSLICES);
+		w->panex.numSlices = ((w->panex.delay < MAX_SLICES) ?
+			w->panex.delay + 1 : MAX_SLICES);
 	}
 	if (w->panex.menu != ACTION_IGNORE) {
 		int menu = w->panex.menu;
@@ -1888,16 +1930,14 @@ DestroyPuzzle(Widget old)
 {
 	PanexWidget w = (PanexWidget) old;
 	Display *display = XtDisplay(w);
-	int pyramid;
+	int i;
 
-	for (pyramid = 0; pyramid <= w->panex.mode; pyramid++)
-		XtReleaseGC(old, w->panex.pyramidGC[pyramid]);
-	XtReleaseGC(old, w->panex.tileGC);
-	XtReleaseGC(old, w->panex.borderGC);
-	XtReleaseGC(old, w->panex.tileBrighterGC);
-	XtReleaseGC(old, w->panex.tileDarkerGC);
-	XtReleaseGC(old, w->panex.frameGC);
-	XtReleaseGC(old, w->panex.inverseGC);
+	for (i = 0; i <= w->panex.mode; i++)
+		XtReleaseGC(old, w->panex.pyramidGC[i]);
+	for (i = 0; i < FG_SHADES; i++)
+		XtReleaseGC(old, w->panex.tileGC[i]);
+	for (i = 0; i < BG_SHADES; i++)
+		XtReleaseGC(old, w->panex.inverseGC[i]);
 	XtRemoveCallbacks(old, XtNselectCallback, w->panex.select);
 	if (w->panex.fontInfo) {
 		XUnloadFont(display, w->panex.fontInfo->fid);
@@ -1980,10 +2020,10 @@ ResizePuzzle(PanexWidget w)
 	w->panex.delta.x = 8;
 	w->panex.delta.y = 2;
 	w->panex.pos.x = MAX(((int) w->core.width - w->panex.delta.x) /
-			MAXSTACKS, w->panex.delta.x);
+			MAX_STACKS, w->panex.delta.x);
 	w->panex.pos.y = MAX(((int) w->core.height - 2 * w->panex.delta.y - 3) /
 			(w->panex.tiles + 1), w->panex.delta.y);
-	w->panex.width = w->panex.pos.x * MAXSTACKS + w->panex.delta.x + 2;
+	w->panex.width = w->panex.pos.x * MAX_STACKS + w->panex.delta.x + 2;
 	w->panex.height = w->panex.pos.y * (w->panex.tiles + 1) +
 		w->panex.delta.y + 3;
 	w->panex.puzzleOffset.x = ((int) w->core.width - w->panex.width + 2) / 2;
@@ -2020,13 +2060,14 @@ Widget request, Widget renew
 	int stack;
 #ifdef WINVER
 	SetValuesPuzzle(w);
-	brush = CreateSolidBrush(w->panex.inverseGC);
+	brush = CreateSolidBrush(w->panex.inverseGC[2]);
 	SETBACK(w->core.hWnd, brush);
 	(void) SRAND(time(NULL));
 	w->panex.bufferTiles[0] = NULL;
 	w->panex.bufferTiles[1] = NULL;
 #else
 	PanexWidget w = (PanexWidget) renew;
+	int i;
 
 	(void) SRAND(getpid());
 	for (stack = 0; stack <= w->panex.mode; stack++)
@@ -2035,24 +2076,22 @@ Widget request, Widget renew
 	w->panex.bufferTiles[1] = None;
 	w->panex.colormap = None;
 	w->panex.fontInfo = NULL;
-	w->panex.tileGC = NULL;
-	w->panex.borderGC = NULL;
-	w->panex.tileBrighterGC = NULL;
-	w->panex.tileDarkerGC = NULL;
-	w->panex.frameGC = NULL;
-	w->panex.inverseGC = NULL;
+	for (i = 0; i < FG_SHADES; i++)
+		w->panex.tileGC[i] = NULL;
+	for (i = 0; i < BG_SHADES; i++)
+		w->panex.inverseGC[i] = NULL;
 #endif
 	w->panex.focus = False;
 	loadFont(w);
-	for (stack = 0; stack < MAXSTACKS; stack++) {
+	for (stack = 0; stack < MAX_STACKS; stack++) {
 		w->panex.tileOfPosition[stack] = NULL;
 		w->panex.positionOfTile[stack] = NULL;
 	}
 	CheckTiles(w);
 	newMoves(&undo);
 	newMoves(&redo);;
-	w->panex.numSlices = ((w->panex.delay < MAXSLICES) ?
-		w->panex.delay + 1 : MAXSLICES);
+	w->panex.numSlices = ((w->panex.delay < MAX_SLICES) ?
+		w->panex.delay + 1 : MAX_SLICES);
 	SizePuzzle(w);
 }
 
