@@ -16,7 +16,7 @@
 #  Dubrovsky.
 #  Break ability taken from the X puzzle by Don Bennett, HP Labs
 #
-#  Copyright (c) 1996 - 2007	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1996 - 2007	David A. Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -188,12 +188,12 @@ SolveHanoiMode(PanexWidget w)
 			if (triangleTurn) {
 				fromStack = triangleStack;
 				toStack = (triangleStack + triangleDirection) %
-					MAXSTACKS;
+					MAX_STACKS;
 				triangleStack = toStack;
 				triangleTurn = FALSE;
 			} else {
-				temp1Stack = (triangleStack + 1) % MAXSTACKS;
-				temp2Stack = (triangleStack + 2) % MAXSTACKS;
+				temp1Stack = (triangleStack + 1) % MAX_STACKS;
+				temp2Stack = (triangleStack + 2) % MAX_STACKS;
 				temp1Loc = TopOfStack(w, temp1Stack, 0);
 				temp2Loc = TopOfStack(w, temp2Stack, 0);
 				if (temp1Loc < 0 && temp2Loc < 0)
@@ -235,7 +235,7 @@ static void PrintStacks(PanexWidget w)
 	int position, stack;
 
 	for (position = 0; position <= w->panex.tiles; position++)
-		for (stack = 0; stack < MAXSTACKS; stack++) {
+		for (stack = 0; stack < MAX_STACKS; stack++) {
 			char tile = '-';
 
 			if (w->panex.tileOfPosition[stack][position].stack >= 0) {
@@ -246,7 +246,7 @@ static void PrintStacks(PanexWidget w)
 				tile += (char) w->panex.tileOfPosition[stack][position].loc;
 			}
 			(void) printf("%d", tile);
-			if (stack == MAXSTACKS - 1)
+			if (stack == MAX_STACKS - 1)
 				(void) printf("\n");
 			else
 				(void) printf(" ");
