@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1996 - 2007	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1996 - 2007	David A. Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -90,7 +90,7 @@ static PanexRec widget;
 
 #ifndef WINVER
 static const char aboutHelp[] = {
-"Panex Version 7.3.2\n"
+"Panex Version 7.3.3\n"
 "Send bugs (reports or fixes) to the author: "
 "David Bagley <bagleyd@tux.org>\n"
 "The latest version is at: "
@@ -103,9 +103,9 @@ static const char optionsHelp[] = {
 "[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
 "[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
 "[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
-"[-tile {color}] [-pyramid{0|1} {color}]\n"
-"[-{border|bd} {color}] [-delay msecs] [-[no]sound]\n"
-"[-moveSound {filename}] [-{font|fn} {fontname}]\n"
+"[-tile {color}] [-pyramid{0|1} {color}] [-delay msecs]\n"
+"[-[no]sound] [-moveSound {filename}]\n"
+"[-{font|fn} {fontname}]\n"
 "[-tiles {int}] [-{mode {int}|hanoi|panex}]\n"
 "[-userName {string}] [-scoreFile {filename}] [-scores]\n"
 "[-version]\n"
@@ -118,7 +118,7 @@ static const char descriptionHelp[] = {
 "estimated from the 1980's.  Mathematicians at Bell\n"
 "Laboratories estimated the number of moves to swap 2 columns "
 "of order 10 to be  27,564 <= N <= 31,537.  It came\n"
-"in two varieties: one with a magenta and a yellow pyramid "
+"in two varieties: one with a magenta and a orange pyramid "
 "of order 10 on silver tiles; in the gold version, the\n"
 "gold version pieces of each color look alike (i.e. no "
 "pyramid is drawn on them), this is a little harder.\n"
@@ -195,29 +195,29 @@ static const char referencesHelp[] = {
 #define SCOREFILE "panex.scores"
 #endif
 
-#define MAXTILES 10
+#define MAX_TILES 10
 #define NEVER (-1)
-#define FILENAMELEN 1024
-#define USERNAMELEN 120
-#define MESSAGELEN (USERNAMELEN+64)
-#define TITLELEN 2048
+#define FILE_NAME_LENGTH 1024
+#define USER_NAME_LENGTH 120
+#define MESSAGE_LENGTH (USER_NAME_LENGTH+64)
+#define TITLE_LENGTH 2048
 #define NOACCESS "noaccess"
 #define NOBODY "nobody"
 
 typedef struct {
 	int score;
-	char name[USERNAMELEN];
+	char name[USER_NAME_LENGTH];
 } PuzzleRecord;
 
-static PuzzleRecord puzzleRecord[MAXMODES][MAXTILES - MINTILES + 1];
+static PuzzleRecord puzzleRecord[MAX_MODES][MAX_TILES - MIN_TILES + 1];
 static int movesDsp = 0;
-static char messageDsp[MESSAGELEN] = "Welcome";
-static char recordDsp[MESSAGELEN] = "NOT RECORDED";
+static char messageDsp[MESSAGE_LENGTH] = "Welcome";
+static char recordDsp[MESSAGE_LENGTH] = "NOT RECORDED";
 
 #ifdef HAVE_MOTIF
-#define MINSPEED 1
-#define MAXSPEED 50
-static Widget moves, record, message, modes[MAXMODES], tile, speed;
+#define MIN_SPEED 1
+#define MAX_SPEED 50
+static Widget moves, record, message, modes[MAX_MODES], tile, speed;
 static char buff[21];
 static const char *modeString[] =
 {
@@ -228,19 +228,19 @@ static Widget optionsDialog, referencesDialog, aboutDialog;
 static Widget clearDialog;
 static Arg arg[3];
 #else
-static char titleDsp[TITLELEN] = "";
+static char titleDsp[TITLE_LENGTH] = "";
 #endif
-static char scoreFileName[FILENAMELEN] = SCOREFILE;
-static char fileName[FILENAMELEN];
+static char scoreFileName[FILE_NAME_LENGTH] = SCOREFILE;
+static char fileName[FILE_NAME_LENGTH];
 #ifdef WINVER
-#define MAXPROGNAME 80
-static char progDsp[MAXPROGNAME] = TITLE;
-static char userNameDsp[USERNAMELEN] = "Guest";
+#define PROGRAM_NAME_LENGTH 80
+static char progDsp[PROGRAM_NAME_LENGTH] = TITLE;
+static char userNameDsp[USER_NAME_LENGTH] = "Guest";
 #else
 static Pixmap pixmap = None;
 static Widget topLevel, puzzle;
 static char *progDsp;
-static char userNameDsp[USERNAMELEN] = "";
+static char userNameDsp[USER_NAME_LENGTH] = "";
 
 #ifdef HAVE_MOTIF
 static void
@@ -262,8 +262,8 @@ PrintRecords(void)
 
 	(void) printf("   HANOI/PANEX  HALL OF FAME\n\n");
 	(void) printf("PANEX TILES USER            MOVES\n");
-	for (mode = 0; mode < MAXMODES; mode++)
-		for (i = 0; i < MAXTILES - MINTILES + 1; i++) {
+	for (mode = 0; mode < MAX_MODES; mode++)
+		for (i = 0; i < MAX_TILES - MIN_TILES + 1; i++) {
 			if (puzzleRecord[mode][i].score > 0)
 				(void) printf("%5d%6d %-12s%9d\n",
 					mode, i + 1,
@@ -278,11 +278,11 @@ InitRecords(void)
 {
 	int i, mode;
 
-	for (mode = 0; mode < MAXMODES; mode++)
-		for (i = 0; i < MAXTILES - MINTILES + 1; i++) {
+	for (mode = 0; mode < MAX_MODES; mode++)
+		for (i = 0; i < MAX_TILES - MIN_TILES + 1; i++) {
 			puzzleRecord[mode][i].score = NEVER;
 			(void) strncpy(puzzleRecord[mode][i].name, NOACCESS,
-				USERNAMELEN);
+				USER_NAME_LENGTH);
 		}
 }
 
@@ -291,7 +291,7 @@ ReadRecords(void)
 {
 	FILE *fp;
 	int i, mode, n;
-	char userName[USERNAMELEN];
+	char userName[USER_NAME_LENGTH];
 	char *buf1 = NULL, *buf2 = NULL;
 	char *fname, *lname;
 
@@ -301,9 +301,9 @@ ReadRecords(void)
 	stringCat(&buf2, buf1, SCOREFILE);
 	free(buf1);
 	fname = buf2;
-	(void) strncpy(fileName, lname, USERNAMELEN);
+	(void) strncpy(fileName, lname, USER_NAME_LENGTH);
 	if ((fp = fopen(fileName, "r")) == NULL) {
-		(void) strncpy(fileName, fname, USERNAMELEN);
+		(void) strncpy(fileName, fname, USER_NAME_LENGTH);
 		/* Try installed directory. */
 		if ((fp = fopen(fileName, "r")) == NULL) {
 			stringCat(&buf1, "Can not read ", fname);
@@ -332,14 +332,14 @@ ReadRecords(void)
 	}
 	free(lname);
 	free(fname);
-	for (mode = 0; mode < MAXMODES; mode++)
-		for (i = 0; i < MAXTILES - MINTILES + 1; i++) {
+	for (mode = 0; mode < MAX_MODES; mode++)
+		for (i = 0; i < MAX_TILES - MIN_TILES + 1; i++) {
 			(void) fscanf(fp, "%d %s\n", &n, userName);
 			if (n <= puzzleRecord[mode][i].score ||
 					puzzleRecord[mode][i].score <= NEVER) {
 				puzzleRecord[mode][i].score = n;
 				(void) strncpy(puzzleRecord[mode][i].name,
-					userName, USERNAMELEN);
+					userName, USER_NAME_LENGTH);
 			}
 		}
 	(void) fclose(fp);
@@ -361,9 +361,9 @@ WriteRecords(void)
 	{
 #if HAVE_FCNTL_H
 		int lfd;
-		char lockFile[FILENAMELEN];
+		char lockFile[FILE_NAME_LENGTH];
 
-		(void) strncpy(lockFile, fileName, FILENAMELEN - 6);
+		(void) strncpy(lockFile, fileName, FILE_NAME_LENGTH - 6);
 		(void) strcat(lockFile, ".lock");
 		while (((lfd = open(lockFile, O_CREAT | O_EXCL, 0644)) < 0) &&
 				errno == EEXIST)
@@ -379,8 +379,8 @@ WriteRecords(void)
 #endif
 		}
 #endif
-		for (mode = 0; mode < MAXMODES; mode++) {
-			for (i = 0; i < MAXTILES - MINTILES + 1; i++)
+		for (mode = 0; mode < MAX_MODES; mode++) {
+			for (i = 0; i < MAX_TILES - MIN_TILES + 1; i++)
 				(void) fprintf(fp, "%d %s\n",
 					puzzleRecord[mode][i].score,
 					puzzleRecord[mode][i].name);
@@ -397,10 +397,10 @@ WriteRecords(void)
 static void
 PrintRecord(int tiles, int mode)
 {
-	int i = tiles - MINTILES, j = mode - HANOI;
+	int i = tiles - MIN_TILES, j = mode - HANOI;
 
-	if (tiles > MAXTILES)
-		(void) strncpy(recordDsp, "NOT RECORDED", MESSAGELEN);
+	if (tiles > MAX_TILES)
+		(void) strncpy(recordDsp, "NOT RECORDED", MESSAGE_LENGTH);
 	else if (puzzleRecord[j][i].score <= NEVER) {
 		(void) sprintf(recordDsp, "NEVER %s", NOACCESS);
 	} else {
@@ -438,14 +438,14 @@ PrintStatus(char *msg, int nMoves
 static Boolean
 HandleSolved(int counter, int tiles, int mode)
 {
-	int i = tiles - MINTILES, j = mode - HANOI;
+	int i = tiles - MIN_TILES, j = mode - HANOI;
 
-	if (tiles <= MAXTILES && (counter < puzzleRecord[j][i].score ||
+	if (tiles <= MAX_TILES && (counter < puzzleRecord[j][i].score ||
 			puzzleRecord[j][i].score <= NEVER)) {
 		ReadRecords();	/* Maybe its been updated by another */
 		puzzleRecord[j][i].score = counter;
 		(void) strncpy(puzzleRecord[j][i].name, userNameDsp,
-			USERNAMELEN);
+			USER_NAME_LENGTH);
 		WriteRecords();
 		PrintRecord(tiles, mode);
 		return True;
@@ -473,7 +473,7 @@ Widget w
 	userName = w->panex.userName;
 	scoreFile = w->panex.scoreFile;
 	if (strcmp(scoreFile, ""))
-		(void) strncpy(scoreFileName, scoreFile, FILENAMELEN);
+		(void) strncpy(scoreFileName, scoreFile, FILE_NAME_LENGTH);
 #else
 	Boolean scoreOnly, versionOnly;
 
@@ -489,7 +489,7 @@ Widget w
 		exit(0);
 	}
 	if (strcmp(scoreFile, ""))
-		(void) strncpy(scoreFileName, scoreFile, FILENAMELEN);
+		(void) strncpy(scoreFileName, scoreFile, FILE_NAME_LENGTH);
 	if (scoreOnly) {
 		InitRecords();
 		ReadRecords();
@@ -500,12 +500,12 @@ Widget w
 	{
 		int delay;
 
-		if (tiles > MAXTILES)
+		if (tiles > MAX_TILES)
 			XtVaSetValues(tile, XmNmaximum, tiles, NULL);
 		XmScaleSetValue(tile, tiles);
 		XmToggleButtonSetState(modes[mode - HANOI], True, False);
 		XtVaGetValues(puzzle, XtNdelay, &delay, NULL);
-		XmScaleSetValue(speed, MAXSPEED + MINSPEED - delay - 1);
+		XmScaleSetValue(speed, MAX_SPEED + MIN_SPEED - delay - 1);
 	}
 #endif
 #endif
@@ -513,13 +513,13 @@ Widget w
 	InitRecords();
 	ReadRecords();
 #ifndef WINVER
-	(void) strncpy(userNameDsp, userName, USERNAMELEN);
+	(void) strncpy(userNameDsp, userName, USER_NAME_LENGTH);
 #endif
 	if (!strcmp(userName, "") || !strcmp(userName, "(null)") ||
 			!strcmp(userName, NOACCESS) ||
 			!strcmp(userName, NOBODY)) {
 #ifdef WINVER
-		(void) strncpy(userNameDsp, userName, USERNAMELEN);
+		(void) strncpy(userNameDsp, userName, USER_NAME_LENGTH);
 #else
 		char *login = getlogin();
 
@@ -593,21 +593,21 @@ CallbackPuzzle(Widget w, caddr_t clientData, panexCallbackStruct *callData)
 		movesDsp = 0;
 		break;
 	case ACTION_ILLEGAL:
-		(void) strncpy(messageDsp, "Illegal move", MESSAGELEN);
+		(void) strncpy(messageDsp, "Illegal move", MESSAGE_LENGTH);
 		break;
 	case ACTION_BLOCKED:
-		(void) strncpy(messageDsp, "Blocked", MESSAGELEN);
+		(void) strncpy(messageDsp, "Blocked", MESSAGE_LENGTH);
 		break;
 	case ACTION_SPACE:
 #if 0
 		/* Too annoying */
 		(void) strncpy(messageDsp, "Spaces can not slide",
-			MESSAGELEN);
+			MESSAGE_LENGTH);
 #endif
 		break;
 	case ACTION_IGNORE:
 		(void) strncpy(messageDsp, "Clear to start",
-			MESSAGELEN);
+			MESSAGE_LENGTH);
 		break;
 	case ACTION_MOVED:
 		movesDsp++;
@@ -622,7 +622,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, panexCallbackStruct *callData)
 				"Congratulations %s!!", userNameDsp);
 		else
 			(void) strncpy(messageDsp, "Solved!",
-				MESSAGELEN);
+				MESSAGE_LENGTH);
 		SET_STARTED(w, False);
 		break;
 	case ACTION_COMPUTED:
@@ -637,7 +637,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, panexCallbackStruct *callData)
 #else
 		XtVaSetValues(w, XtNtiles, tiles, NULL);
 #ifdef HAVE_MOTIF
-		if (tiles > MAXTILES)
+		if (tiles > MAX_TILES)
 			XtVaSetValues(tile, XmNmaximum, tiles, NULL);
 		XmScaleSetValue(tile, tiles);
 #endif
@@ -653,7 +653,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, panexCallbackStruct *callData)
 		XtVaSetValues(w, XtNtiles, tiles, NULL);
 #ifdef HAVE_MOTIF
 		XmScaleSetValue(tile, tiles);
-		if (tiles >= MAXTILES)
+		if (tiles >= MAX_TILES)
 			XtVaSetValues(tile, XmNmaximum, tiles, NULL);
 #endif
 #endif
@@ -687,8 +687,8 @@ CallbackPuzzle(Widget w, caddr_t clientData, panexCallbackStruct *callData)
 
 			XtVaGetValues(puzzle, XtNdelay, &delay, NULL);
 			oldDelay = delay;
-			if (delay > MAXSPEED - MINSPEED)
-				delay = MAXSPEED - MINSPEED;
+			if (delay > MAX_SPEED - MIN_SPEED)
+				delay = MAX_SPEED - MIN_SPEED;
 			if (delay < 0)
 				delay = 0;
 			if (delay != oldDelay) {
@@ -696,7 +696,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, panexCallbackStruct *callData)
 					XtNdelay, delay, NULL);
 			}
 			XmScaleSetValue(speed,
-				MAXSPEED + MINSPEED - delay - 1);
+				MAX_SPEED + MIN_SPEED - delay - 1);
 		}
 		return;
 #endif
@@ -964,8 +964,6 @@ static XrmOptionDescRec options[] =
 	{(char *) "-foreground", (char *) "*panex.Foreground", XrmoptionSepArg, NULL},
 	{(char *) "-bg", (char *) "*Background", XrmoptionSepArg, NULL},
 	{(char *) "-background", (char *) "*Background", XrmoptionSepArg, NULL},
-	{(char *) "-bd", (char *) "*panex.tileBorder", XrmoptionSepArg, NULL},
-	{(char *) "-border", (char *) "*panex.tileBorder", XrmoptionSepArg, NULL},
 	{(char *) "-tile", (char *) "*panex.tileColor", XrmoptionSepArg, NULL},
 	{(char *) "-pyramid0", (char *) "*panex.pyramidColor0", XrmoptionSepArg, NULL},
 	{(char *) "-pyramid1", (char *) "*panex.pyramidColor1", XrmoptionSepArg, NULL},
@@ -1037,7 +1035,7 @@ ModeToggle(Widget w, int mode, XmToggleButtonCallbackStruct *cbs)
 static void
 SpeedSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 {
-	int delay = MAXSPEED + MINSPEED - cbs->value - 1, oldDelay;
+	int delay = MAX_SPEED + MIN_SPEED - cbs->value - 1, oldDelay;
 
 	XtVaGetValues(puzzle,
 		XtNdelay, &oldDelay, NULL);
@@ -1068,7 +1066,7 @@ static Widget
 createQuery(Widget w, char *text, char *title, XtCallbackProc callback)
 {
 	Widget button, messageBox;
-	char titleDsp[FILENAMELEN + 8];
+	char titleDsp[FILE_NAME_LENGTH + 8];
 	XmString titleString = NULL, messageString = NULL;
 	static XmStringCharSet charSet =
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
@@ -1094,7 +1092,7 @@ static Widget
 createHelp(Widget w, char *text, char *title)
 {
 	Widget button, messageBox;
-	char titleDsp[FILENAMELEN + 8];
+	char titleDsp[FILE_NAME_LENGTH + 8];
 	XmString titleString = NULL, messageString = NULL, buttonString = NULL;
 	static XmStringCharSet charSet =
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
@@ -1359,9 +1357,9 @@ main(int argc, char **argv)
 	tile = XtVaCreateManagedWidget("tile",
 		xmScaleWidgetClass, tilesRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Size", 5,
-		XmNminimum, MINTILES,
-		XmNmaximum, MAXTILES,
-		XmNvalue, DEFAULTTILES,
+		XmNminimum, MIN_TILES,
+		XmNmaximum, MAX_TILES,
+		XmNvalue, DEFAULT_TILES,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
 	XtAddCallback(tile, XmNvalueChangedCallback,
@@ -1369,9 +1367,9 @@ main(int argc, char **argv)
 	speed = XtVaCreateManagedWidget("Animation Speed",
 		xmScaleWidgetClass, tilesRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Animation Speed", 16,
-		XmNminimum, MINSPEED,
-		XmNmaximum, MAXSPEED,
-		XmNvalue, MAXSPEED - DEFAULTDELAY,
+		XmNminimum, MIN_SPEED,
+		XmNmaximum, MAX_SPEED,
+		XmNvalue, MAX_SPEED - DEFAULT_DELAY,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
 	XtAddCallback(speed, XmNvalueChangedCallback,
