@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 2007	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1994 - 2007	David A. Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -40,7 +40,7 @@
 
 #define SECTION "setup"
 
-static const char *faceColorString[MAXFACES] =
+static const char *faceColorString[MAX_FACES] =
 {
 	"0 0 255",
 	"255 0 0",
@@ -48,7 +48,7 @@ static const char *faceColorString[MAXFACES] =
 	"0 255 0"
 };
 
-static const char faceColorChar[MAXFACES] =
+static const char faceColorChar[MAX_FACES] =
 {'B', 'R', 'Y', 'G'};
 #else
 
@@ -310,13 +310,13 @@ static XtResource resourcesPuzzle[] =
 	 XtRString, (caddr_t) "FALSE"}, /* DEFAULTSTICKY */
 	{XtNmode, XtCMode, XtRInt, sizeof (int),
 	 XtOffset(PyraminxWidget, pyraminx.mode),
-	 XtRString, (caddr_t) "3"},	/*DEFAULTMODE */
+	 XtRString, (caddr_t) "3"},	/*DEFAULT_MODE */
 	{XtNorient, XtCOrient, XtRBoolean, sizeof (Boolean),
 	 XtOffset(PyraminxWidget, pyraminx.orient),
-	 XtRString, (caddr_t) "FALSE"},	/*DEFAULTORIENT */
+	 XtRString, (caddr_t) "FALSE"},	/*DEFAULT_ORIENT */
 	{XtNpractice, XtCPractice, XtRBoolean, sizeof (Boolean),
 	 XtOffset(PyraminxWidget, pyraminx.practice),
-	 XtRString, (caddr_t) "TRUE"},	/*DEFAULTPRACTICE */
+	 XtRString, (caddr_t) "TRUE"},	/*DEFAULT_PRACTICE */
 	{XtNuserName, XtCUserName, XtRString, sizeof (String),
 	 XtOffset(PyraminxWidget, pyraminx.userName),
 	 XtRString, (caddr_t) ""},
@@ -451,7 +451,7 @@ typedef struct _CRD {
 typedef struct _RowNextP3 {
 	int viewChanged, face, direction, reverse;
 } RowNextP3;
-static int directionNextFace[MAXORIENT][MAXFACES] =
+static int directionNextFace[MAX_ORIENT][MAX_FACES] =
 {
 	{3, 0, 1, 2},
 	{3, 3, 1, 1},
@@ -460,7 +460,7 @@ static int directionNextFace[MAXORIENT][MAXFACES] =
 	{2, 2, 0, 0},
 	{2, 0, 0, 2}
 };
-static PyraminxLoc slideNextRowP2[MAXSIDES][3] =
+static PyraminxLoc slideNextRowP2[MAX_SIDES][3] =
 {
 	{
 		{2, 0},
@@ -473,7 +473,7 @@ static PyraminxLoc slideNextRowP2[MAXSIDES][3] =
 		{2, 3}
 	}
 };
-static RowNextP3 slideNextRowP3[MAXSIDES][MAXORIENT] =
+static RowNextP3 slideNextRowP3[MAX_SIDES][MAX_ORIENT] =
 {
 	{
 		{TRUE, UP, TR, FALSE},
@@ -492,7 +492,7 @@ static RowNextP3 slideNextRowP3[MAXSIDES][MAXORIENT] =
 		{FALSE, DOWN, TOP, TRUE}
 	}
 };
-static int rotOrientRowP3[3][MAXORIENT] =
+static int rotOrientRowP3[3][MAX_ORIENT] =
 /* current orient, rotation */
 {
 	{1, 5, 1, 5, 4, 2},
@@ -500,7 +500,7 @@ static int rotOrientRowP3[3][MAXORIENT] =
 	{3, 1, 3, 1, 0, 4}
 };
 
-static Point triangleUnit[MAXSIDES][4] =
+static Point triangleUnit[MAX_SIDES][4] =
 {
 	{
 		{0, 2},
@@ -515,8 +515,8 @@ static Point triangleUnit[MAXSIDES][4] =
 		{0, 1}
 	}
 };
-static Point triangleList[MAXSIDES][4], letterList[MAXSIDES];
-static Point offsetList[MAXSIDES];
+static Point triangleList[MAX_SIDES][4], letterList[MAX_SIDES];
+static Point offsetList[MAX_SIDES];
 
 static Pixmap dr = 0; /* dummy for future double buffering */
 
@@ -528,10 +528,10 @@ CheckPieces(PyraminxWidget w)
 {
 	char *buf1 = NULL, *buf2 = NULL;
 
-	if (w->pyraminx.size < MINFACETS) {
+	if (w->pyraminx.size < MIN_FACETS) {
 		intCat(&buf1,
 			"Number of triangles on an edge out of bounds, use at least ",
-			MINFACETS);
+			MIN_FACETS);
 		stringCat(&buf2, buf1, ", defaulting to ");
 		free(buf1);
 		intCat(&buf1, buf2, DEFAULTFACETS);
@@ -542,10 +542,10 @@ CheckPieces(PyraminxWidget w)
 	}
 	if (w->pyraminx.mode < PERIOD2 || w->pyraminx.mode > BOTH) {
 		intCat(&buf1, "Mode is in error, use 2 for Period2, 3 for Period3, 4 for Both, defaulting to ",
-			DEFAULTMODE);
+			DEFAULT_MODE);
 		DISPLAY_WARNING(buf1);
 		free(buf1);
-		w->pyraminx.mode = DEFAULTMODE;
+		w->pyraminx.mode = DEFAULT_MODE;
 	}
 
 }
@@ -556,12 +556,12 @@ CheckSolved(PyraminxWidget w)
 	int face, position;
 	PyraminxLoc test = {0, FALSE};
 
-	for (face = 0; face < MAXFACES; face++)
+	for (face = 0; face < MAX_FACES; face++)
 		for (position = 0; position < w->pyraminx.sizeSize; position++) {
 			if (!position) {
 				test.face = w->pyraminx.facetLoc[face][position].face;
 				test.rotation = w->pyraminx.facetLoc[face][position].rotation;
-			} else if (test.face !=		/* MAXSIDES * view + face */
+			} else if (test.face !=		/* MAX_SIDES * view + face */
 					 w->pyraminx.facetLoc[face][position].face ||
 					(w->pyraminx.orient && test.rotation !=
 					w->pyraminx.facetLoc[face][position].rotation))
@@ -577,7 +577,7 @@ PrintFacet(PyraminxWidget w)
 {
 	int face, position, square;
 
-	for (face = 0; face < MAXSIDES; face++) {
+	for (face = 0; face < MAX_SIDES; face++) {
 		square = 1;
 		for (position = 0; position < w->pyraminx.sizeSize; position++) {
 			(void) printf("%d %d  ",
@@ -600,7 +600,7 @@ PrintFace(PyraminxWidget w)
 
 	for (g = 0; g < w->pyraminx.size; g++) {
 		for (h = 0; h < w->pyraminx.size - g; h++)
-			for (side = 0; side < MAXSIDES; side++)
+			for (side = 0; side < MAX_SIDES; side++)
 				if (!side || h < w->pyraminx.size - g - 1)
 					(void) printf("%d %d  ", w->pyraminx.faceLoc[side][h +
 						g * w->pyraminx.size].face,
@@ -632,7 +632,7 @@ PrintRow2(PyraminxWidget w, int orient)
 
 	(void) printf("Row %d:\n", orient);
 	for (g = 0; g < w->pyraminx.size; g++)
-		for (side = 0; side < MAXSIDES; side++)
+		for (side = 0; side < MAX_SIDES; side++)
 			(void) printf("%d %d  ", w->pyraminx.rowLoc[orient][side][g].face,
 				w->pyraminx.rowLoc[orient][side][g].rotation);
 	(void) printf("\n");
@@ -645,7 +645,7 @@ PrintRow3(PyraminxWidget w, int len, int orient)
 
 	(void) printf("Row %d:\n", orient);
 	for (g = 0; g <= len; g++)
-		for (side = 0; side < MAXSIDES; side++)
+		for (side = 0; side < MAX_SIDES; side++)
 			if (!side || g < len)
 				(void) printf("%d %d  ", w->pyraminx.rowLoc[orient][side][g].face,
 				w->pyraminx.rowLoc[orient][side][g].rotation);
@@ -778,7 +778,7 @@ DrawTriangle(PyraminxWidget w, int face, int position, int offset)
 	CRD crd;
 
 	ToCRD(w, face, position, &crd);
-	view = (face / MAXSIDES == UP) ? DOWN : UP;
+	view = (face / MAX_SIDES == UP) ? DOWN : UP;
 	side = crd.diagonal - crd.column - crd.row;
 	if (!w->pyraminx.vertical && view == DOWN) {
 		faceOnView = !side;
@@ -787,7 +787,7 @@ DrawTriangle(PyraminxWidget w, int face, int position, int offset)
 		dy = (w->pyraminx.size - crd.row - 1) *
 			(w->pyraminx.facetLength + w->pyraminx.delta);
 		orient = (w->pyraminx.facetLoc[face][position].rotation +
-			MAXORIENT / 2) % MAXORIENT;
+			MAX_ORIENT / 2) % MAX_ORIENT;
 		if (2 * w->pyraminx.size - crd.column - crd.row - 2 +
 				faceOnView >= w->pyraminx.size) {
 			dx += w->pyraminx.sideOffset;
@@ -860,7 +860,7 @@ DrawAllPieces(PyraminxWidget w)
 {
 	int face, position;
 
-	for (face = 0; face < MAXFACES; face++)
+	for (face = 0; face < MAX_FACES; face++)
 		for (position = 0; position < w->pyraminx.sizeSize; position++)
 			DrawTriangle(w, face, position, FALSE);
 }
@@ -935,13 +935,13 @@ RotateFace(PyraminxWidget w, int view, int faceOnView, int direction)
 	/* Read Face */
 	for (g = 0; g < w->pyraminx.size; g++)
 		for (h = 0; h < w->pyraminx.size - g; h++)
-			for (side = 0; side < MAXSIDES; side++)
+			for (side = 0; side < MAX_SIDES; side++)
 				if (g + h + side < w->pyraminx.size) {
 					if (faceOnView == DOWN) {
 						crd.column = h;
 						crd.row = g;
 						crd.diagonal = h + g + side;
-						face = view * MAXSIDES + ((crd.diagonal >= w->pyraminx.size) ? UP : DOWN);
+						face = view * MAX_SIDES + ((crd.diagonal >= w->pyraminx.size) ? UP : DOWN);
 						position = ToPosition(w, crd);
 						w->pyraminx.faceLoc[side][h + g * w->pyraminx.size] =
 							w->pyraminx.facetLoc[face][position];
@@ -949,7 +949,7 @@ RotateFace(PyraminxWidget w, int view, int faceOnView, int direction)
 						crd.column = w->pyraminx.size - 1 - h;
 						crd.row = w->pyraminx.size - 1 - g;
 						crd.diagonal = crd.column + crd.row + !side;
-						face = view * MAXSIDES + ((crd.diagonal >= w->pyraminx.size) ? UP : DOWN);
+						face = view * MAX_SIDES + ((crd.diagonal >= w->pyraminx.size) ? UP : DOWN);
 						position = ToPosition(w, crd);
 						w->pyraminx.faceLoc[side][h + g * w->pyraminx.size] =
 							w->pyraminx.facetLoc[face][position];
@@ -959,12 +959,12 @@ RotateFace(PyraminxWidget w, int view, int faceOnView, int direction)
 	if (faceOnView == DOWN) {
 		for (g = 0; g < w->pyraminx.size; g++)
 			for (h = 0; h < w->pyraminx.size - g; h++)
-				for (side = 0; side < MAXSIDES; side++)
+				for (side = 0; side < MAX_SIDES; side++)
 					if (g + h + side < w->pyraminx.size) {
 						crd.column = h;
 						crd.row = g;
 						crd.diagonal = h + g + side;
-						face = view * MAXSIDES + ((crd.diagonal >= w->pyraminx.size) ? UP : DOWN);
+						face = view * MAX_SIDES + ((crd.diagonal >= w->pyraminx.size) ? UP : DOWN);
 						position = ToPosition(w, crd);
 						if (direction == CCW)
 							w->pyraminx.facetLoc[face][position] =
@@ -977,9 +977,9 @@ RotateFace(PyraminxWidget w, int view, int faceOnView, int direction)
 						w->pyraminx.facetLoc[face][position].rotation =
 							(direction == CW) ?
 							(w->pyraminx.facetLoc[face][position].rotation + 2) %
-							MAXORIENT :
+							MAX_ORIENT :
 							(w->pyraminx.facetLoc[face][position].rotation + 4) %
-							MAXORIENT;
+							MAX_ORIENT;
 						DrawTriangle(w, face, position, FALSE);
 					}
 	} else {		/* faceOnView == UP */
@@ -990,7 +990,7 @@ RotateFace(PyraminxWidget w, int view, int faceOnView, int direction)
 						crd.column = h;
 						crd.row = g;
 						crd.diagonal = h + g + side;
-						face = view * MAXSIDES + ((crd.diagonal >= w->pyraminx.size) ? UP : DOWN);
+						face = view * MAX_SIDES + ((crd.diagonal >= w->pyraminx.size) ? UP : DOWN);
 						position = ToPosition(w, crd);
 						if (direction == CCW)
 							w->pyraminx.facetLoc[face][position] =
@@ -1003,9 +1003,9 @@ RotateFace(PyraminxWidget w, int view, int faceOnView, int direction)
 						w->pyraminx.facetLoc[face][position].rotation =
 							(direction == CW) ?
 							(w->pyraminx.facetLoc[face][position].rotation + 2) %
-							MAXORIENT :
+							MAX_ORIENT :
 							(w->pyraminx.facetLoc[face][position].rotation + 4) %
-							MAXORIENT;
+							MAX_ORIENT;
 						DrawTriangle(w, face, position, FALSE);
 					}
 	}
@@ -1019,21 +1019,21 @@ ReadCRD2(PyraminxWidget w, int view, int dir, int h, int orient)
 
 	if (dir == TOP || dir == BOTTOM)
 		for (g = 0; g < w->pyraminx.size; g++)
-			for (side = 0; side < MAXSIDES; side++) {
+			for (side = 0; side < MAX_SIDES; side++) {
 				crd.column = h;
 				crd.row = g;
 				crd.diagonal = h + g + side;
-				face = view * MAXSIDES + ((crd.diagonal >= w->pyraminx.size) ? UP : DOWN);
+				face = view * MAX_SIDES + ((crd.diagonal >= w->pyraminx.size) ? UP : DOWN);
 				position = ToPosition(w, crd);
 				w->pyraminx.rowLoc[orient][side][g] =
 					w->pyraminx.facetLoc[face][position];
 	} else if (dir == RIGHT || dir == LEFT)
 		for (g = 0; g < w->pyraminx.size; g++)
-			for (side = 0; side < MAXSIDES; side++) {
+			for (side = 0; side < MAX_SIDES; side++) {
 				crd.column = g;
 				crd.row = h;
 				crd.diagonal = h + g + side;
-				face = view * MAXSIDES + ((crd.diagonal >= w->pyraminx.size) ? UP : DOWN);
+				face = view * MAX_SIDES + ((crd.diagonal >= w->pyraminx.size) ? UP : DOWN);
 				position = ToPosition(w, crd);
 				w->pyraminx.rowLoc[orient][side][g] =
 					w->pyraminx.facetLoc[face][position];
@@ -1042,14 +1042,14 @@ ReadCRD2(PyraminxWidget w, int view, int dir, int h, int orient)
 		i = (faceOnView == UP) ? w->pyraminx.size - 1 : 0;
 		j = h % w->pyraminx.size;
 		for (g = 0; g < w->pyraminx.size; g++) {
-			for (side = 0; side < MAXSIDES; side++) {
+			for (side = 0; side < MAX_SIDES; side++) {
 				s = (((side == UP) && (faceOnView == UP)) ||
 					((side == DOWN) && (faceOnView == DOWN)))
 					? DOWN : UP;
 				crd.column = i;
 				crd.row = j;
 				crd.diagonal = i + j + s;
-				face = view * MAXSIDES + ((crd.diagonal >= w->pyraminx.size) ? UP : DOWN);
+				face = view * MAX_SIDES + ((crd.diagonal >= w->pyraminx.size) ? UP : DOWN);
 				position = ToPosition(w, crd);
 				w->pyraminx.rowLoc[orient][side][g] =
 					w->pyraminx.facetLoc[face][position];
@@ -1078,21 +1078,21 @@ ReadCRD3(PyraminxWidget w, int view, int faceOnView, int dir, int h, int len, in
 
 	if (dir == TOP || dir == BOTTOM) {
 		for (g = 0; g <= len; g++)
-			for (side = 0; side < MAXSIDES; side++)
+			for (side = 0; side < MAX_SIDES; side++)
 				if (!side || g < len) {
 					crd.column = h;
 					crd.row = (faceOnView == UP) ? w->pyraminx.size - 1 - g : g;
 					crd.diagonal = h + crd.row + ((((side == UP) && (faceOnView == DOWN)) ||
 						((side == DOWN) && (faceOnView == UP)))
 						? UP : DOWN);
-					face = view * MAXSIDES + ((crd.diagonal >= w->pyraminx.size) ? UP : DOWN);
+					face = view * MAX_SIDES + ((crd.diagonal >= w->pyraminx.size) ? UP : DOWN);
 					position = ToPosition(w, crd);
 					w->pyraminx.rowLoc[orient][side][g] =
 						w->pyraminx.facetLoc[face][position];
 				}
 	} else if (dir == RIGHT || dir == LEFT) {
 		for (g = 0; g <= len; g++)
-			for (side = 0; side < MAXSIDES; side++)
+			for (side = 0; side < MAX_SIDES; side++)
 				if (!side || g < len) {
 					crd.column = (faceOnView == UP) ? w->pyraminx.size - 1 - g : g;
 					crd.row = h;
@@ -1100,7 +1100,7 @@ ReadCRD3(PyraminxWidget w, int view, int faceOnView, int dir, int h, int len, in
 						((((side == UP) && (faceOnView == DOWN)) ||
 						((side == DOWN) && (faceOnView == UP)))
 						? UP : DOWN);
-					face = view * MAXSIDES + ((crd.diagonal >= w->pyraminx.size) ? UP : DOWN);
+					face = view * MAX_SIDES + ((crd.diagonal >= w->pyraminx.size) ? UP : DOWN);
 					position = ToPosition(w, crd);
 					w->pyraminx.rowLoc[orient][side][g] =
 						w->pyraminx.facetLoc[face][position];
@@ -1110,7 +1110,7 @@ ReadCRD3(PyraminxWidget w, int view, int faceOnView, int dir, int h, int len, in
 		i = (faceOnView == UP) ? w->pyraminx.size - 1 : 0;
 		j = h % w->pyraminx.size;
 		for (g = 0; g <= len; g++) {
-			for (side = 0; side < MAXSIDES; side++) {
+			for (side = 0; side < MAX_SIDES; side++) {
 				if (side == DOWN || g < len) {
 					s = (((side == UP) && (faceOnView == UP)) ||
 						((side == DOWN) && (faceOnView == DOWN)))
@@ -1118,7 +1118,7 @@ ReadCRD3(PyraminxWidget w, int view, int faceOnView, int dir, int h, int len, in
 					crd.column = i;
 					crd.row = j;
 					crd.diagonal = i + j + s;
-					face = view * MAXSIDES + ((crd.diagonal >= w->pyraminx.size) ? UP : DOWN);
+					face = view * MAX_SIDES + ((crd.diagonal >= w->pyraminx.size) ? UP : DOWN);
 					position = ToPosition(w, crd);
 					w->pyraminx.rowLoc[orient][side][g] =
 						w->pyraminx.facetLoc[face][position];
@@ -1137,9 +1137,9 @@ RotateCRD2(PyraminxWidget w, int rotate, int orient)
 	int g, side;
 
 	for (g = 0; g < w->pyraminx.size; g++)
-		for (side = 0; side < MAXSIDES; side++)
+		for (side = 0; side < MAX_SIDES; side++)
 			w->pyraminx.rowLoc[orient][side][g].rotation =
-				(w->pyraminx.rowLoc[orient][side][g].rotation + rotate) % MAXORIENT;
+				(w->pyraminx.rowLoc[orient][side][g].rotation + rotate) % MAX_ORIENT;
 }
 
 static void
@@ -1148,13 +1148,13 @@ RotateCRD3(PyraminxWidget w, int faceOnView, int dir, int len, int orient)
 	int g, side, direction, facetOrient;
 
 	for (g = 0; g <= len; g++)
-		for (side = 0; side < MAXSIDES; side++)
+		for (side = 0; side < MAX_SIDES; side++)
 			if (side == DOWN || g < len) {
-				direction = (faceOnView == UP) ? (dir + 3) % MAXORIENT : dir;
+				direction = (faceOnView == UP) ? (dir + 3) % MAX_ORIENT : dir;
 				facetOrient = w->pyraminx.rowLoc[orient][side][g].rotation;
 				w->pyraminx.rowLoc[orient][side][g].rotation =
 					(facetOrient >= 3) ?
-					(rotOrientRowP3[facetOrient - 3][direction] + 3) % MAXORIENT :
+					(rotOrientRowP3[facetOrient - 3][direction] + 3) % MAX_ORIENT :
 					rotOrientRowP3[facetOrient][direction];
 			}
 }
@@ -1196,25 +1196,25 @@ WriteCRD2(PyraminxWidget w, int view, int dir, int h, int orient)
 
 	if (dir == TOP || dir == BOTTOM) {
 		for (g = 0; g < w->pyraminx.size; g++)
-			for (side = 0; side < MAXSIDES; side++) {
+			for (side = 0; side < MAX_SIDES; side++) {
 				crd.column = h;
 				crd.row = g;
 				crd.diagonal = h + g + side;
-				face = view * MAXSIDES + ((crd.diagonal >= w->pyraminx.size) ? UP : DOWN);
+				face = view * MAX_SIDES + ((crd.diagonal >= w->pyraminx.size) ? UP : DOWN);
 				position = ToPosition(w, crd);
 				w->pyraminx.facetLoc[face][position] =
 					w->pyraminx.rowLoc[orient][side][g];
 				DrawTriangle(w,
-					view * MAXSIDES + ((crd.diagonal >= w->pyraminx.size) ? UP : DOWN),
+					view * MAX_SIDES + ((crd.diagonal >= w->pyraminx.size) ? UP : DOWN),
 					ToPosition(w, crd), FALSE);
 			}
 	} else if (dir == RIGHT || dir == LEFT) {
 		for (g = 0; g < w->pyraminx.size; g++)
-			for (side = 0; side < MAXSIDES; side++) {
+			for (side = 0; side < MAX_SIDES; side++) {
 				crd.column = g;
 				crd.row = h;
 				crd.diagonal = h + g + side;
-				face = view * MAXSIDES + ((crd.diagonal >= w->pyraminx.size) ? UP : DOWN);
+				face = view * MAX_SIDES + ((crd.diagonal >= w->pyraminx.size) ? UP : DOWN);
 				position = ToPosition(w, crd);
 				w->pyraminx.facetLoc[face][position] =
 					w->pyraminx.rowLoc[orient][side][g];
@@ -1225,14 +1225,14 @@ WriteCRD2(PyraminxWidget w, int view, int dir, int h, int orient)
 		i = (faceOnView == UP) ? w->pyraminx.size - 1 : 0;
 		j = h % w->pyraminx.size;
 		for (g = 0; g < w->pyraminx.size; g++) {
-			for (side = 0; side < MAXSIDES; side++) {
+			for (side = 0; side < MAX_SIDES; side++) {
 				s = (((side == UP) && (faceOnView == UP)) ||
 					((side == DOWN) && (faceOnView == DOWN)))
 					? DOWN : UP;
 				crd.column = i;
 				crd.row = j;
 				crd.diagonal = i + j + s;
-				face = view * MAXSIDES + ((crd.diagonal >= w->pyraminx.size) ? UP : DOWN);
+				face = view * MAX_SIDES + ((crd.diagonal >= w->pyraminx.size) ? UP : DOWN);
 				position = ToPosition(w, crd);
 				w->pyraminx.facetLoc[face][position] =
 					w->pyraminx.rowLoc[orient][side][g];
@@ -1269,7 +1269,7 @@ WriteCRD3(PyraminxWidget w, int view, int faceOnView, int dir, int h, int len, i
 
 	if (dir == TOP || dir == BOTTOM) {
 		for (k = 0; k <= len; k++)
-			for (side = 0; side < MAXSIDES; side++)
+			for (side = 0; side < MAX_SIDES; side++)
 				if ((side == DOWN) || k < len) {
 					g = (faceOnView == UP) ? w->pyraminx.size - 1 - k : k;
 					s = (((side == UP) && (faceOnView == DOWN)) ||
@@ -1278,7 +1278,7 @@ WriteCRD3(PyraminxWidget w, int view, int faceOnView, int dir, int h, int len, i
 					crd.column = h;
 					crd.row = g;
 					crd.diagonal = h + g + s;
-					face = view * MAXSIDES + ((crd.diagonal >= w->pyraminx.size) ? UP : DOWN);
+					face = view * MAX_SIDES + ((crd.diagonal >= w->pyraminx.size) ? UP : DOWN);
 					position = ToPosition(w, crd);
 					w->pyraminx.facetLoc[face][position] =
 						w->pyraminx.rowLoc[orient][side][k];
@@ -1286,7 +1286,7 @@ WriteCRD3(PyraminxWidget w, int view, int faceOnView, int dir, int h, int len, i
 				}
 	} else if (dir == RIGHT || dir == LEFT) {
 		for (k = 0; k <= len; k++)
-			for (side = 0; side < MAXSIDES; side++)
+			for (side = 0; side < MAX_SIDES; side++)
 				if ((side == DOWN) || k < len) {
 					g = (faceOnView == UP) ? w->pyraminx.size - 1 - k : k;
 					s = (((side == UP) && (faceOnView == DOWN)) ||
@@ -1295,7 +1295,7 @@ WriteCRD3(PyraminxWidget w, int view, int faceOnView, int dir, int h, int len, i
 					crd.column = g;
 					crd.row = h;
 					crd.diagonal = h + g + s;
-					face = view * MAXSIDES + ((crd.diagonal >= w->pyraminx.size) ? UP : DOWN);
+					face = view * MAX_SIDES + ((crd.diagonal >= w->pyraminx.size) ? UP : DOWN);
 					position = ToPosition(w, crd);
 					w->pyraminx.facetLoc[face][position] =
 						w->pyraminx.rowLoc[orient][side][k];
@@ -1306,7 +1306,7 @@ WriteCRD3(PyraminxWidget w, int view, int faceOnView, int dir, int h, int len, i
 		i = (faceOnView == UP) ? w->pyraminx.size - 1 : 0;
 		j = h % w->pyraminx.size;
 		for (k = 0; k <= len; k++) {
-			for (side = 0; side < MAXSIDES; side++)
+			for (side = 0; side < MAX_SIDES; side++)
 				if ((side == DOWN) || k < len) {
 					s = (((side == UP) && (faceOnView == UP)) ||
 						((side == DOWN) && (faceOnView == DOWN)))
@@ -1314,7 +1314,7 @@ WriteCRD3(PyraminxWidget w, int view, int faceOnView, int dir, int h, int len, i
 					crd.column = i;
 					crd.row = j;
 					crd.diagonal = i + j + s;
-					face = view * MAXSIDES + ((crd.diagonal >= w->pyraminx.size) ? UP : DOWN);
+					face = view * MAX_SIDES + ((crd.diagonal >= w->pyraminx.size) ? UP : DOWN);
 					position = ToPosition(w, crd);
 					w->pyraminx.facetLoc[face][position] =
 						w->pyraminx.rowLoc[orient][side][k];
@@ -1350,7 +1350,7 @@ MovePieces(PyraminxWidget w, int face, CRD crd, int direction, int style)
 	int newSide, newView, rotate, reverse, h, k, newH, faceOnView, len;
 	int newFace, newDirection, bound, l = 0;
 
-	view = face / MAXSIDES;
+	view = face / MAX_SIDES;
 	side = crd.diagonal - crd.column - crd.row;
 	if (style == PERIOD2) {
 		/* Period 2 Slide rows */
@@ -1478,7 +1478,7 @@ MoveControlCb(PyraminxWidget w, int face, int direction, int style)
 	int i, faceOnView;
 	CRD crd;
 
-	faceOnView = face % MAXSIDES;
+	faceOnView = face % MAX_SIDES;
 	if (w->pyraminx.sticky) {
 		if (style == PERIOD2)
 			for (i = 0; i < 3; i++) {
@@ -1600,7 +1600,7 @@ SelectPieces(PyraminxWidget w, int x, int y, int *face, CRD *crd)
 		side = (side == UP) ? DOWN : UP;
 	}
 	crd->diagonal = crd->row + crd->column + side;
-	*face = ((view == UP) ? DOWN : UP) * MAXSIDES +
+	*face = ((view == UP) ? DOWN : UP) * MAX_SIDES +
 		((crd->diagonal >= w->pyraminx.size) ? UP : DOWN);
 	return True;
 }
@@ -1635,9 +1635,9 @@ CheckMoveDir(PyraminxWidget w, int face1, CRD crd1, int face2, CRD crd2,
 					TR : BL;
 				break;
 			}
-		if (!w->pyraminx.vertical && face1 >= MAXSIDES &&
+		if (!w->pyraminx.vertical && face1 >= MAX_SIDES &&
 				*direction > LEFT)
-			*direction = (*direction + MAXSIDES) % MAXFACES;
+			*direction = (*direction + MAX_SIDES) % MAX_FACES;
 	} else {
 		if (crd1.diagonal >= w->pyraminx.size)
 			crd1.diagonal = 2 * w->pyraminx.size - 1 -
@@ -1843,9 +1843,9 @@ CheckMoveDir(PyraminxWidget w, int face1, CRD crd1, int face2, CRD crd2,
 static void
 NarrowSelection(PyraminxWidget w, int style,
 		int *face, CRD * crd, int *direction) {
-	if (!w->pyraminx.vertical && *face >= MAXSIDES &&
-			*direction < MAXORIENT)
-		*direction = (*direction + MAXORIENT / 2) % MAXORIENT;
+	if (!w->pyraminx.vertical && *face >= MAX_SIDES &&
+			*direction < MAX_ORIENT)
+		*direction = (*direction + MAX_ORIENT / 2) % MAX_ORIENT;
 	if (style == PERIOD2) {
 		if (*direction == CW)
 			*direction = TR;
@@ -1916,7 +1916,7 @@ ResetPieces(PyraminxWidget w)
 	int face, position, orient, side;
 
 	w->pyraminx.sizeSize = w->pyraminx.size * w->pyraminx.size;
-	for (face = 0; face < MAXFACES; face++) {
+	for (face = 0; face < MAX_FACES; face++) {
 		if (w->pyraminx.facetLoc[face])
 			free(w->pyraminx.facetLoc[face]);
 		if (!(w->pyraminx.facetLoc[face] = (PyraminxLoc *)
@@ -1931,7 +1931,7 @@ ResetPieces(PyraminxWidget w)
 		}
 	}
 	for (orient = 0; orient < 3; orient++)
-		for (side = 0; side < MAXSIDES; side++) {
+		for (side = 0; side < MAX_SIDES; side++) {
 			if (w->pyraminx.rowLoc[orient][side])
 				free(w->pyraminx.rowLoc[orient][side]);
 			if (!(w->pyraminx.rowLoc[orient][side] = (PyraminxLoc *)
@@ -1939,7 +1939,7 @@ ResetPieces(PyraminxWidget w)
 				DISPLAY_ERROR("Not enough memory, exiting.");
 			}
 		}
-	for (side = 0; side < MAXSIDES; side++) {
+	for (side = 0; side < MAX_SIDES; side++) {
 		if (w->pyraminx.faceLoc)
 			free(w->pyraminx.faceLoc[side]);
 		if (!(w->pyraminx.faceLoc[side] = (PyraminxLoc *)
@@ -1947,7 +1947,7 @@ ResetPieces(PyraminxWidget w)
 			DISPLAY_ERROR("Not enough memory, exiting.");
 		}
 	}
-	for (face = 0; face < MAXFACES; face++)
+	for (face = 0; face < MAX_FACES; face++)
 		for (position = 0; position < w->pyraminx.sizeSize; position++) {
 			w->pyraminx.facetLoc[face][position].face = face;
 			w->pyraminx.facetLoc[face][position].rotation = TOP;
@@ -1966,7 +1966,7 @@ ResizePieces(PyraminxWidget w)
 	w->pyraminx.facetLength = w->pyraminx.faceLength / w->pyraminx.size -
 		w->pyraminx.delta - 1;
 	for (i = 0; i <= 3; i++)
-		for (j = 0; j < MAXSIDES; j++) {
+		for (j = 0; j < MAX_SIDES; j++) {
 			triangleList[j][i].x = triangleUnit[j][i].x *
 				w->pyraminx.facetLength;
 			triangleList[j][i].y = triangleUnit[j][i].y *
@@ -2036,7 +2036,7 @@ GetPieces(PyraminxWidget w)
 	flushMoves(w, &redo, FALSE);
 	while ((c = getc(fp)) != EOF && c != SYMBOL);
 	(void) fscanf(fp, "%d", &size);
-	if (size >= MINFACETS) {
+	if (size >= MIN_FACETS) {
 		for (i = w->pyraminx.size; i < size; i++) {
 			setPuzzle(w, ACTION_INCREMENT);
 		}
@@ -2049,7 +2049,7 @@ GetPieces(PyraminxWidget w)
 		free(buf1);
 		stringCat(&buf1, buf2, " should be between ");
 		free(buf2);
-		intCat(&buf2, buf1, MINFACETS);
+		intCat(&buf2, buf1, MIN_FACETS);
 		free(buf1);
 		stringCat(&buf1, buf2, " and MAXINT");
 		free(buf2);
@@ -2188,8 +2188,8 @@ UndoPieces(PyraminxWidget w)
 			&face, &position, &direction, &style, &control);
 		setMove(&redo,
 			face, position, direction, style, control);
-		direction = (direction < MAXORIENT) ? (direction + MAXORIENT / 2) %
-			MAXORIENT : 3 * MAXORIENT - direction;
+		direction = (direction < MAX_ORIENT) ? (direction + MAX_ORIENT / 2) %
+			MAX_ORIENT : 3 * MAX_ORIENT - direction;
 		if (control)
 			MoveControlCb(w, face, direction, style);
 		else {
@@ -2269,9 +2269,9 @@ RandomizePieces(PyraminxWidget w)
 #endif
 
 	while (big--) {
-		face = NRAND(MAXFACES);
+		face = NRAND(MAX_FACES);
 		if (w->pyraminx.mode == BOTH)
-			style = NRAND(MAXMODES - 1) + PERIOD2;
+			style = NRAND(MAX_MODES - 1) + PERIOD2;
 		else
 			style = w->pyraminx.mode;
 		if (w->pyraminx.sticky) {
@@ -2291,7 +2291,7 @@ RandomizePieces(PyraminxWidget w)
 				randomDirection = NRAND(6);
 			}
 		} else {	/* (!w->pyraminx.sticky) */
-			randomDirection = NRAND(MAXORIENT);
+			randomDirection = NRAND(MAX_ORIENT);
 			position = NRAND(w->pyraminx.sizeSize);
 			if (w->pyraminx.mode == BOTH)
 				style = NRAND(BOTH);
@@ -2331,7 +2331,7 @@ IncrementPieces(PyraminxWidget w)
 static Boolean
 DecrementPieces(PyraminxWidget w)
 {
-	if (w->pyraminx.size <= MINFACETS)
+	if (w->pyraminx.size <= MIN_FACETS)
 		return False;
 	setPuzzle(w, ACTION_DECREMENT);
 	return True;
@@ -2388,17 +2388,17 @@ SetValuesPuzzle(PyraminxWidget w)
 	w->pyraminx.size = GetPrivateProfileInt(SECTION, "size",
 		DEFAULTFACETS, INIFILE);
 	w->pyraminx.mode = GetPrivateProfileInt(SECTION, "mode",
-		DEFAULTMODE, INIFILE);
+		DEFAULT_MODE, INIFILE);
 	w->pyraminx.sticky = (BOOL) GetPrivateProfileInt(SECTION, "sticky",
 		DEFAULTSTICKY, INIFILE);
 	w->pyraminx.orient = (BOOL) GetPrivateProfileInt(SECTION, "orient",
-		DEFAULTORIENT, INIFILE);
+		DEFAULT_ORIENT, INIFILE);
 	w->pyraminx.practice = (BOOL) GetPrivateProfileInt(SECTION, "practice",
-		DEFAULTPRACTICE, INIFILE);
+		DEFAULT_PRACTICE, INIFILE);
 	w->pyraminx.mono = (BOOL) GetPrivateProfileInt(SECTION, "mono",
-		DEFAULTMONO, INIFILE);
+		DEFAULT_MONO, INIFILE);
 	w->pyraminx.reverse = (BOOL) GetPrivateProfileInt(SECTION, "reverseVideo",
-		DEFAULTREVERSE, INIFILE);
+		DEFAULT_REVERSE, INIFILE);
 	/* cyan */
 	(void) GetPrivateProfileString(SECTION, "frameColor", "0 255 255",
 		szBuf, sizeof (szBuf), INIFILE);
@@ -2417,7 +2417,7 @@ SetValuesPuzzle(PyraminxWidget w)
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
 	w->pyraminx.inverseGC = RGB(color.red, color.green, color.blue);
-	for (face = 0; face < MAXFACES; face++) {
+	for (face = 0; face < MAX_FACES; face++) {
 		(void) sprintf(buf, "faceColor%d", face);
 		(void) GetPrivateProfileString(SECTION, buf,
 			faceColorString[face],
@@ -2550,7 +2550,7 @@ SetAllColors(PyraminxWidget w)
 	if (w->pyraminx.borderGC)
 		XtReleaseGC((Widget) w, w->pyraminx.borderGC);
 	w->pyraminx.borderGC = XtGetGC((Widget) w, valueMask, &values);
-	for (face = 0; face < MAXFACES; face++)
+	for (face = 0; face < MAX_FACES; face++)
 		GetColor(w, face);
 	if (w->pyraminx.fontInfo)
 		XSetFont(XtDisplay(w), w->pyraminx.borderGC,
@@ -2565,7 +2565,7 @@ SetValuesPuzzle(Widget current, Widget request, Widget renew)
 	int face;
 
 	CheckPieces(w);
-	for (face = 0; face < MAXFACES; face++) {
+	for (face = 0; face < MAX_FACES; face++) {
 		if (strcmp(w->pyraminx.faceName[face], c->pyraminx.faceName[face])) {
 			setColors = True;
 			break;
@@ -2665,7 +2665,7 @@ DestroyPuzzle(Widget old)
 	Display *display = XtDisplay(w);
 	int face;
 
-	for (face = 0; face < MAXFACES; face++)
+	for (face = 0; face < MAX_FACES; face++)
 		XtReleaseGC(old, w->pyraminx.faceGC[face]);
 	XtReleaseGC(old, w->pyraminx.borderGC);
 	XtReleaseGC(old, w->pyraminx.frameGC);
@@ -2760,7 +2760,7 @@ Widget request, Widget renew
 	w->pyraminx.mono = (DefaultDepthOfScreen(XtScreen(w)) < 2 ||
 		w->pyraminx.mono);
 	w->pyraminx.fontInfo = NULL;
-	for (face = 0; face < MAXFACES; face++)
+	for (face = 0; face < MAX_FACES; face++)
 		w->pyraminx.faceGC[face] = NULL;
 	w->pyraminx.borderGC = NULL;
 	w->pyraminx.frameGC = NULL;
@@ -2768,12 +2768,12 @@ Widget request, Widget renew
 #endif
 	w->pyraminx.focus = False;
 	loadFont(w);
-	for (face = 0; face < MAXFACES; face++)
+	for (face = 0; face < MAX_FACES; face++)
 		w->pyraminx.facetLoc[face] = NULL;
 	for (orient = 0; orient < 3; orient++)
-		for (side = 0; side < MAXSIDES; side++)
+		for (side = 0; side < MAX_SIDES; side++)
 			w->pyraminx.rowLoc[orient][side] = NULL;
-	for (side = 0; side < MAXSIDES; side++)
+	for (side = 0; side < MAX_SIDES; side++)
 		w->pyraminx.faceLoc[side] = NULL;
 	CheckPieces(w);
 	newMoves(&undo);
