@@ -9,7 +9,7 @@
 #  and Puzzles by John Ewing & Czes Kosniowski)
 #  Break ability taken from the X puzzle by Don Bennett, HP Labs
 #
-#  Copyright (c) 1999 - 2007	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1999 - 2007	David A. Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -46,7 +46,7 @@
 #define RotateCornerCCW(w,f) MovePuzzlePiece(w,f,1,(f%2)?BL:TR,PERIOD3,TRUE); \
 	MovePuzzlePiece(w,f,6,(f%2)?TR:BL,PERIOD3,FALSE)
 
-#define topFaceTrans(tf,f) ((tf==0)?f:((tf==1)?MAXFACES-1-(f+MAXFACES/2)%MAXFACES:((tf==2)?(f+MAXFACES/2)%MAXFACES:MAXFACES-1-f)))
+#define topFaceTrans(tf,f) ((tf==0)?f:((tf==1)?MAX_FACES-1-(f+MAX_FACES/2)%MAX_FACES:((tf==2)?(f+MAX_FACES/2)%MAX_FACES:MAX_FACES-1-f)))
 
 #define P_PLUS RotateCornerCW(w,topFaceTrans(topFace,0)) /* Posterior Corner CW */
 #define B_PLUS RotateCornerCW(w,topFaceTrans(topFace,1)) /* Bottom Corner CW */
@@ -73,7 +73,7 @@ static int IndexToEdges[3] =
 static int EdgesToIndex[9] =
 { 3, 0, 3, 1, 3, 3, 2, 3, 3};
 
-static PyraminxSLoc EdgeMate[MAXFACES][3] =
+static PyraminxSLoc EdgeMate[MAX_FACES][3] =
 {
 	{
 		{2, 1},
@@ -205,10 +205,10 @@ OrientLittleCorners(PyraminxWidget w)
 {
 	int face, currentColor;
 
-	for (face = 0; face < MAXFACES; face++) {
+	for (face = 0; face < MAX_FACES; face++) {
 		currentColor = w->pyraminx.facetLoc[face][0].face;
 		if (currentColor != w->pyraminx.facetLoc[face][2].face) {
-			if (currentColor == w->pyraminx.facetLoc[MAXFACES - face - 1][w->pyraminx.sizeSize - 2].face) {
+			if (currentColor == w->pyraminx.facetLoc[MAX_FACES - face - 1][w->pyraminx.sizeSize - 2].face) {
 				RotateLittleCornerCCW(w,face);
 			} else {
 				RotateLittleCornerCW(w,face);
@@ -246,7 +246,7 @@ FindFaceColor(PyraminxWidget w, int face)
 		default:
 			(void) printf("Wrong face %d.\n", face);
 	}
-	for (color = 0; color < MAXFACES; color++) {
+	for (color = 0; color < MAX_FACES; color++) {
 		for (cornerFace = 0; cornerFace < 3; cornerFace++) {
 			if (color == colors[cornerFace])
 				break;
@@ -294,7 +294,7 @@ FindPiece(PyraminxWidget w, int color0, int color1, int *face, int *position)
 		}
 	}
 	faceSkip = *face;
-	for (*face = 0; *face < MAXFACES; (*face)++) {
+	for (*face = 0; *face < MAX_FACES; (*face)++) {
 		if (*face != faceSkip) {
 			for (positionIndex = 0; positionIndex < 3; positionIndex++) {
 				*position = IndexToEdges[positionIndex];
@@ -318,7 +318,7 @@ FaceCorners(PyraminxWidget w, int face, int faceColor)
 	int otherFace;
 
 	if (faceColor != w->pyraminx.facetLoc[face][2].face) {
-		if (faceColor == w->pyraminx.facetLoc[MAXFACES - 1 - face][7].face) {
+		if (faceColor == w->pyraminx.facetLoc[MAX_FACES - 1 - face][7].face) {
 			RotateCornerCW(w,face);
 		} else {
 			RotateCornerCCW(w,face);
@@ -332,7 +332,7 @@ FaceCorners(PyraminxWidget w, int face, int faceColor)
 			RotateCornerCCW(w,otherFace);
 		}
 	}
-	otherFace = MAXFACES - 1 - face;
+	otherFace = MAX_FACES - 1 - face;
 	if (faceColor != w->pyraminx.facetLoc[face][7].face) {
 		if (faceColor == w->pyraminx.facetLoc[otherFace][2].face) {
 			RotateCornerCCW(w,otherFace);
@@ -356,11 +356,11 @@ FaceEdge(PyraminxWidget w, int topFace, int position, int faceColor)
 			newPosition = position + 1;
 			break;
 		case 3:
-			newFace = MAXFACES - 1 - topFace;
+			newFace = MAX_FACES - 1 - topFace;
 			newPosition = position - 1;
 			break;
 		case 6:
-			newFace = MAXFACES - 1 - ((topFace + 2) % 4);
+			newFace = MAX_FACES - 1 - ((topFace + 2) % 4);
 			newPosition = position - 1;
 			break;
 		default:
@@ -380,7 +380,7 @@ FaceEdge6(PyraminxWidget w, int topFace, int faceColor)
 
 	position = 6;
 	color0 = w->pyraminx.facetLoc[topFace][2].face;
-	newFace = MAXFACES - 1 - ((topFace + 2) % 4);
+	newFace = MAX_FACES - 1 - ((topFace + 2) % 4);
 	newPosition = position - 1;
 	color1 = w->pyraminx.facetLoc[newFace][newPosition].face;
 	/* newFace and newPosition variables are reused here */
@@ -454,7 +454,7 @@ TopFace(PyraminxWidget w)
 	FaceEdge(w, topFace, 6, faceColor);
 #else
 	FaceEdge6(w, topFace, faceColor);
-	aBottomFace = MAXFACES - 1 - ((topFace + 2) % 4);
+	aBottomFace = MAX_FACES - 1 - ((topFace + 2) % 4);
 	MovePuzzlePiece(w, aBottomFace, 6, (topFace % 2) ? TR : BL, PERIOD3, TRUE);
 	FaceEdge6(w, topFace, faceColor);
 	MovePuzzlePiece(w, aBottomFace, 6, (topFace % 2) ? TR : BL, PERIOD3, TRUE);
