@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1993 - 2007	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1993 - 2007	David A. Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -250,31 +250,31 @@ static const char solveHelp[] = {
 #define SCOREFILE "pyraminx.scores"
 #endif
 
-#define MAXFACETS 7
+#define MAX_FACETS 7
 #define NEVER (-1)
-#define FILENAMELEN 1024
-#define USERNAMELEN 120
-#define MESSAGELEN (USERNAMELEN+64)
-#define TITLELEN 2048
+#define FILE_NAME_LENGTH 1024
+#define USER_NAME_LENGTH 120
+#define MESSAGE_LENGTH (USER_NAME_LENGTH+64)
+#define TITLE_LENGTH 2048
 #define NOACCESS "noaccess"
 #define NOBODY "nobody"
 
 typedef struct {
 	int score;
-	char name[USERNAMELEN];
+	char name[USER_NAME_LENGTH];
 } PuzzleRecord;
 
-static PuzzleRecord puzzleRecord[MAXMODES][2][MAXFACETS - MINFACETS + 2];
+static PuzzleRecord puzzleRecord[MAX_MODES][2][MAX_FACETS - MIN_FACETS + 2];
 static int movesDsp = 0;
-static char messageDsp[MESSAGELEN] = "Welcome";
-static char recordDsp[MESSAGELEN] = "NOT RECORDED";
+static char messageDsp[MESSAGE_LENGTH] = "Welcome";
+static char recordDsp[MESSAGE_LENGTH] = "NOT RECORDED";
 static int oldSize;
 
 #ifdef HAVE_MOTIF
-#define MINSPEED 1
-#define MAXSPEED 50
+#define MIN_SPEED 1
+#define MAX_SPEED 50
 #define MULTSPEED 20
-static Widget moves, record, message, modes[MAXMODES], orientizeSwitch;
+static Widget moves, record, message, modes[MAX_MODES], orientizeSwitch;
 static Widget stickySwitch, practiceSwitch, facets, speed;
 static char buff[21];
 static const char *modeString[] =
@@ -286,20 +286,20 @@ static Widget optionsDialog, referencesDialog, aboutDialog;
 static Widget solveDialog, practiceDialog, randomizeDialog;
 static Arg arg[3];
 #else
-static char titleDsp[TITLELEN] = "";
+static char titleDsp[TITLE_LENGTH] = "";
 #endif
-static char scoreFileName[FILENAMELEN] = SCOREFILE;
-static char fileName[FILENAMELEN];
+static char scoreFileName[FILE_NAME_LENGTH] = SCOREFILE;
+static char fileName[FILE_NAME_LENGTH];
 static Boolean randomized = False;
 #ifdef WINVER
-#define MAXPROGNAME 80
-static char progDsp[MAXPROGNAME] = TITLE;
-static char userNameDsp[USERNAMELEN] = "Guest";
+#define PROGRAM_NAME_LENGTH 80
+static char progDsp[PROGRAM_NAME_LENGTH] = TITLE;
+static char userNameDsp[USER_NAME_LENGTH] = "Guest";
 #else
 static Pixmap pixmap = None;
 static Widget topLevel, puzzle;
 static char *progDsp;
-static char userNameDsp[USERNAMELEN] = "";
+static char userNameDsp[USER_NAME_LENGTH] = "";
 
 #ifdef HAVE_MOTIF
 static void
@@ -321,9 +321,9 @@ PrintRecords(void)
 
 	(void) printf("             PYRAMINX  HALL OF FAME\n\n");
 	(void) printf("MODE ORIENT FACET USER            MOVES\n");
-	for (mode = 0; mode < MAXMODES; mode++)
+	for (mode = 0; mode < MAX_MODES; mode++)
 		for (orient = 0; orient < 2; orient++)
-			for (i = 0; i <= MAXFACETS - MINFACETS + 1; i++) {
+			for (i = 0; i <= MAX_FACETS - MIN_FACETS + 1; i++) {
 				if (puzzleRecord[mode][orient][i].score > 0)
 					(void) printf("%4d%7d%6d %-12s%9d\n",
 						mode + 2, orient, i + 1,
@@ -338,12 +338,12 @@ InitRecords(void)
 {
 	int i, mode, orient;
 
-	for (mode = 0; mode < MAXMODES; mode++)
+	for (mode = 0; mode < MAX_MODES; mode++)
 		for (orient = 0; orient < 2; orient++)
-			for (i = 0; i <= MAXFACETS - MINFACETS + 1; i++) {
+			for (i = 0; i <= MAX_FACETS - MIN_FACETS + 1; i++) {
 				puzzleRecord[mode][orient][i].score = NEVER;
 				(void) strncpy(puzzleRecord[mode][orient][i].name,
-					NOACCESS, USERNAMELEN);
+					NOACCESS, USER_NAME_LENGTH);
 			}
 }
 
@@ -352,7 +352,7 @@ ReadRecords(void)
 {
 	FILE *fp;
 	int i, n, mode, orient;
-	char userName[USERNAMELEN];
+	char userName[USER_NAME_LENGTH];
 	char *buf1 = NULL, *buf2 = NULL;
 	char *fname, *lname;
 
@@ -362,9 +362,9 @@ ReadRecords(void)
 	stringCat(&buf2, buf1, SCOREFILE);
 	free(buf1);
 	fname = buf2;
-	(void) strncpy(fileName, lname, USERNAMELEN);
+	(void) strncpy(fileName, lname, USER_NAME_LENGTH);
 	if ((fp = fopen(fileName, "r")) == NULL) {
-		(void) strncpy(fileName, fname, USERNAMELEN);
+		(void) strncpy(fileName, fname, USER_NAME_LENGTH);
 		/* Try installed directory. */
 		if ((fp = fopen(fileName, "r")) == NULL) {
 			stringCat(&buf1, "Can not read ", fname);
@@ -393,15 +393,15 @@ ReadRecords(void)
 	}
 	free(lname);
 	free(fname);
-	for (mode = 0; mode < MAXMODES; mode++)
+	for (mode = 0; mode < MAX_MODES; mode++)
 		for (orient = 0; orient < 2; orient++)
-			for (i = 0; i <= MAXFACETS - MINFACETS + 1; i++) {
+			for (i = 0; i <= MAX_FACETS - MIN_FACETS + 1; i++) {
 				(void) fscanf(fp, "%d %s\n", &n, userName);
 				if (n <= puzzleRecord[mode][orient][i].score ||
 						puzzleRecord[mode][orient][i].score <= NEVER) {
 					puzzleRecord[mode][orient][i].score = n;
 					(void) strncpy(puzzleRecord[mode][orient][i].name,
-						userName, USERNAMELEN);
+						userName, USER_NAME_LENGTH);
 				}
 			}
 	(void) fclose(fp);
@@ -423,9 +423,9 @@ WriteRecords(void)
 	{
 #if HAVE_FCNTL_H
 		int lfd;
-		char lockFile[FILENAMELEN];
+		char lockFile[FILE_NAME_LENGTH];
 
-		(void) strncpy(lockFile, fileName, FILENAMELEN - 6);
+		(void) strncpy(lockFile, fileName, FILE_NAME_LENGTH - 6);
 		(void) strcat(lockFile, ".lock");
 		while (((lfd = open(lockFile, O_CREAT | O_EXCL, 0644)) < 0) &&
 				errno == EEXIST)
@@ -441,9 +441,9 @@ WriteRecords(void)
 #endif
 		}
 #endif
-		for (mode = 0; mode < MAXMODES; mode++) {
+		for (mode = 0; mode < MAX_MODES; mode++) {
 			for (orient = 0; orient < 2; orient++) {
-				for (i = 0; i <= MAXFACETS - MINFACETS + 1; i++)
+				for (i = 0; i <= MAX_FACETS - MIN_FACETS + 1; i++)
 					(void) fprintf(fp, "%d %s\n",
 					puzzleRecord[mode][orient][i].score,
 					puzzleRecord[mode][orient][i].name);
@@ -465,12 +465,12 @@ PrintRecord(int size, int mode,
 {
 	int i = mode - PERIOD2;
 	int j = (orient) ? 1 : 0;
-	int k = (sticky) ? MAXFACETS - MINFACETS + 1 : size - MINFACETS;
+	int k = (sticky) ? MAX_FACETS - MIN_FACETS + 1 : size - MIN_FACETS;
 
 	if (practice) {
-		(void) strncpy(recordDsp, "practice", MESSAGELEN);
-	} else if (!sticky && size > MAXFACETS) {
-		(void) strncpy(recordDsp, "NOT RECORDED", MESSAGELEN);
+		(void) strncpy(recordDsp, "practice", MESSAGE_LENGTH);
+	} else if (!sticky && size > MAX_FACETS) {
+		(void) strncpy(recordDsp, "NOT RECORDED", MESSAGE_LENGTH);
 	} else if (puzzleRecord[i][j][k].score <= NEVER) {
 		(void) sprintf(recordDsp, "NEVER %s", NOACCESS);
 	} else {
@@ -520,21 +520,21 @@ HandleSolved(int counter, int size, int mode, Boolean orient, Boolean sticky)
 {
 	int i = mode - PERIOD2;
 	int j = (orient) ? 1 : 0;
-	int k = (sticky) ? MAXFACETS - MINFACETS + 1 : size - MINFACETS;
+	int k = (sticky) ? MAX_FACETS - MIN_FACETS + 1 : size - MIN_FACETS;
 
-	if ((sticky || size <= MAXFACETS) &&
+	if ((sticky || size <= MAX_FACETS) &&
 			(counter < puzzleRecord[i][j][k].score ||
 			puzzleRecord[i][j][k].score <= NEVER)) {
 		ReadRecords();	/* Maybe its been updated by another */
 		puzzleRecord[i][j][k].score = counter;
 		(void) strncpy(puzzleRecord[i][j][k].name, userNameDsp,
-			USERNAMELEN);
+			USER_NAME_LENGTH);
 		if (size < 4 || mode == PERIOD2 || (orient &&
 				(counter < puzzleRecord[i][!j][k].score ||
 				puzzleRecord[i][!j][k].score <= NEVER))) {
 			puzzleRecord[i][!j][k].score = counter;
 			(void) strncpy(puzzleRecord[i][!j][k].name, userNameDsp,
-				USERNAMELEN);
+				USER_NAME_LENGTH);
 		}
 		WriteRecords();
 		PrintRecord(size, mode, orient, sticky, False);
@@ -567,7 +567,7 @@ Widget w
 	userName = w->pyraminx.userName;
 	scoreFile = w->pyraminx.scoreFile;
 	if (strcmp(scoreFile, ""))
-		(void) strncpy(scoreFileName, scoreFile, FILENAMELEN);
+		(void) strncpy(scoreFileName, scoreFile, FILE_NAME_LENGTH);
 #else
 	Boolean scoreOnly, versionOnly;
 
@@ -586,7 +586,7 @@ Widget w
 		exit(0);
 	}
 	if (strcmp(scoreFile, ""))
-		(void) strncpy(scoreFileName, scoreFile, FILENAMELEN);
+		(void) strncpy(scoreFileName, scoreFile, FILE_NAME_LENGTH);
 	if (scoreOnly) {
 		InitRecords();
 		ReadRecords();
@@ -594,7 +594,7 @@ Widget w
 		exit(0);
 	}
 #ifdef HAVE_MOTIF
-	if (size > MAXFACETS)
+	if (size > MAX_FACETS)
 		XtVaSetValues(facets, XmNmaximum, size, NULL);
 	XmScaleSetValue(facets, size);
 	XmToggleButtonSetState(modes[mode - PERIOD2], True, False);
@@ -606,7 +606,7 @@ Widget w
 
 		XtVaGetValues(w, XtNdelay, &delay, NULL);
 		XmScaleSetValue(speed,
-			MAXSPEED + MINSPEED - delay / MULTSPEED - 1);
+			MAX_SPEED + MIN_SPEED - delay / MULTSPEED - 1);
 	}
 #endif
 #endif
@@ -614,13 +614,13 @@ Widget w
 	InitRecords();
 	ReadRecords();
 #ifndef WINVER
-	(void) strncpy(userNameDsp, userName, USERNAMELEN);
+	(void) strncpy(userNameDsp, userName, USER_NAME_LENGTH);
 #endif
 	if (!strcmp(userName, "") || !strcmp(userName, "(null)") ||
 			!strcmp(userName, NOACCESS) ||
 			!strcmp(userName, NOBODY)) {
 #ifdef WINVER
-		(void) strncpy(userNameDsp, userName, USERNAMELEN);
+		(void) strncpy(userNameDsp, userName, USER_NAME_LENGTH);
 #else
 		char *login = getlogin();
 
@@ -714,14 +714,14 @@ CallbackPuzzle(Widget w, caddr_t clientData,
 #ifdef HAVE_MOTIF
 		XtManageChild(solveDialog);
 #else
-		(void) strncpy(messageDsp, solveHelp, MESSAGELEN);
+		(void) strncpy(messageDsp, solveHelp, MESSAGE_LENGTH);
 #endif
 #endif
 		break;
 	case ACTION_RESTORE:
 		if (practice) {
 			(void) strncpy(recordDsp, "practice",
-				MESSAGELEN);
+				MESSAGE_LENGTH);
 #ifdef HAVE_MOTIF
 			PrintState(record, recordDsp);
 #endif
@@ -735,15 +735,15 @@ CallbackPuzzle(Widget w, caddr_t clientData,
 		break;
 	case ACTION_AMBIGUOUS:
 		(void) strncpy(messageDsp, "Ambiguous move",
-			MESSAGELEN);
+			MESSAGE_LENGTH);
 		break;
 	case ACTION_ILLEGAL:
 		if (practice || randomized)
 			(void) strncpy(messageDsp, "Illegal move",
-				MESSAGELEN);
+				MESSAGE_LENGTH);
 		else
 			(void) strncpy(messageDsp,
-				"Randomize to start", MESSAGELEN);
+				"Randomize to start", MESSAGE_LENGTH);
 		break;
 	case ACTION_MOVED:
 		movesDsp++;
@@ -762,7 +762,7 @@ CallbackPuzzle(Widget w, caddr_t clientData,
 				"Congratulations %s!!", userNameDsp);
 		else
 			(void) strncpy(messageDsp, "Solved!",
-				MESSAGELEN);
+				MESSAGE_LENGTH);
 		SET_STARTED(w, False);
 		randomized = False;
 		break;
@@ -775,7 +775,7 @@ CallbackPuzzle(Widget w, caddr_t clientData,
 		practice = !practice;
 		if (!practice)
 			(void) strncpy(messageDsp, "Randomize to start",
-				MESSAGELEN);
+				MESSAGE_LENGTH);
 		PrintRecord(size, mode, orient, sticky, practice);
 #ifdef WINVER
 		w->pyraminx.practice = practice;
@@ -812,7 +812,7 @@ CallbackPuzzle(Widget w, caddr_t clientData,
 #else
 			XtVaSetValues(w, XtNsize, size, NULL);
 #ifdef HAVE_MOTIF
-			if (size > MAXFACETS)
+			if (size > MAX_FACETS)
 				XtVaSetValues(facets, XmNmaximum, size, NULL);
 			XmScaleSetValue(facets, size);
 #endif
@@ -831,7 +831,7 @@ CallbackPuzzle(Widget w, caddr_t clientData,
 			XtVaSetValues(w, XtNsize, size, NULL);
 #ifdef HAVE_MOTIF
 			XmScaleSetValue(facets, size);
-			if (size >= MAXFACETS)
+			if (size >= MAX_FACETS)
 				XtVaSetValues(facets, XmNmaximum, size, NULL);
 #endif
 #endif
@@ -901,8 +901,8 @@ CallbackPuzzle(Widget w, caddr_t clientData,
 
 			XtVaGetValues(puzzle, XtNdelay, &delay, NULL);
 			oldDelay = delay;
-			if (delay > MAXSPEED - MINSPEED)
-				delay = MAXSPEED - MINSPEED;
+			if (delay > MAX_SPEED - MIN_SPEED)
+				delay = MAX_SPEED - MIN_SPEED;
 			if (delay < 0)
 				delay = 0;
 			if (delay != oldDelay) {
@@ -910,7 +910,7 @@ CallbackPuzzle(Widget w, caddr_t clientData,
 					XtNdelay, delay, NULL);
 			}
 			XmScaleSetValue(speed,
-				MAXSPEED + MINSPEED - delay - 1);
+				MAX_SPEED + MIN_SPEED - delay - 1);
 		}
 		return;
 #endif
@@ -1141,14 +1141,14 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 				(void) ReleaseDC(hWnd, widget.core.hDC);
 			}
 			break;
-		case ACTION_SHIFTCONTROL_TOP:
-		case ACTION_SHIFTCONTROL_TR:
-		case ACTION_SHIFTCONTROL_RIGHT:
-		case ACTION_SHIFTCONTROL_BOTTOM:
-		case ACTION_SHIFTCONTROL_BL:
-		case ACTION_SHIFTCONTROL_LEFT:
-		case ACTION_SHIFTCONTROL_CW:
-		case ACTION_SHIFTCONTROL_CCW:
+		case ACTION_SHIFT_CONTROL_TOP:
+		case ACTION_SHIFT_CONTROL_TR:
+		case ACTION_SHIFT_CONTROL_RIGHT:
+		case ACTION_SHIFT_CONTROL_BOTTOM:
+		case ACTION_SHIFT_CONTROL_BL:
+		case ACTION_SHIFT_CONTROL_LEFT:
+		case ACTION_SHIFT_CONTROL_CW:
+		case ACTION_SHIFT_CONTROL_CCW:
 			shift = 1;
 		case ACTION_CONTROL_TOP:
 		case ACTION_CONTROL_TR:
@@ -1171,7 +1171,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 					cursor.x - origin.x,
 					cursor.y - origin.y,
 					(int) LOWORD(wParam) -
-					((shift) ? ACTION_SHIFTCONTROL_TOP :
+					((shift) ? ACTION_SHIFT_CONTROL_TOP :
 					ACTION_CONTROL_TOP),
 					shift, TRUE);
 				(void) ReleaseDC(hWnd, widget.core.hDC);
@@ -1438,7 +1438,7 @@ StickyToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs)
 			size = 4;
 		else
 			size = oldSize;
-		if (size <= MAXFACETS)
+		if (size <= MAX_FACETS)
 			XmScaleSetValue(facets, size);
 		XtVaSetValues(puzzle,
 			XtNsize, size, NULL);
@@ -1473,14 +1473,14 @@ PracticeToggle(Widget w, XtPointer clientData,
 	if (practice)
 		(void) strcpy(messageDsp, "");
 	else
-		(void) strncpy(messageDsp, "Randomize to start", MESSAGELEN);
+		(void) strncpy(messageDsp, "Randomize to start", MESSAGE_LENGTH);
 	PrintState(message, messageDsp);
 }
 
 static void
 SpeedSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 {
-	int delay = MULTSPEED * (MAXSPEED + MINSPEED - cbs->value - 1), oldDelay;
+	int delay = MULTSPEED * (MAX_SPEED + MIN_SPEED - cbs->value - 1), oldDelay;
 
 	XtVaGetValues(puzzle,
 		XtNdelay, &oldDelay, NULL);
@@ -1511,7 +1511,7 @@ static Widget
 createQuery(Widget w, char *text, char *title, XtCallbackProc callback)
 {
 	Widget button, messageBox;
-	char titleDsp[FILENAMELEN + 8];
+	char titleDsp[FILE_NAME_LENGTH + 8];
 	XmString titleString = NULL, messageString = NULL;
 	static XmStringCharSet charSet =
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
@@ -1537,7 +1537,7 @@ static Widget
 createHelp(Widget w, char *text, char *title)
 {
 	Widget button, messageBox;
-	char titleDsp[FILENAMELEN + 8];
+	char titleDsp[FILE_NAME_LENGTH + 8];
 	XmString titleString = NULL, messageString = NULL, buttonString = NULL;
 	static XmStringCharSet charSet =
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
@@ -1806,9 +1806,9 @@ main(int argc, char **argv)
 	facets = XtVaCreateManagedWidget("facets",
 		xmScaleWidgetClass, facetsRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Size", 5,
-		XmNminimum, MINFACETS,
-		XmNmaximum, MAXFACETS,
-		XmNvalue, MINFACETS,
+		XmNminimum, MIN_FACETS,
+		XmNmaximum, MAX_FACETS,
+		XmNvalue, MIN_FACETS,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
 	XtAddCallback(facets, XmNvalueChangedCallback,
@@ -1816,9 +1816,9 @@ main(int argc, char **argv)
 	speed = XtVaCreateManagedWidget("speed",
 		xmScaleWidgetClass, facetsRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Animation Speed", 16,
-		XmNminimum, MINSPEED,
-		XmNmaximum, MAXSPEED,
-		XmNvalue, MAXSPEED - 10,
+		XmNminimum, MIN_SPEED,
+		XmNmaximum, MAX_SPEED,
+		XmNvalue, MAX_SPEED - 10,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
 	XtAddCallback(speed, XmNvalueChangedCallback,
@@ -1848,7 +1848,7 @@ main(int argc, char **argv)
 		XmNpacking, XmPACK_COLUMN, NULL);
 	orientizeSwitch = XtVaCreateManagedWidget("Oriented",
 		xmToggleButtonWidgetClass, switchRowCol,
-		XmNset, DEFAULTORIENT, NULL);
+		XmNset, DEFAULT_ORIENT, NULL);
 	XtAddCallback(orientizeSwitch, XmNvalueChangedCallback,
 		(XtCallbackProc) OrientToggle, (XtPointer) NULL);
 	stickySwitch = XtVaCreateManagedWidget("Sticky",
@@ -1858,7 +1858,7 @@ main(int argc, char **argv)
 		(XtCallbackProc) StickyToggle, (XtPointer) NULL);
 	practiceSwitch = XtVaCreateManagedWidget("Practice",
 		xmToggleButtonWidgetClass, switchRowCol,
-		XmNset, DEFAULTPRACTICE, NULL);
+		XmNset, DEFAULT_PRACTICE, NULL);
 	XtAddCallback(practiceSwitch, XmNvalueChangedCallback,
 		(XtCallbackProc) PracticeToggle, (XtPointer) NULL);
 	messageRowCol = XtVaCreateManagedWidget("messageRowCol",
