@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 2007	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1994 - 2007	David A. Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -45,7 +45,7 @@
 
 #define SECTION "setup"
 
-static const char *faceColorString[MAXFACES] =
+static const char *faceColorString[MAX_FACES] =
 {
 	"255 0 0",
 	"255 255 0",
@@ -55,7 +55,7 @@ static const char *faceColorString[MAXFACES] =
 	"0 0 255"
 };
 
-static const char faceColorChar[MAXFACES] =
+static const char faceColorChar[MAX_FACES] =
 {'R', 'Y', 'W', 'G', 'O', 'B'};
 #else
 
@@ -182,7 +182,7 @@ loadFont(RubikWidget w)
 #define LOGFILE "rubik.log"
 #endif
 
-static int facesToDirection[MAXFACES][MAXFACES] =
+static int facesToDirection[MAX_FACES][MAX_FACES] =
 {
 	{-1, 3, 2, 1, -3, 0},
 	{0, -1, 1, -3, 2, 3},
@@ -191,7 +191,7 @@ static int facesToDirection[MAXFACES][MAXFACES] =
 	{-3, 3, 0, 1, -1, 2},
 	{2, 3, -3, 1, 0, -1}
 };
-static RubikLoc slideNextRow[MAXFACES][MAXORIENT] =
+static RubikLoc slideNextRow[MAX_FACES][MAX_ORIENT] =
 {
 	{
 		{5, TOP},
@@ -230,7 +230,7 @@ static RubikLoc slideNextRow[MAXFACES][MAXORIENT] =
 		{1, BOTTOM}
 	}
 };
-static int rowToRotate[MAXFACES][MAXORIENT] =
+static int rowToRotate[MAX_FACES][MAX_ORIENT] =
 {
 	{3, 2, 1, 5},
 	{2, 4, 5, 0},
@@ -248,10 +248,10 @@ CheckPieces(RubikWidget w)
 {
 	char *buf1 = NULL, *buf2 = NULL;
 
-	if (w->rubik.sizex < MINFACETS) {
+	if (w->rubik.sizex < MIN_FACETS) {
 		intCat(&buf1,
 			"Number of rubik in X direction out of bounds, use at least ",
-			MINFACETS);
+			MIN_FACETS);
 		stringCat(&buf2, buf1, ", defaulting to ");
 		free(buf1);
 		intCat(&buf1, buf2, DEFAULTFACETS);
@@ -260,10 +260,10 @@ CheckPieces(RubikWidget w)
 		free(buf1);
 		w->rubik.sizex = DEFAULTFACETS;
 	}
-	if (w->rubik.sizey < MINFACETS) {
+	if (w->rubik.sizey < MIN_FACETS) {
 		intCat(&buf1,
 			"Number of rubik in Y direction out of bounds, use at least ",
-			MINFACETS);
+			MIN_FACETS);
 		stringCat(&buf2, buf1, ", defaulting to ");
 		free(buf1);
 		intCat(&buf1, buf2, DEFAULTFACETS);
@@ -272,10 +272,10 @@ CheckPieces(RubikWidget w)
 		free(buf1);
 		w->rubik.sizey = DEFAULTFACETS;
 	}
-	if (w->rubik.sizez < MINFACETS) {
+	if (w->rubik.sizez < MIN_FACETS) {
 		intCat(&buf1,
 			"Number of rubik in Z direction out of bounds, use at least ",
-			MINFACETS);
+			MIN_FACETS);
 		stringCat(&buf2, buf1, ", defaulting to ");
 		free(buf1);
 		intCat(&buf1, buf2, DEFAULTFACETS);
@@ -370,14 +370,14 @@ CheckSolved(const RubikWidget w, Boolean rotation)
 	int face, position;
 	RubikLoc test = {0, FALSE};
 
-	for (face = 0; face < MAXFACES; face++)
+	for (face = 0; face < MAX_FACES; face++)
 		for (position = 0; position < sizeFace(w, face); position++) {
 			if (!position) {
 				test.face = w->rubik.cubeLoc[face][position].face;
 				test.rotation = w->rubik.cubeLoc[face][position].rotation;
 			} else if (test.face !=		/* face */
 				   w->rubik.cubeLoc[face][position].face ||
-				   (rotation && test.rotation !=		/* STRT - MAXORIENT */
+				   (rotation && test.rotation !=		/* STRT - MAX_ORIENT */
 				  w->rubik.cubeLoc[face][position].rotation))
 				return False;
 		}
@@ -390,7 +390,7 @@ PrintCube(RubikWidget w)
 {
 	int face, position, sizeOfRow, sizeOfColumn;
 
-	for (face = 0; face < MAXFACES; face++) {
+	for (face = 0; face < MAX_FACES; face++) {
 		faceSizes(w, face, &sizeOfRow, &sizeOfColumn);
 		for (position = 0; position < sizeOfRow * sizeOfColumn; position++) {
 			(void) printf("%d %d  ", w->rubik.cubeLoc[face][position].face,
@@ -437,7 +437,7 @@ DrawAllPieces(const RubikWidget w)
 		return;
 	}
 #endif
-	for (face = 0; face < MAXFACES; face++)
+	for (face = 0; face < MAX_FACES; face++)
 		for (position = 0; position < sizeFace(w, face); position++)
 			DrawSquare(w, face, position, FALSE);
 }
@@ -492,7 +492,7 @@ RotateFace(RubikWidget w, int face, int direction)
 
 		w->rubik.cubeLoc[face][position].rotation =
 			(w->rubik.cubeLoc[face][position].rotation +
-			 direction - MAXORIENT) % MAXORIENT;
+			 direction - MAX_ORIENT) % MAX_ORIENT;
 		DrawSquare(w, face, position, FALSE);
 	}
 	if (faceLoc != NULL)
@@ -507,7 +507,7 @@ SlideRC(RubikWidget w, int face, int direction, int h, int sizeOnOppAxis,
 {
 	*newFace = slideNextRow[face][direction].face;
 	*rotate = slideNextRow[face][direction].rotation;
-	*newDirection = (*rotate + direction) % MAXORIENT;
+	*newDirection = (*rotate + direction) % MAX_ORIENT;
 	switch (*rotate) {
 	case TOP:
 		*newH = h;
@@ -571,7 +571,7 @@ RotateRC(RubikWidget w, int rotate, int orient, int size)
 
 	for (g = 0; g < size; g++)
 		w->rubik.rowLoc[orient][g].rotation =
-			(w->rubik.rowLoc[orient][g].rotation + rotate) % MAXORIENT;
+			(w->rubik.rowLoc[orient][g].rotation + rotate) % MAX_ORIENT;
 }
 
 static void
@@ -671,21 +671,21 @@ MovePieces(RubikWidget w, int face, int position, int direction,
 		face = newFace;
 		direction = newDirection;
 		h = newH;
-		for (k = 2; k <= MAXORIENT + 1; k++) {
+		for (k = 2; k <= MAX_ORIENT + 1; k++) {
 			SlideRC(w, face, direction, h, sizeOnOppAxis,
 			  &newFace, &newDirection, &newH, &rotate, &reverse);
-			if (k != MAXORIENT && k != MAXORIENT + 1)
+			if (k != MAX_ORIENT && k != MAX_ORIENT + 1)
 				ReadRC(w, newFace, newDirection, newH, k,
 				     (k % 2) ? sizeOnDepthAxis : sizeOnAxis);
 			RotateRC(w, rotate, k - 2,
 				 (k % 2) ? sizeOnDepthAxis : sizeOnAxis);
-			if (k != MAXORIENT + 1)
+			if (k != MAX_ORIENT + 1)
 				RotateRC(w, rotate, k - 1,
 				     (k % 2) ? sizeOnAxis : sizeOnDepthAxis);
 			if (reverse == True) {
 				ReverseRC(w, k - 2,
 				     (k % 2) ? sizeOnDepthAxis : sizeOnAxis);
-				if (k != MAXORIENT + 1)
+				if (k != MAX_ORIENT + 1)
 					ReverseRC(w, k - 1,
 						(k % 2) ? sizeOnAxis : sizeOnDepthAxis);
 			}
@@ -696,10 +696,10 @@ MovePieces(RubikWidget w, int face, int position, int direction,
 			h = newH;
 		}
 	} else {
-		for (k = 1; k <= MAXORIENT; k++) {
+		for (k = 1; k <= MAX_ORIENT; k++) {
 			SlideRC(w, face, direction, h, sizeOnOppAxis,
 			  &newFace, &newDirection, &newH, &rotate, &reverse);
-			if (k != MAXORIENT)
+			if (k != MAX_ORIENT)
 				ReadRC(w, newFace, newDirection, newH, k, sizeOnAxis);
 			RotateRC(w, rotate, k - 1, sizeOnAxis);
 			if (reverse == TRUE)
@@ -863,7 +863,7 @@ ResetPieces(RubikWidget w)
 {
 	int face, position, orient, sizeOfFace;
 
-	for (face = 0; face < MAXFACES; face++) {
+	for (face = 0; face < MAX_FACES; face++) {
 		sizeOfFace = sizeFace(w, face);
 		if (w->rubik.cubeLoc[face])
 			free(w->rubik.cubeLoc[face]);
@@ -879,14 +879,14 @@ ResetPieces(RubikWidget w)
 		}
 		for (position = 0; position < sizeOfFace; position++) {
 			w->rubik.cubeLoc[face][position].face = face;
-			w->rubik.cubeLoc[face][position].rotation = STRT - MAXORIENT;
+			w->rubik.cubeLoc[face][position].rotation = STRT - MAX_ORIENT;
 		}
 	}
-	for (orient = 0; orient < MAXORIENT; orient++) {
+	for (orient = 0; orient < MAX_ORIENT; orient++) {
 		if (w->rubik.rowLoc[orient])
 			free(w->rubik.rowLoc[orient]);
 		if (!(w->rubik.rowLoc[orient] = (RubikLoc *)
-				malloc(sizeof (RubikLoc) * MAXMAXSIZE))) {
+				malloc(sizeof (RubikLoc) * MAX_MAX_SIZE))) {
 			DISPLAY_ERROR("Not enough memory, exiting.");
 		}
 	}
@@ -944,7 +944,7 @@ GetPieces(RubikWidget w)
 	flushMoves(w, &redo, FALSE);
 	while ((c = getc(fp)) != EOF && c != SYMBOL);
 	(void) fscanf(fp, "%d", &sizex);
-	if (sizex >= MINFACETS) {
+	if (sizex >= MIN_FACETS) {
 		for (i = w->rubik.sizex; i < sizex; i++) {
 			setPuzzle(w, ACTION_INCX);
 		}
@@ -957,7 +957,7 @@ GetPieces(RubikWidget w)
 		free(buf1);
 		stringCat(&buf1, buf2, " should be between ");
 		free(buf2);
-		intCat(&buf2, buf1, MINFACETS);
+		intCat(&buf2, buf1, MIN_FACETS);
 		free(buf1);
 		stringCat(&buf1, buf2, " and MAXINT");
 		free(buf2);
@@ -966,7 +966,7 @@ GetPieces(RubikWidget w)
 	}
 	while ((c = getc(fp)) != EOF && c != SYMBOL);
 	(void) fscanf(fp, "%d", &sizey);
-	if (sizey >= MINFACETS) {
+	if (sizey >= MIN_FACETS) {
 		for (i = w->rubik.sizey; i < sizey; i++) {
 			setPuzzle(w, ACTION_INCY);
 		}
@@ -979,7 +979,7 @@ GetPieces(RubikWidget w)
 		free(buf1);
 		stringCat(&buf1, buf2, " should be between ");
 		free(buf2);
-		intCat(&buf2, buf1, MINFACETS);
+		intCat(&buf2, buf1, MIN_FACETS);
 		free(buf1);
 		stringCat(&buf1, buf2, " and MAXINT");
 		free(buf2);
@@ -988,7 +988,7 @@ GetPieces(RubikWidget w)
 	}
 	while ((c = getc(fp)) != EOF && c != SYMBOL);
 	(void) fscanf(fp, "%d", &sizez);
-	if (sizez >= MINFACETS) {
+	if (sizez >= MIN_FACETS) {
 		for (i = w->rubik.sizez; i < sizez; i++) {
 			setPuzzle(w, ACTION_INCZ);
 		}
@@ -1001,7 +1001,7 @@ GetPieces(RubikWidget w)
 		free(buf1);
 		stringCat(&buf1, buf2, " should be between ");
 		free(buf2);
-		intCat(&buf2, buf1, MINFACETS);
+		intCat(&buf2, buf1, MIN_FACETS);
 		free(buf1);
 		stringCat(&buf1, buf2, " and MAXINT");
 		free(buf2);
@@ -1107,9 +1107,9 @@ UndoPieces(RubikWidget w)
 			&face, &position, &direction, &control);
 		setMove(&redo,
 			face, position, direction, control);
-		direction = (direction < MAXORIENT) ?
-			(direction + MAXORIENT / 2) % MAXORIENT :
-			3 * MAXORIENT - direction;
+		direction = (direction < MAX_ORIENT) ?
+			(direction + MAX_ORIENT / 2) % MAX_ORIENT :
+			3 * MAX_ORIENT - direction;
 		setPuzzleMove(w, ACTION_UNDO, face, position, direction,
 			MoveAllPieces(w, face, position, direction, control,
 			DOUBLE), DOUBLE);
@@ -1158,8 +1158,8 @@ RandomizePieces(RubikWidget w)
 			3 + NRAND(2);
 
 	w->rubik.cheat = False;
-	if (big > 1000)
-		big = 1000;
+	if (big > 100)
+		big = 100;
 	if (w->rubik.practice)
 		PracticePieces(w);
 	setPuzzle(w, ACTION_RESET);
@@ -1167,9 +1167,9 @@ RandomizePieces(RubikWidget w)
 	big = 3;
 #endif
 	while (big--) {
-		face = NRAND(MAXFACES);
+		face = NRAND(MAX_FACES);
 		position = NRAND(sizeFace(w, face));
-		direction = NRAND(MAXORIENT);
+		direction = NRAND(MAX_ORIENT);
 		MovePuzzle(w, face, position, direction, FALSE, INSTANT);
 	}
 	flushMoves(w, &undo, TRUE);
@@ -1210,13 +1210,13 @@ IncrementPieces(RubikWidget w)
 static void
 DecrementPieces(RubikWidget w)
 {
-	if (w->rubik.sizex > MINFACETS) {
+	if (w->rubik.sizex > MIN_FACETS) {
 		setPuzzle(w, ACTION_DECX);
 	}
-	if (w->rubik.sizey > MINFACETS) {
+	if (w->rubik.sizey > MIN_FACETS) {
 		setPuzzle(w, ACTION_DECY);
 	}
-	if (w->rubik.sizez > MINFACETS) {
+	if (w->rubik.sizez > MIN_FACETS) {
 		setPuzzle(w, ACTION_DECZ);
 	}
 }
@@ -1270,14 +1270,14 @@ SetValuesPuzzle(RubikWidget w)
 	w->rubik.sizez = GetPrivateProfileInt(SECTION, "sizeZ",
 		DEFAULTFACETS, INIFILE);
 	w->rubik.orient = (BOOL) GetPrivateProfileInt(SECTION, "orient",
-		DEFAULTORIENT, INIFILE);
+		DEFAULT_ORIENT, INIFILE);
 	w->rubik.practice = (BOOL) GetPrivateProfileInt(SECTION, "practice",
-		DEFAULTPRACTICE, INIFILE);
+		DEFAULT_PRACTICE, INIFILE);
 	w->rubik.dim = GetPrivateProfileInt(SECTION, "dim", 3, INIFILE);
 	w->rubik.mono = (BOOL) GetPrivateProfileInt(SECTION, "mono",
-		DEFAULTMONO, INIFILE);
+		DEFAULT_MONO, INIFILE);
 	w->rubik.reverse = (BOOL) GetPrivateProfileInt(SECTION, "reverseVideo",
-		DEFAULTREVERSE, INIFILE);
+		DEFAULT_REVERSE, INIFILE);
 	/* cyan */
 	(void) GetPrivateProfileString(SECTION, "frameColor", "0 255 255",
 		szBuf, sizeof (szBuf), INIFILE);
@@ -1296,7 +1296,7 @@ SetValuesPuzzle(RubikWidget w)
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
 	w->rubik.inverseGC = RGB(color.red, color.green, color.blue);
-	for (face = 0; face < MAXFACES; face++) {
+	for (face = 0; face < MAX_FACES; face++) {
 		(void) sprintf(buf, "faceColor%d", face);
 		(void) GetPrivateProfileString(SECTION, buf,
 			faceColorString[face],
@@ -1469,7 +1469,7 @@ SetAllColors(RubikWidget w)
 	if (w->rubik.borderGC)
 		XtReleaseGC((Widget) w, w->rubik.borderGC);
 	w->rubik.borderGC = XtGetGC((Widget) w, valueMask, &values);
-	for (face = 0; face < MAXFACES; face++)
+	for (face = 0; face < MAX_FACES; face++)
 		GetColor(w, face);
 	if (w->rubik.fontInfo)
 		XSetFont(XtDisplay(w), w->rubik.borderGC,
@@ -1484,7 +1484,7 @@ SetValuesPuzzle(Widget current, Widget request, Widget renew)
 	int face;
 
 	CheckPieces(w);
-	for (face = 0; face < MAXFACES; face++) {
+	for (face = 0; face < MAX_FACES; face++) {
 		if (strcmp(w->rubik.faceName[face], c->rubik.faceName[face])) {
 			setColors = True;
 			break;
@@ -1587,7 +1587,7 @@ DestroyPuzzle(Widget old)
 	Display *display = XtDisplay(w);
 	int face;
 
-	for (face = 0; face < MAXFACES; face++)
+	for (face = 0; face < MAX_FACES; face++)
 		XtReleaseGC(old, w->rubik.faceGC[face]);
 	XtReleaseGC(old, w->rubik.borderGC);
 	XtReleaseGC(old, w->rubik.frameGC);
@@ -1630,7 +1630,7 @@ Widget request, Widget renew
 	w->rubik.mono = (DefaultDepthOfScreen(XtScreen(w)) < 2 ||
 		w->rubik.mono);
 	w->rubik.fontInfo = NULL;
-	for (face = 0; face < MAXFACES; face++)
+	for (face = 0; face < MAX_FACES; face++)
 		w->rubik.faceGC[face] = NULL;
 	w->rubik.borderGC = NULL;
 	w->rubik.frameGC = NULL;
@@ -1638,9 +1638,9 @@ Widget request, Widget renew
 #endif
 	w->rubik.focus = False;
 	loadFont(w);
-	for (face = 0; face < MAXFACES; face++)
+	for (face = 0; face < MAX_FACES; face++)
 		w->rubik.cubeLoc[face] = NULL;
-	for (orient = 0; orient < MAXORIENT; orient++)
+	for (orient = 0; orient < MAX_ORIENT; orient++)
 		w->rubik.rowLoc[orient] = NULL;
 	CheckPieces(w);
 	newMoves(&undo);
@@ -1968,21 +1968,21 @@ IncrementAxisPuzzle(RubikWidget w, char axis)
 {
 	switch (axis) {
 	case 'X':
-		if (w->rubik.sizex > MINFACETS)
+		if (w->rubik.sizex > MIN_FACETS)
 			setPuzzle(w, ACTION_DECX);
 		return;
 	case 'x':
 		setPuzzle(w, ACTION_INCX);
 		return;
 	case 'Y':
-		if (w->rubik.sizey > MINFACETS)
+		if (w->rubik.sizey > MIN_FACETS)
 			setPuzzle(w, ACTION_DECY);
 		return;
 	case 'y':
 		setPuzzle(w, ACTION_INCY);
 		return;
 	case 'Z':
-		if (w->rubik.sizez > MINFACETS)
+		if (w->rubik.sizez > MIN_FACETS)
 			setPuzzle(w, ACTION_DECZ);
 		return;
 	case 'z':
@@ -2003,7 +2003,7 @@ void
 IncrementXPuzzle(RubikWidget w, XEvent *event, char **args, int nArgs)
 {
 	if (event->xbutton.state & (ShiftMask | LockMask)) {
-		if (w->rubik.sizex <= MINFACETS)
+		if (w->rubik.sizex <= MIN_FACETS)
 			return;
 		setPuzzle(w, ACTION_DECX);
 	} else
@@ -2014,7 +2014,7 @@ void
 IncrementYPuzzle(RubikWidget w , XEvent *event, char **args, int nArgs)
 {
 	if (event->xbutton.state & (ShiftMask | LockMask)) {
-		if (w->rubik.sizey <= MINFACETS)
+		if (w->rubik.sizey <= MIN_FACETS)
 			return;
 		setPuzzle(w, ACTION_DECY);
 	} else
@@ -2025,7 +2025,7 @@ void
 IncrementZPuzzle(RubikWidget w , XEvent *event, char **args, int nArgs)
 {
 	if (event->xbutton.state & (ShiftMask | LockMask)) {
-		if (w->rubik.sizez <= MINFACETS)
+		if (w->rubik.sizez <= MIN_FACETS)
 			return;
 		setPuzzle(w, ACTION_DECZ);
 	} else
