@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 2007	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1994 - 2007	David A. Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -211,10 +211,10 @@ static XtResource resourcesPuzzle2D[] =
 	 XtRString, (caddr_t) "3"},	/* DEFAULTFACETS */
 	{XtNorient, XtCOrient, XtRBoolean, sizeof (Boolean),
 	 XtOffset(RubikWidget, rubik.orient),
-	 XtRString, (caddr_t) "FALSE"},	/* DEFAULTORIENT */
+	 XtRString, (caddr_t) "FALSE"},	/* DEFAULT_ORIENT */
 	{XtNpractice, XtCPractice, XtRBoolean, sizeof (Boolean),
 	 XtOffset(RubikWidget, rubik.practice),
-	 XtRString, (caddr_t) "TRUE"}, /* DEFAULTPRACTICE */
+	 XtRString, (caddr_t) "TRUE"}, /* DEFAULT_PRACTICE */
 	{XtNuserName, XtCUserName, XtRString, sizeof (String),
 	 XtOffset(RubikWidget, rubik.userName),
 	 XtRString, (caddr_t) ""},
@@ -306,7 +306,7 @@ Rubik2DClassRec rubik2dClassRec =
 WidgetClass rubik2dWidgetClass = (WidgetClass) & rubik2dClassRec;
 #endif
 
-static RowNext rotateToRow[MAXFACES] =	/*CW to min face */
+static RowNext rotateToRow[MAX_FACES] =	/*CW to min face */
 {
 	{1, LEFT, TOP},
 	{0, BOTTOM, RIGHT},
@@ -315,9 +315,9 @@ static RowNext rotateToRow[MAXFACES] =	/*CW to min face */
 	{1, RIGHT, BOTTOM},
 	{0, LEFT, TOP}
 };
-static int  planeToCube[MAXRECT] =
+static int  planeToCube[MAX_RECT] =
 {6, 0, 6, 1, 2, 3, 6, 4, 6, 6, 5, 6};
-static int  cubeToPlane[MAXFACES] =
+static int  cubeToPlane[MAX_FACES] =
 {1, 3, 4, 5, 7, 10};
 
 static Pixmap dr = 0; /* dummy for future double buffering */
@@ -402,7 +402,7 @@ DrawSquare2D(Rubik2DWidget w, int face, int position, int offset)
 	i = position % sizeOfRow;
 	j = position / sizeOfRow;
 	orient = w->rubik.cubeLoc[face][position].rotation;
-	if (w->rubik.vertical || face != MAXFACES - 1) {
+	if (w->rubik.vertical || face != MAX_FACES - 1) {
 		FacePosition(w,
 			cubeToPlane[face] % MAXX, cubeToPlane[face] / MAXX,
 			&dx, &dy);
@@ -587,7 +587,7 @@ SelectPieces2D(Rubik2DWidget w, int x, int y, int *face, int *position)
 			(faceY >= 3 && !w->rubik.vertical))
 		return False;
 	if (faceX == 3)
-		*face = MAXFACES - 1;
+		*face = MAX_FACES - 1;
 	else
 		*face = planeToCube[faceX + faceY * MAXX];
 	faceSizes((RubikWidget) w, *face, &sizeOfRow, &sizeOfColumn);
@@ -606,8 +606,8 @@ SelectPieces2D(Rubik2DWidget w, int x, int y, int *face, int *position)
 Boolean
 NarrowSelection2D(Rubik2DWidget w, int *face, int *position, int *direction)
 {
-	if (*face == MAXFACES - 1 && *direction < MAXORIENT && !w->rubik.vertical)
-		*direction = (*direction + HALF) % MAXORIENT;
+	if (*face == MAX_FACES - 1 && *direction < MAX_ORIENT && !w->rubik.vertical)
+		*direction = (*direction + HALF) % MAX_ORIENT;
 	/* Remap to row movement */
 	if (*direction == CW || *direction == CCW) {
 		int i, j, sizeOfRow, sizeOfColumn, newFace;
@@ -615,7 +615,7 @@ NarrowSelection2D(Rubik2DWidget w, int *face, int *position, int *direction)
 		newFace = rotateToRow[*face].face;
 		faceSizes((RubikWidget) w, newFace, &sizeOfRow, &sizeOfColumn);
 		*direction = (*direction == CCW) ?
-			(rotateToRow[*face].direction + 2) % MAXORIENT :
+			(rotateToRow[*face].direction + 2) % MAX_ORIENT :
 			rotateToRow[*face].direction;
 		if (rotateToRow[*face].sideFace == LEFT ||
 				rotateToRow[*face].sideFace == BOTTOM) {
