@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 2007	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1994 - 2007	David A. Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -235,10 +235,10 @@ static XtResource resourcesPuzzle3D[] =
 	 XtRString, (caddr_t) "3"},	/* DEFAULTFACETS */
 	{XtNorient, XtCOrient, XtRBoolean, sizeof (Boolean),
 	 XtOffset(RubikWidget, rubik.orient),
-	 XtRString, (caddr_t) "FALSE"},	/* DEFAULTORIENT */
+	 XtRString, (caddr_t) "FALSE"},	/* DEFAULT_ORIENT */
 	{XtNpractice, XtCPractice, XtRBoolean, sizeof (Boolean),
 	 XtOffset(RubikWidget, rubik.practice),
-	 XtRString, (caddr_t) "TRUE"}, /* DEFAULTPRACTICE */
+	 XtRString, (caddr_t) "TRUE"}, /* DEFAULT_PRACTICE */
 	{XtNuserName, XtCUserName, XtRString, sizeof (String),
 	 XtOffset(RubikWidget, rubik.userName),
 	 XtRString, (caddr_t) ""},
@@ -330,11 +330,11 @@ Rubik3DClassRec rubik3dClassRec =
 WidgetClass rubik3dWidgetClass = (WidgetClass) & rubik3dClassRec;
 #endif
 
-static Point faceLoc3D[MAXFACES][MAXORIENT];
-static Point cubeLoc3D[MAXFACES][MAXORIENT + 1];
-static Point letter3DList[MAXFACES];
-static Point orient3DList[MAXFACES][MAXORIENT][2];
-static RowNext rotateToRow[MAXFACES] =	/* CW to min face */
+static Point faceLoc3D[MAX_FACES][MAX_ORIENT];
+static Point cubeLoc3D[MAX_FACES][MAX_ORIENT + 1];
+static Point letter3DList[MAX_FACES];
+static Point orient3DList[MAX_FACES][MAX_ORIENT][2];
+static RowNext rotateToRow[MAX_FACES] =	/* CW to min face */
 {
 	{1, LEFT, TOP},
 	{0, BOTTOM, RIGHT},
@@ -545,19 +545,19 @@ MapOrientFrom3D(Rubik3DWidget w, int face, int corner, int *side)
 {
 	switch (face) {
 	case 0:
-		*side = (corner + 2) % MAXORIENT;
+		*side = (corner + 2) % MAX_ORIENT;
 		break;
 	case 1:
 		*side = corner;
 		break;
 	case 2:
-		*side = (corner + 3) % MAXORIENT;
+		*side = (corner + 3) % MAX_ORIENT;
 		break;
 	case 3:
-		*side = (corner + 1) % MAXORIENT;
+		*side = (corner + 1) % MAX_ORIENT;
 		break;
 	case 4:
-		*side = (corner + 1) % MAXORIENT;
+		*side = (corner + 1) % MAX_ORIENT;
 		break;
 	case 5:
 		*side = corner;
@@ -598,7 +598,7 @@ DrawSquare3D(Rubik3DWidget w, int face, int position, int offset)
 		borderGC = w->rubik.borderGC;
 	}
 	POLYGON((RubikWidget) w, dr, faceGC, borderGC,
-		cubeLoc3D[face], MAXORIENT, True, False);
+		cubeLoc3D[face], MAX_ORIENT, True, False);
 	if (w->rubik.mono) {
 		int letterX, letterY;
 		char buf[2];
@@ -662,9 +662,9 @@ DrawFrame3D(Rubik3DWidget w, Boolean focus)
 			(int) (-w->rubik.delta - 2 * w->rubik.letterOffset.y + w->core.height),
 			"Back", 4);
 	}
-	for (face = 0; face < MAXFACES; face++) {
+	for (face = 0; face < MAX_FACES; face++) {
 		POLYLINE((RubikWidget) w, dr, gc,
-			faceLoc3D[face], MAXORIENT, False);
+			faceLoc3D[face], MAX_ORIENT, False);
 	}
 }
 
@@ -672,9 +672,9 @@ static void
 ResizePieces(Rubik3DWidget w)
 {
 	int face, orient, side, corner, sizex, sizey;
-	Point subcubeLoc3D[MAXFACES][MAXORIENT];
-	Point diamondLoc3D[MAXFACES][MAXORIENT];
-	Point subdiamondLoc3D[MAXFACES][MAXORIENT];
+	Point subcubeLoc3D[MAX_FACES][MAX_ORIENT];
+	Point diamondLoc3D[MAX_FACES][MAX_ORIENT];
+	Point subdiamondLoc3D[MAX_FACES][MAX_ORIENT];
 
 	w->rubik.letterOffset.x = -2;
 	w->rubik.letterOffset.y = 4;
@@ -682,10 +682,10 @@ ResizePieces(Rubik3DWidget w)
 		w->rubik.puzzleOffset.x;
 	w->rubik3d.viewMiddle.y = w->rubik3d.faceSize.y +
 		w->rubik.puzzleOffset.y;
-	for (face = 0; face < MAXFACES; face++) {
+	for (face = 0; face < MAX_FACES; face++) {
 		faceLoc3D[face][0].x = w->rubik3d.viewMiddle.x;
 		faceLoc3D[face][0].y = w->rubik3d.viewMiddle.y;
-		for (orient = 1; orient < MAXORIENT; orient++) {
+		for (orient = 1; orient < MAX_ORIENT; orient++) {
 			faceLoc3D[face][orient].x = w->rubik3d.faceSize.x;
 			faceLoc3D[face][orient].y = w->rubik3d.faceSize.y;
 		}
@@ -707,7 +707,7 @@ ResizePieces(Rubik3DWidget w)
 		faceLoc3D[2][3].x /= -1;
 		faceLoc3D[2][3].y = 0;
 
-		for (face = MAXFACES / 2; face < MAXFACES; face++)
+		for (face = MAX_FACES / 2; face < MAX_FACES; face++)
 			faceLoc3D[face][0].y += w->rubik3d.viewSize.y + 3;
 
 		faceLoc3D[3][1].x /= 2;
@@ -743,7 +743,7 @@ ResizePieces(Rubik3DWidget w)
 		faceLoc3D[2][3].y /= 2;
 		faceLoc3D[2][3].x /= -1;
 
-		for (face = MAXFACES / 2; face < MAXFACES; face++)
+		for (face = MAX_FACES / 2; face < MAX_FACES; face++)
 			faceLoc3D[face][0].x += w->rubik3d.viewSize.x + 3;
 
 		faceLoc3D[3][1].x /= -1;
@@ -763,7 +763,7 @@ ResizePieces(Rubik3DWidget w)
 		faceLoc3D[5][2].y /= 2;
 		faceLoc3D[5][3].x = 0;
 	}
-	for (face = 0; face < MAXFACES; face++) {
+	for (face = 0; face < MAX_FACES; face++) {
 		cubeLoc3D[face][0].x = faceLoc3D[face][0].x;
 		cubeLoc3D[face][0].y = faceLoc3D[face][0].y;
 		subcubeLoc3D[face][0].x = faceLoc3D[face][0].x;
@@ -778,7 +778,7 @@ ResizePieces(Rubik3DWidget w)
 			sizex = w->rubik.sizex;
 			sizey = w->rubik.sizey;
 		}
-		for (orient = 1; orient < MAXORIENT; orient++) {
+		for (orient = 1; orient < MAX_ORIENT; orient++) {
 			if (((orient & 1) && (face == 2 || face == 3 || face == 4)) ||
 			    (!(orient & 1) && !(face == 2 || face == 3 || face == 4)))
 				cubeLoc3D[face][orient].x =
@@ -824,9 +824,9 @@ ResizePieces(Rubik3DWidget w)
 				 w->rubik.delta * faceLoc3D[face][orient].y /
 					 w->rubik3d.faceSize.y) / (2 * sizex);
 		}
-		cubeLoc3D[face][MAXORIENT].x = -cubeLoc3D[face][1].x -
+		cubeLoc3D[face][MAX_ORIENT].x = -cubeLoc3D[face][1].x -
 			cubeLoc3D[face][2].x - cubeLoc3D[face][3].x;
-		cubeLoc3D[face][MAXORIENT].y = -cubeLoc3D[face][1].y -
+		cubeLoc3D[face][MAX_ORIENT].y = -cubeLoc3D[face][1].y -
 			cubeLoc3D[face][2].y - cubeLoc3D[face][3].y;
 	}
 	w->rubik3d.cubeSizex.x = MAX(w->rubik3d.faceSize.x /
@@ -875,8 +875,8 @@ ResizePieces(Rubik3DWidget w)
 		letter3DList[5].y = -w->rubik3d.cubeSizey.y / 4;
 	}
 	/* The following figures out where to put the orient lines */
-	for (face = 0; face < MAXFACES; face++) {
-		for (orient = 0; orient < MAXORIENT - 1; orient++) {
+	for (face = 0; face < MAX_FACES; face++) {
+		for (orient = 0; orient < MAX_ORIENT - 1; orient++) {
 			diamondLoc3D[face][orient].x = (cubeLoc3D[face][orient].x +
 				cubeLoc3D[face][orient + 1].x) / 2;
 			diamondLoc3D[face][orient].y = (cubeLoc3D[face][orient].y +
@@ -887,14 +887,14 @@ ResizePieces(Rubik3DWidget w)
 				subcubeLoc3D[face][orient + 1].y) / 2;
 		}
 		/* Its a parallelagram so take advantage of that */
-		diamondLoc3D[face][orient].x = (cubeLoc3D[face][MAXORIENT - 1].x -
-			cubeLoc3D[face][MAXORIENT / 2].x) / 2;
-		diamondLoc3D[face][orient].y = (cubeLoc3D[face][MAXORIENT - 1].y -
-			cubeLoc3D[face][MAXORIENT / 2].y) / 2;
-		subdiamondLoc3D[face][orient].x = (subcubeLoc3D[face][MAXORIENT - 1].x -
-			subcubeLoc3D[face][MAXORIENT / 2].x) / 2;
-		subdiamondLoc3D[face][orient].y = (subcubeLoc3D[face][MAXORIENT - 1].y -
-			subcubeLoc3D[face][MAXORIENT / 2].y) / 2;
+		diamondLoc3D[face][orient].x = (cubeLoc3D[face][MAX_ORIENT - 1].x -
+			cubeLoc3D[face][MAX_ORIENT / 2].x) / 2;
+		diamondLoc3D[face][orient].y = (cubeLoc3D[face][MAX_ORIENT - 1].y -
+			cubeLoc3D[face][MAX_ORIENT / 2].y) / 2;
+		subdiamondLoc3D[face][orient].x = (subcubeLoc3D[face][MAX_ORIENT - 1].x -
+			subcubeLoc3D[face][MAX_ORIENT / 2].x) / 2;
+		subdiamondLoc3D[face][orient].y = (subcubeLoc3D[face][MAX_ORIENT - 1].y -
+			subcubeLoc3D[face][MAX_ORIENT / 2].y) / 2;
 
 		MapOrientFrom3D(w, face, 1, &corner);
 		orient3DList[face][corner][0].x = cubeLoc3D[face][1].x / 2;
@@ -903,9 +903,9 @@ ResizePieces(Rubik3DWidget w)
 			(cubeLoc3D[face][2].x - subcubeLoc3D[face][2].x) / 2;
 		orient3DList[face][corner][1].y = orient3DList[face][corner][0].y +
 			(cubeLoc3D[face][2].y - subcubeLoc3D[face][2].y) / 2;
-		for (orient = 1; orient < MAXORIENT; orient++) {
+		for (orient = 1; orient < MAX_ORIENT; orient++) {
 			side = corner;
-			MapOrientFrom3D(w, face, (orient + 1) % MAXORIENT,
+			MapOrientFrom3D(w, face, (orient + 1) % MAX_ORIENT,
 				&corner);
 			orient3DList[face][corner][0].x =
 				orient3DList[face][side][0].x + diamondLoc3D[face][orient].x;
@@ -1086,7 +1086,7 @@ NarrowSelection3D(Rubik3DWidget w, int *face, int *position, int *direction)
 			if (*face == 0 || *face == 4)
 				return False;
 			if (*face == 5)
-				*direction = (*direction + 2) % MAXORIENT;
+				*direction = (*direction + 2) % MAX_ORIENT;
 		}
 		break;
 	case CCW:
@@ -1178,7 +1178,7 @@ NarrowSelection3D(Rubik3DWidget w, int *face, int *position, int *direction)
 		newFace = rotateToRow[*face].face;
 		faceSizes((RubikWidget) w, newFace, &sizeOfRow, &sizeOfColumn);
 		*direction = (*direction == CCW) ?
-			(rotateToRow[*face].direction + 2) % MAXORIENT :
+			(rotateToRow[*face].direction + 2) % MAX_ORIENT :
 			rotateToRow[*face].direction;
 		if (rotateToRow[*face].sideFace == LEFT ||
 				rotateToRow[*face].sideFace == BOTTOM) {
@@ -1239,7 +1239,7 @@ ResizePuzzle3D(Rubik3DWidget w)
 	/* Unlike the 2d implementation... lets have variable size cubies and
 	   static sized cube */
 	if (w->rubik.vertical) {
-		w->rubik3d.viewSize.y = w->core.height / MAXVIEWS;
+		w->rubik3d.viewSize.y = w->core.height / MAX_VIEWS;
 		w->rubik3d.viewSize.x = w->core.width;
 		if (w->rubik3d.viewSize.x >= DIVIDE(w->rubik3d.viewSize.y)) {
 			w->rubik3d.viewSize.y = MAX(w->rubik3d.viewSize.y, 0);
@@ -1252,9 +1252,9 @@ ResizePuzzle3D(Rubik3DWidget w)
 		w->rubik3d.faceSize.y = MAX(w->rubik3d.viewSize.y / 2 - 2, 1);
 		w->rubik3d.faceDiagonal = w->rubik3d.faceSize.x / 2;
 		w->rubik.puzzleSize.x = w->rubik3d.viewSize.x;
-		w->rubik.puzzleSize.y = MAXVIEWS * w->rubik3d.viewSize.y;
+		w->rubik.puzzleSize.y = MAX_VIEWS * w->rubik3d.viewSize.y;
 	} else {
-		w->rubik3d.viewSize.x = w->core.width / MAXVIEWS;
+		w->rubik3d.viewSize.x = w->core.width / MAX_VIEWS;
 		w->rubik3d.viewSize.y = w->core.height;
 		if (w->rubik3d.viewSize.y >= DIVIDE(w->rubik3d.viewSize.x)) {
 			w->rubik3d.viewSize.x = MAX(w->rubik3d.viewSize.x, 0);
@@ -1267,7 +1267,7 @@ ResizePuzzle3D(Rubik3DWidget w)
 		w->rubik3d.faceSize.y = MAX(w->rubik3d.viewSize.y / 2 - 2, 1);
 		w->rubik3d.faceDiagonal = w->rubik3d.faceSize.y / 2;
 		w->rubik.puzzleSize.y = w->rubik3d.viewSize.y;
-		w->rubik.puzzleSize.x = MAXVIEWS * w->rubik3d.viewSize.x;
+		w->rubik.puzzleSize.x = MAX_VIEWS * w->rubik3d.viewSize.x;
 	}
 	w->rubik.puzzleOffset.x = ((int) w->core.width - w->rubik.puzzleSize.x) / 2;
 	w->rubik.puzzleOffset.y = ((int) w->core.height - w->rubik.puzzleSize.y) / 2;
