@@ -11,7 +11,7 @@
 #  Taken from the algorithm in the Ideal Solution book.
 #  Break ability taken from the X puzzle by Don Bennett, HP Labs
 #
-#  Copyright (c) 1994 - 2007	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1994 - 2007	David A. Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -78,11 +78,11 @@
 #define ORANGE 5
 
 #ifdef DEBUG
-static int mapGeneralToIdeal[MAXFACES] =
+static int mapGeneralToIdeal[MAX_FACES] =
 {5, 4, 1, 2, 6, 3};
 
 #endif
-static int mapIdealToGeneral[MAXFACES] =
+static int mapIdealToGeneral[MAX_FACES] =
 {2, 3, 5, 1, 0, 4};		/* Remember to subtract 1 */
 
 static Boolean SolvingFlag = False;
@@ -209,7 +209,7 @@ Face(RubikWidget w, int m)
 
 	d = mapIdealToGeneral[m - 1];
 	return ((w->rubik.cubeLoc[d][4].rotation -
-		w->rubik.cubeLoc[d][0].rotation + MAXORIENT) % MAXORIENT);
+		w->rubik.cubeLoc[d][0].rotation + MAX_ORIENT) % MAX_ORIENT);
 }
 
 /* This procedure finds the location of a specified corner.  An */
