@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1993 - 2007	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1993 - 2007	David A. Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -248,39 +248,39 @@ static const char solveHelp[] = {
 #define SCOREFILE "rubik.scores"
 #endif
 
-#define MAXFACETS 6
+#define MAX_FACETS 6
 #define NEVER (-1)
-#define FILENAMELEN 1024
-#define USERNAMELEN 120
-#define MESSAGELEN (USERNAMELEN+64)
-#define TITLELEN 2048
+#define FILE_NAME_LENGTH 1024
+#define USER_NAME_LENGTH 120
+#define MESSAGE_LENGTH (USER_NAME_LENGTH+64)
+#define TITLE_LENGTH 2048
 #define NOACCESS "noaccess"
 #define NOBODY "nobody"
 
 typedef struct {
 	int score;
-	char name[USERNAMELEN];
+	char name[USER_NAME_LENGTH];
 } PuzzleRecord;
 
-static PuzzleRecord puzzleRecord[2][MAXFACETS - MINFACETS + 1]
-[MAXFACETS - MINFACETS + 1][MAXFACETS - MINFACETS + 1];
+static PuzzleRecord puzzleRecord[2][MAX_FACETS - MIN_FACETS + 1]
+[MAX_FACETS - MIN_FACETS + 1][MAX_FACETS - MIN_FACETS + 1];
 static int movesDsp = 0;
-static char messageDsp[MESSAGELEN] = "Welcome";
-static char recordDsp[MESSAGELEN] = "NOT RECORDED";
+static char messageDsp[MESSAGE_LENGTH] = "Welcome";
+static char recordDsp[MESSAGE_LENGTH] = "NOT RECORDED";
 #ifndef HAVE_MOTIF
-static char titleDsp[TITLELEN] = "";
+static char titleDsp[TITLE_LENGTH] = "";
 #endif
-static char scoreFileName[FILENAMELEN] = SCOREFILE;
-static char fileName[FILENAMELEN];
+static char scoreFileName[FILE_NAME_LENGTH] = SCOREFILE;
+static char fileName[FILE_NAME_LENGTH];
 static Boolean randomized = False;
 #ifdef WINVER
-#define MAXPROGNAME 80
-static char progDsp[MAXPROGNAME] = TITLE;
-static char userNameDsp[USERNAMELEN] = "Guest";
+#define PROGRAM_NAME_LENGTH 80
+static char progDsp[PROGRAM_NAME_LENGTH] = TITLE;
+static char userNameDsp[USER_NAME_LENGTH] = "Guest";
 #else
 #ifdef HAVE_MOTIF
-#define MINSPEED 1
-#define MAXSPEED 50
+#define MIN_SPEED 1
+#define MAX_SPEED 50
 static Widget moves, record, message, cubesx, cubesy, cubesz;
 static Widget orientizeSwitch, practiceSwitch, speed;
 static char buff[21];
@@ -300,7 +300,7 @@ static Widget topLevel, puzzle2d, puzzle3d;
 static Widget puzzleGL;
 #endif
 static char *progDsp;
-static char userNameDsp[USERNAMELEN] = "";
+static char userNameDsp[USER_NAME_LENGTH] = "";
 
 #ifdef HAVE_MOTIF
 static void
@@ -323,9 +323,9 @@ PrintRecords(void)
 	(void) printf("                RUBIK  HALL OF FAME\n\n");
 	(void) printf("ORIENT   X   Y   Z USER            MOVES\n");
 	for (orient = 0; orient < 2; orient++)
-		for (i = 0; i < MAXFACETS - MINFACETS + 1; i++)
-			for (j = i; j < MAXFACETS - MINFACETS + 1; j++)
-				for (k = j; k < MAXFACETS - MINFACETS + 1; k++) {
+		for (i = 0; i < MAX_FACETS - MIN_FACETS + 1; i++)
+			for (j = i; j < MAX_FACETS - MIN_FACETS + 1; j++)
+				for (k = j; k < MAX_FACETS - MIN_FACETS + 1; k++) {
 					if (puzzleRecord[orient][i][j][k].score > 0)
 						(void) printf("%6d%4d%4d%4d %-12s%9d\n",
 							orient, i + 1, j + 1, k + 1,
@@ -341,24 +341,24 @@ InitRecords(void)
 	int i, j, k, orient;
 
 	for (orient = 0; orient < 2; orient++)
-		for (i = 0; i < MAXFACETS - MINFACETS + 1; i++)
-			for (j = i; j < MAXFACETS - MINFACETS + 1; j++)
-				for (k = j; k < MAXFACETS - MINFACETS + 1; k++) {
+		for (i = 0; i < MAX_FACETS - MIN_FACETS + 1; i++)
+			for (j = i; j < MAX_FACETS - MIN_FACETS + 1; j++)
+				for (k = j; k < MAX_FACETS - MIN_FACETS + 1; k++) {
 					puzzleRecord[orient][k][j][i].score = puzzleRecord[orient][k][i][j].score =
 						puzzleRecord[orient][j][k][i].score = puzzleRecord[orient][j][i][k].score =
 						puzzleRecord[orient][i][k][j].score = puzzleRecord[orient][i][j][k].score = NEVER;
 					(void) strncpy(puzzleRecord[orient][k][j][i].name,
-						NOACCESS, USERNAMELEN);
+						NOACCESS, USER_NAME_LENGTH);
 					(void) strncpy(puzzleRecord[orient][k][i][j].name,
-						NOACCESS, USERNAMELEN);
+						NOACCESS, USER_NAME_LENGTH);
 					(void) strncpy(puzzleRecord[orient][j][k][i].name,
-						NOACCESS, USERNAMELEN);
+						NOACCESS, USER_NAME_LENGTH);
 					(void) strncpy(puzzleRecord[orient][j][i][k].name,
-						NOACCESS, USERNAMELEN);
+						NOACCESS, USER_NAME_LENGTH);
 					(void) strncpy(puzzleRecord[orient][i][k][j].name,
-						NOACCESS, USERNAMELEN);
+						NOACCESS, USER_NAME_LENGTH);
 					(void) strncpy(puzzleRecord[orient][i][j][k].name,
-						NOACCESS, USERNAMELEN);
+						NOACCESS, USER_NAME_LENGTH);
 				}
 }
 
@@ -367,7 +367,7 @@ ReadRecords(void)
 {
 	FILE *fp;
 	int i, j, k, n, orient;
-	char userName[USERNAMELEN];
+	char userName[USER_NAME_LENGTH];
 	char *buf1 = NULL, *buf2 = NULL;
 	char *fname, *lname;
 
@@ -377,9 +377,9 @@ ReadRecords(void)
 	stringCat(&buf2, buf1, SCOREFILE);
 	free(buf1);
 	fname = buf2;
-	(void) strncpy(fileName, lname, USERNAMELEN);
+	(void) strncpy(fileName, lname, USER_NAME_LENGTH);
 	if ((fp = fopen(fileName, "r")) == NULL) {
-		(void) strncpy(fileName, fname, USERNAMELEN);
+		(void) strncpy(fileName, fname, USER_NAME_LENGTH);
 		/* Try installed directory. */
 		if ((fp = fopen(fileName, "r")) == NULL) {
 			stringCat(&buf1, "Can not read ", fname);
@@ -409,9 +409,9 @@ ReadRecords(void)
 	free(lname);
 	free(fname);
 	for (orient = 0; orient < 2; orient++)
-		for (i = 0; i < MAXFACETS - MINFACETS + 1; i++)
-			for (j = i; j < MAXFACETS - MINFACETS + 1; j++)
-				for (k = j; k < MAXFACETS - MINFACETS + 1; k++) {
+		for (i = 0; i < MAX_FACETS - MIN_FACETS + 1; i++)
+			for (j = i; j < MAX_FACETS - MIN_FACETS + 1; j++)
+				for (k = j; k < MAX_FACETS - MIN_FACETS + 1; k++) {
 					(void) fscanf(fp, "%d %s\n", &n, userName);
 					if (n <= puzzleRecord[orient][i][j][k].score ||
 							puzzleRecord[orient][i][j][k].score <= NEVER) {
@@ -419,17 +419,17 @@ ReadRecords(void)
 							puzzleRecord[orient][j][k][i].score = puzzleRecord[orient][j][i][k].score =
 							puzzleRecord[orient][i][k][j].score = puzzleRecord[orient][i][j][k].score = n;
 						(void) strncpy(puzzleRecord[orient][k][j][i].name,
-							userName, USERNAMELEN);
+							userName, USER_NAME_LENGTH);
 						(void) strncpy(puzzleRecord[orient][k][i][j].name,
-							userName, USERNAMELEN);
+							userName, USER_NAME_LENGTH);
 						(void) strncpy(puzzleRecord[orient][j][k][i].name,
-							userName, USERNAMELEN);
+							userName, USER_NAME_LENGTH);
 						(void) strncpy(puzzleRecord[orient][j][i][k].name,
-							userName, USERNAMELEN);
+							userName, USER_NAME_LENGTH);
 						(void) strncpy(puzzleRecord[orient][i][k][j].name,
-							userName, USERNAMELEN);
+							userName, USER_NAME_LENGTH);
 						(void) strncpy(puzzleRecord[orient][i][j][k].name,
-							userName, USERNAMELEN);
+							userName, USER_NAME_LENGTH);
 					}
 				}
 	(void) fclose(fp);
@@ -451,9 +451,9 @@ WriteRecords(void)
 	{
 #if HAVE_FCNTL_H
 		int lfd;
-		char lockFile[FILENAMELEN];
+		char lockFile[FILE_NAME_LENGTH];
 
-		(void) strncpy(lockFile, fileName, FILENAMELEN - 6);
+		(void) strncpy(lockFile, fileName, FILE_NAME_LENGTH - 6);
 		(void) strcat(lockFile, ".lock");
 		while (((lfd = open(lockFile, O_CREAT | O_EXCL, 0644)) < 0) &&
 				errno == EEXIST)
@@ -470,9 +470,9 @@ WriteRecords(void)
 		}
 #endif
 		for (orient = 0; orient < 2; orient++) {
-			for (i = 0; i < MAXFACETS - MINFACETS + 1; i++) {
-				for (j = i; j < MAXFACETS - MINFACETS + 1; j++) {
-					for (k = j; k < MAXFACETS - MINFACETS + 1; k++)
+			for (i = 0; i < MAX_FACETS - MIN_FACETS + 1; i++) {
+				for (j = i; j < MAX_FACETS - MIN_FACETS + 1; j++) {
+					for (k = j; k < MAX_FACETS - MIN_FACETS + 1; k++)
 						(void) fprintf(fp, "%d %s\n",
 							puzzleRecord[orient][i][j][k].score,
 							puzzleRecord[orient][i][j][k].name);
@@ -494,14 +494,14 @@ WriteRecords(void)
 static void
 PrintRecord(int sizex, int sizey, int sizez, Boolean orient, Boolean practice)
 {
-	int i = sizex - MINFACETS, j = sizey - MINFACETS, k = sizez - MINFACETS;
+	int i = sizex - MIN_FACETS, j = sizey - MIN_FACETS, k = sizez - MIN_FACETS;
 	int l = (orient) ? 1 : 0;
 
 	if (practice) {
-		(void) strncpy(recordDsp, "practice", MESSAGELEN);
-	} else if (sizex > MAXFACETS ||
-			sizey > MAXFACETS || sizez > MAXFACETS) {
-		(void) strncpy(recordDsp, "NOT RECORDED", MESSAGELEN);
+		(void) strncpy(recordDsp, "practice", MESSAGE_LENGTH);
+	} else if (sizex > MAX_FACETS ||
+			sizey > MAX_FACETS || sizez > MAX_FACETS) {
+		(void) strncpy(recordDsp, "NOT RECORDED", MESSAGE_LENGTH);
 	} else if (puzzleRecord[l][i][j][k].score <= NEVER) {
 		(void) sprintf(recordDsp, "NEVER %s", NOACCESS);
 	} else {
@@ -525,7 +525,7 @@ MakeEquivalent(String *userName, String *scoreFile,
 	Boolean mono, reverse;
 	Boolean scoreOnly, versionOnly;
 	Pixel foreground, background, pieceBorder;
-	String faceColor[MAXFACES];
+	String faceColor[MAX_FACES];
 
 	XtVaGetValues(puzzle2d,
 		XtNuserName, userName,
@@ -554,7 +554,7 @@ MakeEquivalent(String *userName, String *scoreFile,
 		exit(0);
 	}
 	if (strcmp(*scoreFile, ""))
-		(void) strncpy(scoreFileName, *scoreFile, FILENAMELEN);
+		(void) strncpy(scoreFileName, *scoreFile, FILE_NAME_LENGTH);
 	if (scoreOnly) {
 		InitRecords();
 		ReadRecords();
@@ -650,23 +650,23 @@ PrintStatus(char *msg, int nMoves
 static Boolean
 HandleSolved(int counter, int sizex, int sizey, int sizez, Boolean orient)
 {
-	int i = sizex - MINFACETS, j = sizey - MINFACETS, k = sizez - MINFACETS;
+	int i = sizex - MIN_FACETS, j = sizey - MIN_FACETS, k = sizez - MIN_FACETS;
 	int l = (orient) ? 1 : 0;
 
-	if (sizex <= MAXFACETS && sizey <= MAXFACETS && sizez <= MAXFACETS &&
+	if (sizex <= MAX_FACETS && sizey <= MAX_FACETS && sizez <= MAX_FACETS &&
 			(counter < puzzleRecord[l][i][j][k].score ||
 			puzzleRecord[l][i][j][k].score <= NEVER)) {
 		ReadRecords();	/* Maybe its been updated by another */
 		puzzleRecord[l][i][j][k].score = counter;
 		(void) strncpy(puzzleRecord[l][i][j][k].name, userNameDsp,
-			USERNAMELEN);
+			USER_NAME_LENGTH);
 		if ((sizex <= 2 && sizey <= 2) || (sizey <= 2 && sizez <= 2) ||
 				(sizez <= 2 && sizex <= 2) || (orient &&
 				(counter < puzzleRecord[!l][i][j][k].score ||
 				puzzleRecord[!l][i][j][k].score <= NEVER))) {
 			puzzleRecord[!l][i][j][k].score = counter;
 			(void) strncpy(puzzleRecord[!l][i][j][k].name,
-				userNameDsp, USERNAMELEN);
+				userNameDsp, USER_NAME_LENGTH);
 		}
 		WriteRecords();
 		PrintRecord(sizex, sizey, sizez, orient, False);
@@ -702,37 +702,37 @@ void
 	dim = w->rubik.dim;
 	SET_STARTED(w, False);
 	if (strcmp(scoreFile, ""))
-		(void) strncpy(scoreFileName, scoreFile, FILENAMELEN);
+		(void) strncpy(scoreFileName, scoreFile, FILE_NAME_LENGTH);
 #else
 	int delay;
 
 	MakeEquivalent(&userName, &scoreFile, &sizex, &sizey, &sizez,
 		&orient, &practice, &delay);
 #ifdef HAVE_MOTIF
-	if (sizex > MAXFACETS)
+	if (sizex > MAX_FACETS)
 		XtVaSetValues(cubesx, XmNmaximum, sizex, NULL);
 	XmScaleSetValue(cubesx, sizex);
-	if (sizey > MAXFACETS)
+	if (sizey > MAX_FACETS)
 		XtVaSetValues(cubesy, XmNmaximum, sizey, NULL);
 	XmScaleSetValue(cubesy, sizey);
-	if (sizez > MAXFACETS)
+	if (sizez > MAX_FACETS)
 		XtVaSetValues(cubesz, XmNmaximum, sizez, NULL);
 	XmScaleSetValue(cubesz, sizez);
 	XmToggleButtonSetState(orientizeSwitch, orient, True);
 	XmToggleButtonSetState(practiceSwitch, practice, True);
-	XmScaleSetValue(speed, MAXSPEED + MINSPEED - delay - 1);
+	XmScaleSetValue(speed, MAX_SPEED + MIN_SPEED - delay - 1);
 #endif
 #endif
 	InitRecords();
 	ReadRecords();
 #ifndef WINVER
-	(void) strncpy(userNameDsp, userName, USERNAMELEN);
+	(void) strncpy(userNameDsp, userName, USER_NAME_LENGTH);
 #endif
 	if (!strcmp(userName, "") || !strcmp(userName, "(null)") ||
 			!strcmp(userName, NOACCESS) ||
 			!strcmp(userName, NOBODY)) {
 #ifdef WINVER
-		(void) strncpy(userNameDsp, userName, USERNAMELEN);
+		(void) strncpy(userNameDsp, userName, USER_NAME_LENGTH);
 #else
 		char *login = getlogin();
 
@@ -891,14 +891,14 @@ CallbackPuzzle(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
 #ifdef HAVE_MOTIF
 		XtManageChild(solveDialog);
 #else
-		(void) strncpy(messageDsp, solveHelp, MESSAGELEN);
+		(void) strncpy(messageDsp, solveHelp, MESSAGE_LENGTH);
 #endif
 #endif
 		break;
 	case ACTION_RESTORE:
 		if (practice) {
 			(void) strncpy(recordDsp, "practice",
-				MESSAGELEN);
+				MESSAGE_LENGTH);
 #ifdef HAVE_MOTIF
 			PrintState(record, recordDsp);
 #endif
@@ -936,15 +936,15 @@ CallbackPuzzle(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
 		break;
 	case ACTION_AMBIGUOUS:
 		(void) strncpy(messageDsp, "Ambiguous move",
-			MESSAGELEN);
+			MESSAGE_LENGTH);
 		break;
 	case ACTION_ILLEGAL:
 		if (practice || randomized)
 			(void) strncpy(messageDsp, "Illegal move",
-				MESSAGELEN);
+				MESSAGE_LENGTH);
 		else
 			(void) strncpy(messageDsp,
-				"Randomize to start", MESSAGELEN);
+				"Randomize to start", MESSAGE_LENGTH);
 		break;
 #ifndef WINVER
 	case ACTION_MOVED:
@@ -997,7 +997,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
 				"Congratulations %s!!", userNameDsp);
 		else
 			(void) strncpy(messageDsp, "Solved!",
-				MESSAGELEN);
+				MESSAGE_LENGTH);
 		SET_STARTED(w, False);
 #ifndef WINVER
 #ifdef HAVE_OPENGL
@@ -1024,7 +1024,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
 		practice = !practice;
 		if (!practice)
 			(void) strncpy(messageDsp, "Randomize to start",
-				MESSAGELEN);
+				MESSAGE_LENGTH);
 		PrintRecord(sizex, sizey, sizez, orient, practice);
 #ifdef WINVER
 		w->rubik.practice = practice;
@@ -1077,7 +1077,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
 			XtVaGetValues(puzzleGL,
 				XtNview, &view, NULL);
 #endif
-			view = (view + 1) % (2 * MAXVIEWS);
+			view = (view + 1) % (2 * MAX_VIEWS);
 #ifdef WINVER
 			w->rubik.view = view;
 #else
@@ -1117,7 +1117,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
 #endif
 		XtVaSetValues(otherw1, XtNsizex, sizex, NULL);
 #ifdef HAVE_MOTIF
-		if (sizex > MAXFACETS)
+		if (sizex > MAX_FACETS)
 			XtVaSetValues(cubesx, XmNmaximum, sizex, NULL);
 		XmScaleSetValue(cubesx, sizex);
 #endif
@@ -1137,7 +1137,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
 		XtVaSetValues(otherw1, XtNsizex, sizex, NULL);
 #ifdef HAVE_MOTIF
 		XmScaleSetValue(cubesx, sizex);
-		if (sizex >= MAXFACETS)
+		if (sizex >= MAX_FACETS)
 			XtVaSetValues(cubesx, XmNmaximum, sizex, NULL);
 #endif
 #endif
@@ -1155,7 +1155,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
 #endif
 		XtVaSetValues(otherw1, XtNsizey, sizey, NULL);
 #ifdef HAVE_MOTIF
-		if (sizey > MAXFACETS)
+		if (sizey > MAX_FACETS)
 			XtVaSetValues(cubesy, XmNmaximum, sizey, NULL);
 		XmScaleSetValue(cubesy, sizey);
 #endif
@@ -1175,7 +1175,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
 		XtVaSetValues(otherw1, XtNsizey, sizey, NULL);
 #ifdef HAVE_MOTIF
 		XmScaleSetValue(cubesy, sizey);
-		if (sizey >= MAXFACETS)
+		if (sizey >= MAX_FACETS)
 			XtVaSetValues(cubesy, XmNmaximum, sizey, NULL);
 #endif
 #endif
@@ -1193,7 +1193,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
 #endif
 		XtVaSetValues(otherw1, XtNsizez, sizez, NULL);
 #ifdef HAVE_MOTIF
-		if (sizez > MAXFACETS)
+		if (sizez > MAX_FACETS)
 			XtVaSetValues(cubesz, XmNmaximum, sizez, NULL);
 		XmScaleSetValue(cubesz, sizez);
 #endif
@@ -1213,7 +1213,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, rubikCallbackStruct *callData)
 		XtVaSetValues(otherw1, XtNsizez, sizez, NULL);
 #ifdef HAVE_MOTIF
 		XmScaleSetValue(cubesz, sizez);
-		if (sizez >= MAXFACETS)
+		if (sizez >= MAX_FACETS)
 			XtVaSetValues(cubesz, XmNmaximum, sizez, NULL);
 #endif
 #endif
@@ -1934,14 +1934,14 @@ PracticeToggle(Widget w, XtPointer clientData, XmToggleButtonCallbackStruct *cbs
 	if (practice)
 		(void) strcpy(messageDsp, "");
 	else
-		(void) strncpy(messageDsp, "Randomize to start", MESSAGELEN);
+		(void) strncpy(messageDsp, "Randomize to start", MESSAGE_LENGTH);
 	PrintState(message, messageDsp);
 }
 
 static void
 SpeedSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 {
-	int delay = MAXSPEED + MINSPEED - cbs->value - 1, oldDelay;
+	int delay = MAX_SPEED + MIN_SPEED - cbs->value - 1, oldDelay;
 
 	XtVaGetValues(puzzle2d,
 		XtNdelay, &oldDelay, NULL);
@@ -1976,7 +1976,7 @@ static Widget
 createQuery(Widget w, char *text, char *title, XtCallbackProc callback)
 {
 	Widget button, messageBox;
-	char titleDsp[FILENAMELEN + 8];
+	char titleDsp[FILE_NAME_LENGTH + 8];
 	XmString titleString = NULL, messageString = NULL;
 	static XmStringCharSet charSet =
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
@@ -2002,7 +2002,7 @@ static Widget
 createHelp(Widget w, char *text, char *title)
 {
 	Widget button, messageBox;
-	char titleDsp[FILENAMELEN + 8];
+	char titleDsp[FILE_NAME_LENGTH + 8];
 	XmString titleString = NULL, messageString = NULL, buttonString = NULL;
 	static XmStringCharSet charSet =
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
@@ -2269,9 +2269,9 @@ main(int argc, char **argv)
 	cubesx = XtVaCreateManagedWidget("cubesx",
 		xmScaleWidgetClass, cubesRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Size X", 7,
-		XmNminimum, MINFACETS,
-		XmNmaximum, MAXFACETS,
-		XmNvalue, MINFACETS,
+		XmNminimum, MIN_FACETS,
+		XmNmaximum, MAX_FACETS,
+		XmNvalue, MIN_FACETS,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
 	XtAddCallback(cubesx, XmNvalueChangedCallback,
@@ -2279,9 +2279,9 @@ main(int argc, char **argv)
 	cubesy = XtVaCreateManagedWidget("cubesy",
 		xmScaleWidgetClass, cubesRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Size Y", 7,
-		XmNminimum, MINFACETS,
-		XmNmaximum, MAXFACETS,
-		XmNvalue, MINFACETS,
+		XmNminimum, MIN_FACETS,
+		XmNmaximum, MAX_FACETS,
+		XmNvalue, MIN_FACETS,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
 	XtAddCallback(cubesy, XmNvalueChangedCallback,
@@ -2289,9 +2289,9 @@ main(int argc, char **argv)
 	cubesz = XtVaCreateManagedWidget("cubesz",
 		xmScaleWidgetClass, cubesRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Size Z", 7,
-		XmNminimum, MINFACETS,
-		XmNmaximum, MAXFACETS,
-		XmNvalue, MINFACETS,
+		XmNminimum, MIN_FACETS,
+		XmNmaximum, MAX_FACETS,
+		XmNvalue, MIN_FACETS,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
 	XtAddCallback(cubesz, XmNvalueChangedCallback,
@@ -2303,20 +2303,20 @@ main(int argc, char **argv)
 		XmNpacking, XmPACK_COLUMN, NULL);
 	orientizeSwitch = XtVaCreateManagedWidget("Oriented",
 		xmToggleButtonWidgetClass, switchRowCol,
-		XmNset, DEFAULTORIENT, NULL);
+		XmNset, DEFAULT_ORIENT, NULL);
 	XtAddCallback(orientizeSwitch, XmNvalueChangedCallback,
 		(XtCallbackProc) OrientToggle, (XtPointer) NULL);
 	practiceSwitch = XtVaCreateManagedWidget("Practice",
 		xmToggleButtonWidgetClass, switchRowCol,
-		XmNset, DEFAULTPRACTICE, NULL);
+		XmNset, DEFAULT_PRACTICE, NULL);
 	XtAddCallback(practiceSwitch, XmNvalueChangedCallback,
 		(XtCallbackProc) PracticeToggle, (XtPointer) NULL);
 	speed = XtVaCreateManagedWidget("speed",
 		xmScaleWidgetClass, switchRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Animation Speed", 16,
-		XmNminimum, MINSPEED,
-		XmNmaximum, MAXSPEED,
-		XmNvalue, MAXSPEED - 10,
+		XmNminimum, MIN_SPEED,
+		XmNmaximum, MAX_SPEED,
+		XmNvalue, MAX_SPEED - 10,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
 	XtAddCallback(speed, XmNvalueChangedCallback,
