@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 2007	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1994 - 2007	David A. Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -45,7 +45,7 @@
 
 #define SECTION "setup"
 
-static const char *faceColorString[MAXFACES] =
+static const char *faceColorString[MAX_FACES] =
 {
 	"255 0 0",
 	"0 0 255",
@@ -55,7 +55,7 @@ static const char *faceColorString[MAXFACES] =
 	"255 255 0"
 };
 
-static const char faceColorChar[MAXFACES] =
+static const char faceColorChar[MAX_FACES] =
 {'R', 'B', 'W', 'G', 'P', 'Y'};
 #else
 
@@ -179,7 +179,7 @@ loadFont(SkewbWidget w)
 #define LOGFILE "skewb.log"
 #endif
 
-static int facesToDirection[MAXFACES][MAXFACES] =
+static int facesToDirection[MAX_FACES][MAX_FACES] =
 {
 	{-1, BOTTOM, BOTTOM, BOTTOM, -1, TOP},
 	{RIGHT, -1, RIGHT, -1, RIGHT, RIGHT},
@@ -188,7 +188,7 @@ static int facesToDirection[MAXFACES][MAXFACES] =
 	{-1, TOP, TOP, TOP, -1, BOTTOM},
 	{BOTTOM, RIGHT, -1, LEFT, TOP, -1}
 };
-static int facesToPosition[MAXFACES][MAXFACES][MAXORIENT] =
+static int facesToPosition[MAX_FACES][MAX_FACES][MAX_ORIENT] =
 {
 	{
 		{-1, -1, -1, -1},
@@ -239,7 +239,7 @@ static int facesToPosition[MAXFACES][MAXFACES][MAXORIENT] =
 		{-1, -1, -1, -1}
 	}
 };
-static SkewbLoc slideNextRow[MAXFACES][MAXORIENT][MAXORIENT / 2] =
+static SkewbLoc slideNextRow[MAX_FACES][MAX_ORIENT][MAX_ORIENT / 2] =
 {
 	{
 		{
@@ -350,7 +350,7 @@ static SkewbLoc slideNextRow[MAXFACES][MAXORIENT][MAXORIENT / 2] =
 		}
 	}
 };
-static SkewbLoc minToMaj[MAXFACES][MAXORIENT] =
+static SkewbLoc minToMaj[MAX_FACES][MAX_ORIENT] =
 {				/* other equivalent mappings possible */
 	{
 		{3, CW},
@@ -390,7 +390,7 @@ static SkewbLoc minToMaj[MAXFACES][MAXORIENT] =
 	}
 };
 
-static SkewbLoc slideNextFace[MAXFACES][MAXORIENT] =
+static SkewbLoc slideNextFace[MAX_FACES][MAX_ORIENT] =
 {
 	{
 		{5, STRT},
@@ -430,7 +430,7 @@ static SkewbLoc slideNextFace[MAXFACES][MAXORIENT] =
 	}
 };
 
-static int faceToRotate[MAXFACES][MAXORIENT] =
+static int faceToRotate[MAX_FACES][MAX_ORIENT] =
 {
 	{3, 2, 1, 5},
 	{2, 4, 5, 0},
@@ -440,7 +440,7 @@ static int faceToRotate[MAXFACES][MAXORIENT] =
 	{3, 0, 1, 4}
 };
 
-static SkewbLocPos orthToDiag[MAXFACES][MAXORIENT][MAXORIENT] =
+static SkewbLocPos orthToDiag[MAX_FACES][MAX_ORIENT][MAX_ORIENT] =
 {
 	{
 		{
@@ -608,14 +608,14 @@ CheckSolved(SkewbWidget w)
 	int face, position;
 	SkewbLoc test = {0, FALSE};
 
-	for (face = 0; face < MAXFACES; face++)
-		for (position = 0; position < MAXCUBES; position++) {
+	for (face = 0; face < MAX_FACES; face++)
+		for (position = 0; position < MAX_CUBES; position++) {
 			if (!position) {
 				test.face = w->skewb.cubeLoc[face][position].face;
 				test.rotation = w->skewb.cubeLoc[face][position].rotation;
 			} else if (test.face !=		/*face */
 				  w->skewb.cubeLoc[face][position].face ||
-				  (w->skewb.orient && test.rotation !=		/*STRT - MAXORIENT */
+				  (w->skewb.orient && test.rotation !=		/*STRT - MAX_ORIENT */
 				  w->skewb.cubeLoc[face][position].rotation))
 				return False;
 		}
@@ -629,8 +629,8 @@ PrintCube(SkewbWidget w)
 {
 	int face, position;
 
-	for (face = 0; face < MAXFACES; face++) {
-		for (position = 0; position < MAXCUBES; position++)
+	for (face = 0; face < MAX_FACES; face++) {
+		for (position = 0; position < MAX_CUBES; position++)
 			(void) printf("%d %d  ", w->skewb.cubeLoc[face][position].face,
 				w->skewb.cubeLoc[face][position].rotation);
 		(void) printf("\n");
@@ -668,9 +668,9 @@ DrawAllPieces(SkewbWidget w)
 		DrawAllPiecesGL((SkewbGLWidget) w);
 	}
 #endif
-	for (face = 0; face < MAXFACES; face++) {
+	for (face = 0; face < MAX_FACES; face++) {
 		DrawDiamond(w, face, FALSE);
-		for (position = 0; position < MAXORIENT; position++)
+		for (position = 0; position < MAX_ORIENT; position++)
 			DrawTriangle(w, face, position, FALSE);
 	}
 }
@@ -700,19 +700,19 @@ RotateFace(SkewbWidget w, int face, int direction)
 	int corner;
 
 	/* Read Face */
-	for (corner = 0; corner < MAXORIENT; corner++)
+	for (corner = 0; corner < MAX_ORIENT; corner++)
 		w->skewb.faceLoc[corner] = w->skewb.cubeLoc[face][corner];
 	/* Write Face */
-	for (corner = 0; corner < MAXORIENT; corner++) {
+	for (corner = 0; corner < MAX_ORIENT; corner++) {
 		w->skewb.cubeLoc[face][corner] = (direction == CW) ?
-			w->skewb.faceLoc[(corner + MAXORIENT - 1) % MAXORIENT] :
-			w->skewb.faceLoc[(corner + 1) % MAXORIENT];
+			w->skewb.faceLoc[(corner + MAX_ORIENT - 1) % MAX_ORIENT] :
+			w->skewb.faceLoc[(corner + 1) % MAX_ORIENT];
 		w->skewb.cubeLoc[face][corner].rotation =
-			(w->skewb.cubeLoc[face][corner].rotation + direction) % MAXORIENT;
+			(w->skewb.cubeLoc[face][corner].rotation + direction) % MAX_ORIENT;
 		DrawTriangle(w, face, corner, FALSE);
 	}
-	w->skewb.cubeLoc[face][MAXORIENT].rotation =
-		(w->skewb.cubeLoc[face][MAXORIENT].rotation + direction) % MAXORIENT;
+	w->skewb.cubeLoc[face][MAX_ORIENT].rotation =
+		(w->skewb.cubeLoc[face][MAX_ORIENT].rotation + direction) % MAX_ORIENT;
 	DrawDiamond(w, face, FALSE);
 #ifdef HAVE_OPENGL
 	if (w->skewb.dim == 4) {
@@ -726,7 +726,7 @@ ReadFace(SkewbWidget w, int face, int h)
 {
 	int position;
 
-	for (position = 0; position < MAXCUBES; position++)
+	for (position = 0; position < MAX_CUBES; position++)
 		w->skewb.rowLoc[h][position] = w->skewb.cubeLoc[face][position];
 }
 
@@ -735,16 +735,16 @@ WriteFace(SkewbWidget w, int face, int rotate, int h)
 {
 	int corner, newCorner;
 
-	for (corner = 0; corner < MAXORIENT; corner++) {
-		newCorner = (corner + rotate) % MAXORIENT;
+	for (corner = 0; corner < MAX_ORIENT; corner++) {
+		newCorner = (corner + rotate) % MAX_ORIENT;
 		w->skewb.cubeLoc[face][newCorner] = w->skewb.rowLoc[h][corner];
 		w->skewb.cubeLoc[face][newCorner].rotation =
-			(w->skewb.cubeLoc[face][newCorner].rotation + rotate) % MAXORIENT;
-		DrawTriangle(w, face, (corner + rotate) % MAXORIENT, FALSE);
+			(w->skewb.cubeLoc[face][newCorner].rotation + rotate) % MAX_ORIENT;
+		DrawTriangle(w, face, (corner + rotate) % MAX_ORIENT, FALSE);
 	}
-	w->skewb.cubeLoc[face][MAXORIENT] = w->skewb.rowLoc[h][MAXORIENT];
-	w->skewb.cubeLoc[face][MAXORIENT].rotation =
-		(w->skewb.cubeLoc[face][MAXORIENT].rotation + rotate) % MAXORIENT;
+	w->skewb.cubeLoc[face][MAX_ORIENT] = w->skewb.rowLoc[h][MAX_ORIENT];
+	w->skewb.cubeLoc[face][MAX_ORIENT].rotation =
+		(w->skewb.cubeLoc[face][MAX_ORIENT].rotation + rotate) % MAX_ORIENT;
 	DrawDiamond(w, face, FALSE);
 #ifdef HAVE_OPENGL
 	if (w->skewb.dim == 4) {
@@ -761,11 +761,11 @@ ReadDiagonal(SkewbWidget w, int face, int corner, int orient, int size)
 	if (size == MINOR)
 		w->skewb.minorLoc[orient] = w->skewb.cubeLoc[face][corner];
 	else {			/* size == MAJOR */
-		for (g = 1; g < MAXORIENT; g++)
+		for (g = 1; g < MAX_ORIENT; g++)
 			w->skewb.majorLoc[orient][g - 1] =
-				w->skewb.cubeLoc[face][(corner + g) % MAXORIENT];
-		w->skewb.majorLoc[orient][MAXORIENT - 1] =
-			w->skewb.cubeLoc[face][MAXORIENT];
+				w->skewb.cubeLoc[face][(corner + g) % MAX_ORIENT];
+		w->skewb.majorLoc[orient][MAX_ORIENT - 1] =
+			w->skewb.cubeLoc[face][MAX_ORIENT];
 	}
 }
 
@@ -776,11 +776,11 @@ RotateDiagonal(SkewbWidget w, int rotate, int orient, int size)
 
 	if (size == MINOR)
 		w->skewb.minorLoc[orient].rotation =
-			(w->skewb.minorLoc[orient].rotation + rotate) % MAXORIENT;
+			(w->skewb.minorLoc[orient].rotation + rotate) % MAX_ORIENT;
 	else			/* size == MAJOR */
-		for (g = 0; g < MAXORIENT; g++)
+		for (g = 0; g < MAX_ORIENT; g++)
 			w->skewb.majorLoc[orient][g].rotation =
-				(w->skewb.majorLoc[orient][g].rotation + rotate) % MAXORIENT;
+				(w->skewb.majorLoc[orient][g].rotation + rotate) % MAX_ORIENT;
 }
 
 static void
@@ -792,11 +792,11 @@ WriteDiagonal(SkewbWidget w, int face, int corner, int orient, int size)
 		w->skewb.cubeLoc[face][corner] = w->skewb.minorLoc[orient];
 		DrawTriangle(w, face, corner, FALSE);
 	} else {		/* size == MAJOR */
-		w->skewb.cubeLoc[face][MAXORIENT] =
-			w->skewb.majorLoc[orient][MAXORIENT - 1];
+		w->skewb.cubeLoc[face][MAX_ORIENT] =
+			w->skewb.majorLoc[orient][MAX_ORIENT - 1];
 		DrawDiamond(w, face, FALSE);
-		for (g = 1; g < MAXORIENT; g++) {
-			h = (corner + g) % MAXORIENT;
+		for (g = 1; g < MAX_ORIENT; g++) {
+			h = (corner + g) % MAX_ORIENT;
 			w->skewb.cubeLoc[face][h] = w->skewb.majorLoc[orient][g - 1];
 			DrawTriangle(w, face, h, FALSE);
 		}
@@ -814,17 +814,17 @@ MovePieces(SkewbWidget w, int face, int position, int direction)
 {
 	int newFace, newDirection, newCorner, k, size, rotate;
 
-	if (direction < 2 * MAXORIENT) {
-		/* position as MAXORIENT is ambiguous */
+	if (direction < 2 * MAX_ORIENT) {
+		/* position as MAX_ORIENT is ambiguous */
 		for (size = MINOR; size <= MAJOR; size++) {
 			ReadDiagonal((SkewbWidget) w, face, position, 0, size);
-			for (k = 1; k <= MAXROTATE; k++) {
+			for (k = 1; k <= MAX_ROTATE; k++) {
 				newFace = slideNextRow[face][position][direction / 2].face;
 				rotate = slideNextRow[face][position][direction / 2].rotation %
-					MAXORIENT;
-				newDirection = (rotate + direction) % MAXORIENT;
-				newCorner = (rotate + position) % MAXORIENT;
-				if (k != MAXROTATE)
+					MAX_ORIENT;
+				newDirection = (rotate + direction) % MAX_ORIENT;
+				newCorner = (rotate + position) % MAX_ORIENT;
+				if (k != MAX_ROTATE)
 					ReadDiagonal((SkewbWidget) w, newFace, newCorner, k, size);
 				RotateDiagonal((SkewbWidget) w, rotate, k - 1, size);
 				WriteDiagonal(w, newFace, newCorner, k - 1, size);
@@ -834,21 +834,21 @@ MovePieces(SkewbWidget w, int face, int position, int direction)
 			}
 			if (size == MINOR) {
 				newFace = minToMaj[face][position].face;
-				rotate = minToMaj[face][position].rotation % MAXORIENT;
-				direction = (rotate + direction) % MAXORIENT;
-				position = (position + rotate + 2) % MAXORIENT;
+				rotate = minToMaj[face][position].rotation % MAX_ORIENT;
+				direction = (rotate + direction) % MAX_ORIENT;
+				position = (position + rotate + 2) % MAX_ORIENT;
 				face = newFace;
 			}
 		}
 	} else {
-		RotateFace(w, faceToRotate[face][direction % MAXORIENT], CW);
-		RotateFace(w, faceToRotate[face][(direction + 2) % MAXORIENT], CCW);
+		RotateFace(w, faceToRotate[face][direction % MAX_ORIENT], CW);
+		RotateFace(w, faceToRotate[face][(direction + 2) % MAX_ORIENT], CCW);
 		ReadFace((SkewbWidget) w, face, 0);
-		for (k = 1; k <= MAXORIENT; k++) {
-			newFace = slideNextFace[face][direction % MAXORIENT].face;
-			rotate = slideNextFace[face][direction % MAXORIENT].rotation;
-			newDirection = (rotate + direction) % MAXORIENT;
-			if (k != MAXORIENT)
+		for (k = 1; k <= MAX_ORIENT; k++) {
+			newFace = slideNextFace[face][direction % MAX_ORIENT].face;
+			rotate = slideNextFace[face][direction % MAX_ORIENT].rotation;
+			newDirection = (rotate + direction) % MAX_ORIENT;
+			if (k != MAX_ORIENT)
 				ReadFace((SkewbWidget) w, newFace, k);
 			WriteFace(w, newFace, rotate, k - 1);
 			face = newFace;
@@ -862,10 +862,10 @@ MoveControlCb(SkewbWidget w, int face, int position, int direction)
 {
 	int newFace, rotate;
 
-	if (direction >= 2 * MAXORIENT) {
+	if (direction >= 2 * MAX_ORIENT) {
 		SkewbLocPos newpos;
 
-		newpos = orthToDiag[face][position][direction % MAXORIENT];
+		newpos = orthToDiag[face][position][direction % MAX_ORIENT];
 		face = newpos.face;
 		position = newpos.position;
 		direction = newpos.direction;
@@ -873,9 +873,9 @@ MoveControlCb(SkewbWidget w, int face, int position, int direction)
 	MovePieces(w, face, position, direction);
 	setPuzzleMove(w, ACTION_CONTROL, face, position, direction);
 	newFace = minToMaj[face][position].face;
-	rotate = minToMaj[face][position].rotation % MAXORIENT;
-	direction = (rotate + direction) % MAXORIENT;
-	position = (position + rotate + 2) % MAXORIENT;
+	rotate = minToMaj[face][position].rotation % MAX_ORIENT;
+	direction = (rotate + direction) % MAX_ORIENT;
+	position = (position + rotate + 2) % MAX_ORIENT;
 	MovePieces(w, newFace, position, direction);
 	setPuzzleMove(w, ACTION_CONTROL, newFace, position, direction);
 }
@@ -900,8 +900,8 @@ MovePuzzle(SkewbWidget w, int face, int position, int direction, int control)
 		newpos.face = face;
 		newpos.position = position;
 		newpos.direction = direction;
-		if (direction >= 2 * MAXORIENT)
-			newpos = orthToDiag[face][position][direction % MAXORIENT];
+		if (direction >= 2 * MAX_ORIENT)
+			newpos = orthToDiag[face][position][direction % MAX_ORIENT];
 		MovePieces(w, newpos.face, newpos.position, newpos.direction);
 		setPuzzleMove(w, ACTION_MOVED, newpos.face, newpos.position,
 			newpos.direction);
@@ -932,7 +932,7 @@ CheckMoveDir(int position1, int position2, int *direction)
 {
 	if (position1 == position2)
 		return 2;
-	if (!((position1 - position2 + MAXORIENT) % 2))
+	if (!((position1 - position2 + MAX_ORIENT) % 2))
 		return 0;
 	switch (position1) {
 	case 0:
@@ -950,7 +950,7 @@ CheckMoveDir(int position1, int position2, int *direction)
 	default:
 		return 0;
 	}
-	*direction += 2 * MAXORIENT;
+	*direction += 2 * MAX_ORIENT;
 	return 1;
 }
 
@@ -988,7 +988,7 @@ MovePuzzleInput(SkewbWidget w, int x, int y, int direction, int control,
 		control = 2;
 	else
 		control = (control) ? 1 : 0;
-	if (position == MAXORIENT)
+	if (position == MAX_ORIENT)
 		return;
 	MovePuzzle(w, face, position, direction, control);
 	if (!control && CheckSolved(w)) {
@@ -1001,10 +1001,10 @@ ResetPieces(SkewbWidget w)
 {
 	int face, position;
 
-	for (face = 0; face < MAXFACES; face++)
-		for (position = 0; position < MAXCUBES; position++) {
+	for (face = 0; face < MAX_FACES; face++)
+		for (position = 0; position < MAX_CUBES; position++) {
 			w->skewb.cubeLoc[face][position].face = face;
-			w->skewb.cubeLoc[face][position].rotation = STRT - MAXORIENT;
+			w->skewb.cubeLoc[face][position].rotation = STRT - MAX_ORIENT;
 		}
 	flushMoves(w, &undo, TRUE);
 	flushMoves(w, &redo, FALSE);
@@ -1153,23 +1153,23 @@ UndoPieces(SkewbWidget w)
 			&face, &position, &direction, &control);
 		setMove(&redo,
 			face, position, direction, control);
-		if (direction < 2 * MAXORIENT) {
-			direction = (direction < MAXORIENT) ?
-				(direction + MAXORIENT / 2) % MAXORIENT :
-				3 * MAXORIENT - direction;
+		if (direction < 2 * MAX_ORIENT) {
+			direction = (direction < MAX_ORIENT) ?
+				(direction + MAX_ORIENT / 2) % MAX_ORIENT :
+				3 * MAX_ORIENT - direction;
 		} else {
-			direction = (direction + MAXORIENT / 2) % MAXORIENT +
-				2 * MAXORIENT;
+			direction = (direction + MAX_ORIENT / 2) % MAX_ORIENT +
+				2 * MAX_ORIENT;
 		}
 		if (control == 2)
 			MoveAltCb(w, face, position, direction);
 		else if (control)
 			MoveControlCb(w, face, position, direction);
 		else {
-			if (direction >= 2 * MAXORIENT) {
+			if (direction >= 2 * MAX_ORIENT) {
 				SkewbLocPos newpos;
 
-				newpos = orthToDiag[face][position][direction % MAXORIENT];
+				newpos = orthToDiag[face][position][direction % MAX_ORIENT];
 				face = newpos.face;
 				position = newpos.position;
 				direction = newpos.direction;
@@ -1198,10 +1198,10 @@ RedoPieces(SkewbWidget w)
 		else if (control)
 			MoveControlCb(w, face, position, direction);
 		else {
-			if (direction >= 2 * MAXORIENT) {
+			if (direction >= 2 * MAX_ORIENT) {
 				SkewbLocPos newpos;
 
-				newpos = orthToDiag[face][position][direction % MAXORIENT];
+				newpos = orthToDiag[face][position][direction % MAX_ORIENT];
 				face = newpos.face;
 				position = newpos.position;
 				direction = newpos.direction;
@@ -1231,7 +1231,7 @@ static void
 RandomizePieces(SkewbWidget w)
 {
 	int face, position, direction;
-	int big = MAXCUBES * 3 + NRAND(2);
+	int big = MAX_CUBES * 3 + NRAND(2);
 
 	w->skewb.cheat = False;
 	if (w->skewb.practice)
@@ -1243,9 +1243,9 @@ RandomizePieces(SkewbWidget w)
 #endif
 
 	while (big--) {
-		face = NRAND(MAXFACES);
-		position = NRAND(MAXORIENT);
-		direction = ((NRAND(2)) ? position + 1 : position + 3) % MAXORIENT;
+		face = NRAND(MAX_FACES);
+		position = NRAND(MAX_ORIENT);
+		direction = ((NRAND(2)) ? position + 1 : position + 3) % MAX_ORIENT;
 		MovePuzzle(w, face, position, direction, FALSE);
 	}
 	flushMoves(w, &undo, TRUE);
@@ -1315,14 +1315,14 @@ SetValuesPuzzle(SkewbWidget w)
 	int face;
 
 	w->skewb.orient = (BOOL) GetPrivateProfileInt(SECTION, "orient",
-		DEFAULTORIENT, INIFILE);
+		DEFAULT_ORIENT, INIFILE);
 	w->skewb.practice = (BOOL) GetPrivateProfileInt(SECTION, "practice",
-		DEFAULTPRACTICE, INIFILE);
+		DEFAULT_PRACTICE, INIFILE);
 	w->skewb.dim = GetPrivateProfileInt(SECTION, "dim", 3, INIFILE);
 	w->skewb.mono = (BOOL) GetPrivateProfileInt(SECTION, "mono",
-		DEFAULTMONO, INIFILE);
+		DEFAULT_MONO, INIFILE);
 	w->skewb.reverse = (BOOL) GetPrivateProfileInt(SECTION, "reverseVideo",
-		DEFAULTREVERSE, INIFILE);
+		DEFAULT_REVERSE, INIFILE);
 	/* cyan */
 	(void) GetPrivateProfileString(SECTION, "frameColor", "0 255 255",
 		szBuf, sizeof (szBuf), INIFILE);
@@ -1341,7 +1341,7 @@ SetValuesPuzzle(SkewbWidget w)
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
 	w->skewb.inverseGC = RGB(color.red, color.green, color.blue);
-	for (face = 0; face < MAXFACES; face++) {
+	for (face = 0; face < MAX_FACES; face++) {
 		(void) sprintf(buf, "faceColor%d", face);
 		(void) GetPrivateProfileString(SECTION, buf,
 			faceColorString[face],
@@ -1512,7 +1512,7 @@ SetAllColors(SkewbWidget w)
 	if (w->skewb.borderGC)
 		XtReleaseGC((Widget) w, w->skewb.borderGC);
 	w->skewb.borderGC = XtGetGC((Widget) w, valueMask, &values);
-	for (face = 0; face < MAXFACES; face++)
+	for (face = 0; face < MAX_FACES; face++)
 		GetColor(w, face);
 	if (w->skewb.fontInfo)
 		XSetFont(XtDisplay(w), w->skewb.borderGC,
@@ -1526,7 +1526,7 @@ SetValuesPuzzle(Widget current, Widget request, Widget renew)
 	Boolean redraw = False, setColors = False;
 	int face;
 
-	for (face = 0; face < MAXFACES; face++) {
+	for (face = 0; face < MAX_FACES; face++) {
 		if (strcmp(w->skewb.faceName[face], c->skewb.faceName[face])) {
 			setColors = True;
 			break;
@@ -1622,7 +1622,7 @@ DestroyPuzzle(Widget old)
 	Display *display = XtDisplay(w);
 	int face;
 
-	for (face = 0; face < MAXFACES; face++)
+	for (face = 0; face < MAX_FACES; face++)
 		XtReleaseGC(old, w->skewb.faceGC[face]);
 	XtReleaseGC(old, w->skewb.borderGC);
 	XtReleaseGC(old, w->skewb.frameGC);
@@ -1665,7 +1665,7 @@ Widget request, Widget renew
 	w->skewb.mono = (DefaultDepthOfScreen(XtScreen(w)) < 2 ||
 		w->skewb.mono);
 	w->skewb.fontInfo = NULL;
-	for (face = 0; face < MAXFACES; face++)
+	for (face = 0; face < MAX_FACES; face++)
 		w->skewb.faceGC[face] = NULL;
 	w->skewb.borderGC = NULL;
 	w->skewb.frameGC = NULL;
@@ -1713,7 +1713,7 @@ SelectPuzzle(SkewbWidget w
 
 	if (SelectPieces(w, x, y, &(w->skewb.currentFace),
 			&(w->skewb.currentPosition))) {
-		if (w->skewb.currentPosition == MAXORIENT) {
+		if (w->skewb.currentPosition == MAX_ORIENT) {
 			if (control || alt || w->skewb.practice || !CheckSolved(w)) {
 				DrawDiamond(w, w->skewb.currentFace, TRUE);
 				FLUSH(w);
@@ -1750,7 +1750,7 @@ ReleasePuzzle(SkewbWidget w
 
 	if (w->skewb.currentFace <= IGNORE_DIR)
 		return;
-	if (w->skewb.currentPosition != MAXORIENT)
+	if (w->skewb.currentPosition != MAX_ORIENT)
 		DrawTriangle(w, w->skewb.currentFace, w->skewb.currentPosition,
 			FALSE);
 	if (!control && !alt && !w->skewb.practice && CheckSolved(w))
@@ -1761,7 +1761,7 @@ ReleasePuzzle(SkewbWidget w
 		else
 			ctrl = (ctrl) ? 1 : 0;
 		if (face == w->skewb.currentFace) {
-			if (position == MAXORIENT)
+			if (position == MAX_ORIENT)
 				count = -1;
 			else
 				count = CheckMoveDir(w->skewb.currentPosition,
