@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 2007	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1994 - 2007	David A. Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -216,10 +216,10 @@ static XtResource resourcesPuzzle2D[] =
 	 XtRString, (caddr_t) "9x15bold"},
 	{XtNorient, XtCOrient, XtRBoolean, sizeof (Boolean),
 	 XtOffset(SkewbWidget, skewb.orient),
-	 XtRString, (caddr_t) "FALSE"},	/* DEFAULTORIENT */
+	 XtRString, (caddr_t) "FALSE"},	/* DEFAULT_ORIENT */
 	{XtNpractice, XtCBoolean, XtRBoolean, sizeof (Boolean),
 	 XtOffset(SkewbWidget, skewb.practice),
-	 XtRString, (caddr_t) "TRUE"}, /* DEFAULTPRACTICE */
+	 XtRString, (caddr_t) "TRUE"}, /* DEFAULT_PRACTICE */
 	{XtNuserName, XtCUserName, XtRString, sizeof (String),
 	 XtOffset(SkewbWidget, skewb.userName),
 	 XtRString, (caddr_t) ""},
@@ -305,11 +305,11 @@ Skewb2DClassRec skewb2dClassRec =
 WidgetClass skewb2dWidgetClass = (WidgetClass) & skewb2dClassRec;
 #endif
 
-static int planeToCube[MAXRECT] =
+static int planeToCube[MAX_RECT] =
 {6, 0, 6, 1, 2, 3, 6, 4, 6, 6, 5, 6};
-static int cubeToPlane[MAXFACES] =
+static int cubeToPlane[MAX_FACES] =
 {1, 3, 4, 5, 7, 10};
-static Point diamondUnit[MAXORIENT + 1] =
+static Point diamondUnit[MAX_ORIENT + 1] =
 {
 	{0, 1},
 	{1, -1},
@@ -317,7 +317,7 @@ static Point diamondUnit[MAXORIENT + 1] =
 	{-1, 1},
 	{-1, -1}
 };
-static Point triangleUnit[MAXORIENT][4] =
+static Point triangleUnit[MAX_ORIENT][4] =
 {
 	{
 		{2, 0},
@@ -344,7 +344,7 @@ static Point triangleUnit[MAXORIENT][4] =
 		{-1, 1}
 	}
 };
-static Point letterUnit[MAXCUBES] =
+static Point letterUnit[MAX_CUBES] =
 {
 	{2, 0},
 	{2, 2},
@@ -352,8 +352,8 @@ static Point letterUnit[MAXCUBES] =
 	{0, 0},
 	{1, 1}
 };
-static Point diamondList[MAXORIENT + 1], triangleList[MAXORIENT][4];
-static Point letterList[MAXCUBES], offsetList[MAXCUBES];
+static Point diamondList[MAX_ORIENT + 1], triangleList[MAX_ORIENT][4];
+static Point letterList[MAX_CUBES], offsetList[MAX_CUBES];
 
 static Pixmap dr = 0; /* dummy for future double buffering */
 
@@ -363,7 +363,7 @@ DrawOrientLine(Skewb2DWidget w, int cube, int orient, int dx, int dy,
 {
 	char *buf;
 
-	if (cube == MAXORIENT) {
+	if (cube == MAX_ORIENT) {
 		switch (orient) {
 		case TR:
 			DRAWLINE(w, dr, borderGC,
@@ -403,7 +403,7 @@ DrawOrientLine(Skewb2DWidget w, int cube, int orient, int dx, int dy,
 				DISPLAY_WARNING(buf);
 				free(buf);
 		}
-	} else {	/* cube != MAXORIENT */
+	} else {	/* cube != MAX_ORIENT */
 		switch (orient) {
 		case TR:
 			DRAWLINE(w, dr, borderGC,
@@ -452,8 +452,8 @@ DrawDiamond2D(Skewb2DWidget w, int face, int offset)
 	GC faceGC, borderGC;
 	int dx, dy, orient;
 
-	orient = w->skewb.cubeLoc[face][MAXORIENT].rotation;
-	if (w->skewb.vertical || face != MAXFACES - 1) {
+	orient = w->skewb.cubeLoc[face][MAX_ORIENT].rotation;
+	if (w->skewb.vertical || face != MAX_FACES - 1) {
 		dx = (cubeToPlane[face] % MAXX) * w->skewb2d.viewLength +
 			w->skewb.delta;
 		dy = (cubeToPlane[face] / MAXX) * w->skewb2d.viewLength +
@@ -467,17 +467,17 @@ DrawDiamond2D(Skewb2DWidget w, int face, int offset)
 	}
 	dx += w->skewb.puzzleOffset.x + w->skewb.delta;
 	dy += w->skewb.puzzleOffset.y + w->skewb.delta;
-	diamondList[0].x = offsetList[MAXORIENT].x + dx;
-	diamondList[0].y = offsetList[MAXORIENT].y + dy;
+	diamondList[0].x = offsetList[MAX_ORIENT].x + dx;
+	diamondList[0].y = offsetList[MAX_ORIENT].y + dy;
 	if (offset) {
-		borderGC = w->skewb.faceGC[(int) w->skewb.cubeLoc[face][MAXORIENT].face];
+		borderGC = w->skewb.faceGC[(int) w->skewb.cubeLoc[face][MAX_ORIENT].face];
 		if (w->skewb.mono) {
 			faceGC = w->skewb.inverseGC;
 		} else {
 			faceGC = w->skewb.borderGC;
 		}
 	} else {
-		faceGC = w->skewb.faceGC[(int) w->skewb.cubeLoc[face][MAXORIENT].face];
+		faceGC = w->skewb.faceGC[(int) w->skewb.cubeLoc[face][MAX_ORIENT].face];
 		borderGC = w->skewb.borderGC;
 	}
 	POLYGON((SkewbWidget) w, dr, faceGC, borderGC,
@@ -489,14 +489,14 @@ DrawDiamond2D(Skewb2DWidget w, int face, int offset)
 		buf[0] =
 #ifdef WINVER
 			w->skewb.faceChar[w->skewb.cubeLoc
-				[face][MAXORIENT].face];
+				[face][MAX_ORIENT].face];
 #else
 			w->skewb.faceName[w->skewb.cubeLoc
-				[face][MAXORIENT].face][0];
+				[face][MAX_ORIENT].face][0];
 #endif
 		buf[1] = '\0';
-		letterX = dx + letterList[MAXORIENT].x;
-		letterY = dy + letterList[MAXORIENT].y;
+		letterX = dx + letterList[MAX_ORIENT].x;
+		letterY = dy + letterList[MAX_ORIENT].y;
 		if (offset) {
 			borderGC = w->skewb.borderGC;
 		} else {
@@ -506,7 +506,7 @@ DrawDiamond2D(Skewb2DWidget w, int face, int offset)
 			letterX, letterY, buf, 1);
 	}
 	if (w->skewb.orient)
-		DrawOrientLine(w, MAXORIENT, orient, dx, dy, borderGC);
+		DrawOrientLine(w, MAX_ORIENT, orient, dx, dy, borderGC);
 }
 
 void
@@ -516,7 +516,7 @@ DrawTriangle2D(Skewb2DWidget w, int face, int position, int offset)
 	int dx, dy, letterX, letterY, orient, newCorner;
 
 	orient = w->skewb.cubeLoc[face][position].rotation;
-	if (w->skewb.vertical || face != MAXFACES - 1) {
+	if (w->skewb.vertical || face != MAX_FACES - 1) {
 		dx = (cubeToPlane[face] % MAXX) * w->skewb2d.viewLength +
 			w->skewb.delta - 1;
 		dy = (cubeToPlane[face] / MAXX) * w->skewb2d.viewLength +
@@ -623,13 +623,13 @@ ResizePieces(Skewb2DWidget w)
 	w->skewb.orientLineLength = w->skewb2d.diamondLength / 8;
 	w->skewb.letterOffset.x = -2;
 	w->skewb.letterOffset.y = 4;
-	for (i = 0; i <= MAXORIENT; i++) {
+	for (i = 0; i <= MAX_ORIENT; i++) {
 		diamondList[i].x = diamondUnit[i].x *
 			(w->skewb2d.diamondLength / 2 - w->skewb.delta);
 		diamondList[i].y = diamondUnit[i].y *
 			(w->skewb2d.diamondLength / 2 - w->skewb.delta);
 	}
-	for (i = 0; i < MAXORIENT; i++) {
+	for (i = 0; i < MAX_ORIENT; i++) {
 		for (j = 0; j <= 3; j++) {
 			triangleList[i][j].x = triangleUnit[i][j].x *
 				(w->skewb2d.diamondLength / 2 - 3 *
@@ -640,7 +640,7 @@ ResizePieces(Skewb2DWidget w)
 		}
 	}
 
-	for (i = 0; i < MAXORIENT; i++) {
+	for (i = 0; i < MAX_ORIENT; i++) {
 		if (letterUnit[i].x == 0)
 			letterList[i].x = w->skewb2d.diamondLength / 8 +
 				w->skewb.letterOffset.x;
@@ -678,18 +678,18 @@ ResizePieces(Skewb2DWidget w)
 				w->skewb.delta - 2;
 	}
 	if (diamondUnit[0].x == 0)
-		offsetList[MAXORIENT].x = w->skewb.delta - 2;
+		offsetList[MAX_ORIENT].x = w->skewb.delta - 2;
 	else if (diamondUnit[0].x == 1)
-		offsetList[MAXORIENT].x = w->skewb2d.diamondLength / 2 - 1;
+		offsetList[MAX_ORIENT].x = w->skewb2d.diamondLength / 2 - 1;
 	if (diamondUnit[0].y == 0)
-		offsetList[MAXORIENT].y = w->skewb.delta - 2;
+		offsetList[MAX_ORIENT].y = w->skewb.delta - 2;
 	else if (diamondUnit[0].y == 1)
-		offsetList[MAXORIENT].y = w->skewb2d.diamondLength / 2 - 2;
-	if (letterUnit[MAXORIENT].x == 1)
-		letterList[MAXORIENT].x = w->skewb2d.diamondLength / 2 - 2 +
+		offsetList[MAX_ORIENT].y = w->skewb2d.diamondLength / 2 - 2;
+	if (letterUnit[MAX_ORIENT].x == 1)
+		letterList[MAX_ORIENT].x = w->skewb2d.diamondLength / 2 - 2 +
 			w->skewb.letterOffset.x;
-	if (letterUnit[MAXORIENT].y == 1)
-		letterList[MAXORIENT].y = w->skewb2d.diamondLength / 2 - 2 +
+	if (letterUnit[MAX_ORIENT].y == 1)
+		letterList[MAX_ORIENT].y = w->skewb2d.diamondLength / 2 - 2 +
 			w->skewb.letterOffset.y;
 }
 
@@ -713,16 +713,16 @@ SelectPieces2D(Skewb2DWidget w, int x, int y, int *face, int *position)
 	else if (i + j < w->skewb2d.viewLength / 2 + 7)
 		*position = TL;
 	else
-		*position = MAXORIENT;
+		*position = MAX_ORIENT;
 	if ((faceX != 1 && faceY != 1) ||
 			(faceX >= 3 && w->skewb.vertical) ||
 			(faceY >= 3 && !w->skewb.vertical))
 		return False;
 	*face = planeToCube[faceX + faceY * MAXX];
 	if (faceX == 3) {
-		*face = MAXFACES - 1;
-		if (*position != MAXORIENT)
-			*position = (*position + HALF) % MAXORIENT;
+		*face = MAX_FACES - 1;
+		if (*position != MAX_ORIENT)
+			*position = (*position + HALF) % MAX_ORIENT;
 	}
 	return True;
 }
@@ -730,20 +730,20 @@ SelectPieces2D(Skewb2DWidget w, int x, int y, int *face, int *position)
 Boolean
 NarrowSelection2D(Skewb2DWidget w, int *face, int *position, int *direction)
 {
-	if (*face == MAXFACES - 1 && *direction < MAXORIENT &&
+	if (*face == MAX_FACES - 1 && *direction < MAX_ORIENT &&
 			!w->skewb.vertical) {
-		if (*direction < MAXORIENT)
-			*direction = (*direction + HALF) % MAXORIENT;
-		else if (*direction >= 2 * MAXORIENT)
-			*direction = 2 * MAXORIENT +
-				(*direction + HALF) % MAXORIENT;
+		if (*direction < MAX_ORIENT)
+			*direction = (*direction + HALF) % MAX_ORIENT;
+		else if (*direction >= 2 * MAX_ORIENT)
+			*direction = 2 * MAX_ORIENT +
+				(*direction + HALF) % MAX_ORIENT;
 	}
-	if (*position != MAXORIENT) {
+	if (*position != MAX_ORIENT) {
 		if (*direction == CW)
-			*direction = (*position + 3) % MAXORIENT;
+			*direction = (*position + 3) % MAX_ORIENT;
 		else if (*direction == CCW)
-			*direction = (*position + 1) % MAXORIENT;
-		else if (*direction < MAXORIENT &&
+			*direction = (*position + 1) % MAX_ORIENT;
+		else if (*direction < MAX_ORIENT &&
 				!((*direction + *position) % 2))
 			return False;
 	}
