@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 2007	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1994 - 2007	David A. Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -208,10 +208,10 @@ static XtResource resourcesPuzzle3D[] =
 	 XtRString, (caddr_t) "9x15bold"},
 	{XtNorient, XtCOrient, XtRBoolean, sizeof (Boolean),
 	 XtOffset(SkewbWidget, skewb.orient),
-	 XtRString, (caddr_t) "FALSE"},	/* DEFAULTORIENT */
+	 XtRString, (caddr_t) "FALSE"},	/* DEFAULT_ORIENT */
 	{XtNpractice, XtCBoolean, XtRBoolean, sizeof (Boolean),
 	 XtOffset(SkewbWidget, skewb.practice),
-	 XtRString, (caddr_t) "TRUE"}, /* DEFAULTPRACTICE */
+	 XtRString, (caddr_t) "TRUE"}, /* DEFAULT_PRACTICE */
 	{XtNuserName, XtCUserName, XtRString, sizeof (String),
 	 XtOffset(SkewbWidget, skewb.userName),
 	 XtRString, (caddr_t) ""},
@@ -297,13 +297,13 @@ Skewb3DClassRec skewb3dClassRec =
 WidgetClass skewb3dWidgetClass = (WidgetClass) & skewb3dClassRec;
 #endif
 
-static Point faceLoc3D[MAXFACES][MAXORIENT];
-static Point cubeLoc3D[MAXFACES][MAXORIENT];
-static Point diamondLoc3D[MAXFACES][MAXORIENT + 1];
-static Point triangleLoc3D[MAXFACES][MAXORIENT][4];
-static Point letter3DList[MAXFACES][MAXCUBES];
-static Point orientDiamond[MAXFACES][MAXORIENT][2];
-static Point orientTriangle[MAXFACES][MAXORIENT][2];
+static Point faceLoc3D[MAX_FACES][MAX_ORIENT];
+static Point cubeLoc3D[MAX_FACES][MAX_ORIENT];
+static Point diamondLoc3D[MAX_FACES][MAX_ORIENT + 1];
+static Point triangleLoc3D[MAX_FACES][MAX_ORIENT][4];
+static Point letter3DList[MAX_FACES][MAX_CUBES];
+static Point orientDiamond[MAX_FACES][MAX_ORIENT][2];
+static Point orientTriangle[MAX_FACES][MAX_ORIENT][2];
 
 static Pixmap dr = 0; /* dummy for future double buffering */
 
@@ -400,18 +400,18 @@ MapTo3D(Skewb3DWidget w, int face, int side, int *corner)
 {
 	switch (face) {
 	case 0:
-		*corner = (side + 2) % MAXORIENT;
+		*corner = (side + 2) % MAX_ORIENT;
 		break;
 	case 1:
 	case 5:
 		*corner = side;
 		break;
 	case 2:
-		*corner = (side + 1) % MAXORIENT;
+		*corner = (side + 1) % MAX_ORIENT;
 		break;
 	case 3:
 	case 4:
-		*corner = (side + 3) % MAXORIENT;
+		*corner = (side + 3) % MAX_ORIENT;
 		break;
 	default:
 		{
@@ -429,18 +429,18 @@ MapFrom3D(Skewb3DWidget w, int face, int corner, int *side)
 {
 	switch (face) {
 	case 0:
-		*side = (corner + 2) % MAXORIENT;
+		*side = (corner + 2) % MAX_ORIENT;
 		break;
 	case 1:
 	case 5:
 		*side = corner;
 		break;
 	case 2:
-		*side = (corner + 3) % MAXORIENT;
+		*side = (corner + 3) % MAX_ORIENT;
 		break;
 	case 3:
 	case 4:
-		*side = (corner + 1) % MAXORIENT;
+		*side = (corner + 1) % MAX_ORIENT;
 		break;
 	default:
 		{
@@ -521,18 +521,18 @@ DrawDiamond3D(Skewb3DWidget w, int face, int offset)
 	int dx, dy, rotation;
 
 	DiamondOffset3D(w, face, &dx, &dy);
-	rotation = w->skewb.cubeLoc[face][MAXORIENT].rotation;
+	rotation = w->skewb.cubeLoc[face][MAX_ORIENT].rotation;
 	diamondLoc3D[face][0].x = dx + cubeLoc3D[face][1].x / 2;
 	diamondLoc3D[face][0].y = dy + cubeLoc3D[face][1].y / 2;
 	if (offset) {
-		borderGC = w->skewb.faceGC[(int) w->skewb.cubeLoc[face][MAXORIENT].face];
+		borderGC = w->skewb.faceGC[(int) w->skewb.cubeLoc[face][MAX_ORIENT].face];
 		if (w->skewb.mono) {
 			faceGC = w->skewb.inverseGC;
 		} else {
 			faceGC = w->skewb.borderGC;
 		}
 	} else {
-		faceGC = w->skewb.faceGC[(int) w->skewb.cubeLoc[face][MAXORIENT].face];
+		faceGC = w->skewb.faceGC[(int) w->skewb.cubeLoc[face][MAX_ORIENT].face];
 		borderGC = w->skewb.borderGC;
 	}
 	POLYGON((SkewbWidget) w, dr, faceGC, borderGC,
@@ -544,14 +544,14 @@ DrawDiamond3D(Skewb3DWidget w, int face, int offset)
 		buf[0] =
 #ifdef WINVER
 			w->skewb.faceChar[w->skewb.cubeLoc
-				[face][MAXORIENT].face];
+				[face][MAX_ORIENT].face];
 #else
 			w->skewb.faceName[w->skewb.cubeLoc
-				[face][MAXORIENT].face][0];
+				[face][MAX_ORIENT].face][0];
 #endif
 		buf[1] = '\0';
-		letterX = dx + letter3DList[face][MAXORIENT].x + w->skewb.letterOffset.x;
-		letterY = dy + letter3DList[face][MAXORIENT].y + w->skewb.letterOffset.y;
+		letterX = dx + letter3DList[face][MAX_ORIENT].x + w->skewb.letterOffset.x;
+		letterY = dy + letter3DList[face][MAX_ORIENT].y + w->skewb.letterOffset.y;
 		if (offset) {
 			borderGC = w->skewb.borderGC;
 		} else {
@@ -604,9 +604,9 @@ DrawFrame3D(Skewb3DWidget w, Boolean focus)
 			(int) (-w->skewb.delta - 2 * w->skewb.letterOffset.y + w->core.height),
 			"Back", 4);
 	}
-	for (face = 0; face < MAXFACES; face++) {
+	for (face = 0; face < MAX_FACES; face++) {
 		POLYLINE((SkewbWidget) w, dr, gc,
-			faceLoc3D[face], MAXORIENT, False);
+			faceLoc3D[face], MAX_ORIENT, False);
 	}
 }
 
@@ -614,10 +614,10 @@ static void
 ResizePieces(Skewb3DWidget w)
 {
 	int face, orient, side, corner;
-	Point subcubeLoc3D[MAXFACES][MAXORIENT];
-	Point orientCubeLoc3D[2][MAXFACES][MAXORIENT];
-	Point subdiamondLoc3D[MAXFACES][MAXORIENT];
-	Point orientDiamondLoc3D[2][MAXFACES][MAXORIENT];
+	Point subcubeLoc3D[MAX_FACES][MAX_ORIENT];
+	Point orientCubeLoc3D[2][MAX_FACES][MAX_ORIENT];
+	Point subdiamondLoc3D[MAX_FACES][MAX_ORIENT];
+	Point orientDiamondLoc3D[2][MAX_FACES][MAX_ORIENT];
 
 	w->skewb.letterOffset.x = -2;
 	w->skewb.letterOffset.y = 3;
@@ -625,10 +625,10 @@ ResizePieces(Skewb3DWidget w)
 		w->skewb.puzzleOffset.x;
 	w->skewb3d.viewMiddle.y = w->skewb3d.faceSize.y +
 		w->skewb.puzzleOffset.y;
-	for (face = 0; face < MAXFACES; face++) {
+	for (face = 0; face < MAX_FACES; face++) {
 		faceLoc3D[face][0].x = w->skewb3d.viewMiddle.x;
 		faceLoc3D[face][0].y = w->skewb3d.viewMiddle.y;
-		for (orient = 1; orient < MAXORIENT; orient++) {
+		for (orient = 1; orient < MAX_ORIENT; orient++) {
 			faceLoc3D[face][orient].x = w->skewb3d.faceSize.x;
 			faceLoc3D[face][orient].y = w->skewb3d.faceSize.y;
 		}
@@ -650,7 +650,7 @@ ResizePieces(Skewb3DWidget w)
 		faceLoc3D[2][3].x /= -1;
 		faceLoc3D[2][3].y = 0;
 
-		for (face = MAXFACES / 2; face < MAXFACES; face++)
+		for (face = MAX_FACES / 2; face < MAX_FACES; face++)
 			faceLoc3D[face][0].y += w->skewb3d.viewSize.y + 3;
 
 		faceLoc3D[3][1].x /= 2;
@@ -686,7 +686,7 @@ ResizePieces(Skewb3DWidget w)
 		faceLoc3D[2][3].y /= 2;
 		faceLoc3D[2][3].x /= -1;
 
-		for (face = MAXFACES / 2; face < MAXFACES; face++)
+		for (face = MAX_FACES / 2; face < MAX_FACES; face++)
 			faceLoc3D[face][0].x += w->skewb3d.viewSize.x + 3;
 
 		faceLoc3D[3][1].x /= -1;
@@ -707,14 +707,14 @@ ResizePieces(Skewb3DWidget w)
 		faceLoc3D[5][3].x = 0;
 	}
 
-	for (face = 0; face < MAXFACES; face++) {
+	for (face = 0; face < MAX_FACES; face++) {
 		cubeLoc3D[face][0].x = faceLoc3D[face][0].x;
 		cubeLoc3D[face][0].y = faceLoc3D[face][0].y;
 		subcubeLoc3D[face][0].x = faceLoc3D[face][0].x;
 		subcubeLoc3D[face][0].y = faceLoc3D[face][0].y;
 		orientCubeLoc3D[0][face][0].x = orientCubeLoc3D[1][face][0].x = 0;
 		orientCubeLoc3D[0][face][0].y = orientCubeLoc3D[1][face][0].y = 0;
-		for (orient = 1; orient < MAXORIENT; orient++) {
+		for (orient = 1; orient < MAX_ORIENT; orient++) {
 			cubeLoc3D[face][orient].x = faceLoc3D[face][orient].x - 3 *
 				w->skewb.delta * faceLoc3D[face][orient].x /
 				w->skewb3d.faceSize.x;
@@ -764,7 +764,7 @@ ResizePieces(Skewb3DWidget w)
 		triangleLoc3D[face][3][1].y = -subcubeLoc3D[face][2].y;
 		triangleLoc3D[face][3][2].y = subcubeLoc3D[face][1].y +
 			subcubeLoc3D[face][2].y;
-		for (orient = 0; orient < MAXORIENT; orient++) {
+		for (orient = 0; orient < MAX_ORIENT; orient++) {
 			letter3DList[face][orient].x =
 				(2 * triangleLoc3D[face][orient][1].x +
 				 triangleLoc3D[face][orient][2].x) / 3;
@@ -783,35 +783,35 @@ ResizePieces(Skewb3DWidget w)
 	w->skewb3d.cubeDiag = w->skewb3d.faceDiagonal + 2 * w->skewb.delta;
 
 	if (w->skewb.vertical) {
-		letter3DList[0][MAXORIENT].x = w->skewb3d.cubeSize.x / 4;
-		letter3DList[0][MAXORIENT].y = -w->skewb3d.cubeSize.y / 2 + 2;
-		letter3DList[1][MAXORIENT].x = -w->skewb3d.cubeDiagonal;
-		letter3DList[1][MAXORIENT].y = 0;
-		letter3DList[2][MAXORIENT].x = w->skewb3d.cubeSize.x / 4;
-		letter3DList[2][MAXORIENT].y = w->skewb3d.cubeSize.y / 2 - 2;
-		letter3DList[3][MAXORIENT].x = w->skewb3d.cubeDiagonal;
-		letter3DList[3][MAXORIENT].y = 0;
-		letter3DList[4][MAXORIENT].x = -w->skewb3d.cubeSize.x / 4;
-		letter3DList[4][MAXORIENT].y = -w->skewb3d.cubeSize.y / 2 + 2;
-		letter3DList[5][MAXORIENT].x = -w->skewb3d.cubeSize.x / 4;
-		letter3DList[5][MAXORIENT].y = w->skewb3d.cubeSize.y / 2 - 2;
+		letter3DList[0][MAX_ORIENT].x = w->skewb3d.cubeSize.x / 4;
+		letter3DList[0][MAX_ORIENT].y = -w->skewb3d.cubeSize.y / 2 + 2;
+		letter3DList[1][MAX_ORIENT].x = -w->skewb3d.cubeDiagonal;
+		letter3DList[1][MAX_ORIENT].y = 0;
+		letter3DList[2][MAX_ORIENT].x = w->skewb3d.cubeSize.x / 4;
+		letter3DList[2][MAX_ORIENT].y = w->skewb3d.cubeSize.y / 2 - 2;
+		letter3DList[3][MAX_ORIENT].x = w->skewb3d.cubeDiagonal;
+		letter3DList[3][MAX_ORIENT].y = 0;
+		letter3DList[4][MAX_ORIENT].x = -w->skewb3d.cubeSize.x / 4;
+		letter3DList[4][MAX_ORIENT].y = -w->skewb3d.cubeSize.y / 2 + 2;
+		letter3DList[5][MAX_ORIENT].x = -w->skewb3d.cubeSize.x / 4;
+		letter3DList[5][MAX_ORIENT].y = w->skewb3d.cubeSize.y / 2 - 2;
 	} else {
-		letter3DList[0][MAXORIENT].x = 0;
-		letter3DList[0][MAXORIENT].y = -w->skewb3d.cubeDiagonal;
-		letter3DList[1][MAXORIENT].x = -w->skewb3d.cubeSize.x / 2 + 2;
-		letter3DList[1][MAXORIENT].y = w->skewb3d.cubeSize.y / 4;
-		letter3DList[2][MAXORIENT].x = w->skewb3d.cubeSize.x / 2 - 2;
-		letter3DList[2][MAXORIENT].y = w->skewb3d.cubeSize.y / 4;
-		letter3DList[3][MAXORIENT].x = -w->skewb3d.cubeSize.x / 2 + 2;
-		letter3DList[3][MAXORIENT].y = -w->skewb3d.cubeSize.y / 4;
-		letter3DList[4][MAXORIENT].x = 0;
-		letter3DList[4][MAXORIENT].y = w->skewb3d.cubeDiagonal;
-		letter3DList[5][MAXORIENT].x = w->skewb3d.cubeSize.x / 2 - 2;
-		letter3DList[5][MAXORIENT].y = -w->skewb3d.cubeSize.y / 4;
+		letter3DList[0][MAX_ORIENT].x = 0;
+		letter3DList[0][MAX_ORIENT].y = -w->skewb3d.cubeDiagonal;
+		letter3DList[1][MAX_ORIENT].x = -w->skewb3d.cubeSize.x / 2 + 2;
+		letter3DList[1][MAX_ORIENT].y = w->skewb3d.cubeSize.y / 4;
+		letter3DList[2][MAX_ORIENT].x = w->skewb3d.cubeSize.x / 2 - 2;
+		letter3DList[2][MAX_ORIENT].y = w->skewb3d.cubeSize.y / 4;
+		letter3DList[3][MAX_ORIENT].x = -w->skewb3d.cubeSize.x / 2 + 2;
+		letter3DList[3][MAX_ORIENT].y = -w->skewb3d.cubeSize.y / 4;
+		letter3DList[4][MAX_ORIENT].x = 0;
+		letter3DList[4][MAX_ORIENT].y = w->skewb3d.cubeDiagonal;
+		letter3DList[5][MAX_ORIENT].x = w->skewb3d.cubeSize.x / 2 - 2;
+		letter3DList[5][MAX_ORIENT].y = -w->skewb3d.cubeSize.y / 4;
 	}
 
-	for (face = 0; face < MAXFACES; face++) {
-		for (orient = 0; orient < MAXORIENT - 1; orient++) {
+	for (face = 0; face < MAX_FACES; face++) {
+		for (orient = 0; orient < MAX_ORIENT - 1; orient++) {
 			diamondLoc3D[face][orient].x = (cubeLoc3D[face][orient].x +
 				cubeLoc3D[face][orient + 1].x) / 2;
 			diamondLoc3D[face][orient].y = (cubeLoc3D[face][orient].y +
@@ -834,31 +834,31 @@ ResizePieces(Skewb3DWidget w)
 				 orientCubeLoc3D[1][face][orient + 1].y) / 2;
 		}
 		/* Its a parallelagram so take advantage of that */
-		diamondLoc3D[face][orient].x = (cubeLoc3D[face][MAXORIENT - 1].x -
-			cubeLoc3D[face][MAXORIENT / 2].x) / 2;
-		diamondLoc3D[face][orient].y = (cubeLoc3D[face][MAXORIENT - 1].y -
-			cubeLoc3D[face][MAXORIENT / 2].y) / 2;
-		diamondLoc3D[face][MAXORIENT].x = -diamondLoc3D[face][1].x -
+		diamondLoc3D[face][orient].x = (cubeLoc3D[face][MAX_ORIENT - 1].x -
+			cubeLoc3D[face][MAX_ORIENT / 2].x) / 2;
+		diamondLoc3D[face][orient].y = (cubeLoc3D[face][MAX_ORIENT - 1].y -
+			cubeLoc3D[face][MAX_ORIENT / 2].y) / 2;
+		diamondLoc3D[face][MAX_ORIENT].x = -diamondLoc3D[face][1].x -
 			diamondLoc3D[face][2].x - diamondLoc3D[face][3].x;
-		diamondLoc3D[face][MAXORIENT].y = -diamondLoc3D[face][1].y -
+		diamondLoc3D[face][MAX_ORIENT].y = -diamondLoc3D[face][1].y -
 			diamondLoc3D[face][2].y - diamondLoc3D[face][3].y;
 
-		subdiamondLoc3D[face][orient].x = (subcubeLoc3D[face][MAXORIENT - 1].x -
-			subcubeLoc3D[face][MAXORIENT / 2].x) / 2;
-		subdiamondLoc3D[face][orient].y = (subcubeLoc3D[face][MAXORIENT - 1].y -
-			subcubeLoc3D[face][MAXORIENT / 2].y) / 2;
+		subdiamondLoc3D[face][orient].x = (subcubeLoc3D[face][MAX_ORIENT - 1].x -
+			subcubeLoc3D[face][MAX_ORIENT / 2].x) / 2;
+		subdiamondLoc3D[face][orient].y = (subcubeLoc3D[face][MAX_ORIENT - 1].y -
+			subcubeLoc3D[face][MAX_ORIENT / 2].y) / 2;
 		orientDiamondLoc3D[0][face][orient].x =
-			(orientCubeLoc3D[0][face][MAXORIENT - 1].x -
-			 orientCubeLoc3D[0][face][MAXORIENT / 2].x) / 2;
+			(orientCubeLoc3D[0][face][MAX_ORIENT - 1].x -
+			 orientCubeLoc3D[0][face][MAX_ORIENT / 2].x) / 2;
 		orientDiamondLoc3D[0][face][orient].y =
-			(orientCubeLoc3D[0][face][MAXORIENT - 1].y -
-			 orientCubeLoc3D[0][face][MAXORIENT / 2].y) / 2;
+			(orientCubeLoc3D[0][face][MAX_ORIENT - 1].y -
+			 orientCubeLoc3D[0][face][MAX_ORIENT / 2].y) / 2;
 		orientDiamondLoc3D[1][face][orient].x =
-			(orientCubeLoc3D[1][face][MAXORIENT - 1].x -
-			 orientCubeLoc3D[1][face][MAXORIENT / 2].x) / 2;
+			(orientCubeLoc3D[1][face][MAX_ORIENT - 1].x -
+			 orientCubeLoc3D[1][face][MAX_ORIENT / 2].x) / 2;
 		orientDiamondLoc3D[1][face][orient].y =
-			(orientCubeLoc3D[1][face][MAXORIENT - 1].y -
-			 orientCubeLoc3D[1][face][MAXORIENT / 2].y) / 2;
+			(orientCubeLoc3D[1][face][MAX_ORIENT - 1].y -
+			 orientCubeLoc3D[1][face][MAX_ORIENT / 2].y) / 2;
 
 		MapFrom3D(w, face, 1, &corner);
 		orientDiamond[face][corner][0].x = cubeLoc3D[face][1].x / 2;
@@ -871,9 +871,9 @@ ResizePieces(Skewb3DWidget w)
 		orientTriangle[face][corner][0].y = -orientCubeLoc3D[0][face][2].y / 2;
 		orientTriangle[face][corner][1].x = -orientCubeLoc3D[1][face][2].x / 2;
 		orientTriangle[face][corner][1].y = -orientCubeLoc3D[1][face][2].y / 2;
-		for (orient = 1; orient < MAXORIENT; orient++) {
+		for (orient = 1; orient < MAX_ORIENT; orient++) {
 			side = corner;
-			MapFrom3D(w, face, (orient + 1) % MAXORIENT, &corner);
+			MapFrom3D(w, face, (orient + 1) % MAX_ORIENT, &corner);
 			orientDiamond[face][corner][0].x =
 				orientDiamond[face][side][0].x +
 				diamondLoc3D[face][orient].x;
@@ -959,18 +959,18 @@ SelectPieces3D(Skewb3DWidget w, int x, int y, int *face, int *position)
 	y = y_1;
 	found = 0;
 	DiamondOffset3D(w, *face, &dx, &dy);
-	for (side = 0; side < MAXORIENT; side++) {
+	for (side = 0; side < MAX_ORIENT; side++) {
 		x_1 = dx + orientDiamond[*face][side][0].x;
 		y_1 = dy + orientDiamond[*face][side][0].y;
-		x_2 = dx + orientDiamond[*face][(side + 1) % MAXORIENT][0].x;
-		y_2 = dy + orientDiamond[*face][(side + 1) % MAXORIENT][0].y;
+		x_2 = dx + orientDiamond[*face][(side + 1) % MAX_ORIENT][0].x;
+		y_2 = dy + orientDiamond[*face][(side + 1) % MAX_ORIENT][0].y;
 		if ((x_2 - x_1) * (y - y_1) <= (y_2 - y_1) * (x - x_1)) {
 			*position = side;
 			found++;
 		}
 	}
 	if (found == 0)
-		*position = MAXORIENT;
+		*position = MAX_ORIENT;
 	else if (found > 1)
 		return False;
 	return True;
@@ -986,19 +986,19 @@ NarrowSelection3D(Skewb3DWidget w, int *face, int *position, int *direction)
 	case TL:
 		if (w->skewb.vertical) {
 			if (*face == 1)
-				*direction = *direction + 2 * MAXORIENT;
+				*direction = *direction + 2 * MAX_ORIENT;
 			else if (*face == 3)
-				*direction = (*direction + 3) % MAXORIENT +
-					2 * MAXORIENT;
+				*direction = (*direction + 3) % MAX_ORIENT +
+					2 * MAX_ORIENT;
 		} else {
 			if (*face == 0)
-				*direction = (*direction + 3) % MAXORIENT +
-					2 * MAXORIENT;
+				*direction = (*direction + 3) % MAX_ORIENT +
+					2 * MAX_ORIENT;
 			else if (*face == 4)
-				*direction = (*direction + 2) % MAXORIENT +
-					2 * MAXORIENT;
+				*direction = (*direction + 2) % MAX_ORIENT +
+					2 * MAX_ORIENT;
 			else if (*face == 5)
-				*direction = (*direction + 2) % MAXORIENT;
+				*direction = (*direction + 2) % MAX_ORIENT;
 		}
 		break;
 	case CCW:
@@ -1010,28 +1010,28 @@ NarrowSelection3D(Skewb3DWidget w, int *face, int *position, int *direction)
 	case LEFT:
 		if (w->skewb.vertical) {
 			if (*face == 1)
-				*direction = (TL + *direction) % MAXORIENT;
+				*direction = (TL + *direction) % MAX_ORIENT;
 			else if (*face == 3)
-				*direction = (BL + *direction) % MAXORIENT;
+				*direction = (BL + *direction) % MAX_ORIENT;
 		} else {
 			if (*face == 0)
-				*direction = (TR + *direction) % MAXORIENT;
+				*direction = (TR + *direction) % MAX_ORIENT;
 			else if (*face == 4)
-				*direction = (BR + *direction) % MAXORIENT;
+				*direction = (BR + *direction) % MAX_ORIENT;
 			else if (*face == 5)
-				*direction = (BL + *direction) % MAXORIENT +
-					2 * MAXORIENT;
+				*direction = (BL + *direction) % MAX_ORIENT +
+					2 * MAX_ORIENT;
 		}
 		break;
 	default:
 		return False;
 	}
-	if (*position != MAXORIENT) {
+	if (*position != MAX_ORIENT) {
 		if (*direction == CW)
-			*direction = (*position + 3) % MAXORIENT;
+			*direction = (*position + 3) % MAX_ORIENT;
 		else if (*direction == CCW)
-			*direction = (*position + 1) % MAXORIENT;
-		else if (*direction < MAXORIENT &&
+			*direction = (*position + 1) % MAX_ORIENT;
+		else if (*direction < MAX_ORIENT &&
 				!((*direction + *position) % 2))
 			return False;
 	}
@@ -1072,7 +1072,7 @@ ResizePuzzle3D(Skewb3DWidget w)
 	w->skewb.delta = 4;
 	w->skewb.vertical = (w->core.height >= w->core.width);
 	if (w->skewb.vertical) {
-		tempSize.y = w->core.height / MAXVIEWS;
+		tempSize.y = w->core.height / MAX_VIEWS;
 		tempSize.x = w->core.width;
 		if (tempSize.x >= DIVIDE(tempSize.y)) {
 			w->skewb3d.cubeSize.y = MAX((tempSize.y - 3 * w->skewb.delta) / 2 -
@@ -1090,9 +1090,9 @@ ResizePuzzle3D(Skewb3DWidget w)
 		w->skewb3d.viewSize.x = 2 * w->skewb3d.faceSize.x + 3;
 		w->skewb3d.viewSize.y = 2 * w->skewb3d.faceSize.y + 3;
 		w->skewb.puzzleSize.x = w->skewb3d.viewSize.x + 1;
-		w->skewb.puzzleSize.y = MAXVIEWS * w->skewb3d.viewSize.y + 1;
+		w->skewb.puzzleSize.y = MAX_VIEWS * w->skewb3d.viewSize.y + 1;
 	} else {
-		tempSize.x = w->core.width / MAXVIEWS;
+		tempSize.x = w->core.width / MAX_VIEWS;
 		tempSize.y = w->core.height;
 		if (tempSize.y >= DIVIDE(tempSize.x)) {
 			w->skewb3d.cubeSize.x = MAX((tempSize.x - 3 * w->skewb.delta) / 2 -
@@ -1110,7 +1110,7 @@ ResizePuzzle3D(Skewb3DWidget w)
 		w->skewb3d.viewSize.y = 2 * w->skewb3d.faceSize.y + 3;
 		w->skewb3d.viewSize.x = 2 * w->skewb3d.faceSize.x + 3;
 		w->skewb.puzzleSize.y = w->skewb3d.viewSize.y + 1;
-		w->skewb.puzzleSize.x = MAXVIEWS * w->skewb3d.viewSize.x + 1;
+		w->skewb.puzzleSize.x = MAX_VIEWS * w->skewb3d.viewSize.x + 1;
 	}
 	w->skewb.puzzleOffset.x = ((int) w->core.width - w->skewb.puzzleSize.x) / 2;
 	w->skewb.puzzleOffset.y = ((int) w->core.height - w->skewb.puzzleSize.y) /
