@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 2003 - 2007	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 2003 - 2007	David A. Bagley, bagleyd@tux.org
 #
 #		   All Rights Reserved
 #
@@ -74,7 +74,7 @@ static float MaterialGray[] =
 {0.2, 0.2, 0.2, 1.0};
 
 #ifdef HACK
-static SkewbLocPos orthToDiag[MAXFACES][MAXORIENT][MAXORIENT] =
+static SkewbLocPos orthToDiag[MAX_FACES][MAX_ORIENT][MAX_ORIENT] =
 {
 	{
 		{
@@ -472,10 +472,10 @@ static XtResource resourcesPuzzleGL[] =
 	 XtRString, (caddr_t) "1"},
 	{XtNorient, XtCOrient, XtRBoolean, sizeof (Boolean),
 	 XtOffset(SkewbWidget, skewb.orient),
-	 XtRString, (caddr_t) "FALSE"},	/* DEFAULTORIENT */
+	 XtRString, (caddr_t) "FALSE"},	/* DEFAULT_ORIENT */
 	{XtNpractice, XtCPractice, XtRBoolean, sizeof (Boolean),
 	 XtOffset(SkewbWidget, skewb.practice),
-	 XtRString, (caddr_t) "TRUE"}, /* DEFAULTPRACTICE */
+	 XtRString, (caddr_t) "TRUE"}, /* DEFAULT_PRACTICE */
 	{XtNuserName, XtCUserName, XtRString, sizeof (String),
 	 XtOffset(SkewbWidget, skewb.userName),
 	 XtRString, (caddr_t) ""},
@@ -567,8 +567,8 @@ printCube(SkewbGLWidget w)
 {
 	int face, position;
 
-	for (face = 0; face < MAXFACES; face++) {
-		for (position = 0; position < MAXCUBES; position++) {
+	for (face = 0; face < MAX_FACES; face++) {
+		for (position = 0; position < MAX_CUBES; position++) {
 			(void) printf("%d %d  ",
 				w->skewb.cubeLoc[face][position].face,
 				w->skewb.cubeLoc[face][position].rotation);
@@ -610,14 +610,14 @@ pickColor(SkewbGLWidget w, int C, int mono)
 	color.red = GetRValue(w->skewb.faceGC[C]);
 	color.green = GetGValue(w->skewb.faceGC[C]);
 	color.blue = GetBValue(w->skewb.faceGC[C]);
-#define MAXCOLOR 0xFF
+#define MAX_INTENSITY 0xFF
 #else
 	XColor color;
 
 	color.pixel = w->skewb.faceColor[C];
 	XQueryColor(XtDisplay(w), DefaultColormapOfScreen(XtScreen(w)),
 		&color);
-#define MAXCOLOR 0xFFFF
+#define MAX_INTENSITY 0xFFFF
 #endif
 #ifdef DEBUG
 	(void) printf("i%d %d %d\n", color.red, color.green, color.blue);
@@ -630,13 +630,13 @@ pickColor(SkewbGLWidget w, int C, int mono)
 #ifdef DEBUG
 		(void) printf("m%g\n", intensity);
 #endif
-		Material[0] *= (float) intensity / MAXCOLOR;
-		Material[1] *= (float) intensity / MAXCOLOR;
-		Material[2] *= (float) intensity / MAXCOLOR;
+		Material[0] *= (float) intensity / MAX_INTENSITY;
+		Material[1] *= (float) intensity / MAX_INTENSITY;
+		Material[2] *= (float) intensity / MAX_INTENSITY;
 	} else {
-		Material[0] *= (float) color.red / MAXCOLOR;
-		Material[1] *= (float) color.green / MAXCOLOR;
-		Material[2] *= (float) color.blue / MAXCOLOR;
+		Material[0] *= (float) color.red / MAX_INTENSITY;
+		Material[1] *= (float) color.green / MAX_INTENSITY;
+		Material[2] *= (float) color.blue / MAX_INTENSITY;
 	}
 	}
 #ifdef DEBUG
@@ -652,63 +652,63 @@ draw_stickerless_cubit(void)
 	glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialGray);
 	/* Edge of cubit */
 	glNormal3f(1.0, 1.0, 0.0);
-	glVertex3f(CUBEROUND, CUBELEN, -CUBEROUND);
-	glVertex3f(CUBEROUND, CUBELEN, CUBEROUND);
-	glVertex3f(CUBELEN, CUBEROUND, CUBEROUND);
-	glVertex3f(CUBELEN, CUBEROUND, -CUBEROUND);
+	glVertex3f(CUBE_ROUND, CUBE_LENGTH, -CUBE_ROUND);
+	glVertex3f(CUBE_ROUND, CUBE_LENGTH, CUBE_ROUND);
+	glVertex3f(CUBE_LENGTH, CUBE_ROUND, CUBE_ROUND);
+	glVertex3f(CUBE_LENGTH, CUBE_ROUND, -CUBE_ROUND);
 	glNormal3f(0.0, 1.0, 1.0);
-	glVertex3f(-CUBEROUND, CUBEROUND, CUBELEN);
-	glVertex3f(CUBEROUND, CUBEROUND, CUBELEN);
-	glVertex3f(CUBEROUND, CUBELEN, CUBEROUND);
-	glVertex3f(-CUBEROUND, CUBELEN, CUBEROUND);
+	glVertex3f(-CUBE_ROUND, CUBE_ROUND, CUBE_LENGTH);
+	glVertex3f(CUBE_ROUND, CUBE_ROUND, CUBE_LENGTH);
+	glVertex3f(CUBE_ROUND, CUBE_LENGTH, CUBE_ROUND);
+	glVertex3f(-CUBE_ROUND, CUBE_LENGTH, CUBE_ROUND);
 	glNormal3f(1.0, 0.0, 1.0);
-	glVertex3f(CUBELEN, -CUBEROUND, CUBEROUND);
-	glVertex3f(CUBELEN, CUBEROUND, CUBEROUND);
-	glVertex3f(CUBEROUND, CUBEROUND, CUBELEN);
-	glVertex3f(CUBEROUND, -CUBEROUND, CUBELEN);
+	glVertex3f(CUBE_LENGTH, -CUBE_ROUND, CUBE_ROUND);
+	glVertex3f(CUBE_LENGTH, CUBE_ROUND, CUBE_ROUND);
+	glVertex3f(CUBE_ROUND, CUBE_ROUND, CUBE_LENGTH);
+	glVertex3f(CUBE_ROUND, -CUBE_ROUND, CUBE_LENGTH);
 	glEnd();
 	glBegin(GL_TRIANGLES);
 	glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialGray);
 	/* Put sticker here */
 	glNormal3f(0.0, 0.0, 1.0);
-	glVertex3f(CUBEROUND, -CUBEROUND, CUBELEN);
-	glVertex3f(CUBEROUND, CUBEROUND, CUBELEN);
-	glVertex3f(-CUBEROUND, CUBEROUND, CUBELEN);
+	glVertex3f(CUBE_ROUND, -CUBE_ROUND, CUBE_LENGTH);
+	glVertex3f(CUBE_ROUND, CUBE_ROUND, CUBE_LENGTH);
+	glVertex3f(-CUBE_ROUND, CUBE_ROUND, CUBE_LENGTH);
 	glNormal3f(1.0, 0.0, 0.0);
-	glVertex3f(CUBELEN, CUBEROUND, -CUBEROUND);
-	glVertex3f(CUBELEN, CUBEROUND, CUBEROUND);
-	glVertex3f(CUBELEN, -CUBEROUND, CUBEROUND);
+	glVertex3f(CUBE_LENGTH, CUBE_ROUND, -CUBE_ROUND);
+	glVertex3f(CUBE_LENGTH, CUBE_ROUND, CUBE_ROUND);
+	glVertex3f(CUBE_LENGTH, -CUBE_ROUND, CUBE_ROUND);
 	glNormal3f(0.0, 1.0, 0.0);
-	glVertex3f(-CUBEROUND, CUBELEN, CUBEROUND);
-	glVertex3f(CUBEROUND, CUBELEN, CUBEROUND);
-	glVertex3f(CUBEROUND, CUBELEN, -CUBEROUND);
+	glVertex3f(-CUBE_ROUND, CUBE_LENGTH, CUBE_ROUND);
+	glVertex3f(CUBE_ROUND, CUBE_LENGTH, CUBE_ROUND);
+	glVertex3f(CUBE_ROUND, CUBE_LENGTH, -CUBE_ROUND);
 	/* Corner of cubit */
 	glNormal3f(1.0, 1.0, 1.0);
-	glVertex3f(CUBEROUND, CUBEROUND, CUBELEN);
-	glVertex3f(CUBELEN, CUBEROUND, CUBEROUND);
-	glVertex3f(CUBEROUND, CUBELEN, CUBEROUND);
+	glVertex3f(CUBE_ROUND, CUBE_ROUND, CUBE_LENGTH);
+	glVertex3f(CUBE_LENGTH, CUBE_ROUND, CUBE_ROUND);
+	glVertex3f(CUBE_ROUND, CUBE_LENGTH, CUBE_ROUND);
 	/* Sharper corners of cubit */
 	glNormal3f(-1.0, 1.0, 1.0);
-	glVertex3f(-CUBELEN, CUBEROUND, CUBELEN);
-	glVertex3f(-CUBELEN, CUBELEN, CUBEROUND);
-	glVertex3f(-CUBELEN, CUBEROUND, CUBEROUND);
+	glVertex3f(-CUBE_LENGTH, CUBE_ROUND, CUBE_LENGTH);
+	glVertex3f(-CUBE_LENGTH, CUBE_LENGTH, CUBE_ROUND);
+	glVertex3f(-CUBE_LENGTH, CUBE_ROUND, CUBE_ROUND);
 	glNormal3f(1.0, -1.0, 1.0);
-	glVertex3f(CUBEROUND, -CUBELEN, CUBELEN);
-	glVertex3f(CUBEROUND, -CUBELEN, CUBEROUND);
-	glVertex3f(CUBELEN, -CUBELEN, CUBEROUND);
+	glVertex3f(CUBE_ROUND, -CUBE_LENGTH, CUBE_LENGTH);
+	glVertex3f(CUBE_ROUND, -CUBE_LENGTH, CUBE_ROUND);
+	glVertex3f(CUBE_LENGTH, -CUBE_LENGTH, CUBE_ROUND);
 	glNormal3f(1.0, 1.0, -1.0);
-	glVertex3f(CUBELEN, CUBEROUND, -CUBELEN);
-	glVertex3f(CUBEROUND, CUBEROUND, -CUBELEN);
-	glVertex3f(CUBEROUND, CUBELEN, -CUBELEN);
+	glVertex3f(CUBE_LENGTH, CUBE_ROUND, -CUBE_LENGTH);
+	glVertex3f(CUBE_ROUND, CUBE_ROUND, -CUBE_LENGTH);
+	glVertex3f(CUBE_ROUND, CUBE_LENGTH, -CUBE_LENGTH);
 	glEnd();
 	glBegin(GL_POLYGON);
 	glNormal3f(-1.0, 1.0, 1.0);
-	glVertex3f(-CUBEROUND, CUBEROUND, CUBELEN);
-	glVertex3f(-CUBEROUND, CUBELEN, CUBEROUND);
-	glVertex3f(CUBEROUND, CUBELEN, -CUBEROUND);
-	glVertex3f(CUBELEN, CUBEROUND, -CUBEROUND);
-	glVertex3f(CUBELEN, -CUBEROUND, CUBEROUND);
-	glVertex3f(CUBEROUND, -CUBEROUND, CUBELEN);
+	glVertex3f(-CUBE_ROUND, CUBE_ROUND, CUBE_LENGTH);
+	glVertex3f(-CUBE_ROUND, CUBE_LENGTH, CUBE_ROUND);
+	glVertex3f(CUBE_ROUND, CUBE_LENGTH, -CUBE_ROUND);
+	glVertex3f(CUBE_LENGTH, CUBE_ROUND, -CUBE_ROUND);
+	glVertex3f(CUBE_LENGTH, -CUBE_ROUND, CUBE_ROUND);
+	glVertex3f(CUBE_ROUND, -CUBE_ROUND, CUBE_LENGTH);
 	glEnd();
 	return True;
 }
@@ -750,7 +750,7 @@ DrawOrientLine(SkewbGLWidget w, int face, int rotation,
 {
 	int err = 0;
 	char *buf1, *buf2;
-	float stickerLong = STICKERLONG * size;
+	float stickerLong = STICKER_LONG * size;
 
 	glTranslatef(x, y, z);
 	glBegin(GL_QUADS);
@@ -955,96 +955,96 @@ DrawFacit(SkewbGLWidget w, int face)
 	Boolean mono = w->skewb.mono;
 
 	glPushMatrix();
-	pickColor(w, w->skewb.cubeLoc[face][MAXORIENT].face, mono);
+	pickColor(w, w->skewb.cubeLoc[face][MAX_ORIENT].face, mono);
 	switch (face) {
 	case TOP_FACE:
 		glBegin(GL_QUADS);
 		glNormal3f(0.0, 1.0, 0.0);
-		glVertex3f(0.0, FSTICKERDEPTH, -FSTICKERLONG);
-		glVertex3f(-FSTICKERLONG, FSTICKERDEPTH, 0.0);
-		glVertex3f(0.0, FSTICKERDEPTH, FSTICKERLONG);
-		glVertex3f(FSTICKERLONG, FSTICKERDEPTH, 0.0);
+		glVertex3f(0.0, FSTICKER_DEPTH, -FSTICKER_LONG);
+		glVertex3f(-FSTICKER_LONG, FSTICKER_DEPTH, 0.0);
+		glVertex3f(0.0, FSTICKER_DEPTH, FSTICKER_LONG);
+		glVertex3f(FSTICKER_LONG, FSTICKER_DEPTH, 0.0);
 		glEnd();
 		if (w->skewb.orient) {
 			DrawOrientLine(w, face,
-				w->skewb.cubeLoc[face][MAXORIENT].rotation,
+				w->skewb.cubeLoc[face][MAX_ORIENT].rotation,
 				2.0,
-				0.0, FCUTDEPTH, 0.0);
+				0.0, FCUT_DEPTH, 0.0);
 		}
 		break;
 	case LEFT_FACE:
 		glBegin(GL_QUADS);
 		glNormal3f(-1.0, 0.0, 0.0);
-		glVertex3f(-FSTICKERDEPTH, 0.0, -FSTICKERLONG);
-		glVertex3f(-FSTICKERDEPTH, -FSTICKERLONG, 0.0);
-		glVertex3f(-FSTICKERDEPTH, 0.0, FSTICKERLONG);
-		glVertex3f(-FSTICKERDEPTH, FSTICKERLONG, 0.0);
+		glVertex3f(-FSTICKER_DEPTH, 0.0, -FSTICKER_LONG);
+		glVertex3f(-FSTICKER_DEPTH, -FSTICKER_LONG, 0.0);
+		glVertex3f(-FSTICKER_DEPTH, 0.0, FSTICKER_LONG);
+		glVertex3f(-FSTICKER_DEPTH, FSTICKER_LONG, 0.0);
 		glEnd();
 		if (w->skewb.orient) {
 			DrawOrientLine(w, face,
-				w->skewb.cubeLoc[face][MAXORIENT].rotation,
+				w->skewb.cubeLoc[face][MAX_ORIENT].rotation,
 				2.0,
-				-FCUTDEPTH, 0.0, 0.0);
+				-FCUT_DEPTH, 0.0, 0.0);
 		}
 		break;
 	case FRONT_FACE:
 		glBegin(GL_QUADS);
 		glNormal3f(0.0, 0.0, 1.0);
-		glVertex3f(-FSTICKERLONG, 0.0, FSTICKERDEPTH);
-		glVertex3f(0.0, -FSTICKERLONG, FSTICKERDEPTH);
-		glVertex3f(FSTICKERLONG, 0.0, FSTICKERDEPTH);
-		glVertex3f(0.0, FSTICKERLONG, FSTICKERDEPTH);
+		glVertex3f(-FSTICKER_LONG, 0.0, FSTICKER_DEPTH);
+		glVertex3f(0.0, -FSTICKER_LONG, FSTICKER_DEPTH);
+		glVertex3f(FSTICKER_LONG, 0.0, FSTICKER_DEPTH);
+		glVertex3f(0.0, FSTICKER_LONG, FSTICKER_DEPTH);
 		glEnd();
 		if (w->skewb.orient) {
 			DrawOrientLine(w, face,
-				w->skewb.cubeLoc[face][MAXORIENT].rotation,
+				w->skewb.cubeLoc[face][MAX_ORIENT].rotation,
 				2.0,
-				0.0, 0.0, FCUTDEPTH);
+				0.0, 0.0, FCUT_DEPTH);
 		}
 		break;
 	case RIGHT_FACE:
 		glBegin(GL_QUADS);
 		glNormal3f(1.0, 0.0, 0.0);
-		glVertex3f(FSTICKERDEPTH, FSTICKERLONG, 0.0);
-		glVertex3f(FSTICKERDEPTH, 0.0, FSTICKERLONG);
-		glVertex3f(FSTICKERDEPTH, -FSTICKERLONG, 0.0);
-		glVertex3f(FSTICKERDEPTH, 0.0, -FSTICKERLONG);
+		glVertex3f(FSTICKER_DEPTH, FSTICKER_LONG, 0.0);
+		glVertex3f(FSTICKER_DEPTH, 0.0, FSTICKER_LONG);
+		glVertex3f(FSTICKER_DEPTH, -FSTICKER_LONG, 0.0);
+		glVertex3f(FSTICKER_DEPTH, 0.0, -FSTICKER_LONG);
 		glEnd();
 		if (w->skewb.orient) {
 			DrawOrientLine(w, face,
-				w->skewb.cubeLoc[face][MAXORIENT].rotation,
+				w->skewb.cubeLoc[face][MAX_ORIENT].rotation,
 				2.0,
-				FCUTDEPTH, 0.0, 0.0);
+				FCUT_DEPTH, 0.0, 0.0);
 		}
 		break;
 	case BOTTOM_FACE:
 		glBegin(GL_QUADS);
 		glNormal3f(0.0, -1.0, 0.0);
-		glVertex3f(FSTICKERLONG, -FSTICKERDEPTH, 0.0);
-		glVertex3f(0.0, -FSTICKERDEPTH, FSTICKERLONG);
-		glVertex3f(-FSTICKERLONG, -FSTICKERDEPTH, 0.0);
-		glVertex3f(0.0, -FSTICKERDEPTH, -FSTICKERLONG);
+		glVertex3f(FSTICKER_LONG, -FSTICKER_DEPTH, 0.0);
+		glVertex3f(0.0, -FSTICKER_DEPTH, FSTICKER_LONG);
+		glVertex3f(-FSTICKER_LONG, -FSTICKER_DEPTH, 0.0);
+		glVertex3f(0.0, -FSTICKER_DEPTH, -FSTICKER_LONG);
 		glEnd();
 		if (w->skewb.orient) {
 			DrawOrientLine(w, face,
-				w->skewb.cubeLoc[face][MAXORIENT].rotation,
+				w->skewb.cubeLoc[face][MAX_ORIENT].rotation,
 				2.0,
-				0.0, -FCUTDEPTH, 0.0);
+				0.0, -FCUT_DEPTH, 0.0);
 		}
 		break;
 	case BACK_FACE:
 		glBegin(GL_QUADS);
 		glNormal3f(0.0, 0.0, -1.0);
-		glVertex3f(0.0, FSTICKERLONG, -FSTICKERDEPTH);
-		glVertex3f(FSTICKERLONG, 0.0, -FSTICKERDEPTH);
-		glVertex3f(0.0, -FSTICKERLONG, -FSTICKERDEPTH);
-		glVertex3f(-FSTICKERLONG, 0.0, -FSTICKERDEPTH);
+		glVertex3f(0.0, FSTICKER_LONG, -FSTICKER_DEPTH);
+		glVertex3f(FSTICKER_LONG, 0.0, -FSTICKER_DEPTH);
+		glVertex3f(0.0, -FSTICKER_LONG, -FSTICKER_DEPTH);
+		glVertex3f(-FSTICKER_LONG, 0.0, -FSTICKER_DEPTH);
 		glEnd();
 		if (w->skewb.orient) {
 			DrawOrientLine(w, face,
-				w->skewb.cubeLoc[face][MAXORIENT].rotation,
+				w->skewb.cubeLoc[face][MAX_ORIENT].rotation,
 				2.0,
-				0.0, 0.0, -FCUTDEPTH);
+				0.0, 0.0, -FCUT_DEPTH);
 		}
 		break;
 	}
@@ -1063,20 +1063,20 @@ DrawCubit(SkewbGLWidget w,
 		pickColor(w, back, mono);
 		glNormal3f(0.0, 0.0, -1.0);
 		if (top != NO_FACE) {
-			glVertex3f(-STICKERSHORT, STICKERLONG, -STICKERDEPTH);
-			glVertex3f(STICKERSHORT, STICKERLONG, -STICKERDEPTH);
+			glVertex3f(-STICKER_SHORT, STICKER_LONG, -STICKER_DEPTH);
+			glVertex3f(STICKER_SHORT, STICKER_LONG, -STICKER_DEPTH);
 		}
 		if (left != NO_FACE) {
-			glVertex3f(-STICKERLONG, -STICKERSHORT, -STICKERDEPTH);
-			glVertex3f(-STICKERLONG, STICKERSHORT, -STICKERDEPTH);
+			glVertex3f(-STICKER_LONG, -STICKER_SHORT, -STICKER_DEPTH);
+			glVertex3f(-STICKER_LONG, STICKER_SHORT, -STICKER_DEPTH);
 		}
 		if (bottom != NO_FACE) {
-			glVertex3f(STICKERSHORT, -STICKERLONG, -STICKERDEPTH);
-			glVertex3f(-STICKERSHORT, -STICKERLONG, -STICKERDEPTH);
+			glVertex3f(STICKER_SHORT, -STICKER_LONG, -STICKER_DEPTH);
+			glVertex3f(-STICKER_SHORT, -STICKER_LONG, -STICKER_DEPTH);
 		}
 		if (right != NO_FACE) {
-			glVertex3f(STICKERLONG, STICKERSHORT, -STICKERDEPTH);
-			glVertex3f(STICKERLONG, -STICKERSHORT, -STICKERDEPTH);
+			glVertex3f(STICKER_LONG, STICKER_SHORT, -STICKER_DEPTH);
+			glVertex3f(STICKER_LONG, -STICKER_SHORT, -STICKER_DEPTH);
 		}
 		glEnd();
 		if (w->skewb.orient) {
@@ -1084,25 +1084,25 @@ DrawCubit(SkewbGLWidget w,
 				DrawOrientLine(w, BACK_FACE,
 					w->skewb.cubeLoc[BACK_FACE][1].rotation,
 					0.5,
-					0.1, 0.5 * STICKERSHORT, -CUTDEPTH);
+					0.1, 0.5 * STICKER_SHORT, -CUT_DEPTH);
 			}
 			if (left != NO_FACE && top != NO_FACE) {
 				DrawOrientLine(w, BACK_FACE,
 					w->skewb.cubeLoc[BACK_FACE][2].rotation,
 					0.5,
-					-0.5 * STICKERSHORT, 0.1, -CUTDEPTH);
+					-0.5 * STICKER_SHORT, 0.1, -CUT_DEPTH);
 			}
 			if (right != NO_FACE && bottom != NO_FACE) {
 				DrawOrientLine(w, BACK_FACE,
 					w->skewb.cubeLoc[BACK_FACE][0].rotation,
 					0.5,
-					0.1, -0.5 * STICKERSHORT, -CUTDEPTH);
+					0.1, -0.5 * STICKER_SHORT, -CUT_DEPTH);
 			}
 			if (left != NO_FACE && bottom != NO_FACE) {
 				DrawOrientLine(w, BACK_FACE,
 					w->skewb.cubeLoc[BACK_FACE][3].rotation,
 					0.5,
-					-0.5 * STICKERSHORT, -0.1, -CUTDEPTH);
+					-0.5 * STICKER_SHORT, -0.1, -CUT_DEPTH);
 			}
 		}
 		glPopMatrix();
@@ -1113,20 +1113,20 @@ DrawCubit(SkewbGLWidget w,
 		pickColor(w, front, mono);
 		glNormal3f(0.0, 0.0, 1.0);
 		if (top != NO_FACE) {
-			glVertex3f(STICKERSHORT, STICKERLONG, STICKERDEPTH);
-			glVertex3f(-STICKERSHORT, STICKERLONG, STICKERDEPTH);
+			glVertex3f(STICKER_SHORT, STICKER_LONG, STICKER_DEPTH);
+			glVertex3f(-STICKER_SHORT, STICKER_LONG, STICKER_DEPTH);
 		}
 		if (left != NO_FACE) {
-			glVertex3f(-STICKERLONG, STICKERSHORT, STICKERDEPTH);
-			glVertex3f(-STICKERLONG, -STICKERSHORT, STICKERDEPTH);
+			glVertex3f(-STICKER_LONG, STICKER_SHORT, STICKER_DEPTH);
+			glVertex3f(-STICKER_LONG, -STICKER_SHORT, STICKER_DEPTH);
 		}
 		if (bottom != NO_FACE) {
-			glVertex3f(-STICKERSHORT, -STICKERLONG, STICKERDEPTH);
-			glVertex3f(STICKERSHORT, -STICKERLONG, STICKERDEPTH);
+			glVertex3f(-STICKER_SHORT, -STICKER_LONG, STICKER_DEPTH);
+			glVertex3f(STICKER_SHORT, -STICKER_LONG, STICKER_DEPTH);
 		}
 		if (right != NO_FACE) {
-			glVertex3f(STICKERLONG, -STICKERSHORT, STICKERDEPTH);
-			glVertex3f(STICKERLONG, STICKERSHORT, STICKERDEPTH);
+			glVertex3f(STICKER_LONG, -STICKER_SHORT, STICKER_DEPTH);
+			glVertex3f(STICKER_LONG, STICKER_SHORT, STICKER_DEPTH);
 		}
 		glEnd();
 		if (w->skewb.orient) {
@@ -1134,25 +1134,25 @@ DrawCubit(SkewbGLWidget w,
 				DrawOrientLine(w, FRONT_FACE,
 					w->skewb.cubeLoc[FRONT_FACE][0].rotation,
 					0.5,
-					0.1, 0.5 * STICKERSHORT, CUTDEPTH);
+					0.1, 0.5 * STICKER_SHORT, CUT_DEPTH);
 			}
 			if (left != NO_FACE && top != NO_FACE) {
 				DrawOrientLine(w, FRONT_FACE,
 					w->skewb.cubeLoc[FRONT_FACE][3].rotation,
 					0.5,
-					-0.5 * STICKERSHORT, 0.1, CUTDEPTH);
+					-0.5 * STICKER_SHORT, 0.1, CUT_DEPTH);
 			}
 			if (right != NO_FACE && bottom != NO_FACE) {
 				DrawOrientLine(w, FRONT_FACE,
 					w->skewb.cubeLoc[FRONT_FACE][1].rotation,
 					0.5,
-					0.1, -0.5 * STICKERSHORT, CUTDEPTH);
+					0.1, -0.5 * STICKER_SHORT, CUT_DEPTH);
 			}
 			if (left != NO_FACE && bottom != NO_FACE) {
 				DrawOrientLine(w, FRONT_FACE,
 					w->skewb.cubeLoc[FRONT_FACE][2].rotation,
 					0.5,
-					-0.5 * STICKERSHORT, -0.1, CUTDEPTH);
+					-0.5 * STICKER_SHORT, -0.1, CUT_DEPTH);
 			}
 		}
 		glPopMatrix();
@@ -1163,20 +1163,20 @@ DrawCubit(SkewbGLWidget w,
 		pickColor(w, left, mono);
 		glNormal3f(-1.0, 0.0, 0.0);
 		if (front != NO_FACE) {
-			glVertex3f(-STICKERDEPTH, -STICKERSHORT, STICKERLONG);
-			glVertex3f(-STICKERDEPTH, STICKERSHORT, STICKERLONG);
+			glVertex3f(-STICKER_DEPTH, -STICKER_SHORT, STICKER_LONG);
+			glVertex3f(-STICKER_DEPTH, STICKER_SHORT, STICKER_LONG);
 		}
 		if (top != NO_FACE) {
-			glVertex3f(-STICKERDEPTH, STICKERLONG, STICKERSHORT);
-			glVertex3f(-STICKERDEPTH, STICKERLONG, -STICKERSHORT);
+			glVertex3f(-STICKER_DEPTH, STICKER_LONG, STICKER_SHORT);
+			glVertex3f(-STICKER_DEPTH, STICKER_LONG, -STICKER_SHORT);
 		}
 		if (back != NO_FACE) {
-			glVertex3f(-STICKERDEPTH, STICKERSHORT, -STICKERLONG);
-			glVertex3f(-STICKERDEPTH, -STICKERSHORT, -STICKERLONG);
+			glVertex3f(-STICKER_DEPTH, STICKER_SHORT, -STICKER_LONG);
+			glVertex3f(-STICKER_DEPTH, -STICKER_SHORT, -STICKER_LONG);
 		}
 		if (bottom != NO_FACE) {
-			glVertex3f(-STICKERDEPTH, -STICKERLONG, -STICKERSHORT);
-			glVertex3f(-STICKERDEPTH, -STICKERLONG, STICKERSHORT);
+			glVertex3f(-STICKER_DEPTH, -STICKER_LONG, -STICKER_SHORT);
+			glVertex3f(-STICKER_DEPTH, -STICKER_LONG, STICKER_SHORT);
 		}
 		glEnd();
 		if (w->skewb.orient) {
@@ -1184,25 +1184,25 @@ DrawCubit(SkewbGLWidget w,
 				DrawOrientLine(w, LEFT_FACE,
 					w->skewb.cubeLoc[LEFT_FACE][0].rotation,
 					0.5,
-					-CUTDEPTH, 0.1, 0.5 * STICKERSHORT);
+					-CUT_DEPTH, 0.1, 0.5 * STICKER_SHORT);
 			}
 			if (back != NO_FACE && top != NO_FACE) {
 				DrawOrientLine(w, LEFT_FACE,
 					w->skewb.cubeLoc[LEFT_FACE][3].rotation,
 					0.5,
-					-CUTDEPTH, 0.5 * STICKERSHORT, -0.1);
+					-CUT_DEPTH, 0.5 * STICKER_SHORT, -0.1);
 			}
 			if (front != NO_FACE && bottom != NO_FACE) {
 				DrawOrientLine(w, LEFT_FACE,
 					w->skewb.cubeLoc[LEFT_FACE][1].rotation,
 					0.5,
-					-CUTDEPTH, -0.1, 0.5 * STICKERSHORT);
+					-CUT_DEPTH, -0.1, 0.5 * STICKER_SHORT);
 			}
 			if (back != NO_FACE && bottom != NO_FACE) {
 				DrawOrientLine(w, LEFT_FACE,
 					w->skewb.cubeLoc[LEFT_FACE][2].rotation,
 					0.5,
-					-CUTDEPTH, -0.5 * STICKERSHORT, -0.1);
+					-CUT_DEPTH, -0.5 * STICKER_SHORT, -0.1);
 			}
 		}
 		glPopMatrix();
@@ -1213,20 +1213,20 @@ DrawCubit(SkewbGLWidget w,
 		pickColor(w, right, mono);
 		glNormal3f(1.0, 0.0, 0.0);
 		if (front != NO_FACE) {
-			glVertex3f(STICKERDEPTH, STICKERSHORT, STICKERLONG);
-			glVertex3f(STICKERDEPTH, -STICKERSHORT, STICKERLONG);
+			glVertex3f(STICKER_DEPTH, STICKER_SHORT, STICKER_LONG);
+			glVertex3f(STICKER_DEPTH, -STICKER_SHORT, STICKER_LONG);
 		}
 		if (top != NO_FACE) {
-			glVertex3f(STICKERDEPTH, STICKERLONG, -STICKERSHORT);
-			glVertex3f(STICKERDEPTH, STICKERLONG, STICKERSHORT);
+			glVertex3f(STICKER_DEPTH, STICKER_LONG, -STICKER_SHORT);
+			glVertex3f(STICKER_DEPTH, STICKER_LONG, STICKER_SHORT);
 		}
 		if (back != NO_FACE) {
-			glVertex3f(STICKERDEPTH, -STICKERSHORT, -STICKERLONG);
-			glVertex3f(STICKERDEPTH, STICKERSHORT, -STICKERLONG);
+			glVertex3f(STICKER_DEPTH, -STICKER_SHORT, -STICKER_LONG);
+			glVertex3f(STICKER_DEPTH, STICKER_SHORT, -STICKER_LONG);
 		}
 		if (bottom != NO_FACE) {
-			glVertex3f(STICKERDEPTH, -STICKERLONG, STICKERSHORT);
-			glVertex3f(STICKERDEPTH, -STICKERLONG, -STICKERSHORT);
+			glVertex3f(STICKER_DEPTH, -STICKER_LONG, STICKER_SHORT);
+			glVertex3f(STICKER_DEPTH, -STICKER_LONG, -STICKER_SHORT);
 		}
 		glEnd();
 		if (w->skewb.orient) {
@@ -1234,25 +1234,25 @@ DrawCubit(SkewbGLWidget w,
 				DrawOrientLine(w, RIGHT_FACE,
 					w->skewb.cubeLoc[RIGHT_FACE][3].rotation,
 					0.5,
-					CUTDEPTH, 0.1, 0.5 * STICKERSHORT);
+					CUT_DEPTH, 0.1, 0.5 * STICKER_SHORT);
 			}
 			if (back != NO_FACE && top != NO_FACE) {
 				DrawOrientLine(w, RIGHT_FACE,
 					w->skewb.cubeLoc[RIGHT_FACE][0].rotation,
 					0.5,
-					CUTDEPTH, 0.5 * STICKERSHORT, -0.1);
+					CUT_DEPTH, 0.5 * STICKER_SHORT, -0.1);
 			}
 			if (front != NO_FACE && bottom != NO_FACE) {
 				DrawOrientLine(w, RIGHT_FACE,
 					w->skewb.cubeLoc[RIGHT_FACE][2].rotation,
 					0.5,
-					CUTDEPTH, -0.1, 0.5 * STICKERSHORT);
+					CUT_DEPTH, -0.1, 0.5 * STICKER_SHORT);
 			}
 			if (back != NO_FACE && bottom != NO_FACE) {
 				DrawOrientLine(w, RIGHT_FACE,
 					w->skewb.cubeLoc[RIGHT_FACE][1].rotation,
 					0.5,
-					CUTDEPTH, -0.5 * STICKERSHORT, -0.1);
+					CUT_DEPTH, -0.5 * STICKER_SHORT, -0.1);
 			}
 		}
 		glPopMatrix();
@@ -1263,20 +1263,20 @@ DrawCubit(SkewbGLWidget w,
 		pickColor(w, bottom, mono);
 		glNormal3f(0.0, -1.0, 0.0);
 		if (left != NO_FACE) {
-			glVertex3f(-STICKERLONG, -STICKERDEPTH, STICKERSHORT);
-			glVertex3f(-STICKERLONG, -STICKERDEPTH, -STICKERSHORT);
+			glVertex3f(-STICKER_LONG, -STICKER_DEPTH, STICKER_SHORT);
+			glVertex3f(-STICKER_LONG, -STICKER_DEPTH, -STICKER_SHORT);
 		}
 		if (front != NO_FACE) {
-			glVertex3f(STICKERSHORT, -STICKERDEPTH, STICKERLONG);
-			glVertex3f(-STICKERSHORT, -STICKERDEPTH, STICKERLONG);
+			glVertex3f(STICKER_SHORT, -STICKER_DEPTH, STICKER_LONG);
+			glVertex3f(-STICKER_SHORT, -STICKER_DEPTH, STICKER_LONG);
 		}
 		if (right != NO_FACE) {
-			glVertex3f(STICKERLONG, -STICKERDEPTH, -STICKERSHORT);
-			glVertex3f(STICKERLONG, -STICKERDEPTH, STICKERSHORT);
+			glVertex3f(STICKER_LONG, -STICKER_DEPTH, -STICKER_SHORT);
+			glVertex3f(STICKER_LONG, -STICKER_DEPTH, STICKER_SHORT);
 		}
 		if (back != NO_FACE) {
-			glVertex3f(-STICKERSHORT, -STICKERDEPTH, -STICKERLONG);
-			glVertex3f(STICKERSHORT, -STICKERDEPTH, -STICKERLONG);
+			glVertex3f(-STICKER_SHORT, -STICKER_DEPTH, -STICKER_LONG);
+			glVertex3f(STICKER_SHORT, -STICKER_DEPTH, -STICKER_LONG);
 		}
 		glEnd();
 		if (w->skewb.orient) {
@@ -1284,25 +1284,25 @@ DrawCubit(SkewbGLWidget w,
 				DrawOrientLine(w, BOTTOM_FACE,
 					w->skewb.cubeLoc[BOTTOM_FACE][1].rotation,
 					0.5,
-					0.5 * STICKERSHORT, -CUTDEPTH, -0.1);
+					0.5 * STICKER_SHORT, -CUT_DEPTH, -0.1);
 			}
 			if (left != NO_FACE && back != NO_FACE) {
 				DrawOrientLine(w, BOTTOM_FACE,
 					w->skewb.cubeLoc[BOTTOM_FACE][2].rotation,
 					0.5,
-					-0.5 * STICKERSHORT, -CUTDEPTH, -0.1);
+					-0.5 * STICKER_SHORT, -CUT_DEPTH, -0.1);
 			}
 			if (right != NO_FACE && front != NO_FACE) {
 				DrawOrientLine(w, BOTTOM_FACE,
 					w->skewb.cubeLoc[BOTTOM_FACE][0].rotation,
 					0.5,
-					0.5 * STICKERSHORT, -CUTDEPTH, 0.1);
+					0.5 * STICKER_SHORT, -CUT_DEPTH, 0.1);
 			}
 			if (left != NO_FACE && front != NO_FACE) {
 				DrawOrientLine(w, BOTTOM_FACE,
 					w->skewb.cubeLoc[BOTTOM_FACE][3].rotation,
 					0.5,
-					-0.5 * STICKERSHORT, -CUTDEPTH, 0.1);
+					-0.5 * STICKER_SHORT, -CUT_DEPTH, 0.1);
 			}
 		}
 		glPopMatrix();
@@ -1313,20 +1313,20 @@ DrawCubit(SkewbGLWidget w,
 		pickColor(w, top, mono);
 		glNormal3f(0.0, 1.0, 0.0);
 		if (left != NO_FACE) {
-			glVertex3f(-STICKERLONG, STICKERDEPTH, -STICKERSHORT);
-			glVertex3f(-STICKERLONG, STICKERDEPTH, STICKERSHORT);
+			glVertex3f(-STICKER_LONG, STICKER_DEPTH, -STICKER_SHORT);
+			glVertex3f(-STICKER_LONG, STICKER_DEPTH, STICKER_SHORT);
 		}
 		if (front != NO_FACE) {
-			glVertex3f(-STICKERSHORT, STICKERDEPTH, STICKERLONG);
-			glVertex3f(STICKERSHORT, STICKERDEPTH, STICKERLONG);
+			glVertex3f(-STICKER_SHORT, STICKER_DEPTH, STICKER_LONG);
+			glVertex3f(STICKER_SHORT, STICKER_DEPTH, STICKER_LONG);
 		}
 		if (right != NO_FACE) {
-			glVertex3f(STICKERLONG, STICKERDEPTH, STICKERSHORT);
-			glVertex3f(STICKERLONG, STICKERDEPTH, -STICKERSHORT);
+			glVertex3f(STICKER_LONG, STICKER_DEPTH, STICKER_SHORT);
+			glVertex3f(STICKER_LONG, STICKER_DEPTH, -STICKER_SHORT);
 		}
 		if (back != NO_FACE) {
-			glVertex3f(STICKERSHORT, STICKERDEPTH, -STICKERLONG);
-			glVertex3f(-STICKERSHORT, STICKERDEPTH, -STICKERLONG);
+			glVertex3f(STICKER_SHORT, STICKER_DEPTH, -STICKER_LONG);
+			glVertex3f(-STICKER_SHORT, STICKER_DEPTH, -STICKER_LONG);
 		}
 		glEnd();
 		if (w->skewb.orient) {
@@ -1334,25 +1334,25 @@ DrawCubit(SkewbGLWidget w,
 				DrawOrientLine(w, TOP_FACE,
 					w->skewb.cubeLoc[TOP_FACE][0].rotation,
 					0.5,
-					0.5 * STICKERSHORT, CUTDEPTH, -0.1);
+					0.5 * STICKER_SHORT, CUT_DEPTH, -0.1);
 			}
 			if (left != NO_FACE && back != NO_FACE) {
 				DrawOrientLine(w, TOP_FACE,
 					w->skewb.cubeLoc[TOP_FACE][3].rotation,
 					0.5,
-					-0.5 * STICKERSHORT, CUTDEPTH, -0.1);
+					-0.5 * STICKER_SHORT, CUT_DEPTH, -0.1);
 			}
 			if (right != NO_FACE && front != NO_FACE) {
 				DrawOrientLine(w, TOP_FACE,
 					w->skewb.cubeLoc[TOP_FACE][1].rotation,
 					0.5,
-					0.5 * STICKERSHORT, CUTDEPTH, 0.1);
+					0.5 * STICKER_SHORT, CUT_DEPTH, 0.1);
 			}
 			if (left != NO_FACE && front != NO_FACE) {
 				DrawOrientLine(w, TOP_FACE,
 					w->skewb.cubeLoc[TOP_FACE][2].rotation,
 					0.5,
-					-0.5 * STICKERSHORT, CUTDEPTH, 0.1);
+					-0.5 * STICKER_SHORT, CUT_DEPTH, 0.1);
 			}
 		}
 		glPopMatrix();
@@ -1418,7 +1418,7 @@ DrawCube(SkewbGLWidget w)
 		glRotatef(-90.0, 1, 0, 0);
 		DRAW_STICKERLESS_FACIT();
 		glPopMatrix();
-		for (i = 0; i < MAXFACES; i++) {
+		for (i = 0; i < MAX_FACES; i++) {
 			glPushMatrix();
 			DrawFacit(w, i);
 			glPopMatrix();
@@ -1779,7 +1779,7 @@ static
 #endif
 void
 ExposePuzzleGL(
-#ifdef WINVER 
+#ifdef WINVER
 SkewbGLWidget w
 #else
 Widget renew, XEvent *event, Region region
