@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1993 - 2007	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1993 - 2007	David A. Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -239,32 +239,32 @@ static const char solveHelp[] = {
 #endif
 
 #define NEVER (-1)
-#define FILENAMELEN 1024
-#define USERNAMELEN 120
-#define MESSAGELEN (USERNAMELEN+64)
-#define TITLELEN 2048
+#define FILE_NAME_LENGTH 1024
+#define USER_NAME_LENGTH 120
+#define MESSAGE_LENGTH (USER_NAME_LENGTH+64)
+#define TITLE_LENGTH 2048
 #define NOACCESS "noaccess"
 #define NOBODY "nobody"
 
 typedef struct {
 	int score;
-	char name[USERNAMELEN];
+	char name[USER_NAME_LENGTH];
 } PuzzleRecord;
 
 static PuzzleRecord puzzleRecord[2];
 static int movesDsp = 0;
-static char messageDsp[MESSAGELEN] = "Welcome";
-static char recordDsp[MESSAGELEN] = "NOT RECORDED";
+static char messageDsp[MESSAGE_LENGTH] = "Welcome";
+static char recordDsp[MESSAGE_LENGTH] = "NOT RECORDED";
 #ifndef HAVE_MOTIF
-static char titleDsp[TITLELEN] = "";
+static char titleDsp[TITLE_LENGTH] = "";
 #endif
-static char scoreFileName[FILENAMELEN] = SCOREFILE;
-static char fileName[FILENAMELEN];
+static char scoreFileName[FILE_NAME_LENGTH] = SCOREFILE;
+static char fileName[FILE_NAME_LENGTH];
 static Boolean randomized = False;
 #ifdef WINVER
-#define MAXPROGNAME 80
-static char progDsp[MAXPROGNAME] = TITLE;
-static char userNameDsp[USERNAMELEN] = "Guest";
+#define PROGRAM_NAME_LENGTH 80
+static char progDsp[PROGRAM_NAME_LENGTH] = TITLE;
+static char userNameDsp[USER_NAME_LENGTH] = "Guest";
 #else
 #ifdef HAVE_MOTIF
 static Widget moves, record, message, orientizeSwitch, practiceSwitch;
@@ -285,7 +285,7 @@ static Widget topLevel, puzzle2d, puzzle3d;
 static Widget puzzleGL;
 #endif
 static char *progDsp;
-static char userNameDsp[USERNAMELEN] = "";
+static char userNameDsp[USER_NAME_LENGTH] = "";
 
 #ifdef HAVE_MOTIF
 static void
@@ -324,7 +324,7 @@ InitRecords(void)
 
 	for (orient = 0; orient < 2; orient++) {
 		puzzleRecord[orient].score = NEVER;
-		(void) strncpy(puzzleRecord[orient].name, NOACCESS, USERNAMELEN);
+		(void) strncpy(puzzleRecord[orient].name, NOACCESS, USER_NAME_LENGTH);
 	}
 }
 
@@ -333,7 +333,7 @@ ReadRecords(void)
 {
 	FILE *fp;
 	int n, orient;
-	char userName[USERNAMELEN];
+	char userName[USER_NAME_LENGTH];
 	char *buf1 = NULL, *buf2 = NULL;
 	char *fname, *lname;
 
@@ -343,9 +343,9 @@ ReadRecords(void)
 	stringCat(&buf2, buf1, SCOREFILE);
 	free(buf1);
 	fname = buf2;
-	(void) strncpy(fileName, lname, USERNAMELEN);
+	(void) strncpy(fileName, lname, USER_NAME_LENGTH);
 	if ((fp = fopen(fileName, "r")) == NULL) {
-		(void) strncpy(fileName, fname, USERNAMELEN);
+		(void) strncpy(fileName, fname, USER_NAME_LENGTH);
 		/* Try installed directory. */
 		if ((fp = fopen(fileName, "r")) == NULL) {
 			stringCat(&buf1, "Can not read ", fname);
@@ -380,7 +380,7 @@ ReadRecords(void)
 				puzzleRecord[orient].score <= NEVER) {
 			puzzleRecord[orient].score = n;
 			(void) strncpy(puzzleRecord[orient].name, userName,
-				USERNAMELEN);
+				USER_NAME_LENGTH);
 		}
 	}
 	(void) fclose(fp);
@@ -402,9 +402,9 @@ WriteRecords(void)
 	{
 #if HAVE_FCNTL_H
 		int lfd;
-		char lockFile[FILENAMELEN];
+		char lockFile[FILE_NAME_LENGTH];
 
-		(void) strncpy(lockFile, fileName, FILENAMELEN - 6);
+		(void) strncpy(lockFile, fileName, FILE_NAME_LENGTH - 6);
 		(void) strcat(lockFile, ".lock");
 		while (((lfd = open(lockFile, O_CREAT | O_EXCL, 0644)) < 0) &&
 				errno == EEXIST)
@@ -437,7 +437,7 @@ PrintRecord(Boolean orient, Boolean practice)
 	int i = (orient) ? 1 : 0;
 
 	if (practice) {
-		(void) strncpy(recordDsp, "practice", MESSAGELEN);
+		(void) strncpy(recordDsp, "practice", MESSAGE_LENGTH);
 	} else if (puzzleRecord[i].score <= NEVER) {
 		(void) sprintf(recordDsp, "NEVER %s", NOACCESS);
 	} else {
@@ -459,7 +459,7 @@ MakeEquivalent(String *userName, String *scoreFile,
 	Boolean mono, reverse;
 	Boolean scoreOnly, versionOnly;
 	Pixel foreground, background, pieceBorder;
-	String faceColor[MAXFACES];
+	String faceColor[MAX_FACES];
 
 	XtVaGetValues(puzzle2d,
 		XtNuserName, userName,
@@ -484,7 +484,7 @@ MakeEquivalent(String *userName, String *scoreFile,
 		exit(0);
 	}
 	if (strcmp(*scoreFile, ""))
-		(void) strncpy(scoreFileName, *scoreFile, FILENAMELEN);
+		(void) strncpy(scoreFileName, *scoreFile, FILE_NAME_LENGTH);
 	if (scoreOnly) {
 		InitRecords();
 		ReadRecords();
@@ -575,12 +575,12 @@ HandleSolved(int counter, Boolean orient)
 	if (counter < puzzleRecord[i].score || puzzleRecord[i].score <= NEVER) {
 		ReadRecords();	/* Maybe its been updated by another */
 		puzzleRecord[i].score = counter;
-		(void) strncpy(puzzleRecord[i].name, userNameDsp, USERNAMELEN);
+		(void) strncpy(puzzleRecord[i].name, userNameDsp, USER_NAME_LENGTH);
 		if (orient && (counter < puzzleRecord[!i].score ||
 				puzzleRecord[!i].score <= NEVER)) {
 			puzzleRecord[!i].score = counter;
 			(void) strncpy(puzzleRecord[!i].name, userNameDsp,
-				USERNAMELEN);
+				USER_NAME_LENGTH);
 		}
 		WriteRecords();
 		PrintRecord(orient, False);
@@ -612,7 +612,7 @@ void
 	dim = w->skewb.dim;
 	SET_STARTED(w, False);
 	if (strcmp(scoreFile, ""))
-		(void) strncpy(scoreFileName, scoreFile, FILENAMELEN);
+		(void) strncpy(scoreFileName, scoreFile, FILE_NAME_LENGTH);
 #else
 	MakeEquivalent(&userName, &scoreFile, &orient, &practice);
 #ifdef HAVE_MOTIF
@@ -623,13 +623,13 @@ void
 	InitRecords();
 	ReadRecords();
 #ifndef WINVER
-	(void) strncpy(userNameDsp, userName, USERNAMELEN);
+	(void) strncpy(userNameDsp, userName, USER_NAME_LENGTH);
 #endif
 	if (!strcmp(userName, "") || !strcmp(userName, "(null)") ||
 			!strcmp(userName, NOACCESS) ||
 			!strcmp(userName, NOBODY)) {
 #ifdef WINVER
-		(void) strncpy(userNameDsp, userName, USERNAMELEN);
+		(void) strncpy(userNameDsp, userName, USER_NAME_LENGTH);
 #else
 		char *login = getlogin();
 
@@ -781,14 +781,14 @@ CallbackPuzzle(Widget w, caddr_t clientData, skewbCallbackStruct *callData)
 #ifdef HAVE_MOTIF
 		XtManageChild(solveDialog);
 #else
-		(void) strncpy(messageDsp, solveHelp, MESSAGELEN);
+		(void) strncpy(messageDsp, solveHelp, MESSAGE_LENGTH);
 #endif
 #endif
 		break;
 	case ACTION_RESTORE:
 		if (practice) {
 			(void) strncpy(recordDsp, "practice",
-				MESSAGELEN);
+				MESSAGE_LENGTH);
 #ifdef HAVE_MOTIF
 			PrintState(record, recordDsp);
 #endif
@@ -827,10 +827,10 @@ CallbackPuzzle(Widget w, caddr_t clientData, skewbCallbackStruct *callData)
 	case ACTION_ILLEGAL:
 		if (practice || randomized)
 			(void) strncpy(messageDsp, "Illegal move",
-				MESSAGELEN);
+				MESSAGE_LENGTH);
 		else
 			(void) strncpy(messageDsp,
-				"Randomize to start", MESSAGELEN);
+				"Randomize to start", MESSAGE_LENGTH);
 		break;
 #ifndef WINVER
 	case ACTION_MOVED:
@@ -873,7 +873,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, skewbCallbackStruct *callData)
 				"Congratulations %s!!", userNameDsp);
 		else
 			(void) strncpy(messageDsp, "Solved!",
-				MESSAGELEN);
+				MESSAGE_LENGTH);
 		SET_STARTED(w, False);
 #ifndef WINVER
 #ifdef HAVE_OPENGL
@@ -900,7 +900,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, skewbCallbackStruct *callData)
 		practice = !practice;
 		if (!practice)
 			(void) strncpy(messageDsp, "Randomize to start",
-				MESSAGELEN);
+				MESSAGE_LENGTH);
 		PrintRecord(orient, practice);
 #ifdef WINVER
 		w->skewb.practice = practice;
@@ -953,7 +953,7 @@ CallbackPuzzle(Widget w, caddr_t clientData, skewbCallbackStruct *callData)
 			XtVaGetValues(puzzleGL,
 				XtNview, &view, NULL);
 #endif
-			view = (view + 1) % (2 * MAXVIEWS);
+			view = (view + 1) % (2 * MAX_VIEWS);
 #ifdef WINVER
 			w->skewb.view = view;
 #else
@@ -1514,7 +1514,7 @@ PracticeToggle(Widget w, XtPointer clientData,
 	if (practice)
 		(void) strcpy(messageDsp, "");
 	else
-		(void) strncpy(messageDsp, "Randomize to start", MESSAGELEN);
+		(void) strncpy(messageDsp, "Randomize to start", MESSAGE_LENGTH);
 	PrintState(message, messageDsp);
 }
 
@@ -1540,7 +1540,7 @@ static Widget
 createQuery(Widget w, char *text, char *title, XtCallbackProc callback)
 {
 	Widget button, messageBox;
-	char titleDsp[FILENAMELEN + 8];
+	char titleDsp[FILE_NAME_LENGTH + 8];
 	XmString titleString = NULL, messageString = NULL;
 	static XmStringCharSet charSet =
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
@@ -1566,7 +1566,7 @@ static Widget
 createHelp(Widget w, char *text, char *title)
 {
 	Widget button, messageBox;
-	char titleDsp[FILENAMELEN + 8];
+	char titleDsp[FILE_NAME_LENGTH + 8];
 	XmString titleString = NULL, messageString = NULL, buttonString = NULL;
 	static XmStringCharSet charSet =
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
@@ -1826,12 +1826,12 @@ main(int argc, char **argv)
 		XmNpacking, XmPACK_COLUMN, NULL);
 	orientizeSwitch = XtVaCreateManagedWidget("Oriented",
 		xmToggleButtonWidgetClass, switchRowCol,
-		XmNset, DEFAULTORIENT, NULL);
+		XmNset, DEFAULT_ORIENT, NULL);
 	XtAddCallback(orientizeSwitch, XmNvalueChangedCallback,
 		(XtCallbackProc) OrientToggle, (XtPointer) NULL);
 	practiceSwitch = XtVaCreateManagedWidget("Practice",
 		xmToggleButtonWidgetClass, switchRowCol,
-		XmNset, DEFAULTPRACTICE, NULL);
+		XmNset, DEFAULT_PRACTICE, NULL);
 	XtAddCallback(practiceSwitch, XmNvalueChangedCallback,
 		(XtCallbackProc) PracticeToggle, (XtPointer) NULL);
 	messageRowCol = XtVaCreateManagedWidget("messageRowCol",
