@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 2007	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1994 - 2008	David A. Bagley, bagleyd@tux.org
 #
 #		   All Rights Reserved
 #
@@ -251,7 +251,7 @@ static XtResource resourcesThreeD[] = {
 	 XtRString, (caddr_t) "gray75" /* XtDefaultForeground*/},
 	{XtNdelay, XtCDelay, XtRInt, sizeof (int),
 	 XtOffset(ThreeDWidget, threed.delay),
-	 XtRString, (caddr_t) "50"}, /* DEFAULTDELAY */
+	 XtRString, (caddr_t) "10"}, /* DEFAULT_DELAY */
 	{XtNsound, XtCSound, XtRBoolean, sizeof (Boolean),
 	 XtOffset(ThreeDWidget, threed.sound),
 	 XtRString, (caddr_t) "FALSE"},
@@ -304,48 +304,49 @@ static XtResource resourcesThreeD[] = {
 	 XtOffset(ThreeDWidget, threed.pixmapSize),
 	 XtRString, (caddr_t) "64"},
 	{XtNselectCallback, XtCCallback, XtRCallback, sizeof (caddr_t),
-	 XtOffset(ThreeDWidget, threed.select), XtRCallback, NULL}
+	 XtOffset(ThreeDWidget, threed.select), XtRCallback, (caddr_t) NULL}
 };
 
-ThreeDClassRec threedClassRec = {
+ThreeDClassRec threedClassRec =
+{
 	{
-	 (WidgetClass) & widgetClassRec,	/* superclass */
-	 (char *) "ThreeD",	/* class name */
-	 sizeof (ThreeDRec),	/* widget size */
-	 NULL,		/* class initialize */
-	 NULL,		/* class part initialize */
-	 FALSE,		/* class inited */
-	 (XtInitProc) InitializeThreeD,	/* initialize */
-	 NULL,		/* initialize hook */
-	 XtInheritRealize,	/* realize */
-	 actionsListThreeD,	/* actions */
-	 XtNumber(actionsListThreeD),	/* num actions */
-	 resourcesThreeD,	/* resources */
-	 XtNumber(resourcesThreeD),	/* num resources */
-	 NULLQUARK,	/* xrm class */
-	 TRUE,		/* compress motion */
-	 TRUE,		/* compress exposure */
-	 TRUE,		/* compress enterleave */
-	 TRUE,		/* visible interest */
-	 (XtWidgetProc) DestroyThreeD,	/* destroy */
-	 (XtWidgetProc) ResizeThreeD,	/* resize */
-	 (XtExposeProc) ExposeThreeD,	/* expose */
-	 (XtSetValuesFunc) SetValuesThreeD,	/* set values */
-	 NULL,		/* set values hook */
-	 XtInheritSetValuesAlmost,	/* set values almost */
-	 NULL,		/* get values hook */
-	 NULL,		/* accept focus */
-	 XtVersion,	/* version */
-	 NULL,		/* callback private */
-	 defaultTranslationsThreeD,	/* tm table */
-	 NULL,		/* query geometry */
-	 NULL,		/* display accelerator */
-	 NULL		/* extension */
+		 (WidgetClass) & widgetClassRec,	/* superclass */
+		 (char *) "ThreeD",	/* class name */
+		 sizeof (ThreeDRec),	/* widget size */
+		 NULL,		/* class initialize */
+		 NULL,		/* class part initialize */
+		 FALSE,		/* class inited */
+		 (XtInitProc) InitializeThreeD,	/* initialize */
+		 NULL,		/* initialize hook */
+		 XtInheritRealize,	/* realize */
+		 actionsListThreeD,	/* actions */
+		 XtNumber(actionsListThreeD),	/* num actions */
+		 resourcesThreeD,	/* resources */
+		 XtNumber(resourcesThreeD),	/* num resources */
+		 NULLQUARK,	/* xrm class */
+		 TRUE,		/* compress motion */
+		 TRUE,		/* compress exposure */
+		 TRUE,		/* compress enterleave */
+		 TRUE,		/* visible interest */
+		 (XtWidgetProc) DestroyThreeD,	/* destroy */
+		 (XtWidgetProc) ResizeThreeD,	/* resize */
+		 (XtExposeProc) ExposeThreeD,	/* expose */
+		 (XtSetValuesFunc) SetValuesThreeD,	/* set values */
+		 NULL,		/* set values hook */
+		 XtInheritSetValuesAlmost,	/* set values almost */
+		 NULL,		/* get values hook */
+		 NULL,		/* accept focus */
+		 XtVersion,	/* version */
+		 NULL,		/* callback private */
+		 defaultTranslationsThreeD,	/* tm table */
+		 NULL,		/* query geometry */
+		 NULL,		/* display accelerator */
+		 NULL		/* extension */
 	 }
 	,
 	{
-	 0		/* ignore */
-	 }
+		0		/* ignore */
+	}
 };
 
 WidgetClass threedWidgetClass = (WidgetClass) & threedClassRec;
@@ -374,14 +375,14 @@ CheckGraphicsThreeD(ThreeDWidget w)
 	char *buf1 = NULL, *buf2 = NULL;
 
 	if (w->threed.distance.x < MINDISTANCE ||
-			w->threed.distance.x > MAXDISTANCE) {
-		w->threed.distance.x = (MAXDISTANCE + MINDISTANCE) / 2;
+			w->threed.distance.x > MAX_DISTANCE) {
+		w->threed.distance.x = (MAX_DISTANCE + MINDISTANCE) / 2;
 		intCat(&buf1,
 			"Distance out of bounds, use ",
-			MINDEPTH);
+			MIN_DEPTH);
 		stringCat(&buf2, buf1, "..");
 		free(buf1);
-		intCat(&buf1, buf2, MAXDEPTH);
+		intCat(&buf1, buf2, MAX_DEPTH);
 		free(buf2);
 		stringCat(&buf2, buf1, ", defaulting to ");
 		free(buf1);
@@ -391,14 +392,14 @@ CheckGraphicsThreeD(ThreeDWidget w)
 		free(buf1);
 	}
 	if (w->threed.distance.y < MINDISTANCE ||
-			w->threed.distance.y > MAXDISTANCE) {
-		w->threed.distance.y = (MAXDISTANCE + MINDISTANCE) / 2;
+			w->threed.distance.y > MAX_DISTANCE) {
+		w->threed.distance.y = (MAX_DISTANCE + MINDISTANCE) / 2;
 		intCat(&buf1,
 			"Distance out of bounds, use ",
-			MINDEPTH);
+			MIN_DEPTH);
 		stringCat(&buf2, buf1, "..");
 		free(buf1);
-		intCat(&buf1, buf2, MAXDEPTH);
+		intCat(&buf1, buf2, MAX_DEPTH);
 		free(buf2);
 		stringCat(&buf2, buf1, ", defaulting to ");
 		free(buf1);
@@ -407,15 +408,15 @@ CheckGraphicsThreeD(ThreeDWidget w)
 		DISPLAY_WARNING(buf1);
 		free(buf1);
 	}
-	if (w->threed.distance.z < MINDEPTH ||
-			w->threed.distance.z > MAXDEPTH) {
-		w->threed.distance.z = (MAXDEPTH + MINDEPTH) / 2;
+	if (w->threed.distance.z < MIN_DEPTH ||
+			w->threed.distance.z > MAX_DEPTH) {
+		w->threed.distance.z = (MAX_DEPTH + MIN_DEPTH) / 2;
 		intCat(&buf1,
 			"Distance out of bounds, use ",
-			MINDEPTH);
+			MIN_DEPTH);
 		stringCat(&buf2, buf1, "..");
 		free(buf1);
-		intCat(&buf1, buf2, MAXDEPTH);
+		intCat(&buf1, buf2, MAX_DEPTH);
 		free(buf2);
 		stringCat(&buf2, buf1, ", defaulting to ");
 		free(buf1);
@@ -424,17 +425,17 @@ CheckGraphicsThreeD(ThreeDWidget w)
 		DISPLAY_WARNING(buf1);
 		free(buf1);
 	}
-	if (w->threed.angle.theta < MINDEGREES ||
+	if (w->threed.angle.theta < MIN_DEGREES ||
 			w->threed.angle.theta >= NUM_DEGREES) {
 		w->threed.angle.theta = (NUM_DEGREES +
 			w->threed.angle.theta) % NUM_DEGREES;
 	}
-	if (w->threed.angle.phi < MINDEGREES ||
+	if (w->threed.angle.phi < MIN_DEGREES ||
 			w->threed.angle.phi >= NUM_DEGREES) {
 		w->threed.angle.phi = (NUM_DEGREES +
 			w->threed.angle.phi) % NUM_DEGREES;
 	}
-	if (w->threed.angle.psi < MINDEGREES ||
+	if (w->threed.angle.psi < MIN_DEGREES ||
 			w->threed.angle.psi >= NUM_DEGREES) {
 		w->threed.angle.psi = (NUM_DEGREES +
 			w->threed.angle.psi) % NUM_DEGREES;
@@ -512,7 +513,7 @@ RealizeObject(ThreeDWidget w, Object3D *obj)
 	for (vert = 0; vert < obj->numVertices; vert++) {
 		Vertex *vertex = &(obj->vertex[vert]);
 
- 		vertex->eye.x = obj->local[vert].x +
+		vertex->eye.x = obj->local[vert].x +
 			w->threed.distance.x - obj->origin.x;
 		vertex->eye.y = obj->local[vert].y +
 			w->threed.distance.y - obj->origin.y;
@@ -553,7 +554,7 @@ static void
 DrawObject(ThreeDWidget w, Object3D *obj)
 {
 	int surf, vert, vertex, mapIndex, clickSurface = -1;
-	Point points[MAXPOLYGONVERTICES + 1];
+	Point points[MAX_POLYGON_VERTICES + 1];
 	Pixmap *dr;
 	double s1 = 0.0, s2 = 0.0, s3 = 0.0;
 	Point3D *v1, *v2, *v3;
@@ -563,7 +564,7 @@ DrawObject(ThreeDWidget w, Object3D *obj)
 	/* compute position of object in world */
 	/* if (w->threed.surface) */ {
 #ifdef DEPTHINDEX
- 		OBJ = obj;
+		OBJ = obj;
 #endif
 		(void) qsort((void *) obj->surface,
 			(unsigned int) obj->numSurfaces,
@@ -592,7 +593,7 @@ DrawObject(ThreeDWidget w, Object3D *obj)
 		for (vert = 0; vert < obj->surface[surf].numVertices;
 				vert++, mapIndex++) {
 			vertex = obj->map[mapIndex];
-			if (vert < MAXPOLYGONVERTICES) {
+			if (vert < MAX_POLYGON_VERTICES) {
 				points[vert].x = obj->vertex[vertex].screen.x;
 				points[vert].y = obj->vertex[vertex].screen.y;
 			} else {
@@ -613,7 +614,7 @@ DrawObject(ThreeDWidget w, Object3D *obj)
 		for (vert = 0; vert < obj->surface[surf].numVertices;
 				vert++, mapIndex++) {
 			vertex = obj->map[mapIndex];
-			if (vert < MAXPOLYGONVERTICES) {
+			if (vert < MAX_POLYGON_VERTICES) {
 				/* Its not dynamic but we really after
 				   speed here */
 				points[vert].x = obj->vertex[vertex].screen.x;
@@ -636,6 +637,27 @@ DrawObject(ThreeDWidget w, Object3D *obj)
 		} else {
 			POLYGON(w, *dr, fillGC, lineGC,
 				&points[0], vert, obj->convex, True);
+#ifdef OUTLINE
+#ifndef WINVER
+			if (w->threed.inverseGC[1] != fillGC) {
+				int i;
+
+				for (i = 0; i < vert; i++) {
+					int diff0, diff1;
+
+					diff0 = points[i].y - points[i].x;
+					diff1 = points[i + 1].y - points[i + 1].x;
+					if (diff0 > diff1) {
+						POLYLINE(w, *dr, w->threed.whiteGC,
+							&(points[i]), 2, True);
+					} else {
+						POLYLINE(w, *dr, w->threed.blackGC,
+							&(points[i]), 2, True);
+					}
+				}
+			}
+#endif
+#endif
 		}
 	}
 #ifdef USE_SOUND
@@ -676,22 +698,110 @@ CopyFromBuffer(ThreeDWidget w)
 #endif
 }
 
+#ifndef WINVER
+#define BRIGHT_FACTOR 0.7
+#define DARK_FACTOR 0.7
+
+#define MAX_INTENSITY 0xFFFF
+
+static Pixel
+brighter(ThreeDWidget w, Pixel pixel)
+{
+	XColor color;
+	Colormap colormap = DefaultColormapOfScreen(XtScreen(w));
+	int i = (int) ((1 - BRIGHT_FACTOR) * MAX_INTENSITY);
+
+	color.pixel = pixel;
+	XQueryColor(XtDisplay(w), colormap, &color);
+	if (color.red < i)
+		color.red = i;
+	if (color.green < i)
+		color.green = i;
+	if (color.blue < i)
+		color.blue = i;
+	color.red = (unsigned short) MIN(color.red / BRIGHT_FACTOR, MAX_INTENSITY);
+	color.green = (unsigned short) MIN(color.green / BRIGHT_FACTOR, MAX_INTENSITY);
+	color.blue = (unsigned short) MIN(color.blue / BRIGHT_FACTOR, MAX_INTENSITY);
+	if (XAllocColor(XtDisplay(w), colormap, &color))
+		return color.pixel;
+	return pixel;
+}
+
+static Pixel
+darker(ThreeDWidget w, Pixel pixel)
+{
+	XColor color;
+	Colormap colormap = DefaultColormapOfScreen(XtScreen(w));
+
+	color.pixel = pixel;
+	XQueryColor(XtDisplay(w), colormap, &color);
+	color.red = (unsigned short) (color.red * DARK_FACTOR);
+	color.green = (unsigned short) (color.green * DARK_FACTOR);
+	color.blue = (unsigned short) (color.blue * DARK_FACTOR);
+	if (XAllocColor(XtDisplay(w), colormap, &color))
+		return color.pixel;
+	return pixel;
+}
+
+static void
+Draw3DFrame(const ThreeDWidget w, Pixmap dr, Boolean inside,
+	int x, int y, int width, int height)
+{
+	GC gc;
+
+	if (inside)
+		gc = w->threed.inverseGC[2];
+	else
+		gc = w->threed.inverseGC[1];
+	FILLRECTANGLE(w, dr, gc,
+		x, y, width, 1);
+	FILLRECTANGLE(w, dr, gc,
+		x, y + 1, 1, height - 1);
+	FILLRECTANGLE(w, dr, gc,
+		x + 1, y + 1, width - 2, 1);
+	FILLRECTANGLE(w, dr, gc,
+		x + 1, y + 2, 1, height - 3);
+	if (inside)
+		gc = w->threed.inverseGC[0];
+	else
+		gc = w->threed.inverseGC[1];
+	FILLRECTANGLE(w, dr, gc,
+		x + 1, y + height - 1, width - 1, 1);
+	FILLRECTANGLE(w, dr, gc,
+		x + width - 1, y + 1, 1, height - 2);
+	FILLRECTANGLE(w, dr, gc,
+		x + 2, y + height - 2, width - 3, 1);
+	FILLRECTANGLE(w, dr, gc,
+		x + width - 2, y + 2, 1, height - 4);
+}
+#endif
+
 #if 0
 static void
 EraseFrame(ThreeDWidget w, Pixmap dr, Boolean focus)
 {
-	DRAWRECTANGLE(w, dr, (focus) ? w->threed.frameGC : w->threed.inverseGC,
-		0, 0, w->core.width - 1, w->core.height - 1);
-	FILLRECTANGLE(w, dr, w->threed.inverseGC,
-		1, 1, w->core.width - 2, w->core.height - 2);
+	FILLRECTANGLE(w, dr, w->threed.inverseGC[1],
+		0, 0, w->core.width, w->core.height);
 }
 #endif
 
 static void
 DrawFrame(ThreeDWidget w, Pixmap dr, Boolean focus)
 {
+#ifdef WINVER
 	DRAWRECTANGLE(w, dr, (focus) ? w->threed.frameGC : w->threed.borderGC,
 			0, 0, w->core.width - 1, w->core.height - 1);
+#else
+	Draw3DFrame(w, dr, focus,
+		1, 1, w->core.width - 2, w->core.height - 2);
+	if (focus) {
+		DRAWRECTANGLE(w, dr, w->threed.frameGC,
+			0, 0, w->core.width - 1, w->core.height - 1);
+	} else {
+		DRAWRECTANGLE(w, dr, w->threed.inverseGC[1],
+			0, 0, w->core.width - 1, w->core.height - 1);
+	}
+#endif
 }
 
 static void
@@ -723,13 +833,13 @@ SoundObjects(ThreeDWidget w)
 static char *
 readLine(FILE *fp, char *string, char special)
 {
-#define MAXLINE 1024
-	char buffer[MAXLINE];
+#define MAX_LINE 1024
+	char buffer[MAX_LINE];
 	int length, i = 0, j = 0;
 	Boolean parsed = False;
 
 	for (;;) {
-		if (!fgets(buffer, MAXLINE, fp)) {
+		if (!fgets(buffer, MAX_LINE, fp)) {
 			return NULL;
 		}
 		length = strlen(buffer);
@@ -1034,7 +1144,7 @@ static void
 ReadThreeD(ThreeDWidget w)
 {
 	FILE *fp;
-	char buffer[MAXLINE];
+	char buffer[MAX_LINE];
 	char *string;
 	int i;
 	struct tagColor {
@@ -1089,7 +1199,7 @@ static void
 ReadThreeD(ThreeDWidget w)
 {
 	FILE *fp;
-	char buffer[MAXLINE];
+	char buffer[MAX_LINE];
 	char *buf1 = NULL, *buf2 = NULL;
 	char *fname, *lname, *name;
 
@@ -1124,14 +1234,15 @@ static Boolean
 SetValuesThreeD(Widget current, Widget request, Widget renew)
 {
 	ThreeDWidget c = (ThreeDWidget) current, w = (ThreeDWidget) renew;
-	XGCValues values;
-	XtGCMask valueMask;
 	Boolean redraw = FALSE;
 
 	if (w->threed.numObjects == 0)
 		return False;
 	CheckGraphicsThreeD(w);
 	if (w->threed.foreground != c->threed.foreground) {
+		XGCValues values;
+		XtGCMask valueMask;
+
 		valueMask = GCForeground | GCBackground;
 		values.foreground = w->threed.foreground;
 		values.background = w->core.background_pixel;
@@ -1196,9 +1307,23 @@ SetAllColors(ThreeDWidget w)
 		values.foreground = w->threed.background;
 		values.background = w->threed.foreground;
 	}
-	if (w->threed.inverseGC)
-		XtReleaseGC((Widget) w, w->threed.inverseGC);
-	w->threed.inverseGC = XtGetGC((Widget) w, valueMask, &values);
+	if (w->threed.inverseGC[1])
+		XtReleaseGC((Widget) w, w->threed.inverseGC[1]);
+	w->threed.inverseGC[1] = XtGetGC((Widget) w, valueMask, &values);
+	if (!w->threed.mono) {
+		values.foreground = brighter(w, (w->threed.reverse) ?
+			w->threed.foreground : w->threed.background);
+	}
+	if (w->threed.inverseGC[0])
+		XtReleaseGC((Widget) w, w->threed.inverseGC[0]);
+	w->threed.inverseGC[0] = XtGetGC((Widget) w, valueMask, &values);
+	if (!w->threed.mono) {
+		values.foreground = darker(w, (w->threed.reverse) ?
+			w->threed.foreground : w->threed.background);
+	}
+	if (w->threed.inverseGC[2])
+		XtReleaseGC((Widget) w, w->threed.inverseGC[2]);
+	w->threed.inverseGC[2] = XtGetGC((Widget) w, valueMask, &values);
 	if (w->threed.reverse) {
 		values.background = w->threed.foreground;
 		values.foreground = w->threed.background;
@@ -1261,14 +1386,15 @@ static void
 DestroyThreeD(Widget old)
 {
 	ThreeDWidget w = (ThreeDWidget) old;
-	int color;
+	int i;
 
-	for (color = 0; color < COLORS; color++)
-		XtReleaseGC(old, w->threed.shadeGC[color]);
+	for (i = 0; i < COLORS; i++)
+		XtReleaseGC(old, w->threed.shadeGC[i]);
 	XtReleaseGC(old, w->threed.graphicsGC);
 	XtReleaseGC(old, w->threed.borderGC);
 	XtReleaseGC(old, w->threed.frameGC);
-	XtReleaseGC(old, w->threed.inverseGC);
+	for (i = 0; i < BG_SHADES; i++)
+		XtReleaseGC(old, w->threed.inverseGC[i]);
 	XtRemoveCallbacks(old, XtNselectCallback, w->threed.select);
 }
 #endif
@@ -1333,7 +1459,7 @@ RepaintGraphicsThreeD(ThreeDWidget w)
 #ifndef WINVER
 	/* Clear buffer */
 	XFillRectangle(XtDisplay(w), w->threed.bufferObjects[0],
-		w->threed.inverseGC, 0, 0, w->core.width, w->core.height);
+		w->threed.inverseGC[1], 0, 0, w->core.width, w->core.height);
 #endif
 	RealizeObject(w, &(w->threed.objects[w->threed.object]));
 	DrawObject(w, &(w->threed.objects[w->threed.object]));
@@ -1354,6 +1480,8 @@ ResizeThreeD(ThreeDWidget w)
 	w->threed.center.x = w->core.width / 2;
 	w->threed.center.y = w->core.height / 2;
 	w->threed.size = MIN(w->threed.center.x, w->threed.center.y);
+	w->threed.currentPosition.x = 2 * w->core.width;
+	w->threed.currentPosition.y = 2 * w->core.height;
 }
 
 #ifndef WINVER
@@ -1371,13 +1499,12 @@ Widget request, Widget renew
 	int i;
 
 #ifdef WINVER
-	w->threed.mono = DEFAULTMONO;
-	w->threed.reverse = DEFAULTREVERSE;
+	w->threed.mono = DEFAULT_MONO;
+	w->threed.reverse = DEFAULT_REVERSE;
 	w->threed.bufferObjects[0] = NULL;
 	w->threed.bufferObjects[1] = NULL;
 #else
 	ThreeDWidget w = (ThreeDWidget) renew;
-	int color;
 
 	w->threed.mono = (DefaultDepthOfScreen(XtScreen(w)) < 2 ||
 		w->threed.mono);
@@ -1386,12 +1513,13 @@ Widget request, Widget renew
 	w->threed.colormap = None;
 	w->threed.oldColormap = None;
 	w->threed.fontInfo = NULL;
-	for (color = 0; color < COLORS; color++)
-		w->threed.shadeGC[color] = NULL;
+	for (i = 0; i < COLORS; i++)
+		w->threed.shadeGC[i] = NULL;
 	w->threed.graphicsGC = NULL;
 	w->threed.borderGC = NULL;
 	w->threed.frameGC = NULL;
-	w->threed.inverseGC = NULL;
+	for (i = 0; i < BG_SHADES; i++)
+		w->threed.inverseGC[i] = NULL;
 #endif
 	createTrigTables();
 	ReadThreeD(w);
@@ -1408,14 +1536,12 @@ Widget request, Widget renew
 	w->threed.deltaAngle.theta = w->threed.angle.theta;
 	w->threed.deltaAngle.phi = w->threed.angle.phi;
 	w->threed.deltaAngle.psi = w->threed.angle.psi;
-	w->threed.currentPosition.x = 2 * w->core.width;
-	w->threed.currentPosition.y = 2 * w->core.height;
 	ResizeThreeD(w);
 #ifdef DEBUG
 	(void) printf("%s\n", w->threed.name);
 #endif
 #ifdef WINVER
-	brush = CreateSolidBrush(w->threed.inverseGC);
+	brush = CreateSolidBrush(w->threed.inverseGC[1]);
 	SETBACK(w->core.hWnd, brush);
 #else
 	SetAllColors(w);
@@ -1498,6 +1624,11 @@ MotionThreeD(ThreeDWidget w
 	int oldAngleTheta = w->threed.angle.theta;
 	int oldAnglePhi = w->threed.angle.phi;
 
+	/* In X, it appears motion event is generated before a select */
+	if (w->threed.currentPosition.x == 2 * w->core.width &&
+			w->threed.currentPosition.y == 2 * w->core.height) {
+		return;
+	}
 	w->threed.angle.theta += w->threed.currentPosition.x - x;
 	w->threed.angle.phi += w->threed.currentPosition.y - y;
 	w->threed.angle.theta = (64 * NUM_DEGREES + w->threed.angle.theta) %
@@ -1618,7 +1749,7 @@ MoveLowerPhiThreeD(ThreeDWidget w, XEvent *event, char **args, int n_args)
 	int oldAngle = w->threed.angle.phi;
 
 	w->threed.angle.phi -= DELTADEGREES;
-	if (w->threed.angle.phi < MINDEGREES)
+	if (w->threed.angle.phi < MIN_DEGREES)
 		w->threed.angle.phi += NUM_DEGREES;
 	w->threed.deltaAngle.phi = w->threed.angle.phi - oldAngle;
 	setThreed(w, ACTION_SET);
@@ -1631,7 +1762,7 @@ MoveLowerThetaThreeD(ThreeDWidget w, XEvent *event, char **args, int n_args)
 	int oldAngle = w->threed.angle.theta;
 
 	w->threed.angle.theta -= DELTADEGREES;
-	if (w->threed.angle.theta < MINDEGREES)
+	if (w->threed.angle.theta < MIN_DEGREES)
 		w->threed.angle.theta += NUM_DEGREES;
 	w->threed.deltaAngle.theta = w->threed.angle.theta - oldAngle;
 	setThreed(w, ACTION_SET);
@@ -1644,7 +1775,7 @@ MoveRaiseThetaThreeD(ThreeDWidget w, XEvent *event, char **args, int n_args)
 	int oldAngle = w->threed.angle.theta;
 
 	w->threed.angle.theta += DELTADEGREES;
-	if (w->threed.angle.theta > MAXDEGREES)
+	if (w->threed.angle.theta > MAX_DEGREES)
 		w->threed.angle.theta -= NUM_DEGREES;
 	w->threed.deltaAngle.theta = w->threed.angle.theta - oldAngle;
 	setThreed(w, ACTION_SET);
@@ -1657,7 +1788,7 @@ MoveRaisePhiThreeD(ThreeDWidget w, XEvent *event, char **args, int n_args)
 	int oldAngle = w->threed.angle.phi;
 
 	w->threed.angle.phi += DELTADEGREES;
-	if (w->threed.angle.phi > MAXDEGREES)
+	if (w->threed.angle.phi > MAX_DEGREES)
 		w->threed.angle.phi -= NUM_DEGREES;
 	w->threed.deltaAngle.phi = w->threed.angle.phi - oldAngle;
 	setThreed(w, ACTION_SET);
@@ -1670,7 +1801,7 @@ MoveLowerPsiThreeD(ThreeDWidget w, XEvent *event, char **args, int n_args)
 	int oldAngle = w->threed.angle.psi;
 
 	w->threed.angle.psi -= DELTADEGREES;
-	if (w->threed.angle.psi < MINDEGREES)
+	if (w->threed.angle.psi < MIN_DEGREES)
 		w->threed.angle.psi += NUM_DEGREES;
 	w->threed.deltaAngle.psi = w->threed.angle.psi - oldAngle;
 	setThreed(w, ACTION_SET);
@@ -1683,7 +1814,7 @@ MoveRaisePsiThreeD(ThreeDWidget w, XEvent *event, char **args, int n_args)
 	int oldAngle = w->threed.angle.psi;
 
 	w->threed.angle.psi += DELTADEGREES;
-	if (w->threed.angle.psi > MAXDEGREES)
+	if (w->threed.angle.psi > MAX_DEGREES)
 		w->threed.angle.psi -= NUM_DEGREES;
 	w->threed.deltaAngle.psi = w->threed.angle.psi - oldAngle;
 	setThreed(w, ACTION_SET);
@@ -1699,9 +1830,9 @@ MoveLowerThetaLowerPhiThreeD(ThreeDWidget w, XEvent *event,
 
 	w->threed.angle.theta -= DELTADEGREES;
 	w->threed.angle.phi -= DELTADEGREES;
-	if (w->threed.angle.theta < MINDEGREES)
+	if (w->threed.angle.theta < MIN_DEGREES)
 		w->threed.angle.theta += NUM_DEGREES;
-	if (w->threed.angle.phi < MINDEGREES)
+	if (w->threed.angle.phi < MIN_DEGREES)
 		w->threed.angle.phi += NUM_DEGREES;
 	w->threed.deltaAngle.theta = w->threed.angle.theta - oldAngleTheta;
 	w->threed.deltaAngle.phi = w->threed.angle.phi - oldAnglePhi;
@@ -1718,9 +1849,9 @@ MoveLowerThetaRaisePhiThreeD(ThreeDWidget w, XEvent *event,
 
 	w->threed.angle.theta -= DELTADEGREES;
 	w->threed.angle.phi += DELTADEGREES;
-	if (w->threed.angle.theta < MINDEGREES)
+	if (w->threed.angle.theta < MIN_DEGREES)
 		w->threed.angle.theta += NUM_DEGREES;
-	if (w->threed.angle.phi > MAXDEGREES)
+	if (w->threed.angle.phi > MAX_DEGREES)
 		w->threed.angle.phi -= NUM_DEGREES;
 	w->threed.deltaAngle.theta = w->threed.angle.theta - oldAngleTheta;
 	w->threed.deltaAngle.phi = w->threed.angle.phi - oldAnglePhi;
@@ -1737,9 +1868,9 @@ MoveRaiseThetaLowerPhiThreeD(ThreeDWidget w, XEvent *event,
 
 	w->threed.angle.theta += DELTADEGREES;
 	w->threed.angle.phi -= DELTADEGREES;
-	if (w->threed.angle.theta > MAXDEGREES)
+	if (w->threed.angle.theta > MAX_DEGREES)
 		w->threed.angle.theta -= NUM_DEGREES;
-	if (w->threed.angle.phi < MINDEGREES)
+	if (w->threed.angle.phi < MIN_DEGREES)
 		w->threed.angle.phi += NUM_DEGREES;
 	w->threed.deltaAngle.theta = w->threed.angle.theta - oldAngleTheta;
 	w->threed.deltaAngle.phi = w->threed.angle.phi - oldAnglePhi;
@@ -1756,9 +1887,9 @@ MoveRaiseThetaRaisePhiThreeD(ThreeDWidget w, XEvent *event,
 
 	w->threed.angle.theta += DELTADEGREES;
 	w->threed.angle.phi += DELTADEGREES;
-	if (w->threed.angle.theta > MAXDEGREES)
+	if (w->threed.angle.theta > MAX_DEGREES)
 		w->threed.angle.theta -= NUM_DEGREES;
-	if (w->threed.angle.phi > MAXDEGREES)
+	if (w->threed.angle.phi > MAX_DEGREES)
 		w->threed.angle.phi -= NUM_DEGREES;
 	w->threed.deltaAngle.theta = w->threed.angle.theta - oldAngleTheta;
 	w->threed.deltaAngle.phi = w->threed.angle.phi - oldAnglePhi;
@@ -1769,7 +1900,7 @@ MoveRaiseThetaRaisePhiThreeD(ThreeDWidget w, XEvent *event,
 static void
 MoveRightThreeD(ThreeDWidget w, XEvent *event, char **args, int n_args)
 {
-	if (w->threed.distance.x < MAXDISTANCE)
+	if (w->threed.distance.x < MAX_DISTANCE)
 		w->threed.distance.x += DELTADISTANCE;
 	setThreed(w, ACTION_SET);
 	RepaintGraphicsThreeD(w);
@@ -1787,7 +1918,7 @@ MoveLeftThreeD(ThreeDWidget w, XEvent *event, char **args, int n_args)
 static void
 MoveUpThreeD(ThreeDWidget w, XEvent *event, char **args, int n_args)
 {
-	if (w->threed.distance.y < MAXDISTANCE)
+	if (w->threed.distance.y < MAX_DISTANCE)
 		w->threed.distance.y += DELTADISTANCE;
 	setThreed(w, ACTION_SET);
 	RepaintGraphicsThreeD(w);
@@ -1805,7 +1936,7 @@ MoveDownThreeD(ThreeDWidget w, XEvent *event, char **args, int n_args)
 static void
 MoveOutThreeD(ThreeDWidget w, XEvent *event, char **args, int n_args)
 {
-	if (w->threed.distance.z < MAXDEPTH)
+	if (w->threed.distance.z < MAX_DEPTH)
 		w->threed.distance.z += DELTADEPTH;
 	setThreed(w, ACTION_SET);
 	RepaintGraphicsThreeD(w);
@@ -1814,7 +1945,7 @@ MoveOutThreeD(ThreeDWidget w, XEvent *event, char **args, int n_args)
 static void
 MoveInThreeD(ThreeDWidget w, XEvent *event, char **args, int n_args)
 {
-	if (w->threed.distance.z > MINDEPTH)
+	if (w->threed.distance.z > MIN_DEPTH)
 		w->threed.distance.z -= DELTADEPTH;
 	setThreed(w, ACTION_SET);
 	RepaintGraphicsThreeD(w);
