@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 2007	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1994 - 2007	David A. Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -25,7 +25,7 @@
 
 #ifndef WINVER
 static const char aboutHelp[] = {
-"Threed Version 7.3.1\n"
+"Threed Version 7.3.2\n"
 "Send bugs (reports or fixes) to the author: "
 "David Bagley <bagleyd@tux.org>\n"
 "The latest version is at: "
@@ -304,7 +304,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_DISTXI:
-			if (widget.threed.distance.x <= MAXDISTANCE -
+			if (widget.threed.distance.x <= MAX_DISTANCE -
 					DELTADISTANCE)
 				widget.threed.distance.x += DELTADISTANCE;
 			(void) SetScrollPos(hWnd, SB_HORZ,
@@ -320,7 +320,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_DISTYI:
-			if (widget.threed.distance.y <= MAXDISTANCE -
+			if (widget.threed.distance.y <= MAX_DISTANCE -
 					DELTADISTANCE)
 				widget.threed.distance.y += DELTADISTANCE;
 			(void) SetScrollPos(hWnd, SB_VERT,
@@ -336,12 +336,12 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_DEPTHZI:
-			if (widget.threed.distance.z <= MAXDEPTH - DELTADEPTH)
+			if (widget.threed.distance.z <= MAX_DEPTH - DELTADEPTH)
 				widget.threed.distance.z += DELTADEPTH;
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
 		case ACTION_DEPTHZD:
-			if (widget.threed.distance.z >= MINDEPTH + DELTADEPTH)
+			if (widget.threed.distance.z >= MIN_DEPTH + DELTADEPTH)
 				widget.threed.distance.z -= DELTADEPTH;
 			(void) InvalidateRect(hWnd, NULL, TRUE);
 			break;
@@ -499,7 +499,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 		hPos = GetScrollPos(hWnd, SB_HORZ);
 		switch (wParam) {
 		case SB_TOP:
-			hPos = MAXDISTANCE;
+			hPos = MAX_DISTANCE;
 			break;
 		case SB_BOTTOM:
 			hPos = MINDISTANCE;
@@ -518,8 +518,8 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 		}
 		if (hPos < MINDISTANCE)
 			hPos = MINDISTANCE;
-		else if (hPos > MAXDISTANCE)
-			hPos = MAXDISTANCE;
+		else if (hPos > MAX_DISTANCE)
+			hPos = MAX_DISTANCE;
 		(void) SetScrollPos(hWnd, SB_HORZ, hPos, TRUE);
 		widget.threed.distance.x = hPos;
 		(void) InvalidateRect(hWnd, NULL, TRUE);
@@ -533,7 +533,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			vPos = MINDISTANCE;
 			break;
 		case SB_BOTTOM:
-			vPos = MAXDISTANCE;
+			vPos = MAX_DISTANCE;
 			break;
 		case SB_LINEUP:
 		case SB_PAGEUP:
@@ -549,8 +549,8 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 		}
 		if (vPos < MINDISTANCE)
 			vPos = MINDISTANCE;
-		else if (vPos > MAXDISTANCE)
-			vPos = MAXDISTANCE;
+		else if (vPos > MAX_DISTANCE)
+			vPos = MAX_DISTANCE;
 		(void) SetScrollPos(hWnd, SB_VERT, vPos, TRUE);
 		widget.threed.distance.y = -vPos;
 		(void) InvalidateRect(hWnd, NULL, TRUE);
@@ -599,8 +599,8 @@ WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine,
 		(void *) NULL);
 	if (!hWnd)
 		return FALSE;
-	(void) SetScrollRange(hWnd, SB_HORZ, MINDISTANCE, MAXDISTANCE, TRUE);
-	(void) SetScrollRange(hWnd, SB_VERT, MINDISTANCE, MAXDISTANCE, TRUE);
+	(void) SetScrollRange(hWnd, SB_HORZ, MINDISTANCE, MAX_DISTANCE, TRUE);
+	(void) SetScrollRange(hWnd, SB_VERT, MINDISTANCE, MAX_DISTANCE, TRUE);
 	(void) SetScrollPos(hWnd, SB_HORZ, widget.threed.distance.x, TRUE);
 	(void) SetScrollPos(hWnd, SB_VERT, widget.threed.distance.y, TRUE);
 	hAccel = (HACCEL) LoadAccelerators(hInstance, TITLE);
@@ -652,8 +652,8 @@ WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine,
 #include "pixmaps/threed.xbm"
 #define DEFINE_XBM (char *) threed_bits, threed_width, threed_height
 
-#define FILENAMELEN 1024
-#define TITLELEN 2048
+#define FILE_NAME_LENGTH 1024
+#define TITLE_LENGTH 2048
 
 #ifdef HAVE_MOTIF
 static Widget xDist, yDist, zDist, thetaAng, phiAng, psiAng;
@@ -663,7 +663,7 @@ static Widget optionsDialog, referencesDialog, aboutDialog;
 static Arg arg[3];
 static char *progDsp;
 #else
-static char titleDsp[TITLELEN] = "";
+static char titleDsp[TITLE_LENGTH] = "";
 #endif
 static Pixmap pixmap = None;
 static Widget topLevel, threed;
@@ -1034,7 +1034,7 @@ static Widget
 createHelp(Widget w, char *text, char *title)
 {
 	Widget button, messageBox;
-	char titleDsp[FILENAMELEN + 8];
+	char titleDsp[FILE_NAME_LENGTH + 8];
 	XmString titleString = NULL, messageString = NULL, buttonString = NULL;
 	static XmStringCharSet charSet =
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
@@ -1213,8 +1213,8 @@ int main(int argc, char **argv)
 		xmScaleWidgetClass, distRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "X", 2,
 		XmNminimum, MINDISTANCE,
-		XmNmaximum, MAXDISTANCE,
-		XmNvalue, (MINDISTANCE + MAXDISTANCE) / 2 ,
+		XmNmaximum, MAX_DISTANCE,
+		XmNvalue, (MINDISTANCE + MAX_DISTANCE) / 2 ,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
 	XtAddCallback(xDist, XmNvalueChangedCallback,
@@ -1223,8 +1223,8 @@ int main(int argc, char **argv)
 		xmScaleWidgetClass, distRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Y", 2,
 		XmNminimum, MINDISTANCE,
-		XmNmaximum, MAXDISTANCE,
-		XmNvalue, (MINDISTANCE + MAXDISTANCE) / 2 ,
+		XmNmaximum, MAX_DISTANCE,
+		XmNvalue, (MINDISTANCE + MAX_DISTANCE) / 2 ,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
 	XtAddCallback(yDist, XmNvalueChangedCallback,
@@ -1232,9 +1232,9 @@ int main(int argc, char **argv)
 	zDist = XtVaCreateManagedWidget("zDist",
 		xmScaleWidgetClass, distRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Z", 2,
-		XmNminimum, MINDEPTH,
-		XmNmaximum, MAXDEPTH,
-		XmNvalue, (MINDEPTH + MAXDEPTH) / 2 ,
+		XmNminimum, MIN_DEPTH,
+		XmNmaximum, MAX_DEPTH,
+		XmNvalue, (MIN_DEPTH + MAX_DEPTH) / 2 ,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
 	XtAddCallback(zDist, XmNvalueChangedCallback,
@@ -1247,9 +1247,9 @@ int main(int argc, char **argv)
 	thetaAng = XtVaCreateManagedWidget("thetaAng",
 		xmScaleWidgetClass, angleRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Theta", 6,
-		XmNminimum, MINDEGREES,
-		XmNmaximum, MAXDEGREES,
-		XmNvalue, MINDEGREES,
+		XmNminimum, MIN_DEGREES,
+		XmNmaximum, MAX_DEGREES,
+		XmNvalue, MIN_DEGREES,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
 	XtAddCallback(thetaAng, XmNvalueChangedCallback,
@@ -1257,9 +1257,9 @@ int main(int argc, char **argv)
 	phiAng = XtVaCreateManagedWidget("phiAng",
 		xmScaleWidgetClass, angleRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Phi", 4,
-		XmNminimum, MINDEGREES,
-		XmNmaximum, MAXDEGREES,
-		XmNvalue, MINDEGREES,
+		XmNminimum, MIN_DEGREES,
+		XmNmaximum, MAX_DEGREES,
+		XmNvalue, MIN_DEGREES,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
 	XtAddCallback(phiAng, XmNvalueChangedCallback,
@@ -1267,9 +1267,9 @@ int main(int argc, char **argv)
 	psiAng = XtVaCreateManagedWidget("psiAng",
 		xmScaleWidgetClass, angleRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Psi", 4,
-		XmNminimum, MINDEGREES,
-		XmNmaximum, MAXDEGREES,
-		XmNvalue, MINDEGREES,
+		XmNminimum, MIN_DEGREES,
+		XmNmaximum, MAX_DEGREES,
+		XmNvalue, MIN_DEGREES,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
 	XtAddCallback(psiAng, XmNvalueChangedCallback,
