@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 2007	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1994 - 2008	David A. Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -226,14 +226,11 @@ static XtResource resourcesPuzzle[] =
 	{XtNbackground, XtCBackground, XtRPixel, sizeof (Pixel),
 	 XtOffset(TrianglesWidget, triangles.background),
 	 XtRString, (caddr_t) XtDefaultBackground},
-	{XtNframeColor, XtCColor, XtRPixel, sizeof (Pixel),
-	 XtOffset(TrianglesWidget, triangles.frameColor),
-	 XtRString, (caddr_t) "cyan" /* XtDefaultForeground*/},
 	{XtNtileColor, XtCColor, XtRPixel, sizeof (Pixel),
 	 XtOffset(TrianglesWidget, triangles.tileColor),
 	 XtRString, (caddr_t) "gray75" /*XtDefaultForeground*/},
-	{XtNtileBorder, XtCColor, XtRPixel, sizeof (Pixel),
-	 XtOffset(TrianglesWidget, triangles.borderColor),
+	{XtNtextColor, XtCColor, XtRPixel, sizeof (Pixel),
+	 XtOffset(TrianglesWidget, triangles.textColor),
 	 XtRString, (caddr_t) "gray25" /*XtDefaultBackground*/},
 	{XtNinstall, XtCInstall, XtRBoolean, sizeof (Boolean),
 	 XtOffset(TrianglesWidget, triangles.install),
@@ -243,7 +240,7 @@ static XtResource resourcesPuzzle[] =
 	 XtRString, (caddr_t) PICTURE},
 	{XtNdelay, XtCDelay, XtRInt, sizeof (int),
 	 XtOffset(TrianglesWidget, triangles.delay),
-	 XtRString, (caddr_t) "10"}, /* DEFAULTDELAY */
+	 XtRString, (caddr_t) "10"}, /* DEFAULT_DELAY */
 	{XtNsound, XtCSound, XtRBoolean, sizeof (Boolean),
 	 XtOffset(TrianglesWidget, triangles.sound),
 	 XtRString, (caddr_t) "FALSE"},
@@ -255,10 +252,10 @@ static XtResource resourcesPuzzle[] =
 	 XtRString, (caddr_t) "9x15bold"},
 	{XtNsize, XtCSize, XtRInt, sizeof (int),
 	 XtOffset(TrianglesWidget, triangles.size),
-	 XtRString, (caddr_t) "4"}, /* DEFAULTTILES */
+	 XtRString, (caddr_t) "4"}, /* DEFAULT_TILES */
 	{XtNbase, XtCBase, XtRInt, sizeof (int),
 	 XtOffset(TrianglesWidget, triangles.base),
-	 XtRString, (caddr_t) "10"}, /* DEFAULTBASE */
+	 XtRString, (caddr_t) "10"}, /* DEFAULT_BASE */
 	{XtNuserName, XtCUserName, XtRString, sizeof (String),
 	 XtOffset(TrianglesWidget, triangles.userName),
 	 XtRString, (caddr_t) ""},
@@ -384,7 +381,7 @@ loadFont(TrianglesWidget w)
 #define LOGFILE "triangles.log"
 #endif
 
-static Point triangleUnit[MAXORIENT][ROWTYPES + 1] =
+static Point triangleUnit[MAX_ORIENT][ROW_TYPES + 1] =
 {
 	{
 		{0, 0},
@@ -399,9 +396,9 @@ static Point triangleUnit[MAXORIENT][ROWTYPES + 1] =
 		{1, -1}
 	}
 };
-static Point triangleList[MAXORIENT][ROWTYPES + 1];
+static Point triangleList[MAX_ORIENT][ROW_TYPES + 1];
 #ifdef RHOMBUS
-static Point rhombusUnit[ROWTYPES][ROWTYPES + 2] =
+static Point rhombusUnit[ROW_TYPES][ROW_TYPES + 2] =
 {
 	{
 		{0, 0},
@@ -425,7 +422,7 @@ static Point rhombusUnit[ROWTYPES][ROWTYPES + 2] =
 		{-1, -1}
 	}
 };
-static Point rhombusList[ROWTYPES][ROWTYPES + 2];
+static Point rhombusList[ROW_TYPES][ROW_TYPES + 2];
 #endif
 
 static TrianglesStack undo = {NULL, NULL, NULL, 0};
@@ -436,17 +433,17 @@ CheckTiles(TrianglesWidget w)
 {
 	char *buf1 = NULL, *buf2 = NULL;
 
-	if (w->triangles.size < MINTILES) {
+	if (w->triangles.size < MIN_TILES) {
 		intCat(&buf1,
 			"Number of triangles on an edge out of bounds, use at least ",
-			MINTILES);
+			MIN_TILES);
 		stringCat(&buf2, buf1, ", defaulting to ");
 		free(buf1);
-		intCat(&buf1, buf2, DEFAULTTILES);
+		intCat(&buf1, buf2, DEFAULT_TILES);
 		free(buf2);
 		DISPLAY_WARNING(buf1);
 		free(buf1);
-		w->triangles.size = DEFAULTTILES;
+		w->triangles.size = DEFAULT_TILES;
 	}
 	if (w->triangles.delay < 0) {
 		intCat(&buf1, "Delay can not be negative (",
@@ -457,19 +454,19 @@ CheckTiles(TrianglesWidget w)
 		free(buf2);
 		w->triangles.delay = -w->triangles.delay;
 	}
-	if (w->triangles.base < MINBASE || w->triangles.base > MAXBASE) {
-		intCat(&buf1, "Base out of bounds, use ", MINBASE);
+	if (w->triangles.base < MIN_BASE || w->triangles.base > MAX_BASE) {
+		intCat(&buf1, "Base out of bounds, use ", MIN_BASE);
 		stringCat(&buf2, buf1, "..");
 		free(buf1);
-		intCat(&buf1, buf2, MAXBASE);
+		intCat(&buf1, buf2, MAX_BASE);
 		free(buf2);
 		stringCat(&buf2, buf1, ", defaulting to ");
 		free(buf1);
-		intCat(&buf1, buf2, DEFAULTBASE);
+		intCat(&buf1, buf2, DEFAULT_BASE);
 		free(buf2);
 		DISPLAY_WARNING(buf1);
 		free(buf1);
-		w->triangles.base = DEFAULTBASE;
+		w->triangles.base = DEFAULT_BASE;
 	}
 }
 
@@ -764,16 +761,16 @@ DrawTile(TrianglesWidget w, int pos, int orient, Boolean blank, Boolean erase,
 	Pixmap *dr;
 	Pixmap adr = 0;
 	int dx, dy, row;
-	GC tileGC, borderGC;
+	GC tileGC, textGC;
 
 	/*dr = &(w->triangles.bufferTiles[pressedOffset]);*/
 	dr = &adr;
 	if (erase) {
-		tileGC = w->triangles.inverseGC;
-		borderGC = w->triangles.inverseGC;
+		tileGC = w->triangles.inverseGC[2];
+		textGC = w->triangles.inverseGC[2];
 	} else {
-		tileGC = w->triangles.tileGC;
-		borderGC = w->triangles.borderGC;
+		tileGC = w->triangles.tileGC[1];
+		textGC = w->triangles.textGC;
 	}
 	row = Row(pos);
 	dx = CartesianX(w, pos, row) + offsetX + pressedOffset;
@@ -781,16 +778,16 @@ DrawTile(TrianglesWidget w, int pos, int orient, Boolean blank, Boolean erase,
 	triangleList[orient][0].x = dx;
 	triangleList[orient][0].y = dy;
 	if (blank) {
-		POLYGON(w, *dr, tileGC, borderGC, triangleList[orient], 3,
+		POLYGON(w, *dr, tileGC, textGC, triangleList[orient], 3,
 			True, False);
 	} else {
 		if (pressedOffset != 0) {
-			drawShadow(w, *dr, w->triangles.tileDarkerGC,
+			drawShadow(w, *dr, w->triangles.tileGC[2],
 				-pressedOffset, -pressedOffset,
 				triangleList[orient], orient == UP);
 		}
-		fill3DTriangle(w, *dr, tileGC, w->triangles.tileDarkerGC,
-			w->triangles.tileBrighterGC,
+		fill3DTriangle(w, *dr, tileGC, w->triangles.tileGC[2],
+			w->triangles.tileGC[0],
 			triangleList[orient],
 			pressedOffset == 0, orient == UP);
 	}
@@ -811,7 +808,7 @@ DrawTile(TrianglesWidget w, int pos, int orient, Boolean blank, Boolean erase,
 			w->triangles.digitOffset.y - w->triangles.tileSize.y +
 			- w->triangles.tileSize.y / 7 +
 			w->triangles.delta.y - 2;
-		DRAWTEXT(w, *dr, borderGC,
+		DRAWTEXT(w, *dr, textGC,
 			dx - digitOffsetX,
 			dy + w->triangles.tileSize.y / 2 + digitOffsetY,
 			buf, i);
@@ -842,7 +839,7 @@ MovableTile(TrianglesWidget w)
 
 	/* Are the spaces in a "row" with the mouse click?
 	 * (If two, then one clicked on a space). */
-	for (l = 0; l < ROWTYPES; l++) {
+	for (l = 0; l < ROW_TYPES; l++) {
 		if (w->triangles.currentRow[l] == w->triangles.spaceRow[DOWN][l] &&
 		w->triangles.currentRow[l] == w->triangles.spaceRow[UP][l]) {
 			if (rowType == BLOCKED) {
@@ -869,10 +866,10 @@ DrawRhombus(TrianglesWidget w, int pos, int rowType, int offsetX, int offsetY)
 	dy += offsetY;
 	rhombusList[rowType][0].x = dx;
 	rhombusList[rowType][0].y = dy;
-	XFillPolygon(XtDisplay(w), XtWindow(w), w->triangles.inverseGC,
+	XFillPolygon(XtDisplay(w), XtWindow(w), w->triangles.inverseGC[2],
 		rhombusList[rowType], 4,
 		Convex, CoordModePrevious);
-	XDrawLines(XtDisplay(w), XtWindow(w), w->triangles.inverseGC,
+	XDrawLines(XtDisplay(w), XtWindow(w), w->triangles.inverseGC[2],
 		rhombusList[rowType], 5,
 		CoordModePrevious);
 }
@@ -1209,7 +1206,7 @@ ResetTiles(TrianglesWidget w)
 static void
 EraseFrame(const TrianglesWidget w, Pixmap dr)
 {
-	FILLRECTANGLE(w, dr, w->triangles.inverseGC,
+	FILLRECTANGLE(w, dr, w->triangles.inverseGC[2],
 		0, 0, w->core.width, w->core.height);
 }
 
@@ -1218,7 +1215,10 @@ DrawFrame(TrianglesWidget w, Pixmap dr, Boolean focus)
 {
 	int sumX, sumY, sumX2, offsetX, offsetY;
 	Point tempList[5];
-	GC gc = (focus) ? w->triangles.frameGC : w->triangles.borderGC;
+	GC brighterGC = (focus) ? w->triangles.inverseGC[1] :
+		w->triangles.inverseGC[2];
+	GC darkerGC = (focus) ? w->triangles.inverseGC[3] :
+		w->triangles.inverseGC[2];
 
 	offsetX = w->triangles.puzzleOffset.x;
 	offsetY = w->triangles.puzzleOffset.y;
@@ -1230,48 +1230,78 @@ DrawFrame(TrianglesWidget w, Pixmap dr, Boolean focus)
 	sumX += offsetX;
 	sumY += offsetY;
 	if (offsetY > 0)
-		FILLRECTANGLE(w, dr, w->triangles.borderGC,
+		FILLRECTANGLE(w, dr, w->triangles.textGC,
 			0, 0, w->core.width, offsetY);
 	if (sumY < w->core.height)
-		FILLRECTANGLE(w, dr, w->triangles.borderGC,
+		FILLRECTANGLE(w, dr, w->triangles.textGC,
 			0, sumY + 1, w->core.width, w->core.height - sumY);
 	if (offsetX > 0)
-		FILLRECTANGLE(w, dr, w->triangles.borderGC,
+		FILLRECTANGLE(w, dr, w->triangles.textGC,
 			0, 0, offsetX, w->core.height);
 	if (sumX - 2 < w->core.width)
-		FILLRECTANGLE(w, dr, w->triangles.borderGC,
+		FILLRECTANGLE(w, dr, w->triangles.textGC,
 			sumX - 2, 0, w->core.width - sumX + 2, w->core.height);
 	tempList[0].x = offsetX;
 	tempList[0].y = offsetY;
-	tempList[1].x = sumX2 - 1;
+	tempList[1].x = sumX2 - 3;
 	tempList[1].y = offsetY;
 	tempList[2].x = offsetX;
 	tempList[2].y = sumY;
 	tempList[3].x = offsetX;
 	tempList[3].y = offsetY;
-	POLYGON(w, dr, w->triangles.borderGC, w->triangles.borderGC,
+	POLYGON(w, dr, w->triangles.textGC, w->triangles.textGC,
 		tempList, 3, True, True);
 	tempList[0].x = sumX - 2;
-	tempList[0].y = offsetY;
+	tempList[0].y = offsetY - 1;
 	tempList[1].x = sumX - 2;
-	tempList[1].y = sumY;
-	tempList[2].x = sumX2 - 2;
-	tempList[2].y = offsetY;
+	tempList[1].y = sumY + 1;
+	tempList[2].x = sumX2;
+	tempList[2].y = offsetY - 1;
 	tempList[3].x = sumX - 2;
-	tempList[3].y = offsetY;
-	POLYGON(w, dr, w->triangles.borderGC, w->triangles.borderGC,
+	tempList[3].y = offsetY - 1;
+	POLYGON(w, dr, w->triangles.textGC, w->triangles.textGC,
 		tempList, 3, True, True);
-	tempList[0].x = sumX2 - 2;
+	tempList[0].x = offsetX;
+	tempList[0].y = sumY + 1;
+	tempList[1].x = sumX2 - 3;
+	tempList[1].y = offsetY - 1;
+	POLYLINE(w, dr, darkerGC, tempList, 2, True);
+	tempList[0].x = sumX2 - 1;
+	tempList[0].y = offsetY - 1;
+	tempList[1].x = sumX - 1;
+	tempList[1].y = sumY + 1;
+	tempList[2].x = offsetX + 1;
+	tempList[2].y = sumY + 1;
+	POLYLINE(w, dr, brighterGC, tempList, 3, True);
+	tempList[0].x = offsetX + 1;
+	tempList[0].y = sumY + 1;
+	tempList[1].x = sumX2 - 2;
+	tempList[1].y = offsetY - 1;
+	POLYLINE(w, dr, darkerGC, tempList, 2, True);
+	tempList[0].x = sumX2 - 1;
 	tempList[0].y = offsetY;
-	tempList[1].x = sumX - 2;
+	tempList[1].x = sumX - 1;
 	tempList[1].y = sumY;
-	tempList[2].x = offsetX;
+	tempList[2].x = offsetX + 1;
 	tempList[2].y = sumY;
-	tempList[3].x = sumX2 - 1;
-	tempList[3].y = offsetY;
-	tempList[4].x = sumX2 - 2;
-	tempList[4].y = offsetY;
-	POLYLINE(w, dr, gc, tempList, 5, True);
+	POLYLINE(w, dr, brighterGC, tempList, 3, True);
+	tempList[0].x = offsetX + 1;
+	tempList[0].y = sumY;
+	tempList[1].x = sumX2 - 2;
+	tempList[1].y = offsetY;
+	POLYLINE(w, dr, darkerGC, tempList, 2, True);
+	tempList[0].x = offsetX;
+	tempList[0].y = sumY;
+	tempList[1].x = sumX2 - 3;
+	tempList[1].y = offsetY;
+	POLYLINE(w, dr, darkerGC, tempList, 2, True);
+	tempList[0].x = sumX2;
+	tempList[0].y = offsetY - 1;
+	tempList[1].x = sumX - 2;
+	tempList[1].y = sumY + 1;
+	tempList[2].x = offsetX;
+	tempList[2].y = sumY + 1;
+	POLYLINE(w, dr, brighterGC, tempList, 3, True);
 }
 
 static void
@@ -1742,7 +1772,7 @@ GetTiles(TrianglesWidget w)
 	flushMoves(w, &redo, FALSE);
 	while ((c = getc(fp)) != EOF && c != SYMBOL);
 	(void) fscanf(fp, "%d", &size);
-	if (size >= MINTILES) {
+	if (size >= MIN_TILES) {
 		for (i = w->triangles.size; i < size; i++) {
 			setPuzzle(w, ACTION_INCREMENT);
 		}
@@ -1755,7 +1785,7 @@ GetTiles(TrianglesWidget w)
 		free(buf1);
 		stringCat(&buf1, buf2, " should be between ");
 		free(buf2);
-		intCat(&buf2, buf1, MINTILES);
+		intCat(&buf2, buf1, MIN_TILES);
 		free(buf1);
 		stringCat(&buf1, buf2, " and MAXINT");
 		free(buf2);
@@ -1905,7 +1935,7 @@ IncrementTiles(TrianglesWidget w)
 static void
 DecrementTiles(TrianglesWidget w)
 {
-	if (w->triangles.size <= MINTILES)
+	if (w->triangles.size <= MIN_TILES)
 		return;
 	setPuzzle(w, ACTION_DECREMENT);
 }
@@ -1936,24 +1966,26 @@ SoundTiles(TrianglesWidget w)
 	w->triangles.sound = !w->triangles.sound;
 }
 
-#define FACTOR 0.7
+#define BRIGHT_FACTOR 0.8
+#define DARK_FACTOR 0.75
+
 #ifdef WINVER
-#define MAXINTENSITY 0xFF
+#define MAX_INTENSITY 0xFF
 static int
 brighter(const int light)
 {
-	int i = (int) ((1 - FACTOR) * MAXINTENSITY);
+	int i = (int) ((1 - BRIGHT_FACTOR) * MAX_INTENSITY);
 	int temp = light;
 
 	if (temp < i)
 		temp = i;
-	return MIN(temp / FACTOR, MAXINTENSITY);
+	return MIN(temp / BRIGHT_FACTOR, MAX_INTENSITY);
 }
 
 static int
 darker(const int light)
 {
-	return (int) (light * FACTOR);
+	return (int) (light * DARK_FACTOR);
 }
 
 
@@ -1966,41 +1998,44 @@ SetValuesPuzzle(TrianglesWidget w)
 	char szBuf[80];
 
 	w->triangles.size = GetPrivateProfileInt(SECTION, "size",
-		DEFAULTTILES, INIFILE);
+		DEFAULT_TILES, INIFILE);
 	w->triangles.base = GetPrivateProfileInt(SECTION, "base",
-		DEFAULTBASE, INIFILE);
+		DEFAULT_BASE, INIFILE);
 	w->triangles.mono = (BOOL) GetPrivateProfileInt(SECTION, "mono",
-		DEFAULTMONO, INIFILE);
+		DEFAULT_MONO, INIFILE);
 	w->triangles.reverse = (BOOL) GetPrivateProfileInt(SECTION,
-		"reverseVideo", DEFAULTREVERSE, INIFILE);
-	/* cyan */
-	(void) GetPrivateProfileString(SECTION, "frameColor", "0 255 255",
-		szBuf, sizeof (szBuf), INIFILE);
-	(void) sscanf(szBuf, "%d %d %d",
-		&(color.red), &(color.green), &(color.blue));
-	w->triangles.frameGC = RGB(color.red, color.green, color.blue);
+		"reverseVideo", DEFAULT_REVERSE, INIFILE);
 	/* gray75 */
 	(void) GetPrivateProfileString(SECTION, "tileColor", "191 191 191",
 		szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
-	w->triangles.tileGC = RGB(color.red, color.green, color.blue);
-	w->triangles.tileBrighterGC = RGB(brighter(color.red),
-		brighter(color.green), brighter(color.blue));
-	w->triangles.tileDarkerGC = RGB(darker(color.red),
-		darker(color.green), darker(color.blue));
+	w->triangles.tileGC[1] = RGB(color.red, color.green, color.blue);
+        w->triangles.tileGC[0] = RGB(brighter(color.red),
+                brighter(color.green), brighter(color.blue));
+        w->triangles.tileGC[2] = RGB(darker(color.red),
+                darker(color.green), darker(color.blue));
 	/* gray25 */
-	(void) GetPrivateProfileString(SECTION, "tileBorder", "64 64 64",
+	(void) GetPrivateProfileString(SECTION, "textColor", "64 64 64",
 		szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
-	w->triangles.borderGC = RGB(color.red, color.green, color.blue);
+	w->triangles.textGC = RGB(color.red, color.green, color.blue);
 	/* #AEB2C3 */
 	(void) GetPrivateProfileString(SECTION, "background", "174 178 195",
 		szBuf, sizeof (szBuf), INIFILE);
 	(void) sscanf(szBuf, "%d %d %d",
 		&(color.red), &(color.green), &(color.blue));
-	w->triangles.inverseGC = RGB(color.red, color.green, color.blue);
+	w->triangles.inverseGC[1] = RGB(color.red, color.green, color.blue);
+        w->triangles.inverseGC[0] = RGB(brighter(color.red),
+                brighter(color.green), brighter(color.blue));
+        w->triangles.inverseGC[2] = RGB(darker(color.red),
+                darker(color.green), darker(color.blue));
+        w->triangles.inverseGC[3] = RGB(darker(darker(color.red)),
+                darker(darker(color.green)), darker(darker(color.blue)));
+        w->triangles.inverseGC[4] = RGB(darker(darker(darker(color.red))),
+                darker(darker(darker(color.green))),
+                darker(darker(darker(color.blue))));
 	(void) GetPrivateProfileString(SECTION, "picture", PICTURE,
 		szBuf, sizeof (szBuf), INIFILE);
 	(void) strcpy(w->triangles.picture, szBuf);
@@ -2040,28 +2075,27 @@ DestroyPuzzle(TrianglesWidget w, HBRUSH brush)
 
 #else
 
-#define MAXINTENSITY 0xFFFF
+#define MAX_INTENSITY 0xFFFF
 
 static Pixel
 brighter(TrianglesWidget w, Pixel pixel)
 {
 	XColor color;
-	int i = (int) ((1 - FACTOR) * MAXINTENSITY);
+	Colormap colormap = DefaultColormapOfScreen(XtScreen(w));
+	int i = (int) ((1 - BRIGHT_FACTOR) * MAX_INTENSITY);
 
 	color.pixel = pixel;
-	XQueryColor(XtDisplay(w), DefaultColormapOfScreen(XtScreen(w)),
-		&color);
+	VOID XQueryColor(XtDisplay(w), colormap, &color);
 	if (color.red < i)
 		color.red = i;
 	if (color.green < i)
 		color.green = i;
 	if (color.blue < i)
 		color.blue = i;
-	color.red = (unsigned short) MIN(color.red / FACTOR, MAXINTENSITY);
-	color.green = (unsigned short) MIN(color.green / FACTOR, MAXINTENSITY);
-	color.blue = (unsigned short) MIN(color.blue / FACTOR, MAXINTENSITY);
-	if (XAllocColor(XtDisplay(w), DefaultColormapOfScreen(XtScreen(w)),
-			&color))
+	color.red = (unsigned short) MIN(color.red / BRIGHT_FACTOR, MAX_INTENSITY);
+	color.green = (unsigned short) MIN(color.green / BRIGHT_FACTOR, MAX_INTENSITY);
+	color.blue = (unsigned short) MIN(color.blue / BRIGHT_FACTOR, MAX_INTENSITY);
+	if (XAllocColor(XtDisplay(w), colormap, &color))
 		return color.pixel;
 	return pixel;
 }
@@ -2070,15 +2104,14 @@ static Pixel
 darker(TrianglesWidget w, Pixel pixel)
 {
 	XColor color;
+	Colormap colormap = DefaultColormapOfScreen(XtScreen(w));
 
 	color.pixel = pixel;
-	XQueryColor(XtDisplay(w), DefaultColormapOfScreen(XtScreen(w)),
-		&color);
-	color.red = (unsigned short) (color.red * FACTOR);
-	color.green = (unsigned short) (color.green * FACTOR);
-	color.blue = (unsigned short) (color.blue * FACTOR);
-	if (XAllocColor(XtDisplay(w), DefaultColormapOfScreen(XtScreen(w)),
-			&color))
+	VOID XQueryColor(XtDisplay(w), colormap, &color);
+	color.red = (unsigned short) (color.red * DARK_FACTOR);
+	color.green = (unsigned short) (color.green * DARK_FACTOR);
+	color.blue = (unsigned short) (color.blue * DARK_FACTOR);
+	if (XAllocColor(XtDisplay(w), colormap, &color))
 		return color.pixel;
 	return pixel;
 }
@@ -2097,24 +2130,38 @@ SetAllColors(TrianglesWidget w)
 		values.foreground = w->triangles.background;
 		values.background = w->triangles.foreground;
 	}
-	if (w->triangles.inverseGC)
-		XtReleaseGC((Widget) w, w->triangles.inverseGC);
-	w->triangles.inverseGC = XtGetGC((Widget) w, valueMask, &values);
-	if (w->triangles.mono) {
-		if (w->triangles.reverse) {
-			values.foreground = w->triangles.background;
-			values.background = w->triangles.foreground;
-		} else {
-			values.foreground = w->triangles.foreground;
-			values.background = w->triangles.background;
-		}
-	} else {
-		values.foreground = w->triangles.frameColor;
-		values.background = w->triangles.borderColor;
-	}
-	if (w->triangles.frameGC)
-		XtReleaseGC((Widget) w, w->triangles.frameGC);
-	w->triangles.frameGC = XtGetGC((Widget) w, valueMask, &values);
+	if (w->triangles.inverseGC[1])
+                XtReleaseGC((Widget) w, w->triangles.inverseGC[1]);
+        w->triangles.inverseGC[1] = XtGetGC((Widget) w, valueMask, &values);
+        if (!w->triangles.mono) {
+                values.foreground = brighter(w, (w->triangles.reverse) ?
+                        w->triangles.foreground : w->triangles.background);
+        }
+        if (w->triangles.inverseGC[0])
+                XtReleaseGC((Widget) w, w->triangles.inverseGC[0]);
+        w->triangles.inverseGC[0] = XtGetGC((Widget) w, valueMask, &values);
+        if (!w->triangles.mono) {
+                values.foreground = darker(w, (w->triangles.reverse) ?
+                        w->triangles.foreground : w->triangles.background);
+        }
+        if (w->triangles.inverseGC[2])
+                XtReleaseGC((Widget) w, w->triangles.inverseGC[2]);
+        w->triangles.inverseGC[2] = XtGetGC((Widget) w, valueMask, &values);
+        if (!w->triangles.mono) {
+                values.foreground = darker(w, darker(w, (w->triangles.reverse) ?
+                        w->triangles.foreground : w->triangles.background));
+        }
+        if (w->triangles.inverseGC[3])
+                XtReleaseGC((Widget) w, w->triangles.inverseGC[3]);
+        w->triangles.inverseGC[3] = XtGetGC((Widget) w, valueMask, &values);
+        if (!w->triangles.mono) {
+                values.foreground = darker(w, darker(w, darker(w,
+                        (w->triangles.reverse) ?  w->triangles.foreground :
+                        w->triangles.background)));
+        }
+        if (w->triangles.inverseGC[4])
+                XtReleaseGC((Widget) w, w->triangles.inverseGC[4]);
+        w->triangles.inverseGC[4] = XtGetGC((Widget) w, valueMask, &values);
 	if (w->triangles.mono) {
 		if (w->triangles.reverse) {
 			values.foreground = w->triangles.background;
@@ -2125,23 +2172,23 @@ SetAllColors(TrianglesWidget w)
 		}
 	} else {
 		values.foreground = w->triangles.tileColor;
-		values.background = w->triangles.borderColor;
+		values.background = w->triangles.textColor;
 	}
-	if (w->triangles.tileGC)
-		XtReleaseGC((Widget) w, w->triangles.tileGC);
-	w->triangles.tileGC = XtGetGC((Widget) w, valueMask, &values);
-	if (!w->triangles.mono) {
-		values.foreground = brighter(w, w->triangles.tileColor);
-	}
-	if (w->triangles.tileBrighterGC)
-		XtReleaseGC((Widget) w, w->triangles.tileBrighterGC);
-	w->triangles.tileBrighterGC = XtGetGC((Widget) w, valueMask, &values);
-	if (!w->triangles.mono) {
-		values.foreground = darker(w, w->triangles.tileColor);
-	}
-	if (w->triangles.tileDarkerGC)
-		XtReleaseGC((Widget) w, w->triangles.tileDarkerGC);
-	w->triangles.tileDarkerGC = XtGetGC((Widget) w, valueMask, &values);
+	if (w->triangles.tileGC[1])
+                XtReleaseGC((Widget) w, w->triangles.tileGC[1]);
+        w->triangles.tileGC[1] = XtGetGC((Widget) w, valueMask, &values);
+        if (!w->triangles.mono) {
+                values.foreground = brighter(w, w->triangles.tileColor);
+        }
+        if (w->triangles.tileGC[0])
+                XtReleaseGC((Widget) w, w->triangles.tileGC[0]);
+        w->triangles.tileGC[0] = XtGetGC((Widget) w, valueMask, &values);
+        if (!w->triangles.mono) {
+                values.foreground = darker(w, w->triangles.tileColor);
+        }
+        if (w->triangles.tileGC[2])
+                XtReleaseGC((Widget) w, w->triangles.tileGC[2]);
+        w->triangles.tileGC[2] = XtGetGC((Widget) w, valueMask, &values);
 	if (w->triangles.mono) {
 		if (w->triangles.reverse) {
 			values.foreground = w->triangles.foreground;
@@ -2151,14 +2198,14 @@ SetAllColors(TrianglesWidget w)
 			values.background = w->triangles.foreground;
 		}
 	} else {
-		values.foreground = w->triangles.borderColor;
+		values.foreground = w->triangles.textColor;
 		values.background = w->triangles.tileColor;
 	}
-	if (w->triangles.borderGC)
-		XtReleaseGC((Widget) w, w->triangles.borderGC);
-	w->triangles.borderGC = XtGetGC((Widget) w, valueMask, &values);
+	if (w->triangles.textGC)
+		XtReleaseGC((Widget) w, w->triangles.textGC);
+	w->triangles.textGC = XtGetGC((Widget) w, valueMask, &values);
 	if (w->triangles.fontInfo)
-		XSetFont(XtDisplay(w), w->triangles.borderGC,
+		XSetFont(XtDisplay(w), w->triangles.textGC,
 			w->triangles.fontInfo->fid);
 }
 
@@ -2171,7 +2218,7 @@ SetValuesPuzzle(Widget current, Widget request, Widget renew)
 
 	CheckTiles(w);
 	if (w->triangles.font != c->triangles.font ||
-			w->triangles.borderColor != c->triangles.borderColor ||
+			w->triangles.textColor != c->triangles.textColor ||
 			w->triangles.reverse != c->triangles.reverse ||
 			w->triangles.mono != c->triangles.mono) {
 		loadFont(w);
@@ -2179,7 +2226,7 @@ SetValuesPuzzle(Widget current, Widget request, Widget renew)
 		redrawTiles = True;
 	} else if (w->triangles.background != c->triangles.background ||
 			w->triangles.foreground != c->triangles.foreground ||
-			w->triangles.borderColor != c->triangles.borderColor ||
+			w->triangles.textColor != c->triangles.textColor ||
 			w->triangles.tileColor != c->triangles.tileColor) {
 		SetAllColors(w);
 		redrawTiles = True;
@@ -2194,8 +2241,8 @@ SetValuesPuzzle(Widget current, Widget request, Widget renew)
 		redraw = True;
 	}
 	if (w->triangles.delay != c->triangles.delay) {
-		w->triangles.numSlices = ((w->triangles.delay < MAXSLICES) ?
-			w->triangles.delay + 1 : MAXSLICES);
+		w->triangles.numSlices = ((w->triangles.delay < MAX_SLICES) ?
+			w->triangles.delay + 1 : MAX_SLICES);
 	}
 	if (w->triangles.menu != ACTION_IGNORE) {
 		int menu = w->triangles.menu;
@@ -2256,22 +2303,21 @@ DestroyPuzzle(Widget old)
 {
 	TrianglesWidget w = (TrianglesWidget) old;
 	Display *display = XtDisplay(w);
-	int sel;
+	int i;
 
-	XtReleaseGC(old, w->triangles.tileGC);
-	XtReleaseGC(old, w->triangles.borderGC);
-	XtReleaseGC(old, w->triangles.tileBrighterGC);
-	XtReleaseGC(old, w->triangles.tileDarkerGC);
-	XtReleaseGC(old, w->triangles.frameGC);
-	XtReleaseGC(old, w->triangles.inverseGC);
+	XtReleaseGC(old, w->triangles.textGC);
+	for (i = 0; i < FG_SHADES; i++)
+                XtReleaseGC(old, w->triangles.tileGC[i]);
+        for (i = 0; i < BG_SHADES; i++)
+                XtReleaseGC(old, w->triangles.inverseGC[i]);
 	XtRemoveCallbacks(old, XtNselectCallback, w->triangles.select);
 	if (w->triangles.colormap != None) {
 		XInstallColormap(display, w->triangles.oldColormap);
 		XFreeColormap(display, w->triangles.colormap);
 	}
-	for (sel = 0; sel < 2; sel++)
-		if (w->triangles.bufferTiles[sel] != None)
-			XFreePixmap(display, w->triangles.bufferTiles[sel]);
+	for (i = 0; i < 2; i++)
+		if (w->triangles.bufferTiles[i] != None)
+			XFreePixmap(display, w->triangles.bufferTiles[i]);
 	if (w->triangles.fontInfo) {
 		XUnloadFont(display, w->triangles.fontInfo->fid);
 		XFreeFont(display, w->triangles.fontInfo);
@@ -2292,7 +2338,6 @@ static void
 ResizeTiles(TrianglesWidget w)
 {
 	int i, j;
-	int sel;
 
 #ifdef WINVER
 	if (w->core.memDC == NULL) {
@@ -2301,13 +2346,13 @@ ResizeTiles(TrianglesWidget w)
 			DISPLAY_ERROR("Not enough memory, exiting.");
 		}
 	}
-	for (sel = 0; sel < 2; sel++) {
-		if (w->triangles.bufferTiles[sel] != NULL) {
-			DeleteObject(w->triangles.bufferTiles[sel]);
-				w->triangles.bufferTiles[sel] = NULL;
+	for (i = 0; i < 2; i++) {
+		if (w->triangles.bufferTiles[i] != NULL) {
+			DeleteObject(w->triangles.bufferTiles[i]);
+				w->triangles.bufferTiles[i] = NULL;
 		}
 		if (!(w->triangles.picture && *(w->triangles.picture))) {
-			if ((w->triangles.bufferTiles[sel] =
+			if ((w->triangles.bufferTiles[i] =
 				CreateCompatibleBitmap(w->core.hDC,
 					w->core.width,
 					w->core.height)) == NULL) {
@@ -2325,12 +2370,12 @@ ResizeTiles(TrianglesWidget w)
 		w->triangles.mono = (xgwa.depth < 2 || w->triangles.mono);
 		w->triangles.oldColormap = xgwa.colormap;
 	}
-	for (sel = 0; sel < 2; sel++) {
-		if (w->triangles.bufferTiles[sel] != None) {
-			XFreePixmap(display, w->triangles.bufferTiles[sel]);
-			w->triangles.bufferTiles[sel] = None;
+	for (i = 0; i < 2; i++) {
+		if (w->triangles.bufferTiles[i] != None) {
+			XFreePixmap(display, w->triangles.bufferTiles[i]);
+			w->triangles.bufferTiles[i] = None;
 		}
-		if ((w->triangles.bufferTiles[sel] = XCreatePixmap(display,
+		if ((w->triangles.bufferTiles[i] = XCreatePixmap(display,
 			window, w->core.width, w->core.height,
 			xgwa.depth)) == None) {
 			DISPLAY_ERROR("Not enough memory, exiting.");
@@ -2339,8 +2384,8 @@ ResizeTiles(TrianglesWidget w)
 #endif
 	if (w->triangles.picture && *(w->triangles.picture)) {
 #ifdef WINVER
-		for (sel = 0; sel < 2; sel++) {
-			w->triangles.bufferTiles[sel] =
+		for (i = 0; i < 2; i++) {
+			w->triangles.bufferTiles[i] =
 				LoadBitmap(w->core.hInstance,
 				w->triangles.picture);
 		}
@@ -2368,30 +2413,30 @@ ResizeTiles(TrianglesWidget w)
 			xgwa.visual, AllocNone);
 	}
 	SetAllColors(w);
-	for (sel = 0; sel < 2; sel++) {
-		FILLRECTANGLE(w, w->triangles.bufferTiles[sel],
-			w->triangles.inverseGC,
+	for (i = 0; i < 2; i++) {
+		FILLRECTANGLE(w, w->triangles.bufferTiles[i],
+			w->triangles.inverseGC[2],
 			0, 0, w->core.width, w->core.height);
 		if ((w->triangles.picture && *(w->triangles.picture))) {
 
-			(void) XPutImage(display, w->triangles.bufferTiles[sel],
-				w->triangles.inverseGC, w->triangles.image, 0, 0,
+			(void) XPutImage(display, w->triangles.bufferTiles[i],
+				w->triangles.inverseGC[2], w->triangles.image, 0, 0,
 				0, 0,
 				MIN(w->triangles.image->width, w->core.width),
 				MIN(w->triangles.image->height, w->core.height));
 		}
 	}
 #endif
-	for (j = 0; j < MAXORIENT; j++)
-		for (i = 0; i <= ROWTYPES; i++) {
+	for (j = 0; j < MAX_ORIENT; j++)
+		for (i = 0; i <= ROW_TYPES; i++) {
 			triangleList[j][i].x = (w->triangles.tileSize.x / 2) *
 				triangleUnit[j][i].x;
 			triangleList[j][i].y = w->triangles.tileSize.y *
 				triangleUnit[j][i].y;
 		}
 #ifdef RHOMBUS
-	for (j = 0; j < ROWTYPES; j++)
-		for (i = 0; i <= ROWTYPES + 1; i++) {
+	for (j = 0; j < ROW_TYPES; j++)
+		for (i = 0; i <= ROW_TYPES + 1; i++) {
 			rhombusList[j][i].x = ((w->triangles.tileSize.x + w->triangles.delta.x) / 2 ) *
 				rhombusUnit[j][i].x;
 			rhombusList[j][i].y = (w->triangles.tileSize.y + w->triangles.delta.y - 1) *
@@ -2469,13 +2514,14 @@ Widget request, Widget renew
 {
 #ifdef WINVER
 	SetValuesPuzzle(w);
-	brush = CreateSolidBrush(w->triangles.inverseGC);
+	brush = CreateSolidBrush(w->triangles.inverseGC[2]);
 	SETBACK(w->core.hWnd, brush);
 	(void) SRAND(time(NULL));
 	w->triangles.bufferTiles[0] = NULL;
 	w->triangles.bufferTiles[1] = NULL;
 #else
 	TrianglesWidget w = (TrianglesWidget) renew;
+	int i;
 
 	(void) SRAND(getpid());
 	w->triangles.bufferTiles[0] = None;
@@ -2483,12 +2529,11 @@ Widget request, Widget renew
 	w->triangles.colormap = None;
 	w->triangles.oldColormap = None;
 	w->triangles.fontInfo = NULL;
-	w->triangles.tileGC = NULL;
-	w->triangles.borderGC = NULL;
-	w->triangles.tileBrighterGC = NULL;
-	w->triangles.tileDarkerGC = NULL;
-	w->triangles.frameGC = NULL;
-	w->triangles.inverseGC = NULL;
+	w->triangles.textGC = NULL;
+	for (i = 0; i < FG_SHADES; i++)
+                w->triangles.tileGC[i] = NULL;
+        for (i = 0; i < BG_SHADES; i++)
+                w->triangles.inverseGC[i] = NULL;
 	w->triangles.image = NULL;
 #endif
 	w->triangles.focus = False;
@@ -2497,8 +2542,8 @@ Widget request, Widget renew
 	CheckTiles(w);
 	newMoves(&undo);
 	newMoves(&redo);
-	w->triangles.numSlices = ((w->triangles.delay < MAXSLICES) ?
-		w->triangles.delay + 1 : MAXSLICES);
+	w->triangles.numSlices = ((w->triangles.delay < MAX_SLICES) ?
+		w->triangles.delay + 1 : MAX_SLICES);
 	w->triangles.cheat = False;
 	w->triangles.cw = (NRAND(2) == 0); /* they take the same # of moves */
 	SizePuzzle(w);
