@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1993 - 2007	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1993 - 2008	David A. Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -88,7 +88,7 @@ static TrianglesRec widget;
 
 #ifndef WINVER
 static const char aboutHelp[] = {
-"Triangles Version 7.3.2\n"
+"Triangles Version 7.3.3\n"
 "Send bugs (reports or fixes) to the author: "
 "David Bagley <bagleyd@tux.org>\n"
 "The latest version is at: "
@@ -99,7 +99,7 @@ static const char optionsHelp[] = {
 "[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]]\n"
 "[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
 "[-{foreground|fg} {color}] [-{background|bg} {color}]\n"
-"[-tile {color}] [-{border|bd} {color}] [-delay msecs]\n"
+"[-tile {color}] [-text {color}] [-delay msecs]\n"
 "[-[no]sound] [-bumpSound {filename}]\n"
 "[-{font|fn} {fontname}] [-size {int}] [-base {int}]\n"
 "[-userName {string}] [-scoreFile {filename}] [-scores]\n"
@@ -183,28 +183,28 @@ static const char solveHelp[] = {
 #define SCOREFILE "triangles.scores"
 #endif
 
-#define MAXTILES 16
+#define MAX_TILES 16
 #define NEVER (-1)
-#define FILENAMELEN 1024
-#define USERNAMELEN 120
-#define MESSAGELEN (USERNAMELEN+64)
-#define TITLELEN 2048
+#define FILE_NAME_LENGTH 1024
+#define USER_NAME_LENGTH 120
+#define MESSAGE_LENGTH (USER_NAME_LENGTH+64)
+#define TITLE_LENGTH 2048
 #define NOACCESS "noaccess"
 #define NOBODY "nobody"
 
 typedef struct {
 	int score;
-	char name[USERNAMELEN];
+	char name[USER_NAME_LENGTH];
 } PuzzleRecord;
 
-static PuzzleRecord puzzleRecord[MAXTILES - MINTILES + 1];
+static PuzzleRecord puzzleRecord[MAX_TILES - MIN_TILES + 1];
 static int movesDsp = 0;
-static char messageDsp[MESSAGELEN] = "Welcome";
-static char recordDsp[MESSAGELEN] = "NOT RECORDED";
+static char messageDsp[MESSAGE_LENGTH] = "Welcome";
+static char recordDsp[MESSAGE_LENGTH] = "NOT RECORDED";
 
 #ifdef HAVE_MOTIF
-#define MINSPEED 1
-#define MAXSPEED 50
+#define MIN_SPEED 1
+#define MAX_SPEED 50
 #ifdef ANIMATE
 static Widget speed;
 #endif
@@ -215,20 +215,20 @@ static Widget optionsDialog, referencesDialog, aboutDialog;
 static Widget solveDialog, clearDialog;
 static Arg arg[3];
 #else
-static char titleDsp[TITLELEN] = "";
+static char titleDsp[TITLE_LENGTH] = "";
 #endif
-static char scoreFileName[FILENAMELEN] = SCOREFILE;
-static char fileName[FILENAMELEN];
+static char scoreFileName[FILE_NAME_LENGTH] = SCOREFILE;
+static char fileName[FILE_NAME_LENGTH];
 static Boolean randomized = False;
 #ifdef WINVER
-#define MAXPROGNAME 80
-static char progDsp[MAXPROGNAME] = TITLE;
-static char userNameDsp[USERNAMELEN] = "Guest";
+#define PROGRAM_NAME_LENGTH 80
+static char progDsp[PROGRAM_NAME_LENGTH] = TITLE;
+static char userNameDsp[USER_NAME_LENGTH] = "Guest";
 #else
 static Pixmap pixmap = None;
 static Widget topLevel, puzzle;
 static char *progDsp;
-static char userNameDsp[USERNAMELEN] = "";
+static char userNameDsp[USER_NAME_LENGTH] = "";
 
 #ifdef HAVE_MOTIF
 static void
@@ -250,7 +250,7 @@ PrintRecords(void)
 
 	(void) printf("TRIANGLES  HALL OF FAME\n\n");
 	(void) printf(" TILES USER            MOVES\n");
-	for (i = 0; i < MAXTILES - MINTILES + 1; i++) {
+	for (i = 0; i < MAX_TILES - MIN_TILES + 1; i++) {
 		if (puzzleRecord[i].score > 0)
 			(void) printf("%6d %-12s%9d\n",
 				i + 1,
@@ -265,9 +265,9 @@ InitRecords(void)
 {
 	int i;
 
-	for (i = 0; i < MAXTILES - MINTILES + 1; i++) {
+	for (i = 0; i < MAX_TILES - MIN_TILES + 1; i++) {
 		puzzleRecord[i].score = NEVER;
-		(void) strncpy(puzzleRecord[i].name, NOACCESS, USERNAMELEN);
+		(void) strncpy(puzzleRecord[i].name, NOACCESS, USER_NAME_LENGTH);
 	}
 }
 
@@ -276,7 +276,7 @@ ReadRecords(void)
 {
 	FILE *fp;
 	int i, n;
-	char userName[USERNAMELEN];
+	char userName[USER_NAME_LENGTH];
 	char *buf1 = NULL, *buf2 = NULL;
 	char *fname, *lname;
 
@@ -286,9 +286,9 @@ ReadRecords(void)
 	stringCat(&buf2, buf1, SCOREFILE);
 	free(buf1);
 	fname = buf2;
-	(void) strncpy(fileName, lname, USERNAMELEN);
+	(void) strncpy(fileName, lname, USER_NAME_LENGTH);
 	if ((fp = fopen(fileName, "r")) == NULL) {
-		(void) strncpy(fileName, fname, USERNAMELEN);
+		(void) strncpy(fileName, fname, USER_NAME_LENGTH);
 		/* Try installed directory. */
 		if ((fp = fopen(fileName, "r")) == NULL) {
 			stringCat(&buf1, "Can not read ", fname);
@@ -317,13 +317,13 @@ ReadRecords(void)
 	}
 	free(lname);
 	free(fname);
-	for (i = 0; i < MAXTILES - MINTILES + 1; i++) {
+	for (i = 0; i < MAX_TILES - MIN_TILES + 1; i++) {
 		(void) fscanf(fp, "%d %s\n", &n, userName);
 		if (n <= puzzleRecord[i].score ||
 				puzzleRecord[i].score <= NEVER) {
 			puzzleRecord[i].score = n;
 			(void) strncpy(puzzleRecord[i].name, userName,
-				USERNAMELEN);
+				USER_NAME_LENGTH);
 		}
 	}
 	(void) fclose(fp);
@@ -345,9 +345,9 @@ WriteRecords(void)
 	{
 #if HAVE_FCNTL_H
 		int lfd;
-		char lockFile[FILENAMELEN];
+		char lockFile[FILE_NAME_LENGTH];
 
-		(void) strncpy(lockFile, fileName, FILENAMELEN - 6);
+		(void) strncpy(lockFile, fileName, FILE_NAME_LENGTH - 6);
 		(void) strcat(lockFile, ".lock");
 		while (((lfd = open(lockFile, O_CREAT | O_EXCL, 0644)) < 0) &&
 				errno == EEXIST)
@@ -363,7 +363,7 @@ WriteRecords(void)
 #endif
 		}
 #endif
-		for (i = 0; i < MAXTILES - MINTILES + 1; i++)
+		for (i = 0; i < MAX_TILES - MIN_TILES + 1; i++)
 			(void) fprintf(fp, "%d %s\n",
 				puzzleRecord[i].score,
 				puzzleRecord[i].name);
@@ -378,10 +378,10 @@ WriteRecords(void)
 static void
 PrintRecord(int size)
 {
-	int i = size - MINTILES;
+	int i = size - MIN_TILES;
 
-	if (size > MAXTILES) {
-		(void) strncpy(recordDsp, "NOT RECORDED", MESSAGELEN);
+	if (size > MAX_TILES) {
+		(void) strncpy(recordDsp, "NOT RECORDED", MESSAGE_LENGTH);
 	} else if (puzzleRecord[i].score <= NEVER) {
 		(void) sprintf(recordDsp, "NEVER %s", NOACCESS);
 	} else {
@@ -418,14 +418,14 @@ PrintStatus(char *msg, int nMoves
 static Boolean
 HandleSolved(int counter, int size)
 {
-	int i = size - MINTILES;
+	int i = size - MIN_TILES;
 
-	if (size <= MAXTILES && (counter < puzzleRecord[i].score ||
+	if (size <= MAX_TILES && (counter < puzzleRecord[i].score ||
 			puzzleRecord[i].score <= NEVER)) {
 		ReadRecords();	/* Maybe its been updated by another */
 		puzzleRecord[i].score = counter;
 		(void) strncpy(puzzleRecord[i].name, userNameDsp,
-			USERNAMELEN);
+			USER_NAME_LENGTH);
 		WriteRecords();
 		PrintRecord(size);
 		return True;
@@ -452,7 +452,7 @@ Widget w
 	userName = w->triangles.userName;
 	scoreFile = w->triangles.scoreFile;
 	if (strcmp(scoreFile, ""))
-		(void) strncpy(scoreFileName, scoreFile, FILENAMELEN);
+		(void) strncpy(scoreFileName, scoreFile, FILE_NAME_LENGTH);
 #else
 	Boolean scoreOnly, versionOnly;
 
@@ -467,7 +467,7 @@ Widget w
 		exit(0);
 	}
 	if (strcmp(scoreFile, ""))
-		(void) strncpy(scoreFileName, scoreFile, FILENAMELEN);
+		(void) strncpy(scoreFileName, scoreFile, FILE_NAME_LENGTH);
 	if (scoreOnly) {
 		InitRecords();
 		ReadRecords();
@@ -475,7 +475,7 @@ Widget w
 		exit(0);
 	}
 #ifdef HAVE_MOTIF
-	if (size > MAXTILES)
+	if (size > MAX_TILES)
 		XtVaSetValues(tile, XmNmaximum, size, NULL);
 	XmScaleSetValue(tile, size);
 #ifdef ANIMATE
@@ -483,7 +483,7 @@ Widget w
 		int delay;
 
 		XtVaGetValues(w, XtNdelay, &delay, NULL);
-		XmScaleSetValue(speed, MAXSPEED + MINSPEED - delay - 1);
+		XmScaleSetValue(speed, MAX_SPEED + MIN_SPEED - delay - 1);
 	}
 #endif
 #endif
@@ -492,13 +492,13 @@ Widget w
 	InitRecords();
 	ReadRecords();
 #ifndef WINVER
-	(void) strncpy(userNameDsp, userName, USERNAMELEN);
+	(void) strncpy(userNameDsp, userName, USER_NAME_LENGTH);
 #endif
 	if (!strcmp(userName, "") || !strcmp(userName, "(null)") ||
 			!strcmp(userName, NOACCESS) ||
 			!strcmp(userName, NOBODY)) {
 #ifdef WINVER
-		(void) strncpy(userNameDsp, userName, USERNAMELEN);
+		(void) strncpy(userNameDsp, userName, USER_NAME_LENGTH);
 #else
 		char *login = getlogin();
 
@@ -574,7 +574,7 @@ CallbackPuzzle(Widget w, caddr_t clientData,
 #ifdef HAVE_MOTIF
 		XtManageChild(solveDialog);
 #else
-		(void) strncpy(messageDsp, solveHelp, MESSAGELEN);
+		(void) strncpy(messageDsp, solveHelp, MESSAGE_LENGTH);
 #endif
 #endif
 			break;
@@ -584,18 +584,18 @@ CallbackPuzzle(Widget w, caddr_t clientData,
 		randomized = False;
 		break;
 	case ACTION_BLOCKED:
-		(void) strncpy(messageDsp, "Blocked", MESSAGELEN);
+		(void) strncpy(messageDsp, "Blocked", MESSAGE_LENGTH);
 		break;
 	case ACTION_SPACE:
 #if 0
 		/* Too annoying */
 		(void) strncpy(messageDsp, "Spaces can not slide",
-			MESSAGELEN);
+			MESSAGE_LENGTH);
 #endif
 		break;
 	case ACTION_IGNORE:
 		(void) strncpy(messageDsp, "Clear to start",
-			MESSAGELEN);
+			MESSAGE_LENGTH);
 		break;
 	case ACTION_MOVED:
 		movesDsp++;
@@ -610,7 +610,7 @@ CallbackPuzzle(Widget w, caddr_t clientData,
 				"Congratulations %s!!", userNameDsp);
 		else
 			(void) strncpy(messageDsp, "Solved!",
-				MESSAGELEN);
+				MESSAGE_LENGTH);
 		SET_STARTED(w, False);
 		break;
 	case ACTION_COMPUTED:
@@ -630,7 +630,7 @@ CallbackPuzzle(Widget w, caddr_t clientData,
 #else
 		XtVaSetValues(w, XtNsize, size, NULL);
 #ifdef HAVE_MOTIF
-		if (size > MAXTILES)
+		if (size > MAX_TILES)
 			XtVaSetValues(tile, XmNmaximum, size, NULL);
 		XmScaleSetValue(tile, size);
 #endif
@@ -646,7 +646,7 @@ CallbackPuzzle(Widget w, caddr_t clientData,
 		XtVaSetValues(w, XtNsize, size, NULL);
 #ifdef HAVE_MOTIF
 		XmScaleSetValue(tile, size);
-		if (size >= MAXTILES)
+		if (size >= MAX_TILES)
 			XtVaSetValues(tile, XmNmaximum, size, NULL);
 #endif
 #endif
@@ -667,8 +667,8 @@ CallbackPuzzle(Widget w, caddr_t clientData,
 			XtVaGetValues(puzzle,
 				XtNdelay, &delay, NULL);
 			oldDelay = delay;
-			if (delay > MAXSPEED - MINSPEED)
-				delay = MAXSPEED - MINSPEED;
+			if (delay > MAX_SPEED - MIN_SPEED)
+				delay = MAX_SPEED - MIN_SPEED;
 			if (delay < 0)
 				delay = 0;
 			if (delay != oldDelay) {
@@ -676,7 +676,7 @@ CallbackPuzzle(Widget w, caddr_t clientData,
 					XtNdelay, delay, NULL);
 			}
 			XmScaleSetValue(speed,
-				MAXSPEED + MINSPEED - delay - 1);
+				MAX_SPEED + MIN_SPEED - delay - 1);
 		}
 		return;
 #endif
@@ -949,9 +949,8 @@ static XrmOptionDescRec options[] =
 	{(char *) "-foreground", (char *) "*triangles.Foreground", XrmoptionSepArg, NULL},
 	{(char *) "-bg", (char *) "*Background", XrmoptionSepArg, NULL},
 	{(char *) "-background", (char *) "*Background", XrmoptionSepArg, NULL},
-	{(char *) "-bd", (char *) "*triangles.tileBorder", XrmoptionSepArg, NULL},
-	{(char *) "-border", (char *) "*triangles.tileBorder", XrmoptionSepArg, NULL},
 	{(char *) "-tile", (char *) "*triangles.tileColor", XrmoptionSepArg, NULL},
+	{(char *) "-text", (char *) "*triangles.textColor", XrmoptionSepArg, NULL},
 	{(char *) "-install", (char *) "*triangles.install", XrmoptionNoArg, (char *) "TRUE"},
 	{(char *) "-noinstall", (char *) "*triangles.install", XrmoptionNoArg, (char *) "FALSE"},
 	{(char *) "-picture", (char *) "*triangles.picture", XrmoptionSepArg, NULL},
@@ -1002,7 +1001,7 @@ TileSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 static void
 SpeedSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct *cbs)
 {
-	int delay = MAXSPEED + MINSPEED - cbs->value - 1, oldDelay;
+	int delay = MAX_SPEED + MIN_SPEED - cbs->value - 1, oldDelay;
 
 	XtVaGetValues(puzzle,
 		XtNdelay, &oldDelay, NULL);
@@ -1034,7 +1033,7 @@ static Widget
 createQuery(Widget w, char *text, char *title, XtCallbackProc callback)
 {
 	Widget button, messageBox;
-	char titleDsp[FILENAMELEN + 8];
+	char titleDsp[FILE_NAME_LENGTH + 8];
 	XmString titleString = NULL, messageString = NULL;
 	static XmStringCharSet charSet =
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
@@ -1060,7 +1059,7 @@ static Widget
 createHelp(Widget w, char *text, char *title)
 {
 	Widget button, messageBox;
-	char titleDsp[FILENAMELEN + 8];
+	char titleDsp[FILE_NAME_LENGTH + 8];
 	XmString titleString = NULL, messageString = NULL, buttonString = NULL;
 	static XmStringCharSet charSet =
 		(XmStringCharSet) XmSTRING_DEFAULT_CHARSET;
@@ -1313,9 +1312,9 @@ main(int argc, char **argv)
 	tile = XtVaCreateManagedWidget("tile",
 		xmScaleWidgetClass, tilesRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Size", 5,
-		XmNminimum, MINTILES,
-		XmNmaximum, MAXTILES,
-		XmNvalue, DEFAULTTILES,
+		XmNminimum, MIN_TILES,
+		XmNmaximum, MAX_TILES,
+		XmNvalue, DEFAULT_TILES,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
 	XtAddCallback(tile, XmNvalueChangedCallback,
@@ -1324,9 +1323,9 @@ main(int argc, char **argv)
 	speed = XtVaCreateManagedWidget("Animation Speed",
 		xmScaleWidgetClass, tilesRowCol,
 		XtVaTypedArg, XmNtitleString, XmRString, "Animation Speed", 16,
-		XmNminimum, MINSPEED,
-		XmNmaximum, MAXSPEED,
-		XmNvalue, MAXSPEED - DEFAULTDELAY,
+		XmNminimum, MIN_SPEED,
+		XmNmaximum, MAX_SPEED,
+		XmNvalue, MAX_SPEED - DEFAULT_DELAY,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
 	XtAddCallback(speed, XmNvalueChangedCallback,
